@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace PhpParser\Node\Stmt;
 
@@ -15,12 +15,16 @@ class Static_ extends Stmt
      * @param StaticVar[] $vars       Variable definitions
      * @param array       $attributes Additional attributes
      */
-    public function __construct(array $vars, array $attributes = array()) {
-        parent::__construct(null, $attributes);
+    public function __construct(array $vars, array $attributes = []) {
+        parent::__construct($attributes);
         $this->vars = $vars;
     }
 
-    public function getSubNodeNames() {
-        return array('vars');
+    public function getSubNodeNames() : array {
+        return ['vars'];
+    }
+    
+    public function getType() : string {
+        return 'Stmt_Static';
     }
 }
