@@ -1,9 +1,10 @@
 OC.L10N.register(
     "accessibility",
     {
-    "High contrast theme" : "Højkontrasttema",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Et højkontrasttema letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
+    "Dark theme" : "Mørk tema",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Et mørk tema, venligere for øjnene ved at dæmpe lysstyrken. Det er stadig under udvikling så indberet venligst alle problemer du måtte finde.",
+    "High contrast mode" : "Højkontrasttilstand",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En højkontrasttilstand letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
     "Dyslexia font" : "Skrifftype for ordblinde",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype designet til at undgå læsefejl pga. ordblindhed",
     "Accessibility" : "Handicapvenlig",
@@ -13,6 +14,13 @@ OC.L10N.register(
     "our issue tracker" : "vores problem følger",
     "our design team" : "vores design team",
     "Enable" : "Aktiver",
-    "Dark theme (beta)" : "Mørkt tema (beta)"
+    "High contrast theme" : "Højkontrasttema",
+    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Et højkontrasttema letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
+    "Dark theme (beta)" : "Mørkt tema (beta)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic er en gratis skrifttype/font designet til at undgå typiske læsefejl pga. ordblindhed. Skrifttypen er skabt af Abelardo Gonzalez, som har udgivet den med en open-source licens.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Tilbyder flere handicapvenlige indstillinger til at lette brugen af Nextcloud",
+    "Themes" : "Temaer",
+    "Fonts" : "Fonte",
+    "enabled" : "aktiveret"
 },
 "nplurals=2; plural=(n != 1);");
