@@ -1,10 +1,10 @@
 OC.L10N.register(
     "accessibility",
     {
-    "High contrast theme" : "Kontraste altua gaia",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste altuko gaia nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
     "Dark theme" : "Gai iluna",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Gai iluna begiak leuntzeko argitasun orokorra eta distira murriztuz. Garapenean dagoen aukera da, beraz jakinarazi aurkitzen dituzun arazoak.",
+    "High contrast mode" : "Kontraste altuko modua",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste altuko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
     "Dyslexia font" : "Dislexia letra-tipoa",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
     "Accessibility" : "Erabilerraztasuna",
@@ -14,6 +14,8 @@ OC.L10N.register(
     "our issue tracker" : "gure akats egunkaria",
     "our design team" : "gure diseinatzaile taldea",
     "Enable" : "Gaitu",
+    "High contrast theme" : "Kontraste altuko gaia",
+    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste altuko gaia nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
     "Dark theme (beta)" : "Gai beltza (beta)",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic dislexia eragindako ohiko irakurketa akats batzuk arintzeko diseinatuta dagoen tipografia/letra mota librea. Abelardo Gonzalezek sortu zuen tipografia hau eta  kode irekiko lizentzia baten bidez kaleratu zuen.",
     "Provides multiple accessibilities options to ease your use of nextcloud" : "Hainbat irisgarritasun aukera eskaintzen ditu nextclouden erabilera errazteko",
