@@ -1,9 +1,10 @@
 OC.L10N.register(
     "accessibility",
     {
-    "High contrast theme" : "고대비 테마",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
+    "Dark theme" : "어두운 테마",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "어두운 테마는 전체적인 밝기를 낮춰 눈을 편안하게 해 줍니다. 아직 개발 중인 기능이니 문제가 있다면 보고해 주세요.",
+    "High contrast mode" : "고대비 모드",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
     "Dyslexia font" : "난독증용 글꼴",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
     "Accessibility" : "접근성",
@@ -13,6 +14,13 @@ OC.L10N.register(
     "our issue tracker" : "우리의 이슈 트래커",
     "our design team" : "우리의 디자인 팀",
     "Enable" : "활성화",
-    "Dark theme (beta)" : "어두운 테마(베타)"
+    "High contrast theme" : "고대비 테마",
+    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
+    "Dark theme (beta)" : "어두운 테마(베타)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Nextcloud 사용을 편리하게 하는 여러 접근성 옵션",
+    "Themes" : "테마",
+    "Fonts" : "글꼴",
+    "enabled" : "활성화"
 },
 "nplurals=1; plural=0;");
