@@ -1,9 +1,10 @@
 OC.L10N.register(
     "accessibility",
     {
-    "High contrast theme" : "Visoko kontrastna tema",
-    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, povečajo pa se možnosti hitre uporabe.",
+    "Dark theme" : "Temna tema",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temna tema zmanjša splošno svetlost vmesnika. Tema je še v razvoju, zato je priporočljivo poslati tudi poročila o napakah, ki jih opazite.",
+    "High contrast mode" : "Visoko kontrastna tema",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, poveča pa se jasnost prikaza.",
     "Dyslexia font" : "Pisava za posameznike z disleksijo",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Pisava OpenDyslexic je brezplačna pisava, zasnovana in oblikovana po priporočilih za posameznike z disleksijo. Zmanjša nekatere splošne težave pri branju.",
     "Accessibility" : "Dostopnost",
@@ -13,6 +14,13 @@ OC.L10N.register(
     "our issue tracker" : "sledilnik napak",
     "our design team" : "oblikovalska skupina",
     "Enable" : "Omogoči",
-    "Dark theme (beta)" : "Temna tema (preizkusno)"
+    "High contrast theme" : "Visoko kontrastna tema",
+    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Visoko kontrastna tema omogoča nazornejši prikaz vmesnika. Pogled se poenostavi, povečajo pa se možnosti hitre uporabe.",
+    "Dark theme (beta)" : "Temna tema (preizkusno)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "Pisava OpenDyslexic je brezplačna pisava, zasnovana za lajšanje nekaterih težav z branjem, ki so najpogosteje značilne za dislektike. Pisavo je zasnoval Abelardo Gonzalez in jo objavil z odprtokodnim dovoljenjem.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Omogoča številne možnosti dostopnosti za enostavnejšo uporabo oblaka nextcloud.",
+    "Themes" : "Teme",
+    "Fonts" : "Pisave",
+    "enabled" : "omogočeno"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
