@@ -2,6 +2,12 @@ OC.L10N.register(
     "comments",
     {
     "Comments" : "Kommentarar",
+    "You commented" : "Du kommenterte",
+    "%1$s commented" : "%1$skommenterte",
+    "{author} commented" : "{author} kommenterte",
+    "You commented on %1$s" : "Du kommenterte på %1$s",
+    "You commented on {file}" : "Du kommenterte på {file}",
+    "%1$s commented on %2$s" : "%1$s kommenterte på %2$s",
     "Edit comment" : "Rediger kommentar",
     "Delete comment" : "Slett kommentar",
     "New comment …" : "Ny kommentar...",
@@ -10,13 +16,6 @@ OC.L10N.register(
     "No comments yet, start the conversation!" : "Ingen kommetarar enno, start samtala!",
     "More comments …" : "Fleire kommentarar...",
     "Save" : "Lagra",
-    "Comment" : "Kommentér",
-    "You commented" : "Du kommenterte",
-    "%1$s commented" : "%1$skommenterte",
-    "{author} commented" : "{author} kommenterte",
-    "You commented on %1$s" : "Du kommenterte på %1$s",
-    "You commented on {file}" : "Du kommenterte på {file}",
-    "%1$s commented on %2$s" : "%1$s kommenterte på %2$s",
-    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du ble nemnt i \"%s\", i en kommentar av ein brukar som i ettertid har blitt sletta"
+    "Comment" : "Kommentér"
 },
 "nplurals=2; plural=(n != 1);");
