@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
     "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
     "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
+    "Death of %s" : "Den úmrtí %s",
     "Contact birthdays" : "Narozeniny kontaktů",
+    "Calendar:" : "Kalendář:",
+    "Date:" : "Datum:",
+    "Where:" : "Kde:",
+    "Description:" : "Popis:",
+    "Untitled event" : "Nenazvaná událost",
+    "_%n year_::_%n years_" : ["%n rok","%n roky","%n let","%n roky"],
+    "_%n month_::_%n months_" : ["%n měsíc","%n měsíce","%n měsíců","%n měsíce"],
+    "_%n day_::_%n days_" : ["%n den","%n dny","%n dnů","%n dny"],
+    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodin","%n hodiny"],
+    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
+    "%s (in %s)" : "%s (v %s)",
+    "%s (%s ago)" : "%s (před %s)",
+    "Calendar: %s" : "Kalendář: %s",
+    "Date: %s" : "Datum: %s",
+    "Description: %s" : "Popis: %s",
+    "Where: %s" : "Kde: %s",
     "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
     "Invitation canceled" : "Pozvánka zrušena",
     "Hello %s," : "Dobrý den %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Setkání „%1$s“ s %2$s bylo zrušeno.",
     "%1$s invited you to »%2$s«" : "%1$s vás pozval(a) na „%2$s“",
     "When:" : "Kdy:",
-    "Where:" : "Kde:",
-    "Description:" : "Popis:",
     "Link:" : "Odkaz:",
     "Accept" : "Přijmout",
     "Decline" : "Zamítnout",
@@ -81,10 +96,8 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
     "Birthday calendars will be generated by a background job." : "Narozeninový kalendář bude vytvořen na pozadí.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "A tedy nebudou zpřístupněny ihned po povolení, ale objeví se až se zpožděním.",
-    "%s via %s" : "%s přes %s",
-    "The meeting »%s« with %s was canceled." : "Setkání »%s« s %s bylo zrušeno.",
-    "The meeting »%s« with %s was updated." : "Setkání „%s“ s %s bylo aktualizováno.",
-    "%s invited you to »%s«" : "%s vás zve na „%s“",
+    "Send notifications for events" : "Posílat upozornění na události",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Oznámení budou odeslána prostřednictvím úloh na pozadí, takže je třeba, aby se děly dostatečně často.",
     "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
