@@ -44,6 +44,9 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
     "A calendar <strong>todo</strong> was modified" : "Ενός ημερολογίου η <strong>εκκρεμότητα</strong> τροποποιήθηκε",
     "Contact birthdays" : "Γενέθλια επαφών",
+    "Where:" : "Που:",
+    "Description:" : "Περιγραφή:",
+    "Untitled event" : "Συμβάν χωρίς τίτλο",
     "%1$s via %2$s" : "%1$s μέσω %2$s",
     "Invitation canceled" : "Η πρόσκληση ακυρώθηκε.",
     "Hello %s," : "Γεια σου %s,",
@@ -52,8 +55,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Το meeting » %1$s« με τον/την %2$s ενημερώθηκε.",
     "%1$s invited you to »%2$s«" : "Ο %1$s σας προσκάλεσε στο »%2$s«",
     "When:" : "Πότε:",
-    "Where:" : "Που:",
-    "Description:" : "Περιγραφή:",
     "Link:" : "Σύνδεσμος:",
     "Accept" : "Αποδοχή",
     "Decline" : "Απόρριψη",
@@ -68,13 +69,11 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Παρακαλώ επικοινωνήστε απ' ευθείας με τον διοργανωτή.",
     "Are you accepting the invitation?" : "Αποδέχεστε την πρόσκληση;",
     "Save" : "Αποθήκευση",
+    "Your attendance was updated successfully." : "Η παρουσία σας ενημερώθηκε με επιτυχία.",
     "Send invitations to attendees" : "Αποστολή προσκλήσεων στους συμμετέχοντες.",
     "Automatically generate a birthday calendar" : "Δημιουργία ημερολογίου γενεθλίων αυτόματα",
     "Birthday calendars will be generated by a background job." : "Τα ημερολόγια γενεθλίων θα δημιουργηθούν από μία εργασία παρασκηνίου.",
-    "%s via %s" : "%s μέσω %s",
-    "The meeting »%s« with %s was canceled." : "Το meeting »%s« με τον/την %s ακυρώθηκε.",
-    "The meeting »%s« with %s was updated." : "Το meeting » %s « με τον/την %s ενημερώθηκε.",
-    "%s invited you to »%s«" : "Ο %s σας προσκάλεσε στο  »%s«",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Οι ειδοποιήσεις θα αποστέλλονται μέσω εργασιών στο παρασκήνιο, οπότε αυτές πρέπει να συμβαίνουν αρκετά συχνά.",
     "Please make sure to properly set up the email settings above." : "Παρακαλούμε σιγουρευθείτε οτι θα ενημερώσετε τις ρυθμίσεις email, παραπάνω."
 },
 "nplurals=2; plural=(n != 1);");
