@@ -43,6 +43,7 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "<strong>Kalendaro</strong> estis modifita",
     "A calendar <strong>event</strong> was modified" : "Kalendara <strong>okazaĵo</strong> estis modifita",
     "A calendar <strong>todo</strong> was modified" : "Kalendara <strong>farendaĵo</strong> estis modifita",
+    "Death of %s" : "Morto de %s",
     "Contact birthdays" : "Kontaktaj datrevenoj",
     "Calendar:" : "Kalendaro:",
     "Date:" : "Dato:",
@@ -50,6 +51,16 @@ OC.L10N.register(
     "Description:" : "Priskribo:",
     "Untitled event" : "Sentitola okazaĵo",
     "_%n year_::_%n years_" : ["%n jaro","%n jaroj"],
+    "_%n month_::_%n months_" : ["%n monato","%n monatoj"],
+    "_%n day_::_%n days_" : ["%n tago","%n tagoj"],
+    "_%n hour_::_%n hours_" : ["%n horo","%n horoj"],
+    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutoj"],
+    "%s (in %s)" : "%s (en %s)",
+    "%s (%s ago)" : "%s (antaŭ %s)",
+    "Calendar: %s" : "Kalendaro: %s",
+    "Date: %s" : "Dato: %s",
+    "Description: %s" : "Priskribo: %s",
+    "Where: %s" : "Kie: %s",
     "%1$s via %2$s" : "%1$s pere de %2$s",
     "Invitation canceled" : "Invito nuligita",
     "Hello %s," : "Saluton %s,",
@@ -85,6 +96,9 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Aŭtomate estigi datrevenan kalendaron",
     "Birthday calendars will be generated by a background job." : "Datrevenaj kalendaroj estos kreitaj de fona tasko.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Tial, ili disponeblos nur post kelke da tempo.",
+    "Send notifications for events" : "Sendi sciigojn pri okazaĵoj",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Sciigoj sendiĝos pere de fonaj taskoj, tiu do bezonas okazi sufiĉe ofte.",
+    "Enable notifications for events via push" : "Ebligi sciigojn pri okazaĵoj per puŝteĥniko",
     "Please make sure to properly set up the email settings above." : "Bv. kontroli, ĉu la supraj retpoŝtaj agordoj estas bone agorditaj."
 },
 "nplurals=2; plural=(n != 1);");
