@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "Foi modificado un <strong>calendario</strong>",
     "A calendar <strong>event</strong> was modified" : "Foi modificado un <strong>evento</strong> do calendario",
     "A calendar <strong>todo</strong> was modified" : "Foi modificado un <strong>asunto pendente</strong> do calendario",
+    "Death of %s" : "Falecemento de %s",
     "Contact birthdays" : "Aniversario do contacto",
+    "Calendar:" : "Calendario:",
+    "Date:" : "Data:",
+    "Where:" : "Onde:",
+    "Description:" : "Descrición:",
+    "Untitled event" : "Evento sen título",
+    "_%n year_::_%n years_" : ["%n ano","%n anos"],
+    "_%n month_::_%n months_" : ["%n mes","%n meses"],
+    "_%n day_::_%n days_" : ["%n día","%n días"],
+    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
+    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
+    "%s (in %s)" : "%s (n %s)",
+    "%s (%s ago)" : "%s (hai %s)",
+    "Calendar: %s" : "Calendario: %s",
+    "Date: %s" : "Data: %s",
+    "Description: %s" : "Descrición: %s",
+    "Where: %s" : "Onde: %s",
     "%1$s via %2$s" : "%1$s mediante %2$s",
     "Invitation canceled" : "Convite cancelado",
     "Hello %s," : "Ola %s,",
@@ -52,12 +69,10 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "A xuntanza «%1$s» con %2$s foi actualizada.",
     "%1$s invited you to »%2$s«" : "%1$s convidouno a «%2$s»",
     "When:" : "Cando:",
-    "Where:" : "Onde:",
-    "Description:" : "Descrición:",
     "Link:" : "Ligazón:",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
-    "More options …" : "Máis opcións …",
+    "More options …" : "Máis opcións…",
     "More options at %s" : "Máis opcións en %s",
     "Contacts" : "Contactos",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
@@ -75,16 +90,15 @@ OC.L10N.register(
     "Save" : "Gardar",
     "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
     "Calendar server" : "Servidor do calendario",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén o {calendarappstoreopen}aplicativo do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén a {calendarappstoreopen}aplicación do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
     "Send invitations to attendees" : "Enviar convites aos asistentes",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrese de ter configurado correctamente {emailopen}o servidor de correo-e{linkclose}.",
     "Automatically generate a birthday calendar" : "Xerar automaticamente o calendario de aniversarios",
     "Birthday calendars will be generated by a background job." : "O calendario de aniversarios xerase cun traballo en segundo plano",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Por isto, non estarán dispoñíbeis inmediatamente tras activalos, senón que aparecerán após certo tempo",
-    "%s via %s" : "%s mediante %s",
-    "The meeting »%s« with %s was canceled." : "A xuntanza «%s» con %s foi cancelada.",
-    "The meeting »%s« with %s was updated." : "A xuntanza «%s» con %s foi actualizada.",
-    "%s invited you to »%s«" : "%s convidouno a «%s»",
+    "Send notifications for events" : "Enviar notificacións para eventos",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "As notificacións enviaranse mediante procesos en segundo plano, polo que estes teñen que suceder bastante a miúdo.",
+    "Enable notifications for events via push" : "Enviar notificacións para eventos mediante «push»",
     "Please make sure to properly set up the email settings above." : "Asegúrese de ter configurado correctamente o correo de enriba."
 },
 "nplurals=2; plural=(n != 1);");
