@@ -44,6 +44,8 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "달력 <strong>행사</strong>가 수정됨",
     "A calendar <strong>todo</strong> was modified" : "달력의 <strong>할 일</strong>이 수정됨",
     "Contact birthdays" : "연락처에 등록된 생일",
+    "Where:" : "장소:",
+    "Description:" : "설명:",
     "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "Invitation canceled" : "초대장 취소됨",
     "Hello %s," : "%s 님 안녕하세요,",
@@ -52,8 +54,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "\"%1$s\" 행사(%2$s 님이 진행함)가 업데이트되었습니다.",
     "%1$s invited you to »%2$s«" : "%1$s 님이 \"%2$s\"에 초대함",
     "When:" : "일시:",
-    "Where:" : "장소:",
-    "Description:" : "설명:",
     "Link:" : "링크:",
     "Accept" : "수락",
     "Decline" : "거절",
@@ -81,10 +81,6 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "자동으로 생일 달력 생성",
     "Birthday calendars will be generated by a background job." : "배경 작업으로 생일 달력을 생성합니다.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "생일 달력이 생성되는 데 시간이 걸릴 수도 있습니다.",
-    "%s via %s" : "%s(%s 경유)",
-    "The meeting »%s« with %s was canceled." : "\"%s\" 행사(%s 님이 진행함)가 취소되었습니다.",
-    "The meeting »%s« with %s was updated." : "\"%s\" 행사(%s 님이 진행함)가 업데이트되었습니다.",
-    "%s invited you to »%s«" : "%s 님이 \"%s\"에 초대함",
     "Please make sure to properly set up the email settings above." : "이메일 설정이 올바른지 확인하십시오."
 },
 "nplurals=1; plural=0;");
