@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
     "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
     "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast",
+    "Death of %s" : "Dood van %s",
     "Contact birthdays" : "Verjaardagen",
+    "Calendar:" : "Agenda",
+    "Date:" : "Datum",
+    "Where:" : "Waar:",
+    "Description:" : "Omschrijving:",
+    "Untitled event" : "Afspraken zonder naam",
+    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
+    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
+    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
+    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
+    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
+    "%s (in %s)" : "%s (in %s)",
+    "%s (%s ago)" : "%s (%s geleden)",
+    "Calendar: %s" : "Agenda: %s",
+    "Date: %s" : "Datum: %s",
+    "Description: %s" : "Beschrijving: %s",
+    "Where: %s" : "Waar: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Invitation canceled" : "Uitnodiging geannuleerd",
     "Hello %s," : "Hallo %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "De vergadering »%1$s« met %2$s is bijgewerkt.",
     "%1$s invited you to »%2$s«" : "%1$s heeft je uitgenodigd voor »%2$s«",
     "When:" : "Wanneer:",
-    "Where:" : "Waar:",
-    "Description:" : "Omschrijving:",
     "Link:" : "Link:",
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
@@ -81,10 +96,9 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
     "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
-    "%s via %s" : "%s via %s",
-    "The meeting »%s« with %s was canceled." : "De vergadering »%s« met %s is geannuleerd.",
-    "The meeting »%s« with %s was updated." : "De vergadering »%s« met %s is bijgewerkt.",
-    "%s invited you to »%s«" : "%s heeft je uitgenodigd voor »%s«",
+    "Send notifications for events" : "Versturen meldingen voor afspraken",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
+    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
     "Please make sure to properly set up the email settings above." : "Zorg ervoor dat je de bovenstaande e-mailinstellingen correct instelt."
 },
 "nplurals=2; plural=(n != 1);");
