@@ -5,11 +5,11 @@ OC.L10N.register(
     "Todos" : "Úlohy",
     "Personal" : "Osobné",
     "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
-    "You created calendar {calendar}" : "Vytvorili ste kalendár [calendar]",
+    "You created calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
     "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
-    "You deleted calendar {calendar}" : "Zmazali ste kalendár [calendar]",
+    "You deleted calendar {calendar}" : "Vytvorili ste kalendár {calendar}",
     "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
-    "You updated calendar {calendar}" : "Upravili ste kalendár [calendar]",
+    "You updated calendar {calendar}" : "Upravili ste kalendár {calendar}",
     "You shared calendar {calendar} as public link" : "Sprístupnili ste kalendár {calendar}  ako verejný odkaz",
     "You removed public link for calendar {calendar}" : "Odstránili ste verejný odkaz pre kalendár {calendar}",
     "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
@@ -24,9 +24,9 @@ OC.L10N.register(
     "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
     "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
-    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť [event] v kalendári [calendar]",
-    "{actor} deleted event {event} from calendar {calendar}" : "[actor] zmazal udalosť [event] z kalendára [calendar]",
-    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť [event] z kalendára [calendar]",
+    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť {event} v kalendári {calendar}",
+    "{actor} deleted event {event} from calendar {calendar}" : "{actor} zmazal udalosť {event} from z kalendára {calendar}",
+    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť {event} z kalendára {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
     "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
     "Busy" : "Zaneprázdnený",
@@ -44,6 +44,22 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
     "A calendar <strong>todo</strong> was modified" : "<strong>Pripomienka</strong> v kalendári bola upravená",
     "Contact birthdays" : "Narodeniny kontaktu",
+    "Calendar:" : "Kalendár:",
+    "Date:" : "Dátum:",
+    "Where:" : "Kde:",
+    "Description:" : "Popis:",
+    "Untitled event" : "Udalosť bez názvu",
+    "_%n year_::_%n years_" : ["%n rokov","%n rokov","%n rokov","%n rokov"],
+    "_%n month_::_%n months_" : ["%n mesiac","%n mesiace","%n mesiacov","%n mesiacov"],
+    "_%n day_::_%n days_" : ["%n deň","%n dni","%n dní","%n dní"],
+    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodín","%n hodín"],
+    "_%n minute_::_%n minutes_" : ["%n minúta","%n minúty","%n minút","%n minút"],
+    "%s (in %s)" : "%s (v %s)",
+    "%s (%s ago)" : "%s (pred %s)",
+    "Calendar: %s" : "Kalendár: %s",
+    "Date: %s" : "Dátum: %s",
+    "Description: %s" : "Popis: %s",
+    "Where: %s" : "Kde: %s",
     "%1$s via %2$s" : "%1$s cez %2$s",
     "Invitation canceled" : "Pozvánka bola zrušená",
     "Hello %s," : "Ahoj %s,",
@@ -52,8 +68,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Stretnutie »%1$s« s %2$s bolo aktualizované.",
     "%1$s invited you to »%2$s«" : "%1$s vám poslal pozvánku na »%2$s«",
     "When:" : "Kedy:",
-    "Where:" : "Kde:",
-    "Description:" : "Popis:",
     "Link:" : "Odkaz:",
     "Accept" : "Schváliť",
     "Decline" : "Odmietnuť",
@@ -81,10 +95,7 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
     "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Preto nebudú dostupné hneď po povolení, ale zobrazia sa po určitom čase",
-    "%s via %s" : "%s cez %s",
-    "The meeting »%s« with %s was canceled." : "Stretnutie »%s« s %s bolo zrušené.",
-    "The meeting »%s« with %s was updated." : "Stretnutie »%s« s %s bolo aktualizované.",
-    "%s invited you to »%s«" : "%s vám poslal pozvánku na »%s«",
+    "Send notifications for events" : "Zaslať upozornenia na udalosti",
     "Please make sure to properly set up the email settings above." : "Uistite sa, že máte správne nastavené vyššie uvedené nastavenia e-mailu."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
