@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
     "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
     "A calendar <strong>todo</strong> was modified" : "<strong>Подсетник</strong> из календара је измењен",
+    "Death of %s" : " %s смрт",
     "Contact birthdays" : "Рођендани контаката",
+    "Calendar:" : "Календар:",
+    "Date:" : "Датум:",
+    "Where:" : "Место:",
+    "Description:" : "Опис:",
+    "Untitled event" : "Неименовани догађај",
+    "_%n year_::_%n years_" : ["%n година","%n године","%n  година"],
+    "_%n month_::_%n months_" : ["%n месец","%n месеца","%n месеци"],
+    "_%n day_::_%n days_" : ["%n дан","%n дана","%n дана"],
+    "_%n hour_::_%n hours_" : ["%n сат","%n сата","%n сати"],
+    "_%n minute_::_%n minutes_" : ["%n минут","%n минута","%n минута"],
+    "%s (in %s)" : "%s (у %s)",
+    "%s (%s ago)" : "%s (пре %s)",
+    "Calendar: %s" : "Календар: %s",
+    "Date: %s" : "Датум: %s",
+    "Description: %s" : "Опис: %s",
+    "Where: %s" : "Место: %s",
     "%1$s via %2$s" : "%1$s преко %2$s",
     "Invitation canceled" : "Позивница отказана",
     "Hello %s," : "Здраво %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Састанак „%1$s“ са %2$s је ажуриран.",
     "%1$s invited you to »%2$s«" : "%1$s Вас је позвао на „%2$s“",
     "When:" : "Време:",
-    "Where:" : "Место:",
-    "Description:" : "Опис:",
     "Link:" : "Веза:",
     "Accept" : "Прихвати",
     "Decline" : "Одбиј",
@@ -81,10 +96,9 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Аутоматски изгенериши календар рођендана",
     "Birthday calendars will be generated by a background job." : "Календари рођендана ће бити генерисани као позадински послови.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Зато можда неће бити видљиви баш одмах по укључивању, али ће се појавити после неког времена.",
-    "%s via %s" : "%s путем %s",
-    "The meeting »%s« with %s was canceled." : "Састанак „%s“ са  %s је отказан.",
-    "The meeting »%s« with %s was updated." : "Састанак „%s“ са %s је ажуриран.",
-    "%s invited you to »%s«" : "%s Вас је позвао на „%s“",
+    "Send notifications for events" : "Шаљи обавештења о догађајима",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Обавештења ће бити слана кроз послове у позадини, па би требало да су они постављени да се често извршавају.",
+    "Enable notifications for events via push" : "Укључи обавештења за догађаје преко гурања догађаја",
     "Please make sure to properly set up the email settings above." : "Пазите да правилно подесите поставке е-поште изнад."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
