@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
     "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
     "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
+    "Death of %s" : "Död av %s",
     "Contact birthdays" : "Födelsedagar",
+    "Calendar:" : "Kalender:",
+    "Date:" : "Datum:",
+    "Where:" : "Var:",
+    "Description:" : "Beskrivning:",
+    "Untitled event" : "Namnlös händelse",
+    "_%n year_::_%n years_" : ["%n år","%n år"],
+    "_%n month_::_%n months_" : ["%n månad","%n månader"],
+    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
+    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
+    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
+    "%s (in %s)" : "%s (på %s)",
+    "%s (%s ago)" : "%s (%s sedan)",
+    "Calendar: %s" : "Kalender: %s",
+    "Date: %s" : "Datum: %s",
+    "Description: %s" : "Beskrivning: %s",
+    "Where: %s" : "Var: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Invitation canceled" : "Inbjudan avbruten",
     "Hello %s," : "He %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Mötet »%1$s« med %2$s uppdaterades.",
     "%1$s invited you to »%2$s«" : "%1$s bjöd in dig till »%2$s«",
     "When:" : "När",
-    "Where:" : "Var:",
-    "Description:" : "Beskrivning:",
     "Link:" : "Länk:",
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
@@ -81,10 +96,9 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
     "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
-    "%s via %s" : "%s via %s",
-    "The meeting »%s« with %s was canceled." : "Mötet »%s« med%s avbröts.",
-    "The meeting »%s« with %s was updated." : "Mötet »%s« med %s uppdaterades.",
-    "%s invited you to »%s«" : "%s bjöd in dig till »%s«",
+    "Send notifications for events" : "Skicka aviseringar för händelser",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Aviseringar skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
+    "Enable notifications for events via push" : "Aktivera aviseringar för händelser via push",
     "Please make sure to properly set up the email settings above." : "Vänligen säkerställ att epost-inställningarna ovan är korrekt angivna"
 },
 "nplurals=2; plural=(n != 1);");
