@@ -1,7 +1,8 @@
 <?php
+declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
- * @copyright Copyright (c) 2016, Georg Ehrke
+ * @copyright Copyright (c) 2019, Georg Ehrke
  *
  * @author Achim Königs <garfonso@tratschtante.de>
  * @author Georg Ehrke <oc.list@georgehrke.com>
@@ -32,6 +33,8 @@ use Exception;
 use OCA\DAV\CardDAV\CardDavBackend;
 use OCA\DAV\DAV\GroupPrincipalBackend;
 use OCP\IConfig;
+use OCP\IDBConnection;
+use OCP\IL10N;
 use Sabre\VObject\Component\VCalendar;
 use Sabre\VObject\Component\VCard;
 use Sabre\VObject\DateTimeParser;
@@ -40,6 +43,11 @@ use Sabre\VObject\InvalidDataException;
 use Sabre\VObject\Property\VCard\DateAndOrTime;
 use Sabre\VObject\Reader;
 
+/**
+ * Class BirthdayService
+ *
+ * @package OCA\DAV\CalDAV
+ */
 class BirthdayService {
 
 	const BIRTHDAY_CALENDAR_URI = 'contact_birthdays';
@@ -56,19 +64,34 @@ class BirthdayService {
 	/** @var IConfig */
 	private $config;
 
+	/** @var IDBConnection */
+	private $dbConnection;
+
+	/** @var IL10N */
+	private $l10n;
+
 	/**
 	 * BirthdayService constructor.
 	 *
 	 * @param CalDavBackend $calDavBackEnd
 	 * @param CardDavBackend $cardDavBackEnd
 	 * @param GroupPrincipalBackend $principalBackend
-	 * @param IConfig $config;
+	 * @param IConfig $config
+	 * @param IDBConnection $dbConnection
+	 * @param IL10N $l10n
 	 */
-	public function __construct(CalDavBackend $calDavBackEnd, CardDavBackend $cardDavBackEnd, GroupPrincipalBackend $principalBackend, IConfig $config) {
+	public function __construct(CalDavBackend $calDavBackEnd,
+								CardDavBackend $cardDavBackEnd,
+								GroupPrincipalBackend $principalBackend,
+								IConfig $config,
+								IDBConnection $dbConnection,
+								IL10N $l10n) {
 		$this->calDavBackEnd = $calDavBackEnd;
 		$this->cardDavBackEnd = $cardDavBackEnd;
 		$this->principalBackend = $principalBackend;
 		$this->config = $config;
+		$this->dbConnection = $dbConnection;
+		$this->l10n = $l10n;
 	}
 
 	/**
@@ -76,7 +99,9 @@ class BirthdayService {
 	 * @param string $cardUri
 	 * @param string $cardData
 	 */
-	public function onCardChanged($addressBookId, $cardUri, $cardData) {
+	public function onCardChanged(int $addressBookId,
+								  string $cardUri,
+								  string $cardData) {
 		if (!$this->isGloballyEnabled()) {
 			return;
 		}
@@ -85,10 +110,11 @@ class BirthdayService {
 		$book = $this->cardDavBackEnd->getAddressBookById($addressBookId);
 		$targetPrincipals[] = $book['principaluri'];
 		$datesToSync = [
-			['postfix' => '', 'field' => 'BDAY', 'symbol' => '*'],
-			['postfix' => '-death', 'field' => 'DEATHDATE', 'symbol' => "†"],
-			['postfix' => '-anniversary', 'field' => 'ANNIVERSARY', 'symbol' => "⚭"],
+			['postfix' => '', 'field' => 'BDAY'],
+			['postfix' => '-death', 'field' => 'DEATHDATE'],
+			['postfix' => '-anniversary', 'field' => 'ANNIVERSARY'],
 		];
+
 		foreach ($targetPrincipals as $principalUri) {
 			if (!$this->isUserEnabled($principalUri)) {
 				continue;
@@ -96,7 +122,7 @@ class BirthdayService {
 
 			$calendar = $this->ensureCalendarExists($principalUri);
 			foreach ($datesToSync as $type) {
-				$this->updateCalendar($cardUri, $cardData, $book, $calendar['id'], $type);
+				$this->updateCalendar($cardUri, $cardData, $book, (int) $calendar['id'], $type);
 			}
 		}
 	}
@@ -105,7 +131,8 @@ class BirthdayService {
 	 * @param int $addressBookId
 	 * @param string $cardUri
 	 */
-	public function onCardDeleted($addressBookId, $cardUri) {
+	public function onCardDeleted(int $addressBookId,
+								  string $cardUri) {
 		if (!$this->isGloballyEnabled()) {
 			return;
 		}
@@ -131,10 +158,10 @@ class BirthdayService {
 	 * @return array|null
 	 * @throws \Sabre\DAV\Exception\BadRequest
 	 */
-	public function ensureCalendarExists($principal) {
-		$book = $this->calDavBackEnd->getCalendarByUri($principal, self::BIRTHDAY_CALENDAR_URI);
-		if (!is_null($book)) {
-			return $book;
+	public function ensureCalendarExists(string $principal):?array {
+		$calendar = $this->calDavBackEnd->getCalendarByUri($principal, self::BIRTHDAY_CALENDAR_URI);
+		if (!is_null($calendar)) {
+			return $calendar;
 		}
 		$this->calDavBackEnd->createCalendar($principal, self::BIRTHDAY_CALENDAR_URI, [
 			'{DAV:}displayname' => 'Contact birthdays',
@@ -146,12 +173,15 @@ class BirthdayService {
 	}
 
 	/**
-	 * @param string $cardData
-	 * @param string $dateField
-	 * @param string $summarySymbol
-	 * @return null|VCalendar
+	 * @param $cardData
+	 * @param $dateField
+	 * @param $postfix
+	 * @return VCalendar|null
+	 * @throws InvalidDataException
 	 */
-	public function buildDateFromContact($cardData, $dateField, $summarySymbol) {
+	public function buildDateFromContact(string $cardData,
+										 string $dateField,
+										 string $postfix):?VCalendar {
 		if (empty($cardData)) {
 			return null;
 		}
@@ -190,23 +220,40 @@ class BirthdayService {
 		}
 
 		$unknownYear = false;
+		$originalYear = null;
 		if (!$dateParts['year']) {
-			$birthday = '1900-' . $dateParts['month'] . '-' . $dateParts['date'];
+			$birthday = '1970-' . $dateParts['month'] . '-' . $dateParts['date'];
 
 			$unknownYear = true;
+		} else {
+			$parameters = $birthday->parameters();
+			if (isset($parameters['X-APPLE-OMIT-YEAR'])) {
+				$omitYear = $parameters['X-APPLE-OMIT-YEAR'];
+				if ($dateParts['year'] === $omitYear) {
+					$birthday = '1970-' . $dateParts['month'] . '-' . $dateParts['date'];
+					$unknownYear = true;
+				}
+			} else {
+				$originalYear = (int)$dateParts['year'];
+
+				if ($originalYear < 1970) {
+					$birthday = '1970-' . $dateParts['month'] . '-' . $dateParts['date'];
+				}
+			}
 		}
 
 		try {
-			$date = new \DateTime($birthday);
+			if ($birthday instanceof DateAndOrTime) {
+				$date = $birthday->getDateTime();
+			} else {
+				$date = new \DateTimeImmutable($birthday);
+			}
 		} catch (Exception $e) {
 			return null;
 		}
-		if ($unknownYear) {
-			$summary = $doc->FN->getValue() . ' ' . $summarySymbol;
-		} else {
-			$year = (int)$date->format('Y');
-			$summary = $doc->FN->getValue() . " ($summarySymbol$year)";
-		}
+
+		$summary = $this->formatTitle($dateField, $doc->FN->getValue(), $originalYear, $this->dbConnection->supports4ByteText());
+
 		$vCal = new VCalendar();
 		$vCal->VERSION = '2.0';
 		$vEvent = $vCal->createComponent('VEVENT');
@@ -216,15 +263,23 @@ class BirthdayService {
 		);
 		$vEvent->DTSTART['VALUE'] = 'DATE';
 		$vEvent->add('DTEND');
-		$date->add(new \DateInterval('P1D'));
+
+		$dtEndDate = (new \DateTime())->setTimestamp($date->getTimeStamp());
+		$dtEndDate->add(new \DateInterval('P1D'));
 		$vEvent->DTEND->setDateTime(
-			$date
+			$dtEndDate
 		);
+
 		$vEvent->DTEND['VALUE'] = 'DATE';
-		$vEvent->{'UID'} = $doc->UID;
+		$vEvent->{'UID'} = $doc->UID . $postfix;
 		$vEvent->{'RRULE'} = 'FREQ=YEARLY';
 		$vEvent->{'SUMMARY'} = $summary;
 		$vEvent->{'TRANSP'} = 'TRANSPARENT';
+		$vEvent->{'X-NEXTCLOUD-BC-FIELD-TYPE'} = $dateField;
+		$vEvent->{'X-NEXTCLOUD-BC-UNKNOWN-YEAR'} = $unknownYear ? '1' : '0';
+		if ($originalYear !== null) {
+			$vEvent->{'X-NEXTCLOUD-BC-YEAR'} = (string) $originalYear;
+		}
 		$alarm = $vCal->createComponent('VALARM');
 		$alarm->add($vCal->createProperty('TRIGGER', '-PT0M', ['VALUE' => 'DURATION']));
 		$alarm->add($vCal->createProperty('ACTION', 'DISPLAY'));
@@ -237,14 +292,28 @@ class BirthdayService {
 	/**
 	 * @param string $user
 	 */
-	public function syncUser($user) {
+	public function resetForUser(string $user):void {
+		$principal = 'principals/users/'.$user;
+		$calendar = $this->calDavBackEnd->getCalendarByUri($principal, self::BIRTHDAY_CALENDAR_URI);
+		$calendarObjects = $this->calDavBackEnd->getCalendarObjects($calendar['id'], CalDavBackend::CALENDAR_TYPE_CALENDAR);
+
+		foreach($calendarObjects as $calendarObject) {
+			$this->calDavBackEnd->deleteCalendarObject($calendar['id'], $calendarObject['uri'], CalDavBackend::CALENDAR_TYPE_CALENDAR);
+		}
+	}
+
+	/**
+	 * @param string $user
+	 * @throws \Sabre\DAV\Exception\BadRequest
+	 */
+	public function syncUser(string $user):void {
 		$principal = 'principals/users/'.$user;
 		$this->ensureCalendarExists($principal);
 		$books = $this->cardDavBackEnd->getAddressBooksForUser($principal);
 		foreach($books as $book) {
 			$cards = $this->cardDavBackEnd->getCards($book['id']);
 			foreach($cards as $card) {
-				$this->onCardChanged($book['id'], $card['uri'], $card['carddata']);
+				$this->onCardChanged((int) $book['id'], $card['uri'], $card['carddata']);
 			}
 		}
 	}
@@ -254,25 +323,25 @@ class BirthdayService {
 	 * @param VCalendar $newCalendarData
 	 * @return bool
 	 */
-	public function birthdayEvenChanged($existingCalendarData, $newCalendarData) {
+	public function birthdayEvenChanged(string $existingCalendarData,
+										VCalendar $newCalendarData):bool {
 		try {
 			$existingBirthday = Reader::read($existingCalendarData);
 		} catch (Exception $ex) {
 			return true;
 		}
-		if ($newCalendarData->VEVENT->DTSTART->getValue() !== $existingBirthday->VEVENT->DTSTART->getValue() ||
+
+		return (
+			$newCalendarData->VEVENT->DTSTART->getValue() !== $existingBirthday->VEVENT->DTSTART->getValue() ||
 			$newCalendarData->VEVENT->SUMMARY->getValue() !== $existingBirthday->VEVENT->SUMMARY->getValue()
-		) {
-			return true;
-		}
-		return false;
+		);
 	}
 
 	/**
 	 * @param integer $addressBookId
 	 * @return mixed
 	 */
-	protected function getAllAffectedPrincipals($addressBookId) {
+	protected function getAllAffectedPrincipals(int $addressBookId) {
 		$targetPrincipals = [];
 		$shares = $this->cardDavBackEnd->getShares($addressBookId);
 		foreach ($shares as $share) {
@@ -290,14 +359,20 @@ class BirthdayService {
 
 	/**
 	 * @param string $cardUri
-	 * @param string  $cardData
+	 * @param string $cardData
 	 * @param array $book
 	 * @param int $calendarId
-	 * @param string[] $type
+	 * @param array $type
+	 * @throws InvalidDataException
+	 * @throws \Sabre\DAV\Exception\BadRequest
 	 */
-	private function updateCalendar($cardUri, $cardData, $book, $calendarId, $type) {
+	private function updateCalendar(string $cardUri,
+									string $cardData,
+									array $book,
+									int $calendarId,
+									array $type):void {
 		$objectUri = $book['uri'] . '-' . $cardUri . $type['postfix'] . '.ics';
-		$calendarData = $this->buildDateFromContact($cardData, $type['field'], $type['symbol']);
+		$calendarData = $this->buildDateFromContact($cardData, $type['field'], $type['postfix']);
 		$existing = $this->calDavBackEnd->getCalendarObject($calendarId, $objectUri);
 		if (is_null($calendarData)) {
 			if (!is_null($existing)) {
@@ -319,18 +394,17 @@ class BirthdayService {
 	 *
 	 * @return bool
 	 */
-	private function isGloballyEnabled() {
-		$isGloballyEnabled = $this->config->getAppValue('dav', 'generateBirthdayCalendar', 'yes');
-		return $isGloballyEnabled === 'yes';
+	private function isGloballyEnabled():bool {
+		return $this->config->getAppValue('dav', 'generateBirthdayCalendar', 'yes') === 'yes';
 	}
 
 	/**
-	 * checks if the user opted-out of birthday calendars
+	 * Checks if the user opted-out of birthday calendars
 	 *
-	 * @param $userPrincipal
+	 * @param string $userPrincipal The user principal to check for
 	 * @return bool
 	 */
-	private function isUserEnabled($userPrincipal) {
+	private function isUserEnabled(string $userPrincipal):bool {
 		if (strpos($userPrincipal, 'principals/users/') === 0) {
 			$userId = substr($userPrincipal, 17);
 			$isEnabled = $this->config->getUserValue($userId, 'dav', 'generateBirthdayCalendar', 'yes');
@@ -341,4 +415,69 @@ class BirthdayService {
 		return true;
 	}
 
+	/**
+	 * Formats title of Birthday event
+	 *
+	 * @param string $field Field name like BDAY, ANNIVERSARY, ...
+	 * @param string $name Name of contact
+	 * @param int|null $year Year of birth, anniversary, ...
+	 * @param bool $supports4Byte Whether or not the database supports 4 byte chars
+	 * @return string The formatted title
+	 */
+	private function formatTitle(string $field,
+								 string $name,
+								 int $year=null,
+								 bool $supports4Byte=true):string {
+		if ($supports4Byte) {
+			switch ($field) {
+				case 'BDAY':
+					return implode('', [
+						'🎂 ',
+						$name,
+						$year ? (' (' . $year . ')') : '',
+					]);
+
+				case 'DEATHDATE':
+					return implode('', [
+						$this->l10n->t('Death of %s', [$name]),
+						$year ? (' (' . $year . ')') : '',
+					]);
+
+				case 'ANNIVERSARY':
+					return implode('', [
+						'💍 ',
+						$name,
+						$year ? (' (' . $year . ')') : '',
+					]);
+
+				default:
+					return '';
+			}
+		} else {
+			switch($field) {
+				case 'BDAY':
+					return implode('', [
+						$name,
+						' ',
+						$year ? ('(*' . $year . ')') : '*',
+					]);
+
+				case 'DEATHDATE':
+					return implode('', [
+						$this->l10n->t('Death of %s', [$name]),
+						$year ? (' (' . $year . ')') : '',
+					]);
+
+				case 'ANNIVERSARY':
+					return implode('', [
+						$name,
+						' ',
+						$year ? ('(⚭' . $year . ')') : '⚭',
+					]);
+
+				default:
+					return '';
+			}
+		}
+	}
 }
