@@ -23,6 +23,7 @@
 namespace OCA\DAV\CardDAV;
 
 use OCA\DAV\DAV\Sharing\IShareable;
+use OCA\DAV\Exception\UnsupportedLimitOnInitialSyncException;
 use OCP\IL10N;
 use Sabre\CardDAV\Backend\BackendInterface;
 use Sabre\CardDAV\Card;
@@ -112,6 +113,14 @@ class AddressBook extends \Sabre\CardDAV\AddressBook implements IShareable {
 			]
 		];
 
+		if ($this->getOwner() === 'principals/system/system') {
+			$acl[] = [
+				'privilege' => '{DAV:}read',
+				'principal' => '{DAV:}authenticated',
+				'protected' => true,
+			];
+		}
+
 		if (!$this->isShared()) {
 			return $acl;
 		}
@@ -130,13 +139,6 @@ class AddressBook extends \Sabre\CardDAV\AddressBook implements IShareable {
 				];
 			}
 		}
-		if ($this->getOwner() === 'principals/system/system') {
-			$acl[] = [
-					'privilege' => '{DAV:}read',
-					'principal' => '{DAV:}authenticated',
-					'protected' => true,
-			];
-		}
 
 		$acl = $this->carddavBackend->applyShareAcl($this->getResourceId(), $acl);
 		$allowedPrincipals = [$this->getOwner(), parent::getOwner(), 'principals/system/system'];
@@ -218,4 +220,12 @@ class AddressBook extends \Sabre\CardDAV\AddressBook implements IShareable {
 		}
 		return true;
 	}
+
+	public function getChanges($syncToken, $syncLevel, $limit = null) {
+		if (!$syncToken && $limit) {
+			throw new UnsupportedLimitOnInitialSyncException();
+		}
+
+		return parent::getChanges($syncToken, $syncLevel, $limit);
+	}
 }
