@@ -32,7 +32,7 @@ OC.L10N.register(
     "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Pozdravljeni,<br><br> administrator je vklopil šifriranje na strežniku. Vaše datoteke bodo šifrirane z geslom <strong>%s</strong>.<br><br> Prosimo, prijavite se na spletno stran, pojdite na sekcijo 'basic encryption module' vaših osebnih nastavitev in posodobite vaše šifrirno geslo z vnosom tega gesla v polje 'old log-in password' in vašega trenutnega prijavnega gesla.<br><br>",
     "Encrypt the home storage" : "Šifriraj domačo shrambo",
     "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Izbrana možnost omogoči šifriranje vseh datotek, shranjenih v glavni shrambi, sicer so šifrirane le datoteke v zunanjih shrambah.",
-    "Enable recovery key" : "Omogoči obnovitev gesla",
+    "Enable recovery key" : "Omogoči obnovitveni ključ",
     "Disable recovery key" : "Onemogoči obnovitev gesla",
     "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Obnovitveni ključ je dodatni šifrirni ključ, ki se uporablja pri šifriranju datotek. Omogoča obnovitev uporabnikovih datotek, če uporabnih pozabi svoje geslo za dostop.",
     "Recovery key password" : "Ključ za obnovitev gesla",
@@ -44,14 +44,13 @@ OC.L10N.register(
     "Change Password" : "Spremeni geslo",
     "Your private key password no longer matches your log-in password." : "Zasebno geslo ni več skladno s prijavnim geslom.",
     "Set your old private key password to your current log-in password:" : "Nastavite star zasebni ključ na trenutno prijavno geslo:",
-    " If you don't remember your old password you can ask your administrator to recover your files." : "Če ste pozabili svoje geslo, lahko vaše datoteke obnovi le skrbnik sistema.",
+    " If you don't remember your old password you can ask your administrator to recover your files." : "V kolikor se gesla ne spomnite več, lahko vaše datoteke obnovi le skrbnik sistema.",
     "Old log-in password" : "Staro geslo",
     "Current log-in password" : "Trenutno geslo",
     "Update Private Key Password" : "Posodobi zasebni ključ",
     "Enable password recovery:" : "Omogoči obnovitev gesla:",
     "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Nastavitev te možnosti omogoča ponovno pridobitev dostopa do šifriranih datotek, v primeru, da boste geslo pozabili.",
     "Enabled" : "Omogočeno",
-    "Disabled" : "Onemogočeno",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega. Zaženite ukaz 'occ encryption:migrate' ali pa stopite v stik s skrbnikom sistema."
+    "Disabled" : "Onemogočeno"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
