@@ -45,13 +45,11 @@ OC.L10N.register(
     "Search global and public address book for users" : "グローバルまたはユーザーの公開アドレス帳を検索する",
     "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
     "Federated Cloud" : "クラウド共有",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloudサーバまたはその他のOpen Cloud Mesh(OCM)互換のサーバとサービスを使用しているユーザであれば、共有ダイアログにFederated Cloud IDを入力するだけで誰とでも共有できます。例:person@cloud.example.com",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloudサーバーまたはその他のOpen Cloud Mesh(OCM)互換のサーバーとサービスを使用しているユーザーであれば、共有ダイアログにFederated Cloud IDを入力するだけで誰とでも共有できます。例:person@cloud.example.com",
     "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
     "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
     "Add to your website" : "ウェブサイトに追加",
     "Share with me via Nextcloud" : "Nextcloud 経由で共有",
-    "HTML Code:" : "HTMLコード:",
-    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないか、自己証明書を使っています。"
+    "HTML Code:" : "HTMLコード:"
 },
 "nplurals=1; plural=0;");
