@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeni delež {ime} od {lastnika}@{daljinsko}?",
     "Remote share" : "Oddaljeno mesto za souporabo",
+    "Remote share password" : "Geslo za oddaljeno souporabo",
     "Cancel" : "Prekliči",
     "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
     "Copy" : "Kopiraj",
@@ -11,7 +12,10 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
     "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
     "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka Nextcloud",
+    "Server to server sharing is not enabled on this server" : "Na tem strežniku souporaba strežnik na strežnik ni omogočena.",
     "Couldn't establish a federated share." : "Ni mogoče vzpostaviti zveznega mesta za souporabo.",
+    "Couldn't establish a federated share, maybe the password was wrong." : "Zvezne povezave za souporabo ni mogoče ustvariti. Morda je navedeno napačno geslo.",
+    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Zvezne povezave za souporabo ni mogoče ustvariti. Kaže, da je podana zahteva za povezavo z nepodprto staro različico oblaka (Nextzcloud ≤ 9).",
     "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
     "File is already shared with %s" : "Datoteka je že v souporabi pri %s",
     "Could not find share" : "Ni mogoče najti mape v souporabi",
@@ -22,6 +26,7 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "Omogoči souporabo prek #Nextcloud ID zveznega oblaka",
     "Sharing" : "Souporaba",
     "Federated file sharing" : "Souporaba v zveznem oblaku",
+    "Provide federated file sharing across servers" : "Omogoči zvezno souporabo prek različnih strežnikov",
     "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
     "Open documentation" : "Odpri dokumentacijo",
     "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
@@ -30,7 +35,6 @@ OC.L10N.register(
     "Your Federated Cloud ID:" : "Vaš ID zveznega oblaka:",
     "Add to your website" : "Dodaj na spletišče",
     "Share with me via Nextcloud" : "Omogoči souporabo prek oblaka Nextcloud",
-    "HTML Code:" : "Koda HTML:",
-    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletelo, ker je ima uporabnik %s predmet že v souporabi."
+    "HTML Code:" : "Koda HTML:"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
