@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Copia",
     "Choose target folder" : "Tria la carpeta de destinació",
     "Open" : "Obre",
+    "Delete file" : "Suprimeix el fitxer",
+    "Delete folder" : "Suprimeix la carpeta",
     "Disconnect storage" : "Desonnecta l'emmagatzematge",
     "Unshare" : "Deixa de compartir",
     "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer \"{file}\"",
@@ -160,15 +162,14 @@ OC.L10N.register(
     "Deleted shares" : "Comparticions suprimides",
     "Text file" : "Fitxer de text",
     "New text file.txt" : "Nou fitxer de text text.txt",
-    "Target folder" : "Carpeta de destinació",
     "File handling" : "Gestió de fitxers",
     "Maximum upload size" : "Mida màxima de càrrega",
     "max. possible: " : "màxim possible:",
     "Save" : "Desa",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Amb PHP-FPM pot trigar 5 minuts a aplicar els canvis.",
     "Missing permissions to edit from here." : "Falta els permisos per editar des d'aquí.",
-    "%s of %s used" : "Utilitzats %s de %s",
     "Cancel upload" : "Cancel·la la càrrega",
+    "%s of %s used" : "Utilitzats %s de %s",
     "%1$s%% of %2$s used" : "%1$s%% de %2$s utilitzat"
 },
 "nplurals=2; plural=(n != 1);");
