@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopírovat",
     "Choose target folder" : "Zvolte cílovou složku",
     "Open" : "Otevřít",
+    "Delete file" : "Smazat soubor",
+    "Delete folder" : "Smazat složku",
     "Disconnect storage" : "Odpojit úložiště",
     "Unshare" : "Zrušit sdílení",
     "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor {file}",
@@ -84,7 +86,7 @@ OC.L10N.register(
     "View in folder" : "Zobrazit ve složce",
     "Copied!" : "Zkopírováno!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přístup k tomuto souboru/složce)",
-    "Path" : "Popis umístění",
+    "Path" : "Cesta",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajtů"],
     "Favorited" : "Přidáno k oblíbeným",
     "Favorite" : "Oblíbené",
@@ -159,15 +161,14 @@ OC.L10N.register(
     "Deleted shares" : "Smazaná sdílení",
     "Text file" : "Textový soubor",
     "New text file.txt" : "Nový textový soubor.txt",
-    "Target folder" : "Cílový adresář",
     "File handling" : "Zacházení se soubory",
     "Maximum upload size" : "Maximální velikost pro odesílání",
     "max. possible: " : "největší možná: ",
     "Save" : "Uložit",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Při použití PHP-FPM může změna nastavení trvat až 5 minut od uložení.",
     "Missing permissions to edit from here." : "Pro úpravy v aktuálním náhledu chybí oprávnění.",
-    "%s of %s used" : "%s z %s použito",
     "Cancel upload" : "Zrušit nahrávání",
+    "%s of %s used" : "%s z %s použito",
     "%1$s%% of %2$s used" : "použito %1$s%% z %2$s"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
