@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopieren",
     "Choose target folder" : "Zielordner wählen",
     "Open" : "Öffnen",
+    "Delete file" : "Datei löschen",
+    "Delete folder" : "Ordner löschen",
     "Disconnect storage" : "Speicher trennen",
     "Unshare" : "Freigabe aufheben",
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
@@ -113,11 +115,11 @@ OC.L10N.register(
     "{user} created an encrypted file in {file}" : "{user} hat die verschlüsselte Datei in {file} erstellt",
     "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
     "You changed {file}" : "Du hast {file} geändert",
-    "You changed an encrypted file in {file}" : "Du hast die verschlüsselte Datei in {file} geändert",
+    "You changed an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} geändert",
     "{user} changed {file}" : "{user} hat {file} geändert",
-    "{user} changed an encrypted file in {file}" : "{user} hat die verschlüsselte Datei in {file} geändert",
+    "{user} changed an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} geändert",
     "You deleted {file}" : "Du hast {file} gelöscht",
-    "You deleted an encrypted file in {file}" : "Du hast die verschlüsselte Datei in {file} gelöscht",
+    "You deleted an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} gelöscht",
     "{user} deleted {file}" : "{user} hat {file} gelöscht",
     "{user} deleted an encrypted file in {file}" : "{user} hat die verschlüsselte Datei in {file} gelöscht",
     "You restored {file}" : "Du hast {file} wiederhergestellt",
@@ -135,6 +137,8 @@ OC.L10N.register(
     "Unlimited" : "Unbegrenzt",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "File Management" : "Dateiverwaltung",
+    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
+    "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
     "%s used" : "%s verwendet",
     "%s%% of %s used" : "%s%% von %s verwendet",
     "%1$s of %2$s used" : "%1$s von %2$s verwendet",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "Gelöschte Freigaben",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
-    "Target folder" : "Zielordner",
     "File handling" : "Dateibehandlung",
     "Maximum upload size" : "Maximale Upload-Größe",
     "max. possible: " : "maximal möglich:",
     "Save" : "Speichern",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Mit PHP-FPM kann es bis zu 5 Minuten dauern, bis die Einstellungen übernommen werden.",
     "Missing permissions to edit from here." : "Fehlende Berechtigungen, um dies von hier aus zu bearbeiten.",
-    "%s of %s used" : "%s von %s verwendet",
     "Cancel upload" : "Hochladen abbrechen",
+    "%s of %s used" : "%s von %s verwendet",
     "%1$s%% of %2$s used" : "%1$s%% von %2$s verwendet"
 },
 "nplurals=2; plural=(n != 1);");
