@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Copiar",
     "Choose target folder" : "Elegir carpeta de destino",
     "Open" : "Abrir",
+    "Delete file" : "Eliminar archivo",
+    "Delete folder" : "Eliminar carpeta",
     "Disconnect storage" : "Desconectar almacenamiento",
     "Unshare" : "Dejar de compartir",
     "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
@@ -135,9 +137,11 @@ OC.L10N.register(
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Subida (máx. %s)",
     "File Management" : "Gestión de archivos",
-    "%s of %s used" : "%s de %s usado",
-    "%1$s%% of %2$s used" : "%1$s %% de %2$s usados",
+    "Error while loading the file data" : "Error al cargar el archivo de datos",
+    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
     "%s used" : "usado %s",
+    "%s%% of %s used" : "%s%% de %s usado",
+    "%1$s of %2$s used" : "%1$s de %2$s utilizados",
     "Settings" : "Ajustes",
     "Show hidden files" : "Mostrar archivos ocultos",
     "WebDAV" : "WebDAV",
@@ -160,7 +164,6 @@ OC.L10N.register(
     "Deleted shares" : "Recursos compartidos eliminados",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
-    "Target folder" : "Directorio de destino",
     "File handling" : "Manejo de archivos",
     "Maximum upload size" : "Tamaño de subida máximo ",
     "max. possible: " : "máx. posible: ",
@@ -168,6 +171,7 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar hasta 5 minutos en realizarse los cambios.",
     "Missing permissions to edit from here." : "Faltan permisos para poder editar desde aquí.",
     "Cancel upload" : "Cancelar subida",
-    "%1$s of %2$s used" : "%1$s de %2$s utilizados"
+    "%s of %s used" : "%s de %s usado",
+    "%1$s%% of %2$s used" : "%1$s %% de %2$s usados"
 },
 "nplurals=2; plural=(n != 1);");
