@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopioi",
     "Choose target folder" : "Valitse kohdekansio",
     "Open" : "Avaa",
+    "Delete file" : "Poista tiedosto",
+    "Delete folder" : "Poista kansio",
     "Disconnect storage" : "Katkaise yhteys tallennustilaan",
     "Unshare" : "Peru jakaminen",
     "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
@@ -48,6 +50,8 @@ OC.L10N.register(
     "copy" : "kopio",
     "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
     "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
+    "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
     "{newName} already exists" : "{newName} on jo olemassa",
     "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
@@ -106,12 +110,18 @@ OC.L10N.register(
     "Moved by {user}" : "Siirtänyt {user}",
     "\"remote user\"" : "\"etäkäyttäjä\"",
     "You created {file}" : "Loit tiedoston {file}",
+    "You created an encrypted file in {file}" : "Loit salatun tiedoston {file}",
     "{user} created {file}" : "{user} loi tiedoston {file}",
+    "{user} created an encrypted file in {file}" : "{user} loi salatun tiedoston {file}",
     "{file} was created in a public folder" : "Tiedosto {file} luotiin julkisessa kansiossa",
     "You changed {file}" : "Muutit tiedostoa {file}",
+    "You changed an encrypted file in {file}" : "Muutit salattua tiedostoa {file}",
     "{user} changed {file}" : "{user} muutti tiedostoa {file}",
+    "{user} changed an encrypted file in {file}" : "{user} muutti salattua tiedostoa {file}",
     "You deleted {file}" : "Poistit tiedoston {file}",
+    "You deleted an encrypted file in {file}" : "Poistit salatun tiedoston {file}",
     "{user} deleted {file}" : "{user} poisti tiedoston {file}",
+    "{user} deleted an encrypted file in {file}" : "{user} poisti salatun tiedoston {file}",
     "You restored {file}" : "Palautit tiedoston {file}",
     "{user} restored {file}" : "{user} palautti tiedoston {file}",
     "You renamed {oldfile} to {newfile}" : "Uudelleennimesit tiedoston {oldfile} tiedostoksi {newfile}",
@@ -152,15 +162,14 @@ OC.L10N.register(
     "Deleted shares" : "Poistetut jaot",
     "Text file" : "Tekstitiedosto",
     "New text file.txt" : "Uusi tekstitiedosto.txt",
-    "Target folder" : "Kohdekansio",
     "File handling" : "Tiedostonhallinta",
     "Maximum upload size" : "Lähetettävän tiedoston suurin sallittu koko",
     "max. possible: " : "suurin mahdollinen:",
     "Save" : "Tallenna",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM:tä käyttäen muutoksien voimaantulossa saattaa kestää 5 minuuttia.",
     "Missing permissions to edit from here." : "Käyttöoikeudet eivät riitä tätä kautta muokkaamiseen.",
-    "%s of %s used" : "%s / %s käytetty",
     "Cancel upload" : "Perus lähetys",
+    "%s of %s used" : "%s / %s käytetty",
     "%1$s%% of %2$s used" : "%1$s%%/%2$s käytetty"
 },
 "nplurals=2; plural=(n != 1);");
