@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Copier",
     "Choose target folder" : "Sélectionner le dossier cible",
     "Open" : "Ouvrir",
+    "Delete file" : "Supprimer le fichier",
+    "Delete folder" : "Supprimer le dossier",
     "Disconnect storage" : "Déconnecter ce support de stockage",
     "Unshare" : "Ne plus partager",
     "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
@@ -135,6 +137,8 @@ OC.L10N.register(
     "Unlimited" : "Illimité",
     "Upload (max. %s)" : "Envoi (max. %s)",
     "File Management" : "Gestion de fichier",
+    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
+    "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
     "%s used" : "%s utilisés",
     "%s%% of %s used" : "%s%% de %s utilisé",
     "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "Partages supprimés",
     "Text file" : "Fichier texte",
     "New text file.txt" : "Nouveau fichier texte.txt",
-    "Target folder" : "Dossier cible",
     "File handling" : "Gestion de fichiers",
     "Maximum upload size" : "Taille max. d'envoi",
     "max. possible: " : "Max. possible :",
     "Save" : "Enregistrer",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Avec PHP-FPM il peut se passer jusqu'à 5 minutes pour que les changements soient appliqués.",
     "Missing permissions to edit from here." : "Permissions insuffisantes pour modifier à partir d'ici.",
-    "%s of %s used" : "%s de %s utilisé",
     "Cancel upload" : "Annuler l'envoi",
+    "%s of %s used" : "%s de %s utilisé",
     "%1$s%% of %2$s used" : "%1$s%% de %2$s utilisés"
 },
 "nplurals=2; plural=(n > 1);");
