@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Copia",
     "Choose target folder" : "Scegli la cartella di destinazione",
     "Open" : "Apri",
+    "Delete file" : "Elimina file",
+    "Delete folder" : "Elimina cartella",
     "Disconnect storage" : "Disconnetti archiviazione",
     "Unshare" : "Rimuovi condivisione",
     "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
@@ -135,9 +137,11 @@ OC.L10N.register(
     "Unlimited" : "Illimitata",
     "Upload (max. %s)" : "Carica (massimo %s)",
     "File Management" : "Gestione dei file",
-    "%s of %s used" : "%s di %s utilizzati",
-    "%1$s%% of %2$s used" : "%1$s%% di %2$s utilizzati",
+    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
+    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
     "%s used" : "%s utilizzato",
+    "%s%% of %s used" : "%s%% di %s utilizzati",
+    "%1$s of %2$s used" : "%1$s di %2$s utilizzati",
     "Settings" : "Impostazioni",
     "Show hidden files" : "Mostra i file nascosti",
     "WebDAV" : "WebDAV",
@@ -160,7 +164,6 @@ OC.L10N.register(
     "Deleted shares" : "Condivisioni eliminate",
     "Text file" : "File di testo",
     "New text file.txt" : "Nuovo file di testo.txt",
-    "Target folder" : "Cartella di destinazione",
     "File handling" : "Gestione file",
     "Maximum upload size" : "Dimensione massima caricamento",
     "max. possible: " : "numero mass.: ",
@@ -168,6 +171,7 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
     "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
     "Cancel upload" : "Annulla caricamento",
-    "%1$s of %2$s used" : "%1$s di %2$s utilizzati"
+    "%s of %s used" : "%s di %s utilizzati",
+    "%1$s%% of %2$s used" : "%1$s%% di %2$s utilizzati"
 },
 "nplurals=2; plural=(n != 1);");
