@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopijuoti",
     "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Open" : "Atverti",
+    "Delete file" : "Ištrinti failą",
+    "Delete folder" : "Ištrinti aplanką",
     "Disconnect storage" : "Atjungti saugyklą",
     "Unshare" : "Nebesidalinti",
     "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui \"{file}\"",
@@ -135,7 +137,9 @@ OC.L10N.register(
     "Unlimited" : "Neribotai",
     "Upload (max. %s)" : "Įkelti (maks. %s)",
     "File Management" : "Failų tvarkymas",
+    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
     "%s used" : "%s panaudota",
+    "%s%% of %s used" : "naudojama %s%% iš %s",
     "%1$s of %2$s used" : "naudojama %1$s iš %2$s",
     "Settings" : "Nustatymai",
     "Show hidden files" : "Rodyti paslėptus failus",
@@ -159,15 +163,14 @@ OC.L10N.register(
     "Deleted shares" : "Ištrinti viešiniai",
     "Text file" : "Tekstinis failas",
     "New text file.txt" : "Naujas tekstinis failas.txt",
-    "Target folder" : "Paskirties aplankas",
     "File handling" : "Failų apdorojimas",
     "Maximum upload size" : "Maksimalus įkeliamo failo dydis",
     "max. possible: " : "daug. leidžiama:",
     "Save" : "Įrašyti",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Naudojant PHP-FPM, pakeitimų taikymas gali užtrukti 5 minutes.",
     "Missing permissions to edit from here." : "Draudžiama iš čia redaguoti",
-    "%s of %s used" : "naudojama %s iš %s",
     "Cancel upload" : "Atsisakyti įkėlimo",
+    "%s of %s used" : "naudojama %s iš %s",
     "%1$s%% of %2$s used" : "%1$s naudojama %% iš %2$s"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
