@@ -7,7 +7,7 @@ OC.L10N.register(
     "All files" : "Wszystkie pliki",
     "Recent" : "Ostatnie",
     "Favorites" : "Ulubione",
-    "File could not be found" : "Nie można odnaleźć pliku",
+    "File could not be found" : "Nie można znaleźć pliku",
     "Move or copy" : "Przenieś lub kopiuj",
     "Download" : "Pobierz",
     "Delete" : "Usuń",
@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopiuj",
     "Choose target folder" : "Wybierz katalog docelowy",
     "Open" : "Otwórz",
+    "Delete file" : "Usuń plik",
+    "Delete folder" : "Usuń katalog",
     "Disconnect storage" : "Odłącz magazyn",
     "Unshare" : "Zatrzymaj udostępnianie",
     "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
@@ -135,6 +137,8 @@ OC.L10N.register(
     "Unlimited" : "Brak limitu",
     "Upload (max. %s)" : "Wysyłka (max. %s)",
     "File Management" : "Zarządzanie plikami",
+    "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
+    "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
     "%s used" : "Wykorzystane: %s",
     "%s%% of %s used" : "Wykorzystane: %s%% z %s",
     "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
@@ -149,7 +153,7 @@ OC.L10N.register(
     "Select all" : "Wybierz wszystko",
     "Upload too large" : "Wysyłany plik jest za duży",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
-    "No favorites yet" : "Brak jeszcze ulubionych",
+    "No favorites yet" : "Brak ulubionych",
     "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
     "Tags" : "Etykiety",
     "Deleted files" : "Usunięte pliki",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "Usunięte współdzielenie",
     "Text file" : "Plik tekstowy",
     "New text file.txt" : "Nowy plik tekstowy.txt",
-    "Target folder" : "Katalog docelowy",
     "File handling" : "Zarządzanie plikami",
     "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
     "max. possible: " : "maks. możliwy:",
     "Save" : "Zapisz",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Z PHP-FPM zastosowanie zmian może zająć 5 minut.",
     "Missing permissions to edit from here." : "Brakuje uprawnień do edycji.",
-    "%s of %s used" : "Wykorzystano %s z %s",
     "Cancel upload" : "Anuluj wysyłanie",
+    "%s of %s used" : "Wykorzystano %s z %s",
     "%1$s%% of %2$s used" : "Wykorzystane: %1$s%% z %2$s"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
