@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Copiar",
     "Choose target folder" : "Escolher pasta destino",
     "Open" : "Abrir",
+    "Delete file" : "Excluir arquivo",
+    "Delete folder" : "Excluir pasta",
     "Disconnect storage" : "Desconectar armazenamento",
     "Unshare" : "Descompartilhar",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
@@ -135,6 +137,8 @@ OC.L10N.register(
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Envio (max. %s)",
     "File Management" : "Gerenciamento de Arquivos",
+    "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
+    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
     "%s used" : "%s usado",
     "%s%% of %s used" : "%s%% usados de %s",
     "%1$s of %2$s used" : "%1$s usado de %2$s",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "Compartilhamentos excluídos",
     "Text file" : "Arquivo texto",
     "New text file.txt" : "Novo texto file.txt",
-    "Target folder" : "Pasta destino",
     "File handling" : "Tratamento de arquivo",
     "Maximum upload size" : "Tamanho máximo para envio",
     "max. possible: " : "max. possível:",
     "Save" : "Salvar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com PHP-FPM pode demorar 5 minutos para que as alterações sejam aplicadas.",
     "Missing permissions to edit from here." : "Faltando permissões para editar aqui.",
-    "%s of %s used" : "%s de %s usado",
     "Cancel upload" : "Cancelar envio",
+    "%s of %s used" : "%s de %s usado",
     "%1$s%% of %2$s used" : "%1$s%% de %2$s usados"
 },
 "nplurals=2; plural=(n > 1);");
