@@ -32,6 +32,9 @@ OC.L10N.register(
     "Rename" : "Premenovať",
     "Copy" : "Kopírovať",
     "Choose target folder" : "Vyberte cieľový priečinok",
+    "Open" : "Otvoriť",
+    "Delete file" : "Zmazať súbor",
+    "Delete folder" : "Zmazať priečinok",
     "Disconnect storage" : "Odpojiť úložisko",
     "Unshare" : "Zneprístupniť",
     "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
@@ -134,9 +137,9 @@ OC.L10N.register(
     "Unlimited" : "Neobmedzené",
     "Upload (max. %s)" : "Nahrať (max. %s)",
     "File Management" : "Správa súborov",
-    "%s of %s used" : "Využité: %s z %s",
-    "%1$s%% of %2$s used" : "použité %1$s%% z %2$s",
     "%s used" : "%s použitých",
+    "%s%% of %s used" : "Využité %s%% z %s",
+    "%1$s of %2$s used" : "Využité: %1$s z %2$s",
     "Settings" : "Nastavenia",
     "Show hidden files" : "Zobraziť skryté súbory",
     "WebDAV" : "WebDAV",
@@ -159,7 +162,6 @@ OC.L10N.register(
     "Deleted shares" : "Vymazané zdieľania",
     "Text file" : "Textový súbor",
     "New text file.txt" : "Nový text file.txt",
-    "Target folder" : "Cieľový priečinok",
     "File handling" : "Nastavenie správania sa k súborom",
     "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
     "max. possible: " : "najväčšie možné:",
@@ -167,6 +169,7 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Použitím PHP-FPM môžu byť zmeny vykonané do 5 minút.",
     "Missing permissions to edit from here." : "Chýbajú oprávnenia pre možnosť tu upravovať.",
     "Cancel upload" : "Zrušiť nahrávanie",
-    "%1$s of %2$s used" : "Využité: %1$s z %2$s"
+    "%s of %s used" : "Využité: %s z %s",
+    "%1$s%% of %2$s used" : "použité %1$s%% z %2$s"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
