@@ -9,7 +9,7 @@ OC.L10N.register(
     "Favorites" : "Favoriter",
     "File could not be found" : "Fil kunde inte hittas",
     "Move or copy" : "Flytta eller kopiera",
-    "Download" : "Ladda ned",
+    "Download" : "Hämta",
     "Delete" : "Radera",
     "Home" : "Hem",
     "Close" : "Stäng",
@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopiera",
     "Choose target folder" : "Välj målmapp",
     "Open" : "Öppna",
+    "Delete file" : "Radera fil",
+    "Delete folder" : "Radera mapp",
     "Disconnect storage" : "Koppla bort lagring",
     "Unshare" : "Sluta dela",
     "Could not load info for file \"{file}\"" : "Kunde inte ladda information för fil \"{file}\"",
@@ -42,7 +44,7 @@ OC.L10N.register(
     "Pending" : "Väntar",
     "Unable to determine date" : "Misslyckades avgöra datum",
     "This operation is forbidden" : "Denna operation är förbjuden",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, vänligen kontrollera loggarna eller kontakta administratören",
     "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
     "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
     "copy" : "kopia",
@@ -130,11 +132,13 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil har blivit <strong>ändrad</strong> eller <strong>bytt namn</strong>",
     "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
     "A file or folder has been <strong>deleted</strong>" : "En fil eller mapp har <strong>tagits bort</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast i flödet)</em>",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa aviseringar om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast i flödet)</em>",
     "A file or folder has been <strong>restored</strong>" : "En fil eller mapp har <strong>återställts</strong>",
     "Unlimited" : "Obegränsad",
     "Upload (max. %s)" : "Ladda upp (högst %s)",
     "File Management" : "Filhantering",
+    "Error while loading the file data" : "Fel vid inläsning av filens data",
+    "Unable to change the favourite state of the file" : "Kan inte ändra filens favoritstatus",
     "%s used" : "%s använt",
     "%s%% of %s used" : "%s%% av %s använt",
     "%1$s of %2$s used" : "%1$s av %2$s använt",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "Raderade delningar",
     "Text file" : "Textfil",
     "New text file.txt" : "Ny textfil.txt",
-    "Target folder" : "Målmapp",
     "File handling" : "Filhantering",
     "Maximum upload size" : "Största storlek att ladda upp",
     "max. possible: " : "max. möjligt:",
     "Save" : "Spara",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
     "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
-    "%s of %s used" : "%s av %s använt",
     "Cancel upload" : "Avbryt uppladdning",
+    "%s of %s used" : "%s av %s använt",
     "%1$s%% of %2$s used" : "%1$s%% av %2$s använt"
 },
 "nplurals=2; plural=(n != 1);");
