@@ -70,10 +70,11 @@ OC.L10N.register(
     "Domain" : "Domaini",
     "Rackspace" : "Rackspace",
     "API key" : "API-avain",
-    "Global credentials" : "Globaalit valtuudet",
+    "Global credentials" : "Yleiset tunnistetiedot",
     "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
     "Username and password" : "Käyttäjätunnus ja salasana",
     "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
+    "Global credentials, user entered" : "Yleiset tunnistetiedot, käyttäjän syöttämät",
     "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
     "RSA public key" : "Julkinen RSA-avain",
     "Public key" : "Julkinen avain",
@@ -103,6 +104,8 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Jaa",
+    "Show hidden files" : "Näytä piilotiedostot",
+    "Timeout" : "Aikakatkaisu",
     "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
     "Username as share" : "Käyttäjänimi jakona",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -117,6 +120,7 @@ OC.L10N.register(
     "Name" : "Nimi",
     "Storage type" : "Tallennustilan tyyppi",
     "Scope" : "Näkyvyysalue",
+    "Open documentation" : "Avaa dokumentaatio",
     "Folder name" : "Kansion nimi",
     "External storage" : "Erillinen tallennustila",
     "Authentication" : "Tunnistautuminen",
@@ -126,7 +130,6 @@ OC.L10N.register(
     "Add storage" : "Lisää tallennustila",
     "Advanced settings" : "Lisäasetukset",
     "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Jotkin määritetyt erilliset liitospisteet eivät ole yhdistettynä. Napsauta punaisia rivejä saadaksesi lisätietoja",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää asentamaan puuttuva kohde."
+    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja."
 },
 "nplurals=2; plural=(n != 1);");
