@@ -1,26 +1,29 @@
 OC.L10N.register(
     "files_external",
     {
-    "External storages" : "Zunanje hrambe",
+    "External storages" : "Zunanje shrambe",
     "Personal" : "Osebno",
     "System" : "Sistem",
     "Grant access" : "Odobri dostop",
     "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
-    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo.",
+    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo PIN.",
     "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
     "Generate keys" : "Ustvari ključe",
     "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
     "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
     "(group)" : "(skupina)",
-    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost z Mac NFD šifriranjem (počasno)",
+    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost s šifriranjem Mac NFD (počasno)",
     "Enable encryption" : "Omogoči šifriranje",
-    "Enable previews" : "Omogoči predogled",
+    "Enable previews" : "Omogoči predoglede",
     "Enable sharing" : "Omogoči souporabo",
     "Check for changes" : "Preveri za spremembe",
     "Never" : "Nikoli",
     "Once every direct access" : "Enkrat ob neposrednem dostopu",
+    "Read only" : "Le za branje",
     "Delete" : "Izbriši",
     "Admin defined" : "Skrbnik je določen",
+    "Are you sure you want to delete this external storage?" : "Ali ste prepričani, da želite izbrisati to  zunanjo shrambo?",
+    "Delete storage?" : "Ali ste prepričani, da želite izbrisati shrambo?",
     "Saved" : "Shranjeno",
     "Saving..." : "Poteka shranjevanje ...",
     "Save" : "Shrani",
@@ -38,15 +41,15 @@ OC.L10N.register(
     "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
     "Invalid mount point" : "Neveljavna priklopna točka",
     "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
-    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
+    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe » %s «",
     "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa \"%s\" ni dovoljena.",
-    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve \"%s\" ni dovoljena.",
+    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve » %s « ni dovoljena.",
     "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
     "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
     "Insufficient data: %s" : "Nepopolni podatki: %s",
     "%s" : "%s",
     "Access key" : "Ključ za dostop",
-    "Secret key" : "Skriti ključ",
+    "Secret key" : "Skrivni ključ",
     "Builtin" : "Vgrajeno",
     "None" : "Brez",
     "OAuth1" : "OAuth1",
@@ -55,17 +58,23 @@ OC.L10N.register(
     "OAuth2" : "OAuth2",
     "Client ID" : "ID odjemalca",
     "Client secret" : "Skrivni ključ odjemalca",
+    "OpenStack v2" : "OpenStack v2",
     "Tenant name" : "Ime uporabnika",
     "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
+    "OpenStack v3" : "OpenStack v3",
     "Domain" : "Domena",
     "Rackspace" : "Rackspace",
     "API key" : "Ključ API",
+    "Global credentials" : "Splošna poverila",
     "Log-in credentials, save in database" : "Prijavne poverilnice, shrani v bazo",
     "Username and password" : "Uporabniško ime in geslo",
     "Log-in credentials, save in session" : "Prijavna poverila, shrani v seji",
+    "Global credentials, user entered" : "Uporabniško vpisana splošna poverila",
     "User entered, store in database" : "Uporabnik vnešen, vpis v bazo",
     "RSA public key" : "Javni ključ RSA",
     "Public key" : "Javni ključ",
+    "RSA private key" : "Zasebni ključ RSA",
+    "Private key" : "Zasebni ključ",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Pomnilniško vedro",
     "Hostname" : "Ime gostitelja",
@@ -103,7 +112,6 @@ OC.L10N.register(
     "Available for" : "Na voljo za",
     "Add storage" : "Dodaj shrambo",
     "Advanced settings" : "Napredne nastavitve",
-    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Nekatere izmed nastavljenih zunanjih priklopnih točk niso povezane. Več podrobnosti se pokaže s klikom na rdeče vrstice."
+    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
