@@ -63,7 +63,6 @@ OC.L10N.register(
     "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
     "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
     "Wrong share ID, share doesn't exist" : "Wrong share ID, share doesn't exist",
-    "could not delete share" : "could not delete share",
     "Could not delete share" : "Could not delete share",
     "Please specify a file or folder path" : "Please specify a file or folder path",
     "Wrong path, file/folder doesn't exist" : "Wrong path, file/folder doesn't exist",
@@ -88,8 +87,8 @@ OC.L10N.register(
     "Add to your Nextcloud" : "Add to your Nextcloud",
     "Share API is disabled" : "Share API is disabled",
     "File sharing" : "File sharing",
-    "Share" : "Share",
     "Sharing" : "Sharing",
+    "Share" : "Share",
     "No entries found in this folder" : "No entries found in this folder",
     "Name" : "Name",
     "Share time" : "Share time",
@@ -104,6 +103,7 @@ OC.L10N.register(
     "Upload files to %s" : "Upload files to %s",
     "Select or drop files" : "Select or drop files",
     "Uploading files…" : "Uploading files…",
-    "Uploaded files:" : "Uploaded files:"
+    "Uploaded files:" : "Uploaded files:",
+    "could not delete share" : "could not delete share"
 },
 "nplurals=2; plural=(n != 1);");
