@@ -15,16 +15,14 @@ OC.L10N.register(
     "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
     "Invalid server URL" : "URL del servidor inválido",
     "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
-    "Share" : "Compartir",
     "No expiration date set" : "No se ha establecido la fecha de expiración",
     "Shared by" : "Compartido por",
-    "Sharing" : "Compartiendo",
     "File shares" : "Archivos compartidos",
     "Downloaded via public link" : "Descargado mediante una liga pública",
     "Downloaded by {email}" : "Descargado por {email}",
     "{file} downloaded via public link" : "{file} descargado mediante una liga pública",
     "{email} downloaded {file}" : "{email} descargó {file}",
-    "Shared with group {group}" : "Compartido con el gupo {group}",
+    "Shared with group {group}" : "Compartido con el grupo {group}",
     "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
     "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
     "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
@@ -65,7 +63,6 @@ OC.L10N.register(
     "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
     "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
     "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
-    "could not delete share" : "no fue posible borrar el elemento compartido",
     "Could not delete share" : "No fue posible borrar el elemento compartido",
     "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
     "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el correo / carpeta no existe ",
@@ -85,12 +82,13 @@ OC.L10N.register(
     "Could not lock path" : "No fue posible bloquear la ruta",
     "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
     "Can't change permissions for public share links" : "No es posible cambiar los permisos para ligas públicas compartidas",
-    "Cannot increase permissions" : "No es posible incrementar los permisos",
     "shared by %s" : "compartido por %s",
     "Direct link" : "Liga directa",
     "Add to your Nextcloud" : "Agregar a tu Nextcloud",
     "Share API is disabled" : "El API para compartir está deshabilitado",
     "File sharing" : "Compartir archivos",
+    "Sharing" : "Compartiendo",
+    "Share" : "Compartir",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Name" : "Nombre",
     "Share time" : "Compartido desde",
@@ -106,9 +104,6 @@ OC.L10N.register(
     "Select or drop files" : "Selecciona o suelta los archivos",
     "Uploading files…" : "Cargando archivos...",
     "Uploaded files:" : "Archivos cargados:",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "Se presentó  una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %s",
-    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
-    "The password is wrong. Try again." : "La contraseña es incorrecta. Por favor inténtalo de nuevo.",
-    "Password" : "Contraseña"
+    "could not delete share" : "no fue posible borrar el elemento compartido"
 },
 "nplurals=2; plural=(n != 1);");
