@@ -1,21 +1,20 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with others" : "Dalinamasi su kitais ",
-    "Shared with you" : "Pasidalinta su jumis",
-    "Shared by link" : "Dalinamasi pagal nuorodą",
+    "Shared with others" : "Bendrinama su kitais",
+    "Shared with you" : "Bendrinama su jumis",
+    "Shared by link" : "Bendrinama pagal nuorodą",
     "Deleted shares" : "Ištrinti viešiniai",
-    "Shares" : "Pasidalinimai",
-    "Nothing shared with you yet" : "Niekas su jumis dar nesidalina",
-    "Files and folders others share with you will show up here" : "Čia bus rodomi failai ir aplankai, su kuriais dalijamasi su jumis",
-    "Nothing shared yet" : "Niekuo nesidalinate ",
-    "Files and folders you share will show up here" : "Čia bus rodomi bendrinami failai ir aplankai",
-    "No shared links" : "Nėra dalinimosi nuorodų",
-    "Files and folders you share by link will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos bendrinate naudodami nuorodą",
-    "No deleted shares" : "Ištrintų pasidalinimų nėra",
-    "Shares you deleted will show up here" : "Čia atsiras ištrinti pasidalinimai",
-    "No shares" : "Nėra pasidalinimų",
-    "Shares will show up here" : "Čia atsiras pasidalinimai",
+    "Shares" : "Viešiniai",
+    "Nothing shared with you yet" : "Kol kas su jumis nieko nėra bendrinama",
+    "Files and folders others share with you will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos su jumis bendrina kiti asmenys",
+    "Nothing shared yet" : "Kol kas nieko nebendrinama",
+    "Files and folders you share will show up here" : "Čia bus rodomi jūsų bendrinami failai ir aplankai",
+    "Files and folders you share by link will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos bendrinate pagal nuorodą",
+    "No deleted shares" : "Ištrintų viešinių nėra",
+    "Shares you deleted will show up here" : "Čia bus rodomi jūsų ištrinti viešiniai",
+    "No shares" : "Nėra jokių viešinių",
+    "Shares will show up here" : "Čia bus rodomi viešiniai",
     "Restore share" : "Atkurti viešinį",
     "Something happened. Unable to restore the share." : "Kažkas nutiko. Nepavyko atkurti viešinio.",
     "Move or copy" : "Perkelti ar kopijuoti",
@@ -23,11 +22,11 @@ OC.L10N.register(
     "Delete" : "Ištrinti",
     "You can upload into this folder" : "Galite įkelti į šį aplanką",
     "Terms of service" : "Naudojimosi sąlygos",
-    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
+    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
     "Invalid server URL" : "Neteisingas serverio URL adresas",
     "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "No expiration date set" : "Dalinimosi pabaigos data yra nenustatyta",
-    "Shared by" : "Pasidalino",
+    "Shared by" : "Bendrina",
     "File shares" : "Bendrinami failai",
     "Downloaded via public link" : "Atsisiųstas per viešąją nuorodą",
     "Downloaded by {email}" : "Atsisiuntė {email}",
@@ -35,7 +34,7 @@ OC.L10N.register(
     "{email} downloaded {file}" : "{email} atsisiuntė {file}",
     "Shared with group {group}" : "Pasidalinta su grupe {group}",
     "Removed share for group {group}" : "Nebesidalinama su grupe: {group}",
-    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
+    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
     "{actor} removed share for group {group}" : "{actor} nustojo dalintis su {group} grupe",
     "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
     "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
@@ -79,7 +78,6 @@ OC.L10N.register(
     "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pradėtas bendrinti iš <strong>kito serverio</strong>",
     "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas buvo <strong>pasidalintas</strong>",
     "Wrong share ID, share doesn't exist" : "Neteisingas dalinamų duomenų ID",
-    "could not delete share" : "nepavyko nustoti dalintis duomenimis",
     "Could not delete share" : "Nepavyko nustoti dalintis duomenimis",
     "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
     "Wrong path, file/folder doesn't exist" : "Neteisingas kelias, failo/aplanko nėra",
@@ -99,17 +97,19 @@ OC.L10N.register(
     "Could not lock path" : "Nepavyko užrakinti kelio",
     "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
     "Can't change permissions for public share links" : "Negalima keisti leidimų viešai bendrinamoms nuorodoms",
-    "Cannot increase permissions" : "Negalima pridėti papildomų leidimų",
     "shared by %s" : "pasidalino %s",
     "Download all files" : "Atsisiųsti visus failus ",
     "Direct link" : "Tiesioginė nuoroda",
     "Add to your Nextcloud" : "Pridėti į jūsų NextCloud",
     "Share API is disabled" : "Bendrinimo API yra išjungtas",
     "File sharing" : "Failų pasidalinimas",
+    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Cancel" : "Atsisakyti",
+    "No elements found." : "Nerasta jokių elementų.",
+    "Sharing" : "Bendrinimas",
     "Link to a file" : "Nuoroda į failą",
     "Shared" : "Pasidalinta",
     "Share" : "Dalintis",
-    "Sharing" : "Bendrinimas",
     "No entries found in this folder" : "Šiame aplanke įrašų nerasta",
     "Name" : "Pavadinimas",
     "Share time" : "Bendrinimo laikas",
@@ -129,6 +129,6 @@ OC.L10N.register(
     "Uploading files…" : "Įkeliami failai…",
     "Uploaded files:" : "Įkelti failai:",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "Įkeldami failus, sutinkate su %1$snaudojimosi sąlygomis%2$s.",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "%s dalinimasis nepavyko, nes sistema nepalaiko šio duomenų tipo: %s"
+    "could not delete share" : "nepavyko nustoti dalintis duomenimis"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
