@@ -16,40 +16,45 @@ OC.L10N.register(
     "No shares" : "Brez souporabe",
     "Shares will show up here" : "Predmeti v souporabi bodo prikazani na tem mestu.",
     "Download" : "Prejmi",
-    "You can upload into this folder" : "V to mapo je dovoljeno poslati datoteke",
+    "Delete" : "Izbriši",
+    "You can upload into this folder" : "V to mapo je dovoljeno pošiljati datoteke",
     "Invalid server URL" : "Neveljaven URL strežnika",
-    "Share" : "Souporaba",
     "No expiration date set" : "Datum poteka ni določen",
     "Shared by" : "V souporabi z",
-    "Sharing" : "Souporaba",
     "File shares" : "Datoteke v souporabi",
-    "Downloaded via public link" : "Prejeto preko javne povezave",
+    "Downloaded via public link" : "Prejeto prek javne povezave",
+    "{file} downloaded via public link" : "Datoteka {file} je prejeta prek javne povezave",
     "Removed public link" : "Javno povezava je odstranjena",
     "Public link expired" : "Javna povezava je potekla",
+    "You removed public link for {file}" : "Odstranite povezavo do datoteke {file}",
+    "{user} accepted the remote share" : "Uporabnik {user} potrdi oddaljeno souporabo",
+    "{user} accepted the remote share of {file}" : "Uporabnik {user} potrdi oddaljeno souporabo {file}",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Datoteko oziroma mapo v souporabi prek elektronske pošte oziroma javne povezave je uporabnik <strong>prejel na svoj krajevni disk</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Datoteka ali mapa je bila dodana v souporabo prek <strong>drugega strežnika</strong>",
-    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>.",
+    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>",
     "Wrong share ID, share doesn't exist" : "Napačen ID mesta uporabe; mesto ne obstaja!",
     "Could not delete share" : "Tega predmeta v souporabi ni mogoče izbrisati.",
     "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
     "Wrong path, file/folder doesn't exist" : "Napačna pot; datoteka ali mapa ne obstaja",
+    "Could not create share" : "Mesta souporabe ni mogoče ustvariti",
     "invalid permissions" : "neustrezna dovoljenja",
     "Please specify a valid user" : "Navesti je treba veljavnega uporabnika.",
     "Group sharing is disabled by the administrator" : "Skupinska souporaba je skrbniško onemogočena",
     "Please specify a valid group" : "Navesti je treba veljavno skupino",
     "Public link sharing is disabled by the administrator" : "Souporaba prek javne povezave je skrbniško onemogočena",
     "Public upload disabled by the administrator" : "Javno pošiljanje v oblak je skrbniško onemogočeno",
-    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za javne mape v skupni rabi.",
+    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za mape v javni skupni rabi.",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
     "Unknown share type" : "Neznana vrsta mesta souporabe",
     "Not a directory" : "Predmet ni mapa",
     "Could not lock path" : "Poti ni mogoče zakleniti",
     "Wrong or no update parameter given" : "Parameter posodobitve ni podan ali pa je navedena napačna vrednost",
     "Can't change permissions for public share links" : "Za javne povezave souporabe, spreminjanje dovoljenj ni mogoče.",
-    "Cannot increase permissions" : "Ni mogoče povišati dovoljenj",
     "Direct link" : "Neposredna povezava",
     "Add to your Nextcloud" : "Dodaj v svoj Nextcloud",
     "Share API is disabled" : "Vmesnik API za souporabo je onemogočen",
+    "Share" : "Souporaba",
+    "Sharing" : "Souporaba",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Name" : "Ime",
     "Share time" : "Čas souporabe",
@@ -65,9 +70,6 @@ OC.L10N.register(
     "Select or drop files" : "Izberi ali povleci datoteke",
     "Uploading files…" : "Poteka pošiljanje datotek ...",
     "Uploaded files:" : "Poslane datoteke:",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "Deljenje %s ni uspelo ker sistem ne dovoli souporabe za tip %s",
-    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
-    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
-    "Password" : "Geslo"
+    "could not delete share" : "mesta souporabe ni mogoče ustvariti"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
