@@ -73,7 +73,6 @@ OC.L10N.register(
     "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
     "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
     "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
-    "could not delete share" : "無法刪除分享",
     "Could not delete share" : "無法刪除分享",
     "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
     "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
@@ -99,8 +98,9 @@ OC.L10N.register(
     "Add to your Nextcloud" : "加入到您的 Nextcloud",
     "Share API is disabled" : "分享 API 已停用",
     "File sharing" : "檔案分享",
-    "Share" : "分享",
+    "Searching..." : "正在搜尋 ...",
     "Sharing" : "分享",
+    "Share" : "分享",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
     "Name" : "名稱",
     "Share time" : "分享時間",
@@ -117,6 +117,6 @@ OC.L10N.register(
     "Select or drop files" : "選擇或拖曳檔案至此",
     "Uploading files…" : "上傳檔案中…",
     "Uploaded files:" : "已上傳的檔案：",
-    "Sharing %s failed because the back end does not allow shares from type %s" : "分享 %s 失敗，因為後端不允許來自 %s 類型的分享"
+    "could not delete share" : "無法刪除分享"
 },
 "nplurals=1; plural=0;");
