@@ -13,9 +13,6 @@ OC.L10N.register(
     "Select all" : "Esbillar too",
     "Name" : "Nome",
     "Deleted" : "Desanicióse",
-    "Delete" : "Desaniciar",
-    "Couldn't delete %s permanently" : "Nun pudo desaniciase dafechu %s",
-    "Couldn't restore %s" : "Nun pudo restaurase %s",
-    "Error" : "Fallu"
+    "Delete" : "Desaniciar"
 },
 "nplurals=2; plural=(n != 1);");
