@@ -13,9 +13,6 @@ OC.L10N.register(
     "Select all" : "Seleccionar todo",
     "Name" : "Nombre",
     "Deleted" : "Borrado",
-    "Delete" : "Borrar",
-    "Couldn't delete %s permanently" : "No fue posible borrar %s de manera permanente",
-    "Couldn't restore %s" : "No se pudo restaurar %s",
-    "Error" : "Error"
+    "Delete" : "Borrar"
 },
 "nplurals=2; plural=(n != 1);");
