@@ -4,7 +4,6 @@ OC.L10N.register(
     "Versions" : "Versi",
     "Failed to revert {file} to revision {timestamp}." : "Gagal mengembalikan {file} ke revisi {timestamp}.",
     "_%n byte_::_%n bytes_" : ["%n bytes"],
-    "Restore" : "Pulihkan",
-    "Could not revert: %s" : "Tidak dapat mengembalikan: %s"
+    "Restore" : "Pulihkan"
 },
 "nplurals=1; plural=0;");
