@@ -2,13 +2,10 @@ OC.L10N.register(
     "files_versions",
     {
     "Versions" : "版本",
+    "This application automatically maintains older versions of files that are changed." : "本應用程式會自動保存修改前舊版本的檔案",
     "Failed to revert {file} to revision {timestamp}." : "無法還原檔案 {file} 至版本 {timestamp}",
     "_%n byte_::_%n bytes_" : ["%n bytes"],
     "Restore" : "復原",
-    "No other versions available" : "沒有其他版本了",
-    "This application automatically maintains older versions of files that are changed." : "本應用程式會自動保存修改前舊版本的檔案",
-    "Could not revert: %s" : "無法還原：%s",
-    "No earlier versions available" : "沒有更早的版本了",
-    "More versions …" : "更多版本…"
+    "No other versions available" : "沒有其他版本了"
 },
 "nplurals=1; plural=0;");
