@@ -5,9 +5,7 @@ OC.L10N.register(
     "Desktop client" : "نرم افزار دسکتاپ",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
-    "Access files via WebDAV" : "دسترسی فایل ها از طریق WebDAV",
     "Connect your desktop apps to %s" : "اتصال برنامه دسکتاب خود به %s",
-    "Connect your Calendar" : "اتصال تقویم خودتان",
-    "Connect your Contacts" : "اتصال مخاطبان شما"
+    "Access files via WebDAV" : "دسترسی فایل ها از طریق WebDAV"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n > 1);");
