@@ -23,14 +23,14 @@
 
 namespace OCA\FirstRunWizard\AppInfo;
 
+use OCA\FirstRunWizard\Notification\AppHint;
 use OCA\FirstRunWizard\Notification\Notifier;
 use OCP\AppFramework\App;
+use OCP\AppFramework\Http\TemplateResponse;
 use OCP\IConfig;
 use OCP\IL10N;
-use OCP\IRequest;
 use OCP\IUser;
 use OCP\IUserSession;
-use OCP\Util;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 
 class Application extends App {
@@ -51,13 +51,12 @@ class Application extends App {
 	}
 
 	protected function registerScripts() {
-		/* Always load scripts and styles since we need those for the about menu */
-		\OC_Util::addStyle('firstrunwizard', 'firstrunwizard');
-		\OC_Util::addScript('firstrunwizard', 'jquery.colorbox');
-		\OC_Util::addScript('firstrunwizard', 'firstrunwizard');
-
 		/** @var EventDispatcherInterface $dispatcher */
-		$dispatcher = $this->getContainer()->query(EventDispatcherInterface::class);
+		$dispatcher = $this->getContainer()->getServer()->getEventDispatcher();
+
+		$dispatcher->addListener(TemplateResponse::EVENT_LOAD_ADDITIONAL_SCRIPTS_LOGGEDIN, function() {
+			\OC_Util::addScript('firstrunwizard', 'about');
+		});
 
 		// Display the first run wizard only on the files app,
 		$dispatcher->addListener('OCA\Files::loadAdditionalScripts', function() {
@@ -71,7 +70,7 @@ class Application extends App {
 
 			/** @var IConfig $config */
 			$config = $this->getContainer()->query(IConfig::class);
-
+			$appHint = $this->getContainer()->query(AppHint::class);
 
 			if ($config->getUserValue($user->getUID(), 'firstrunwizard', 'show', '1') !== '0') {
 				\OC_Util::addScript('firstrunwizard', 'activate');
@@ -79,18 +78,15 @@ class Application extends App {
 				$jobList = $this->getContainer()->getServer()->getJobList();
 				$jobList->add('OCA\FirstRunWizard\Notification\BackgroundJob', ['uid' => $userSession->getUser()->getUID()]);
 			}
+			$appHint->sendAppHintNotifications();
 		});
 	}
 
 	protected function registerNotificationNotifier() {
-		$this->getContainer()->getServer()->getNotificationManager()->registerNotifier(function() {
-			return $this->getContainer()->query(Notifier::class);
-		}, function() {
-			$l = $this->getContainer()->query(IL10N::class);
-			return [
-				'id' => 'firstrunwizard',
-				'name' => $l->t('First run wizard'),
-			];
-		});
+		$this->getContainer()->getServer()->getNotificationManager()->registerNotifierService(Notifier::class);
+
+		/** @var AppHint $appHint */
+		$appHint = $this->getContainer()->query(AppHint::class);
+		$appHint->registerAppListener();
 	}
 }
