@@ -74,9 +74,9 @@ OC.L10N.register(
     "Add to your Nextcloud" : "Adder a tu Nextcloud",
     "This share is password-protected" : "Iste compartimento es protegite per contrasigno",
     "The password is wrong. Try again." : "Le contrasigno es incorrecte. Tenta de novo.",
+    "Cancel upload" : "Cancellar incarga",
     "Sort by name" : "Ordinar per nomine",
     "Sort by date" : "Ordinar per data",
-    "Cancel upload" : "Cancellar incarga",
     "Album information" : "Information del Album",
     "File list" : "Lista del files",
     "Sorry, this file could not be found." : "Pardono, il es impossibile trovar iste file.",
@@ -97,7 +97,6 @@ OC.L10N.register(
     "the link has expired" : "le ligamine ha expirate",
     "sharing is disabled" : "le compartimento de files es disactivate",
     "For more information, please ask the person who has sent you this link." : "Pro obtener plus informationes, per favor demanda le persona qui ha te inviate iste ligamine.",
-    "Picture view" : "Visualisation de Imagine",
-    "New" : "Nove"
+    "Picture view" : "Visualisation de Imagine"
 },
 "nplurals=2; plural=(n != 1);");
