@@ -2,20 +2,24 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Chyba při analýze záznamu událostí",
-    "Cased by " : "Zastaralé",
     "Copy" : "Zkopírovat",
     "Copy raw" : "Zkopírovat tak, jak je (raw)",
     "Copy formatted" : "Zkopírovat včetně formátu",
     "No server logs" : "Žádné záznamy událostí ze serveru",
     "One or more entries are hidden by the log level filter" : "Jeden nebo více záznamů je skryto filtrem úrovně protokolu",
     "Everything is working fine" : "Všechno funguje správně",
+    "Level" : "Úroveň",
+    "App" : "Aplikace",
+    "Message" : "Zpráva",
+    "Time" : "Čas",
     "Log levels" : "Stupně podrobností záznamu událostí",
     "Log content" : "Obsah záznamu událostí",
-    "Live update" : "Živá aktualizace",
+    "Live update" : "Aktualizace za provozu",
     "Download logs" : "Stáhnout záznamy událostí",
     "Logging" : "Zaznamenávání událostí",
     "Log Reader" : "Čtečka protokolů",
     "A log reader for Nextcloud" : "Čtečka záznamů událostí (log) pro Nextcloud",
-    "Log reader for Nextcloud" : "Čtečka záznamů událostí pro Nextcloud"
+    "Log reader for Nextcloud" : "Čtečka záznamů událostí pro Nextcloud",
+    "Cased by " : "Zastaralé"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
