@@ -2,13 +2,16 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Eraro dum analizo de protokolo",
-    "Cased by " : "Kaŭzita de ",
     "Copy" : "Kopii",
     "Copy raw" : "Kopii krude",
     "Copy formatted" : "Kopii aranĝite",
     "No server logs" : "Neniu servila protokolo",
     "One or more entries are hidden by the log level filter" : "Unu aŭ pliaj elementoj estas kaŝita pro protokolnivela filtrado",
     "Everything is working fine" : "Ĉio bone funkcias",
+    "Level" : "Nivelo",
+    "App" : "Aplikaĵo",
+    "Message" : "Mesaĝo",
+    "Time" : "Dato",
     "Log levels" : "Protokolniveloj",
     "Log content" : "Protokolenhavo",
     "Live update" : "Tuj montri novajn erojn",
@@ -16,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Protokolo",
     "Log Reader" : "Protokola legilo",
     "A log reader for Nextcloud" : "Protokola legilo por Nextcloud",
-    "Log reader for Nextcloud" : "Protokola legilo por Nextcloud"
+    "Log reader for Nextcloud" : "Protokola legilo por Nextcloud",
+    "Cased by " : "Kaŭzita de "
 },
 "nplurals=2; plural=(n != 1);");
