@@ -2,13 +2,16 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Napló feldolgozási hiba",
-    "Cased by " : "Létrehozta",
     "Copy" : "Másolás",
     "Copy raw" : "Másolás eredeti formába",
     "Copy formatted" : "Másolás formázva",
     "No server logs" : "Nincsenek kiszolgálónaplók",
     "One or more entries are hidden by the log level filter" : "Egy vagy több bejegyzés elrejtve a naplózási szint szűrő miatt",
     "Everything is working fine" : "Minden rendben működik",
+    "Level" : "Szint",
+    "App" : "Alkalmazás",
+    "Message" : "Üzenet",
+    "Time" : "Idő",
     "Log levels" : "Naplózási szintek",
     "Log content" : "Naplótartalom",
     "Live update" : "Élő frissítés",
@@ -16,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Naplózás",
     "Log Reader" : "Naplóolvasó",
     "A log reader for Nextcloud" : "Egy naplóolvasó a Nextcloudhoz",
-    "Log reader for Nextcloud" : "Naplóolvasó a Nextcloudhoz"
+    "Log reader for Nextcloud" : "Naplóolvasó a Nextcloudhoz",
+    "Cased by " : "Létrehozta"
 },
 "nplurals=2; plural=(n != 1);");
