@@ -2,20 +2,20 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Villa við að þátta annál",
-    "Cased by " : "Flokkað af",
-    "Log levels" : "Annálsstig",
-    "Log content" : "Efni atvikaskrár",
-    "Live update" : "Uppfærsla í beinni",
-    "Download logs" : "Sækja annála",
     "Copy" : "Afrita",
     "Copy raw" : "Afrita hrátt",
     "Copy formatted" : "Afrita sniðið",
     "No server logs" : "Engir annálar netþjóna",
     "One or more entries are hidden by the log level filter" : "Ein eða fleiri færslur eru faldar vegna síunar á stigi atvikaskráningar",
     "Everything is working fine" : "Allt virkar eins og á að sér",
+    "Log levels" : "Annálsstig",
+    "Log content" : "Efni atvikaskrár",
+    "Live update" : "Uppfærsla í beinni",
+    "Download logs" : "Sækja annála",
     "Logging" : "Atvikaskráning",
     "Log Reader" : "Annálalesari",
     "A log reader for Nextcloud" : "Atvikaskráalesari fyrir Nextcloud",
-    "Log reader for Nextcloud" : "Atvikaskráalesari fyrir Nextcloud"
+    "Log reader for Nextcloud" : "Atvikaskráalesari fyrir Nextcloud",
+    "Cased by " : "Flokkað af"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
