@@ -2,13 +2,16 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Errore durante l'elaborazione dei log",
-    "Cased by " : "Racchiuso tra",
     "Copy" : "Copia",
     "Copy raw" : "Copia grezza",
     "Copy formatted" : "Copia formattata",
     "No server logs" : "Nessun log del server",
     "One or more entries are hidden by the log level filter" : "Uns o più voci sono nascoste dal filtro del livello di registrazione",
     "Everything is working fine" : "Tutto funziona correttamente",
+    "Level" : "Livello",
+    "App" : "Applicazione",
+    "Message" : "Messaggio",
+    "Time" : "Ora",
     "Log levels" : "Livelli di log",
     "Log content" : "Contenuto dei log",
     "Live update" : "Aggiornamento in diretta",
@@ -16,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Registrazione",
     "Log Reader" : "Lettore dei log",
     "A log reader for Nextcloud" : "Un lettore di log per Nextcloud",
-    "Log reader for Nextcloud" : "Lettore di log per Nextcloud"
+    "Log reader for Nextcloud" : "Lettore di log per Nextcloud",
+    "Cased by " : "Racchiuso tra"
 },
 "nplurals=2; plural=(n != 1);");
