@@ -2,19 +2,24 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "ログ解析失敗",
-    "Cased by " : "ケース",
-    "Log levels" : "ログレベル",
-    "Log content" : "ログ情報",
-    "Live update" : "ライブアップデート",
-    "Download logs" : "ログのダウンロード",
     "Copy" : "コピー",
+    "Copy raw" : "そのままコピー",
     "Copy formatted" : "フォーマット済みのコピー",
     "No server logs" : "サーバーログがありません",
     "One or more entries are hidden by the log level filter" : "ログレベルでフィルタリングされている行があります",
     "Everything is working fine" : "問題ありません",
+    "Level" : "レベル",
+    "App" : "アプリ",
+    "Message" : "メッセージ",
+    "Time" : "時間",
+    "Log levels" : "ログレベル",
+    "Log content" : "ログ情報",
+    "Live update" : "ライブアップデート",
+    "Download logs" : "ログのダウンロード",
     "Logging" : "ログ",
     "Log Reader" : "ログリーダー",
     "A log reader for Nextcloud" : "NextCloudのためのログリーダー",
-    "Log reader for Nextcloud" : "NextCloudのためのログリーダー"
+    "Log reader for Nextcloud" : "NextCloudのためのログリーダー",
+    "Cased by " : "ケース"
 },
 "nplurals=1; plural=0;");
