@@ -2,7 +2,6 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Błąd w trakcie przetwarzania loga",
-    "Cased by " : "Spowodowane przez",
     "Copy" : "Kopiuj",
     "Copy raw" : "Kopiuj raw",
     "Copy formatted" : "Kopiuj sformatowany",
@@ -20,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Dziennik zdarzeń",
     "Log Reader" : "Czytnik logów",
     "A log reader for Nextcloud" : "Czytnik logów dla Nextcloud",
-    "Log reader for Nextcloud" : "Czytnik logów dla Nextcloud"
+    "Log reader for Nextcloud" : "Czytnik logów dla Nextcloud",
+    "Cased by " : "Spowodowane przez"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
