@@ -2,13 +2,16 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Registro de análise de erros",
-    "Cased by " : "Revestido por",
     "Copy" : "Copiar",
     "Copy raw" : "Copia básica",
     "Copy formatted" : "Cópia formatada",
     "No server logs" : "Sem registros no servidor",
     "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
     "Everything is working fine" : "Tudo está funcionando bem",
+    "Level" : "Nível",
+    "App" : "Aplicativo",
+    "Message" : "Mensagem",
+    "Time" : "Hora",
     "Log levels" : "Níveis de registro",
     "Log content" : "Conteúdo do registro",
     "Live update" : "Atualização ao vivo",
@@ -16,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Registro",
     "Log Reader" : "Leitor de Registro",
     "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
-    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud"
+    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud",
+    "Cased by " : "Revestido por"
 },
 "nplurals=2; plural=(n > 1);");
