@@ -8,11 +8,18 @@ OC.L10N.register(
     "No server logs" : "Inga serverloggar",
     "One or more entries are hidden by the log level filter" : "En eller flera poster är gömda av loggningsnivåfiltret",
     "Everything is working fine" : "Allting fungerar fint",
+    "Level" : "Nivå",
+    "App" : "App",
+    "Message" : "Meddelande",
+    "Time" : "Tid",
     "Log levels" : "Loggnivåer",
     "Log content" : "Logginnehåll",
     "Live update" : "Live-uppdatering",
     "Download logs" : "Ladda ner loggar",
     "Logging" : "Loggar",
-    "Log Reader" : "Loggläsare"
+    "Log Reader" : "Loggläsare",
+    "A log reader for Nextcloud" : "En loggläsare för Nextcloud",
+    "Log reader for Nextcloud" : "Loggläsare för Nextcloud",
+    "Cased by " : "Orsakat av"
 },
 "nplurals=2; plural=(n != 1);");
