@@ -2,13 +2,16 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "Günlük işlenirken sorun çıktı",
-    "Cased by " : "Dosyalayan",
     "Copy" : "Kopyala",
     "Copy raw" : "Ham olarak kopyala",
     "Copy formatted" : "Biçim ile kopyala",
     "No server logs" : "Herhangi bir sunucu günlüğü yok",
     "One or more entries are hidden by the log level filter" : "Bir ya da bir kaç kayıt günlük düzeyi süzgeci ile gizlenmiş",
     "Everything is working fine" : "Her şey sorunsuz çalışıyor",
+    "Level" : "Düzey",
+    "App" : "Uygulama",
+    "Message" : "İleti",
+    "Time" : "Zaman",
     "Log levels" : "Günlük düzeyleri",
     "Log content" : "Günlük içeriği",
     "Live update" : "Canlı güncelleme",
@@ -16,6 +19,7 @@ OC.L10N.register(
     "Logging" : "Günlükleme",
     "Log Reader" : "Günlük Okuyucu",
     "A log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
-    "Log reader for Nextcloud" : "Nextcloud günlük okuyucusu"
+    "Log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
+    "Cased by " : "Dosyalayan"
 },
 "nplurals=2; plural=(n > 1);");
