@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Nextcloud announcements" : "Nextcloud oznámení",
     "Nextcloud announcement" : "Oznámení ohledně Nextcloud",
+    "Disable announcements" : "Vypnout oznamování",
+    "(These announcements are only shown to administrators)" : "(Tato oznámení jsou zobrazována pouze správcům)",
     "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Oznámení z projektu Nextcloud přinášejí nejnovější zprávy o dění v něm do vašich oznámení",
     "Shows the latest news of Nextcloud in your notifications." : "Zobrazuje novinky o Nextcloudu ve vašich oznámeních.",
     "These groups will be notified about the announcements." : "Tyto skupiny budou upozorněny na oznámení."
