@@ -24,7 +24,7 @@ namespace OCA\Notifications\AppInfo;
 use OC\Authentication\Token\IProvider;
 use OCA\Notifications\App;
 use OCA\Notifications\Capabilities;
-use OCA\Notifications\Controller\EndpointController;
+use OCA\Notifications\Notifier\AdminNotifications;
 use OCP\AppFramework\IAppContainer;
 use OCP\Util;
 
@@ -41,30 +41,37 @@ class Application extends \OCP\AppFramework\App {
 		});
 	}
 
-	public function register() {
+	public function register(): void {
 		$this->registerNotificationApp();
+		$this->registerAdminNotifications();
 		$this->registerUserInterface();
 	}
 
-	protected function registerNotificationApp() {
-		$container = $this->getContainer();
-		$container->getServer()->getNotificationManager()->registerApp(function() use($container) {
-			return $container->query(App::class);
-		});
+	protected function registerNotificationApp(): void {
+		$this->getContainer()
+			->getServer()
+			->getNotificationManager()
+			->registerApp(App::class);
+	}
+	protected function registerAdminNotifications(): void {
+		$this->getContainer()
+			->getServer()
+			->getNotificationManager()
+			->registerNotifierService(AdminNotifications::class);
 	}
 
-	protected function registerUserInterface() {
+	protected function registerUserInterface(): void {
 		// Only display the app on index.php except for public shares
 		$server = $this->getContainer()->getServer();
 		$request = $server->getRequest();
 
 		if ($server->getUserSession()->getUser() !== null
-			&& substr($request->getScriptName(), 0 - strlen('/index.php')) === '/index.php'
-			&& substr($request->getPathInfo(), 0, strlen('/s/')) !== '/s/'
-			&& substr($request->getPathInfo(), 0, strlen('/login/')) !== '/login/') {
-			Util::addScript('notifications', 'merged');
+			&& strpos($request->getPathInfo(), '/s/') !== 0
+			&& strpos($request->getPathInfo(), '/login/') !== 0
+			&& substr($request->getScriptName(), 0 - \strlen('/index.php')) === '/index.php') {
+
+			Util::addScript('notifications', 'notifications');
 			Util::addStyle('notifications', 'styles');
 		}
-
 	}
 }
