@@ -66,7 +66,7 @@ class Push {
 		$this->log = $log;
 	}
 
-	public function pushToDevice(int $id, INotification $notification) {
+	public function pushToDevice(int $id, INotification $notification): void {
 		$user = $this->userManager->get($notification->getUser());
 		if (!($user instanceof IUser)) {
 			return;
@@ -170,6 +170,76 @@ class Push {
 		}
 	}
 
+	public function pushDeleteToDevice(string $userId, int $notificationId): void {
+		$user = $this->userManager->get($userId);
+		if (!($user instanceof IUser)) {
+			return;
+		}
+
+		$devices = $this->getDevicesForUser($userId);
+		if (empty($devices)) {
+			return;
+		}
+
+		$userKey = $this->keyManager->getKey($user);
+		$pushNotifications = [];
+		foreach ($devices as $device) {
+			try {
+				$payload = json_encode($this->encryptAndSignDelete($userKey, $device, $notificationId));
+
+				$proxyServer = rtrim($device['proxyserver'], '/');
+				if (!isset($pushNotifications[$proxyServer])) {
+					$pushNotifications[$proxyServer] = [];
+				}
+				$pushNotifications[$proxyServer][] = $payload;
+			} catch (InvalidTokenException $e) {
+				// Token does not exist anymore, should drop the push device entry
+				$this->deletePushToken($device['token']);
+			} catch (\InvalidArgumentException $e) {
+				// Failed to encrypt message for device: public key is invalid
+				$this->deletePushToken($device['token']);
+			}
+		}
+
+		if (empty($pushNotifications)) {
+			return;
+		}
+
+		$client = $this->clientService->newClient();
+		foreach ($pushNotifications as $proxyServer => $notifications) {
+			try {
+				$response = $client->post($proxyServer . '/notifications', [
+					'body' => [
+						'notifications' => $notifications,
+					],
+				]);
+			} catch (\Exception $e) {
+				$this->log->logException($e, [
+					'app' => 'notifications',
+					'level' => $e->getCode() === Http::STATUS_BAD_REQUEST ? ILogger::INFO : ILogger::WARN,
+				]);
+				continue;
+			}
+
+			$status = $response->getStatusCode();
+			if ($status !== Http::STATUS_OK && $status !== Http::STATUS_SERVICE_UNAVAILABLE) {
+				$body = $response->getBody();
+				$this->log->error('Could not send notification to push server [{url}]: {error}',[
+					'error' => \is_string($body) ? $body : 'no reason given',
+					'url' => $proxyServer,
+					'app' => 'notifications',
+				]);
+			} else if ($status === Http::STATUS_SERVICE_UNAVAILABLE && $this->config->getSystemValue('debug', false)) {
+				$body = $response->getBody();
+				$this->log->debug('Could not send notification to push server [{url}]: {error}',[
+					'error' => \is_string($body) ? $body : 'no reason given',
+					'url' => $proxyServer,
+					'app' => 'notifications',
+				]);
+			}
+		}
+	}
+
 	/**
 	 * @param Key $userKey
 	 * @param array $device
@@ -197,6 +267,8 @@ class Push {
 		$dataLength = 245 - strlen(json_encode($data));
 		if (strlen($subject) > $dataLength) {
 			$data['subject'] = substr($subject, 0, $dataLength) . '…';
+		} else {
+			$data['subject'] = $subject;
 		}
 
 		if ($isTalkNotification) {
@@ -223,6 +295,47 @@ class Push {
 		];
 	}
 
+	/**
+	 * @param Key $userKey
+	 * @param array $device
+	 * @param int $id
+	 * @return array
+	 * @throws InvalidTokenException
+	 * @throws \InvalidArgumentException
+	 */
+	protected function encryptAndSignDelete(Key $userKey, array $device, int $id): array {
+		// Check if the token is still valid...
+		$this->tokenProvider->getTokenById($device['token']);
+
+		if ($id === 0) {
+			$data = [
+				'delete-all' => true,
+			];
+		} else {
+			$data = [
+				'nid' => $id,
+				'delete' => true,
+			];
+		}
+
+		if (!openssl_public_encrypt(json_encode($data), $encryptedSubject, $device['devicepublickey'], OPENSSL_PKCS1_PADDING)) {
+			$this->log->error(openssl_error_string(), ['app' => 'notifications']);
+			throw new \InvalidArgumentException('Failed to encrypt message for device');
+		}
+
+		openssl_sign($encryptedSubject, $signature, $userKey->getPrivate(), OPENSSL_ALGO_SHA512);
+		$base64EncryptedSubject = base64_encode($encryptedSubject);
+		$base64Signature = base64_encode($signature);
+
+		return [
+			'deviceIdentifier' => $device['deviceidentifier'],
+			'pushTokenHash' => $device['pushtokenhash'],
+			'subject' => $base64EncryptedSubject,
+			'signature' => $base64Signature,
+			'priority' => 'normal',
+		];
+	}
+
 	/**
 	 * @param string $uid
 	 * @return array[]
