@@ -5,11 +5,12 @@ OC.L10N.register(
     "OAuth 2.0" : "OAuth 2.0",
     "OAuth 2.0 clients" : "לקוחות OAuth 2.0",
     "Name" : "שם",
-    "Client Identifier" : "זיהוי לקו",
-    "Add client" : "הוספת לקוחי",
-    "OAuth 2.0 allows external services to request access to %s." : "OAuth 2.0 מאפשר לשירותים חיצוניים לבקש גישה אל %s.",
     "Redirection URI" : "כתובת הפנייה",
+    "Client Identifier" : "זיהוי לקו",
     "Secret" : "סוד",
-    "Add" : "הוספה"
+    "Add client" : "הוספת לקוחי",
+    "Add" : "הוספה",
+    "Show client secret" : "הצגת סוד לקוח",
+    "Delete" : "מחיקה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
