@@ -11,6 +11,6 @@ OC.L10N.register(
     "Secret" : "Tajný kľúč",
     "Add client" : "Pridať klienta",
     "Add" : "Pridať",
-    "OAuth 2.0 allows external services to request access to %s." : "OAuth 2.0 umožňuje externým službám vyžiadať prístup k %s."
+    "Delete" : "Zmazať"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
