@@ -11,29 +11,31 @@ OC.L10N.register(
     "Links" : "Estekak",
     "Federated sent" : "Bidalitako federatuak",
     "Federated received" : "Jasotako federatuak",
-    "Last 24 hours" : "Azken 24 orduak",
-    "Last 1 hour" : "Azken ordu 1",
-    "Last 5 mins" : "Azken 5 minutuak",
     "Copy" : "Kopiatu",
     "Copied!" : "Kopiatua!",
     "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
-    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kpiatzeko.",
+    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
     "Monitoring" : "Jarraipena",
-    "CPU load" : "CPU erabilera",
-    "Memory usage" : "Memoria erabilera",
+    "Files:" : "Fitxategiak:",
     "Active users" : "Erabiltzaile aktiboak",
     "Shares" : "Partekatutakoak",
-    "Storage" : "Biltegiratzea",
-    "Users:" : "Erabiltzaileak:",
-    "Files:" : "Fitxategiak:",
-    "Version:" : "Bertsioa:",
     "PHP" : "PHP",
+    "Version:" : "Bertsioa:",
     "Memory Limit:" : "Memoria muga:",
     "Max Execution Time:" : "Gehienezko exekuzio denbora:",
     "Upload max size:" : "Igotzeko gehienezko tamaina:",
     "Database" : "Datu-basea",
     "Type:" : "Mota:",
     "Size:" : "Tamaina:",
-    "External monitoring tool" : "Kanpo jarraipen tresna"
+    "External monitoring tool" : "Kanpo jarraipen tresna",
+    "Last 24 hours" : "Azken 24 orduak",
+    "Last 1 hour" : "Azken ordu 1",
+    "Last 5 mins" : "Azken 5 minutuak",
+    "CPU load" : "CPU erabilera",
+    "Memory usage" : "Memoria erabilera",
+    "Storage" : "Biltegiratzea",
+    "Users:" : "Erabiltzaileak:",
+    "Nextcloud" : "Nextcloud",
+    "Apps installed:" : "Instalatutako aplikazioak:"
 },
 "nplurals=2; plural=(n != 1);");
