@@ -10,20 +10,48 @@ OC.L10N.register(
     "Users" : "Felhasználók",
     "Groups" : "Csoportok",
     "Links" : "Hivatkozások",
+    "Mails" : "Levelek",
     "Federated sent" : "Küldött egyesítés",
     "Federated received" : "Fogadott egyesítés",
+    "24 hours" : "24 óra",
+    "1 hour" : "1 óra",
+    "5 mins" : "5 perc",
     "Copy" : "Másolás",
     "Copied!" : "Másolva!",
     "Not supported!" : "Nem támogatott!",
     "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
     "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
+    "System" : "Rendszer",
     "Monitoring" : "Megfigyelés",
     "Monitoring app with useful server information" : "Monitorozó alkalmazás hasznos szerver információkkal",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Hasznos szerver információk szolgáltatása, mint a CPU terhelés, RAM foglaltság, felhasználók száma, stb.",
+    "Operating System" : "Operációs rendszer",
+    "CPU" : "CPU",
+    "Memory" : "Memória",
+    "Server time" : "Kiszolgáló idő",
+    "Time Servers" : "Időkiszolgálók",
+    "Load" : "Terhelés",
+    "Disk" : "Lemez",
+    "Mount" : "Csatolás",
+    "Filesystem" : "Fájlrendszer",
+    "Size" : "Méret",
+    "Available" : "Elérhető",
+    "Used" : "Használt",
+    "You will get a notification once one of your disks is nearly full." : "Értesítést lesz küldve, ha az egyik lemez majdnem megtelt.",
     "Files:" : "Fájlok:",
     "Storages:" : "Tárhelyek:",
     "Free Space:" : "Szabad hely:",
+    "Network" : "Hálózat",
+    "Hostname" : "Hosztnév",
+    "DNS" : "DNS",
+    "Gateway" : "Átjáró",
+    "Status" : "Állapot",
+    "Speed" : "Sebesség",
+    "MAC" : "MAC",
+    "IPv4" : "IPv4",
+    "IPv6" : "IPv6",
     "Active users" : "Aktív felhasználók",
+    "Total users:" : "Összes felhasználó:",
     "Shares" : "Megosztások",
     "PHP" : "PHP",
     "Version:" : "Verzió:",
