@@ -10,20 +10,50 @@ OC.L10N.register(
     "Users" : "Používatelia",
     "Groups" : "Skupiny",
     "Links" : "Odkazy",
+    "Mails" : "Maily",
     "Federated sent" : "Odoslané do Zduženého Cloudu",
     "Federated received" : "Prijaté zo Združeného Cloudu",
+    "Talk conversations" : "Diskusné rozhovory",
+    "24 hours" : "24 hodín",
+    "1 hour" : "1 hodina",
+    "5 mins" : "5 minút",
     "Copy" : "Kopírovať",
     "Copied!" : "Skopírované!",
     "Not supported!" : "Nepodporované!",
     "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
     "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
+    "System" : "Systém",
     "Monitoring" : "Sledovanie",
     "Monitoring app with useful server information" : "Monitorovacia aplikácia s užitočnými informáciami o servri",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o servri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
+    "Operating System" : "Operačný systém",
+    "CPU" : "CPU",
+    "Memory" : "Pamäť",
+    "Server time" : "Čas servera",
+    "Uptime" : "Doba behu",
+    "Time Servers" : "Servery času",
+    "Load" : "Záťaž",
+    "Disk" : "Disk",
+    "Mount" : "Prípojný bod",
+    "Filesystem" : "Súborový systém",
+    "Size" : "Veľkosť",
+    "Available" : "Dostupné",
+    "Used" : "Použité",
+    "You will get a notification once one of your disks is nearly full." : "Ak je niektorý z vašich diskov skoro plný, dostanete varovanie.",
     "Files:" : "Súbory:",
     "Storages:" : "Úložiská:",
     "Free Space:" : "Voľné miesto:",
+    "Network" : "Sieť",
+    "Hostname" : "Názov servera",
+    "DNS" : "DNS",
+    "Gateway" : "Brána",
+    "Status" : "Stav",
+    "Speed" : "Rýchlosť",
+    "MAC" : "MAC",
+    "IPv4" : "IPv4",
+    "IPv6" : "IPv6",
     "Active users" : "Aktívni používatelia",
+    "Total users:" : "Užívateľov celkom:",
     "Shares" : "Sprístupnené položky",
     "PHP" : "PHP",
     "Version:" : "Verzia:",
@@ -36,6 +66,7 @@ OC.L10N.register(
     "External monitoring tool" : "Externý sledovací nástroj",
     "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
     "Did you know?" : "Vedeli ste?",
+    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Pridaním \"?format=json\" na koniec URL získate výsledok vo formáte JSON!",
     "Last 24 hours" : "Posledných 24 hodín",
     "Last 1 hour" : "Posledná 1 hodina",
     "Last 5 mins" : "Posledných 5 minút",
