@@ -14,31 +14,49 @@ OC.L10N.register(
     "Federated sent" : "Sammankopplingar skickade",
     "Federated received" : "Sammankopplingar mottagna",
     "Talk conversations" : "Talk-konversationer",
-    "Last 24 hours" : "Senaste 24 timmarna",
-    "Last 1 hour" : "Senaste timmen",
-    "Last 5 mins" : "Senaste 5 minuterna",
+    "24 hours" : "24 timmar",
+    "1 hour" : "1 timme",
+    "5 mins" : "5 min",
     "Copy" : "Kopiera",
     "Copied!" : "Kopierat!",
     "Not supported!" : "Stöds ej!",
     "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
     "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
+    "System" : "System",
     "Monitoring" : "Övervakning",
     "Monitoring app with useful server information" : "Övervaknings-app med användbar serverinformation",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Ger användbar serverinformation, såsom CPU belastning, RAM-användning, diskanvändning, antal användare, m.m.",
-    "CPU load" : "CPU-användning",
-    "Memory usage" : "Minnesanvändning",
-    "Active users" : "Aktiva användare",
-    "Shares" : "Delningar",
-    "Storage" : "Lagring",
-    "Users:" : "Användare:",
+    "Operating System" : "Operativsystem",
+    "CPU" : "CPU",
+    "Memory" : "Minne",
+    "Server time" : "Servertid",
+    "Uptime" : "Upptid",
+    "Time Servers" : "Tidservrar",
+    "Load" : "Last",
+    "Disk" : "Lagring",
+    "Mount" : "Montera",
+    "Filesystem" : "Filsystem",
+    "Size" : "Storlek",
+    "Available" : "Tillgänglig",
+    "Used" : "Använt",
+    "You will get a notification once one of your disks is nearly full." : "Du får ett meddelande när en av dina diskar är nästan full.",
     "Files:" : "Filer:",
     "Storages:" : "Lagring:",
     "Free Space:" : "Ledigt utrymme:",
-    "Nextcloud" : "Nextcloud",
-    "Version:" : "Version:",
-    "Apps installed:" : "Installerade appar:",
-    "Apps updates available:" : "Tillgängliga app-uppdateringar",
+    "Network" : "Nätverk",
+    "Hostname" : "Värdnamn",
+    "DNS" : "DNS",
+    "Gateway" : "Gateway",
+    "Status" : "Status",
+    "Speed" : "Hastighet",
+    "MAC" : "MAC",
+    "IPv4" : "IPv4",
+    "IPv6" : "IPv6",
+    "Active users" : "Aktiva användare",
+    "Total users:" : "Antal användare:",
+    "Shares" : "Delningar",
     "PHP" : "PHP",
+    "Version:" : "Version:",
     "Memory Limit:" : "Minneskapacitetsgräns:",
     "Max Execution Time:" : "Längsta körningstid:",
     "Upload max size:" : "Största uppladdningsstorlek:",
@@ -48,6 +66,16 @@ OC.L10N.register(
     "External monitoring tool" : "Externt övervakningsverktyg",
     "You can connect an external monitoring tool by using this end point:" : "Du kan ansluta ett externt övervakningsverktyg genom att använda denna adress:",
     "Did you know?" : "Visste du?",
-    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Lägg till \"?format=json\" i slutet av webbadressen för att få resultatet i JSON-format!"
+    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Lägg till \"?format=json\" i slutet av webbadressen för att få resultatet i JSON-format!",
+    "Last 24 hours" : "Senaste 24 timmarna",
+    "Last 1 hour" : "Senaste timmen",
+    "Last 5 mins" : "Senaste 5 minuterna",
+    "CPU load" : "CPU-användning",
+    "Memory usage" : "Minnesanvändning",
+    "Storage" : "Lagring",
+    "Users:" : "Användare:",
+    "Nextcloud" : "Nextcloud",
+    "Apps installed:" : "Installerade appar:",
+    "Apps updates available:" : "Tillgängliga appuppdateringar"
 },
 "nplurals=2; plural=(n != 1);");
