@@ -15,20 +15,26 @@ OC.L10N.register(
     "Your server has no Nextcloud Subscription" : "У вашего сервера нет подписки Nextcloud",
     "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Ваш сервер Nextcloud не поддерживается подпиской Nextcloud Enterprise.",
     "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Имея Enterprise подписку, вы можете быть на 100% уверены, что наши разработчики нацелены на безопасность, оснащенность, производительность и функциональность вашего облачного сервера!",
+    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Если нарушаются настройки вашего сервера, и сотрудники больше не могут работать, вам не нужно полагаться на поиск решений на онлайн-форумах. У вас есть прямой доступ к нашим опытным инженерам!",
+    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "У вас есть контракт с поставщиком, предоставляющим раннюю информацию по безопасности, мерам снижения риска, исправлениям и обновлениям.",
+    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Если вам нужно задержаться на текущей версии без сбоев, вам не нужно запускать программное обеспечение без обновлений безопасности.",
+    "You have the best expertise at hand to deal with performance and scalability issues." : "Вам предоставляется лучший опыт решения проблем производительности и масштабируемости.",
+    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "У вас есть доступ к необходимой документации, чтобы быстро ответить на вопросы соответствия или выполнить требования GDPR, HIPAA и других нормативных требований.",
+    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Мы также можем предоставить интеграцию с Outlook, Online Office, масштабируемое и интегрированное аудио-видео общение и чат, а также другие функции, доступные бесплатно только в ограниченной форме, или развитие дальнейших интеграций и возможностей для ваших нужд.",
     "A subscription helps you get the most out of Nextcloud!" : "Откройте все возможности с подпиской Nextcloud!",
     "Learn more now" : "Узнайте больше сейчас",
     "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %1$s, поскольку зарегистрировано больше %2$s пользователей.",
     "Your Nextcloud server Subscription is over limit" : "Ваша подписка на сервере Nextcloud превысила ограничение",
     "Dear admin," : "Дорогой администратор,",
-    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка Nextcloud не покрывает то количество пользователей, которые в настоящее время активны на этом сервере. Свяжитесь с менеджером аккаунта Nextcloud, чтобы обновить подписку!",
+    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Ваша подписка Nextcloud не распространяется на количество пользователей, которые в данный момент активны на этом сервере. Свяжитесь с менеджером своей учётной записи Nextcloud, чтобы обновить подписку!",
     "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "Ваш менеджер %1$s доступен по адресу электронной почты %2$s или номеру телефона %3$s.",
     "Thank you," : "Спасибо,",
     "Your Nextcloud team" : "Ваша команда Nextcloud",
-    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %s, поскольку число зарегистрированных пользователей превысило число покрываемых подпиской.",
+    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Это сообщение было отправлено всем администраторам приложением поддержки вашего сервера Nextcloud по адресу %s, поскольку число зарегистрированных пользователей превысило число покрываемых подпиской.",
     "Your Nextcloud server Subscription is expired" : "Срок подписки на ваш сервер Nextcloud истек",
     "Your Nextcloud server Subscription is expired!" : "Срок подписки на ваш сервер Nextcloud истек!",
-    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка на Nextcloud истекла! Свяжитесь с аккаунт-менеджером Nextcloud, чтобы обновить подписку!",
-    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %s, поскольку ваша подписка истекла.",
+    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Ваша подписка Nextcloud истекла! Свяжитесь с менеджером своей учётной записи Nextcloud, чтобы обновить подписку!",
+    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Это сообщение было отправлено всем администраторам приложением поддержки вашего сервера Nextcloud по адресу %s, поскольку ваша подписка истекла.",
     "Support" : "Поддержка",
     "Getting support and help for your Nextcloud" : "Получение поддержки и помощи для вашего Nextcloud",
     "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Приложение поддержки предоставляет вам прямой доступ к техпомощи и консультационным ресурсам, специальным опциям для контакта с вашим менеджером учетных записей и обзор вашей корпоративной подписки.",
@@ -47,21 +53,32 @@ OC.L10N.register(
     "_Expires in %n month_::_Expires in %n months_" : ["Истекает через месяц","Истекает через %n месяца","Истекает через  %n месяцев","Истекает через  %n месяца"],
     "_Expires in %n week_::_Expires in %n weeks_" : ["Истекает через неделю","Истекает через %n недели","Истекает через %n недель","Истекает через %n недели"],
     "_Expires in %n day_::_Expires in %n days_" : ["Истекает через день","Истекает через %n дня","Истекает через %n дней","Истекает через %n дня"],
-    "_For %n users_::_For %n users_" : ["Для одного пользователя","Для %n пользователей","Для  %n пользователей","Для %n пользователей"],
+    "For an unlimited amount of users" : "Для неограниченного числа пользователей",
+    "_For %n active users_::_For %n active users_" : ["Для %n активного пользователя","Для %n активных пользователей","Для %n активных пользователей","Для %n активных пользователей"],
+    "_For %n users_::_For %n users_" : ["Для %n пользователя","Для %n пользователей","Для %n пользователей","Для %n пользователей"],
     "_currently at %n user_::_currently at %n users_" : ["используется одним пользователем","используется %n пользователями","используется %n пользователями","используется %n пользователями"],
     "Includes support for %s" : "Включает поддержку %s",
     "Includes support for %1$s & %2$s" : "Включает поддержку %1$s и %2$s",
     "Includes support for %1$s, %2$s & %3$s" : "Включает поддержку %1$s, %2$s и %3$s",
     "Update subscription key" : "Обновить ключ подписки",
     "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s является Вашим аккаунт менеджером. Не стесняйтесь обращаться к нам, если у вас есть вопросы относительно вашей подписки.",
+    "You can find answers to common question in our portal and also file support requests there." : "Вы можете найти ответы на общие вопросы и подать обращение в поддержку на нашем портале.",
     "Access Nextcloud portal" : "Доступ к порталу Nextcloud",
     "System information" : "Системная информация",
+    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Сбор системной информации для техподдержки. Кнопка ниже генерирует текстовый файл в папке «Информация о системе» и предоставляет общий доступ к нему по общедоступной ссылке, защищенной паролем. Ссылка действительна в течение 2 недель.",
     "Generate system report" : "Сгенерировать системный отчет",
     "Enterprise subscription recommended" : "Мы рекомендуем Enterprise подписку",
     "No active enterprise subscription" : "Нет активной Enterprise подписки",
     "Unsupported" : "Не поддерживается",
     "This Nextcloud server has no Enterprise Subscription." : "Этот сервер Nextcloud не имеет Enterprise подписки.",
+    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Подписка Nextcloud Enterprise позволяет вам максимально эффективно использовать Nextcloud, обеспечивать безопасность ваших данных и работу вашего сервера в любое время.",
     "Advantages" : "Преимущества",
+    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Доступ к техническим знаниям и опыту разработчиков Nextcloud через документацию и поддержку",
+    "Access to additional capabilities like Outlook integration, online office and more" : "Доступ к дополнительным возможностям, таким как интеграция с Outlook, Online Office и т. д.",
+    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Доступ к опыту и возможностям масштабируемости для приложений Files и Talk",
+    "Optional branding, consulting, architecture advice" : "Дополнительный брендинг, консалтинг, советы по архитектуре",
+    "Confidential security notification service, mitigations, patches and advice" : "Служба конфиденциальных уведомлений о безопасности, меры по устранению неполадок, исправления и рекомендации",
+    "Compliance certification, advice and documentation" : "Сертификация соответствия, консультация и документация",
     "Get a quote" : "Получить квоту",
     "More information" : "Больше информации",
     "Subscription benefits" : "Преимущества подписки",
@@ -72,6 +89,7 @@ OC.L10N.register(
     "GitHub" : "GitHub",
     "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud использует GitHub как платформу для совместной работы. Там Вы можете напрямую сообщать об ошибках.",
     "Chat" : "Чат",
+    "Chat with us on our IRC channel #nextcloud on Freenode." : "Общайтесь с нами на нашем IRC-канале #nextcloud на Freenode.",
     "Nextcloud forum" : "Nextcloud форум",
     "Nextcloud at GitHub" : "Nextcloud на GitHub",
     "Open chat" : "Открытый чат",
@@ -84,8 +102,9 @@ OC.L10N.register(
     "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Ключ подписки не может быть подтвержден, поскольку сервер не имеет доступ в интернет. Обратитесь в службу поддержки, чтобы решить эту проблему.",
     "The subscription key had an invalid format." : "Ключ подписки имеет неверный формат",
     "While fetching the subscription information an error happened." : "Ошибка при загрузке информации о подписке.",
+    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Кнопка ниже генерирует текстовый файл в папке «Информация о системе» и предоставляет общий доступ к нему по общедоступной ссылке, защищенной паролем. Ссылка действительна в течение 2 недель.",
     "News" : "Новости",
-    "Follow us on Google+" : "Следите за нашими новостями в Google Plus",
+    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Чтобы получать актуальную информацию о том, что происходит в Nextcloud, подпишитесь на рассылку и следите за нами в социальных сетях.",
     "Like our Facebook page" : "Посмотрите нашу страницу на Facebook",
     "Follow us on Twitter" : "Следите за нашими новостями в Twitter",
     "Check out our blog" : "Просмотрите наш блог",
