@@ -2,14 +2,10 @@ OC.L10N.register(
     "systemtags",
     {
     "Tags" : "Etichette",
+    "Tag name is empty" : "Il nome del'etichetta è vuoto",
     "Update" : "Aggiorna",
     "Create" : "Crea",
     "Select tag…" : "Seleziona etichetta...",
-    "Tagged files" : "File etichettati",
-    "Select tags to filter by" : "Seleziona le etichette per filtrare",
-    "No tags found" : "Nessuna etichetta trovata",
-    "Please select tags to filter by" : "Seleziona le etichette per filtrare",
-    "No files found for the selected tags" : "Nessun file trovato per le etichette selezionate",
     "System tag %1$s added by the system" : "Etichetta di sistema %1$s aggiunta dal sistema",
     "Added system tag {systemtag}" : "Aggiunta l'etichetta di sistema {systemtag}",
     "Added system tag %1$s" : "Aggiunta l'etichetta di sistema %1$s",
@@ -50,6 +46,11 @@ OC.L10N.register(
     "Collaborative tags" : "Etichette collaborative",
     "Collaborative tagging functionality which shares tags among users." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
+    "Tagged files" : "File etichettati",
+    "Select tags to filter by" : "Seleziona le etichette per filtrare",
+    "No tags found" : "Nessuna etichetta trovata",
+    "Please select tags to filter by" : "Seleziona le etichette per filtrare",
+    "No files found for the selected tags" : "Nessun file trovato per le etichette selezionate",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per iso interno, poiché gli utenti non possono vederle o assegnarle.",
     "Select tag …" : "Seleziona etichetta...",
     "Create a new tag" : "Crea una nuova etichetta",
@@ -62,7 +63,6 @@ OC.L10N.register(
     "No files in here" : "Qui non c'è alcun file",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Size" : "Dimensione",
-    "Modified" : "Modificato",
-    "Create and edit collaborative tags. These tags affect all users." : "Crea e modifica etichette collaborative. Queste etichette interessano tutti gli utenti."
+    "Modified" : "Modificato"
 },
 "nplurals=2; plural=(n != 1);");
