@@ -2,14 +2,10 @@ OC.L10N.register(
     "systemtags",
     {
     "Tags" : "Etiketler",
+    "Tag name is empty" : "Etiket adı boş",
     "Update" : "Güncelle",
     "Create" : "Ekle",
     "Select tag…" : "Etiket seçin...",
-    "Tagged files" : "Etiketli dosyalar",
-    "Select tags to filter by" : "Süzülecek etiketleri seçin",
-    "No tags found" : "Herhangi bir etiket bulunamadı",
-    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
-    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
     "System tag %1$s added by the system" : "%1$s sistem etiketi sistem tarafından eklendi",
     "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
     "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
@@ -50,6 +46,11 @@ OC.L10N.register(
     "Collaborative tags" : "İşbirliği etiketleri",
     "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan işbirlikli etiketleme özelliği.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İşbirlikli etiketleme özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
+    "Tagged files" : "Etiketli dosyalar",
+    "Select tags to filter by" : "Süzülecek etiketleri seçin",
+    "No tags found" : "Herhangi bir etiket bulunamadı",
+    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
+    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İşbirliği etiketlerini tüm kullanıcılar kullanabilir. Kısıtlı etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
     "Select tag …" : "Etiket seçin...",
     "Create a new tag" : "Etiket ekle",
@@ -62,7 +63,6 @@ OC.L10N.register(
     "No files in here" : "Burada herhangi bir dosya yok",
     "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
     "Size" : "Boyut",
-    "Modified" : "Değiştirilme",
-    "Create and edit collaborative tags. These tags affect all users." : "İşbirliği etiketlerini oluşturun ve düzenleyin. Bu etiketler tüm kullanıcıları etkiler."
+    "Modified" : "Değiştirilme"
 },
 "nplurals=2; plural=(n > 1);");
