@@ -8,8 +8,11 @@ OC.L10N.register(
     "Name cannot be empty" : "A név nem lehet üres",
     "The given name is too long" : "A megadott név túl hosszú",
     "The given web address is too long" : "A megadott webcím túl hosszú",
+    "The given web address is not a valid URL" : "A megadott webcím URL címe érvénytelen",
     "The given legal notice address is too long" : "A megadott jogi nyilatkozat címe túl hosszú",
+    "The given legal notice address is not a valid URL" : "A megadott jogi nyilatkozat URL címe érvénytelen",
     "The given privacy policy address is too long" : "A megadott adatvédelmi irányelvek címe túl hosszú",
+    "The given privacy policy address is not a valid URL" : "A megadott adatvédelmi irányelvek URL címe érvénytelen",
     "The given slogan is too long" : "A megadott szlogen túl hosszú",
     "The given color is invalid" : "A megadott szín érvénytelen",
     "The file was uploaded" : "A fájl fel lett töltve",
