@@ -7,9 +7,12 @@ OC.L10N.register(
     "a safe home for all your data" : "надёжный дом для всех ваших данных",
     "Name cannot be empty" : "Имя не может быть пустым",
     "The given name is too long" : "Указанное название слишком длинное",
-    "The given web address is too long" : "Указанный веб адрес слишком длинный",
+    "The given web address is too long" : "Указанный веб-адрес слишком длинный",
+    "The given web address is not a valid URL" : "Указанный веб-адрес не является действительным URL",
     "The given legal notice address is too long" : "Указанный адрес на официальное уведомление слишком длинный",
+    "The given legal notice address is not a valid URL" : "Указанный адрес на официальное уведомление не является действительным URL",
     "The given privacy policy address is too long" : "Указанный адрес политики конфиденциальности слишком длинный",
+    "The given privacy policy address is not a valid URL" : "Указанный адрес политики конфиденциальности не является действительным URL",
     "The given slogan is too long" : "Указанный слоган слишком длинный",
     "The given color is invalid" : "Задан неправильный цвет",
     "The file was uploaded" : "Файл был загружен",
