@@ -8,8 +8,11 @@ OC.L10N.register(
     "Name cannot be empty" : "名称不能为空",
     "The given name is too long" : "输入的名称过长",
     "The given web address is too long" : "输入的地址过长",
+    "The given web address is not a valid URL" : "提供的web地址不是一个合法的URL",
     "The given legal notice address is too long" : "提供的法律通告地址太长",
+    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的URL",
     "The given privacy policy address is too long" : "提供的隐私政策地址太长",
+    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的URL",
     "The given slogan is too long" : "输入的标语过长",
     "The given color is invalid" : "提供的颜色无效",
     "The file was uploaded" : "文件已上传",
@@ -27,6 +30,7 @@ OC.L10N.register(
     "Legal notice" : "法律声明",
     "Privacy policy" : "隐私政策",
     "Adjust the Nextcloud theme" : "调整 Nextcloud 主题",
+    "Open documentation" : "打开文档",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "主题使得方便地定制您的实例的外观和体验成为可能。所有用户都可以使用。",
     "Name" : "名字",
     "Reset to default" : "重置为默认设置",
