@@ -15,9 +15,8 @@ OC.L10N.register(
     "Two factor backup codes" : "Kétfaktoros biztonsági mentési kódok",
     "A two-factor auth backup codes provider" : "Kétfaktoros azonosítás biztonsági kódok szolgáltatója",
     "Submit" : "Küldés",
-    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "A biztonsági kódok elkészültek. Felhasználva: {{used}}, ennyiből: {{total}}.",
-    "Nextcloud backup codes" : "Nextcloud biztonsági kódok",
     "activated" : "Aktivált",
-    "updated" : "frissítve"
+    "updated" : "frissítve",
+    "Nextcloud backup codes" : "Nextcloud biztonsági kódok"
 },
 "nplurals=2; plural=(n != 1);");
