@@ -1,12 +1,12 @@
 OC.L10N.register(
     "updatenotification",
     {
-    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Dowiedz się jak zaktualizować.",
-    "Channel updated" : "Kanał zaktualizowany",
+    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Uzyskaj więcej informacji na temat aktualizacji.",
+    "Channel updated" : "Zaktualizowano kanał",
     "Update notifications" : "Powiadomienia o aktualizacji",
-    "The update server could not be reached since %d days to check for new updates." : "Połączenie z serwerem z aktualizacjami w celu sprawdzenia nowych aktualizacji nie powiodło się od %d dni.",
-    "Please check the Nextcloud and server log files for errors." : "Proszę sprawdzić pliki z logami Nextcloud i serwera w celu znalezienia błędów.",
-    "Update to %1$s is available." : "Aktualizacja do %1$s jest dostępna.",
+    "The update server could not be reached since %d days to check for new updates." : "Serwer aktualizacji nie był dostępny od %d dni w celu sprawdzenia dostępności nowych aktualizacji.",
+    "Please check the Nextcloud and server log files for errors." : "Sprawdź pliki dziennika Nextcloud i serwera pod kątem błędów.",
+    "Update to %1$s is available." : "Dostępna jest aktualizacja do wersji %1$s.",
     "Update for %1$s to version %2$s is available." : "Dostępna jest aktualizacja dla %1$s do wersji %2$s.",
     "Update for {app} to version %s is available." : "Dostępna jest aktualizacja dla {app} do wersji %s.",
     "Update notification" : "Powiadomienie o aktualizacji",
@@ -14,7 +14,7 @@ OC.L10N.register(
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Wersja, której używasz, nie jest już wspierana. Pamiętaj, aby jak najszybciej zaktualizować do nowszej wersji.",
     "Apps missing updates" : "Brakujące aktualizacje aplikacji",
     "View in store" : "Zobacz w sklepie",
-    "Apps with available updates" : "Dostępne aktualizacje",
+    "Apps with available updates" : "Dostępne aktualizacje dla aplikacji",
     "Open updater" : "Otwórz aktualizator",
     "Download now" : "Pobierz teraz",
     "What's new?" : "Co nowego?",
@@ -22,10 +22,10 @@ OC.L10N.register(
     "Your version is up to date." : "Posiadasz aktualną wersję.",
     "A non-default update server is in use to be checked for updates:" : "Do sprawdzania aktualizacji nie są używane domyślne serwery aktualizacji:",
     "Update channel:" : "Kanał aktualizacji:",
-    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Zawsze możesz zaktualizować do nowszej wersji. Ale nigdy nie możesz powrócić do wersji stabilnej.",
+    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Zawsze możesz zaktualizować do nowszej wersji. Ale nigdy nie możesz powrócić do wersji bardziej stabilnej.",
     "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Zauważ, że po opublikowaniu nowej wersji może minąć trochę czasu, zanim pojawi się ona tutaj. Publikację dla naszych użytkowników rozkładamy w czasie, a czasami pomijamy wersję, gdy znajdziemy jakieś błędy.",
-    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach: ",
-    "Only notification for app updates are available." : "Tylko powiadomienia o aktualizacjach aplikacji są dostępne.",
+    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach:",
+    "Only notification for app updates are available." : "Dostępne są tylko powiadomienia o aktualizacjach aplikacji.",
     "The selected update channel makes dedicated notifications for the server obsolete." : "Wybrany kanał aktualizacji dla dedykowanych powiadomień dla serwera jest nieaktualny.",
     "The selected update channel does not support updates of the server." : "Wybrany kanał aktualizacji nie obsługuje danego serwera.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Dostępna jest nowa wersja: <strong>{newVersionString}</strong>",
@@ -33,20 +33,19 @@ OC.L10N.register(
     "Checking apps for compatible updates" : "Sprawdzanie aplikacji pod kątem zgodnych aktualizacji",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Upewnij się, że opcja <samp>appstoreenabled</samp> w Twoim config.php nie jest ustawiona na false.",
     "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nie można połączyć się z appstore lub całkowicie zgłasza brak aktualizacji. Wyszukaj aktualizacje ręcznie lub upewnij się, że masz dostęp do Internetu i możesz łączyć się z appstore.",
-    "<strong>All</strong> apps have an update for this version available" : "<strong>Wszystkie</strong> aplikacje mają aktualizację dla tej wersji",
+    "<strong>All</strong> apps have an update for this version available" : "<strong>Wszystkie</strong> aplikacje mają dostępną aktualizację dla tej wersji",
     "View changelog" : "Zobacz listę zmian",
     "Enterprise" : "Komercyjna",
-    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Do użytku komercyjnego. Zapewnia zawsze najnowszy poziom poprawek, które zostaną wprowadzone dopiero po przetestowaniu przez Nextcloud GmbH. Aktualizacja usunie błędy krytyczne i wprowadzi dodatkowe ulepszenia. Ten kanał jest dostępny tylko dla klientów, którzy otrzymują pakiet Nextcloud Enterprise.",
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Do użytku komercyjnego. Zapewnia zawsze najnowszy poziom poprawek, które zostaną wprowadzone dopiero po przetestowaniu przez Nextcloud GmbH. Aktualizacja usunie błędy krytyczne i wprowadzi dodatkowe ulepszenia. Ten kanał jest dostępny tylko dla klientów, którzy posiadają pakiet Nextcloud Enterprise.",
     "Stable" : "Stabilna",
     "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnowsza wersja stabilna. Jest odpowiednia do regularnego używania i zawsze będzie aktualizowana do najnowszej wersji głównej.",
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Wersja przedpremierowa tylko do testowania nowych funkcji. Nie jest do środowisk produkcyjnych.",
-    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikacja nie ma aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają aktualizacji dla tej wersji","<strong>%n</strong> aplikacji nie mają aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają aktualizacji dla tej wersji"],
+    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikacja nie ma dostępnej aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają dostępnych aktualizacji dla tej wersji","<strong>%n</strong> aplikacji nie ma dostępnych aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają dostępnych aktualizacji dla tej wersji"],
     "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Zawsze możesz zaktualizować do nowszej wersji z eksperymentalnego kanału. Ale nigdy nie możesz powrócić do wersji ze stabilnego kanału.",
     "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> zawsze zapewni najnowsze poprawki, ale nie zaktualizuje się do następnej wersji głównej. Ta aktualizacja zwykle ma miejsce przy drugiej wersji wydania (x.0.2).",
     "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> to najnowsza stabilna wersja. Jest odpowiednia do regularnego używania i zawsze będzie aktualizowana do najnowszej wersji głównej.",
     "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> jest wersją przedpremierową tylko do testowania nowych funkcji. Nie jest do środowisk produkcyjnych.",
-    "Could not start updater, please try the manual update" : "Nie można uruchomić aktualizacji, spróbuj zaktualizować ręcznie",
     "Production" : "Produkcyjna",
     "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Zawsze będzie dostarczać najnowsze poprawki, ale nie będzie aktualizowana do następnej wersji głównej. Ta aktualizacja zazwyczaj ma miejsce przy drugiej wersji wydania (x.0.2) i tylko wtedy, gdy instancja jest już w najnowszej wersji."
 },
