@@ -3,38 +3,40 @@ OC.L10N.register(
     {
     "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
     "Channel updated" : "Uppdateringskanal uppdaterad",
-    "Update notifications" : "Uppdateringsnotifikationer",
+    "Update notifications" : "Uppdateringsaviseringar",
     "The update server could not be reached since %d days to check for new updates." : "Uppdateringsservern kunde inte nås. Senaste kontakt för %d dagar sedan.",
     "Please check the Nextcloud and server log files for errors." : "Vänligen kontrollera ditt moln och dess serverloggar för felmeddelanden.",
     "Update to %1$s is available." : "Uppdatering till %1$s är tillgänglig.",
     "Update for %1$s to version %2$s is available." : "Uppdatering för %1$s till version %2$s är tillgänglig.",
     "Update for {app} to version %s is available." : "Uppdatering för {app} till version %s är tillgänglig.",
     "Update notification" : "Uppdatera notifikation",
-    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visar uppdateringsmeddelanden för Nextcloud och tillhandahåller SSO för uppdateraren.",
+    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visar uppdateringsaviseringar för Nextcloud och tillhandahåller SSO för uppdateraren.",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Den version som du kör underhålls inte längre. Se till att uppdatera till en aktuell version så snart som möjligt.",
     "Apps missing updates" : "Appar saknar uppdateringar",
     "View in store" : "Visa i butik",
     "Apps with available updates" : "Appar med tillgängliga uppdateringar",
     "Open updater" : "Öppna uppdateraren",
-    "Download now" : "Ladda ned nu",
+    "Download now" : "Hämta nu",
     "What's new?" : "Vad är nytt?",
-    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Var god uppdatera sidan.",
+    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Vänligen uppdatera sidan.",
     "Your version is up to date." : "Din version är uppdaterad.",
-    "A non-default update server is in use to be checked for updates:" : "En icke-standard updateringsserver används för att kolla efter uppdateringar:",
+    "A non-default update server is in use to be checked for updates:" : "En icke-standard uppdateringsserver används för att kontrolleras efter uppdateringar:",
     "Update channel:" : "Uppdateringskanal:",
     "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid uppdatera till en nyare version, men du kan aldrig nedgradera till en mer stabil version.",
     "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Notera att när en ny version släppts kan det ta lite tid innan den dyker upp här. Vi rullar ut nya versioner till våra användare vid utspridda tillfällen och hoppar ibland över versioner när problem hittas.",
     "Notify members of the following groups about available updates:" : "Notifiera medlemmar i följande grupper om tillgängliga uppdateraingar:",
-    "Only notification for app updates are available." : "Endast notifikation för app-uppdateringar är tillgängliga.",
-    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade notiser för servern förlegade.",
+    "Only notification for app updates are available." : "Endast notifikation för appuppdateringar är tillgängliga.",
+    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade aviseringar för servern förlegade.",
     "The selected update channel does not support updates of the server." : "Den valda uppdateringskanalen stödjer inte uppdateringar för servern.",
     "A new version is available: <strong>{newVersionString}</strong>" : "En ny version är tillgänglig: <strong>{newVersionString}</strong>",
     "Checked on {lastCheckedDate}" : "Kontrollerad {lastCheckedDate}",
     "Checking apps for compatible updates" : "Kontrollera appar för kompatibla uppdateringar",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Se till att din config.php inte ställer in <samp>appstoreenabled</samp> till falsk.",
-    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kunde inte ansluta till appstore eller så returnerades inga uppdateringar alls. Sök manuellt för uppdateringar och säkerställ att din server har tillgång till internet och kan ansluta till appstore.",
+    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kunde inte ansluta till appbutiken eller så returnerades inga uppdateringar alls. Sök manuellt för uppdateringar och säkerställ att din server har tillgång till internet och kan ansluta till appbutiken.",
     "<strong>All</strong> apps have an update for this version available" : "<strong>Alla</strong> appar har en uppdatering för den här versionen tillgänglig",
     "View changelog" : "Visa ändringslogg",
+    "Enterprise" : "Enterprise",
+    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Innehåller alltid den senaste patchnivån, men uppdateras inte omedelbart till nästa större version. Den uppdateringen sker när Nextcloud GmbH har utfört ytterligare verifiering och testning för storskaliga och kritiska installationer. Den här kanalen är endast tillgänglig för kunder och tillhandahåller Nextcloud Enterprise-paketet.",
     "Stable" : "Stabil",
     "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den senaste stabila versionen. Den är lämplig för regelbunden användning och kommer alltid att uppdatera till den senaste större mer omfattande versionen.",
     "Beta" : "Beta",
@@ -44,7 +46,6 @@ OC.L10N.register(
     "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>produktion</strong> kommer alltid att tillhandahålla den senaste patchnivån, men uppdateras inte omedelbart till nästa större version. Uppdateringen sker vanligen med den andra mindre versionen (x.0.2).",
     "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> är den senaste stabila versionen. Den är lämplig för regelbunden användning och kommer alltid att uppdatera till den senaste mer omfattande versionen.",
     "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> är en förhandsversion endast för att testa nya funktioner, inte för produktionsmiljöer.",
-    "Could not start updater, please try the manual update" : "Kunde inte starta uppdateraren, vänligen försök uppdatera manuellt",
     "Production" : "Produktion",
     "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Kommer alltid att tillhandahålla den senaste patchnivån, men uppdateras inte omedelbart till nästa större version. Uppdateringen sker vanligen med den andra mindre versionen (x.0.2) och endast om instansen redan har den senaste mindre versionen."
 },
