@@ -2,9 +2,11 @@
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
+ * @author Allan Nordhøy <epost@anotheragency.no>
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Juan Pablo Villafáñez <jvillafanez@solidgear.es>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
@@ -26,9 +28,9 @@
  */
 
 // Check user and app status
-OCP\JSON::checkAdminUser();
-OCP\JSON::checkAppEnabled('user_ldap');
-OCP\JSON::callCheck();
+\OC_JSON::checkAdminUser();
+\OC_JSON::checkAppEnabled('user_ldap');
+\OC_JSON::callCheck();
 
 $l = \OC::$server->getL10N('user_ldap');
 
@@ -67,20 +69,20 @@ try {
 				$ldapWrapper->read($connection->getConnectionResource(), '', 'objectClass=*', array('dn'));
 			} catch (\Exception $e) {
 				if($e->getCode() === 1) {
-					OCP\JSON::error(array('message' => $l->t('Invalid configuration: Anonymous binding is not allowed.')));
+					\OC_JSON::error(array('message' => $l->t('Invalid configuration: Anonymous binding is not allowed.')));
 					exit;
 				}
 			}
-			OCP\JSON::success(array('message'
+			\OC_JSON::success(array('message'
 			=> $l->t('Valid configuration, connection established!')));
 		} else {
-			OCP\JSON::error(array('message'
+			\OC_JSON::error(array('message'
 			=> $l->t('Valid configuration, but binding failed. Please check the server settings and credentials.')));
 		}
 	} else {
-		OCP\JSON::error(array('message'
+		\OC_JSON::error(array('message'
 		=> $l->t('Invalid configuration. Please have a look at the logs for further details.')));
 	}
 } catch (\Exception $e) {
-	OCP\JSON::error(array('message' => $e->getMessage()));
+	\OC_JSON::error(array('message' => $e->getMessage()));
 }
