@@ -8,12 +8,13 @@ OC.L10N.register(
     "No data specified" : "Ni navedenih podatkov",
     " Could not set configuration %s" : "Ni mogoče uveljaviti nastavitev %s",
     "Action does not exist" : "Dejanje ne obstaja",
+    "Very weak password" : "Zelo šibko geslo",
     "The Base DN appears to be wrong" : "Enoznačno ime (DN) podatkovne zbirke je napačno",
     "Testing configuration…" : "Poteka preizkušanje nastavitev ...",
     "Configuration incorrect" : "Nastavitev ni ustrezna",
     "Configuration incomplete" : "Nastavitev je nepopolna",
     "Configuration OK" : "Nastavitev je ustrezna",
-    "Select groups" : "Izberi skupine",
+    "Select groups" : "Izbor skupin",
     "Select object classes" : "Izbor razredov predmeta",
     "Please check the credentials, they seem to be wrong." : "Preverite poverila! Najverjetneje so napačna.",
     "Please specify the port, it could not be auto-detected." : "Določiti je treba ustrezna vrata, ker jih ni mogoče samodejno zaznati.",
@@ -40,6 +41,8 @@ OC.L10N.register(
     "The group box was disabled, because the LDAP / AD server does not support memberOf." : "Skupina je onemogočena, ker na strežniku ni omogočena podpora atributu memberOf.",
     "Please login with the new password" : "Prijavite se z novim geslom",
     "Your password will expire tomorrow." : "Vaše geslo bo poteklo naslednji dan",
+    "Your password will expire today." : "Geslo vam poteče danes!",
+    "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["Geslo bo poteklo čez %n dan.","Geslo bo poteklo čez %n dneva","Geslo bo poteklo čez %n dni.","Geslo bo poteklo čez %n dni."],
     "_%s group found_::_%s groups found_" : ["%s najdena skupina","%s najdeni skupini","%s najdene skupine","%s najdenih skupin"],
     "_%s user found_::_%s users found_" : ["%s najden uporabnik","%s najdena uporabnika","%s najdeni uporabniki","%s najdenih uporabnikov"],
     "Could not find the desired feature" : "Želene zmožnosti ni mogoče najti",
@@ -82,6 +85,8 @@ OC.L10N.register(
     "Saving" : "Poteka shranjevanje ...",
     "Back" : "Nazaj",
     "Continue" : "Nadaljuj",
+    "Current password" : "Trenutno geslo",
+    "New password" : "Novo geslo",
     "Cancel" : "Prekliči",
     "Server" : "Strežnik",
     "Users" : "Uporabniki",
@@ -123,7 +128,7 @@ OC.L10N.register(
     "Chunksize used for paged LDAP searches that may return bulky results like user or group enumeration. (Setting it 0 disables paged LDAP searches in those situations.)" : "Velikost odvoda za razbremenitev delovnega pomnilnika, ki ga uporablja iskalnik LDAP, pri oštevilčenju uporabnika ali skupine (vrednost 0 možnost onemogoči).",
     "Special Attributes" : "Posebni atributi",
     "Quota Field" : "Polje količinske omejitve",
-    "Quota Default" : "Privzeta količinska omejitev",
+    "Quota Default" : "Privzeta omejitev",
     "Email Field" : "Polje elektronske pošte",
     "User Home Folder Naming Rule" : "Pravila poimenovanja uporabniške osebne mape",
     "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "Pustite prazno za uporabniško ime (privzeto), sicer navedite atribut LDAP/AD.",
