@@ -27,7 +27,9 @@
 
 namespace OCA\User_LDAP;
 
-class Group_Proxy extends Proxy implements \OCP\GroupInterface, IGroupLDAP {
+use OCP\Group\Backend\IGetDisplayNameBackend;
+
+class Group_Proxy extends Proxy implements \OCP\GroupInterface, IGroupLDAP, IGetDisplayNameBackend {
 	private $backends = array();
 	private $refBackend = null;
 
@@ -272,4 +274,7 @@ class Group_Proxy extends Proxy implements \OCP\GroupInterface, IGroupLDAP {
 		return $this->handleRequest($gid, 'getNewLDAPConnection', array($gid));
 	}
 
+	public function getDisplayName(string $gid): string {
+		return $this->handleRequest($gid, 'getDisplayName', [$gid]);
+	}
 }
