@@ -100,7 +100,7 @@ class LDAP implements ILDAPWrapper {
 
 	/**
 	 * @param LDAP $link
-	 * @return mixed|string
+	 * @return integer
 	 */
 	public function errno($link) {
 		return $this->invokeLDAPMethod('errno', $link);
@@ -108,7 +108,7 @@ class LDAP implements ILDAPWrapper {
 
 	/**
 	 * @param LDAP $link
-	 * @return int|mixed
+	 * @return string
 	 */
 	public function error($link) {
 		return $this->invokeLDAPMethod('error', $link);
@@ -189,9 +189,24 @@ class LDAP implements ILDAPWrapper {
 	 * @param int $attrsOnly
 	 * @param int $limit
 	 * @return mixed
+	 * @throws \Exception
 	 */
 	public function search($link, $baseDN, $filter, $attr, $attrsOnly = 0, $limit = 0) {
-		return $this->invokeLDAPMethod('search', $link, $baseDN, $filter, $attr, $attrsOnly, $limit);
+		$oldHandler = set_error_handler(function($no, $message, $file, $line) use (&$oldHandler) {
+			if(strpos($message, 'Partial search results returned: Sizelimit exceeded') !== false) {
+				return true;
+			}
+			$oldHandler($no, $message, $file, $line);
+			return true;
+		});
+		try {
+			$result = $this->invokeLDAPMethod('search', $link, $baseDN, $filter, $attr, $attrsOnly, $limit);
+			restore_error_handler();
+			return $result;
+		} catch (\Exception $e) {
+			restore_error_handler();
+			throw $e;
+		}
 	}
 
 	/**
@@ -204,6 +219,17 @@ class LDAP implements ILDAPWrapper {
 		return $this->invokeLDAPMethod('mod_replace', $link, $userDN, array('userPassword' => $password));
 	}
 
+	/**
+	 * @param LDAP $link
+	 * @param string $userDN
+	 * @param string $oldPassword
+	 * @param string $password
+	 * @return bool
+	 */
+	public function exopPasswd($link, $userDN, $oldPassword, $password) {
+		return $this->invokeLDAPMethod('exop_passwd', $link, $userDN, $oldPassword, $password);
+	}
+
 	/**
 	 * @param LDAP $link
 	 * @param string $option
@@ -238,16 +264,6 @@ class LDAP implements ILDAPWrapper {
 		return function_exists('ldap_connect');
 	}
 
-	/**
-	 * Checks whether PHP supports LDAP Paged Results
-	 * @return boolean if it the case, false otherwise
-	 * */
-	public function hasPagedResultSupport() {
-		$hasSupport = function_exists('ldap_control_paged_result')
-			&& function_exists('ldap_control_paged_result_response');
-		return $hasSupport;
-	}
-
 	/**
 	 * Checks whether the submitted parameter is a resource
 	 * @param Resource $resource the resource variable to check
@@ -352,6 +368,7 @@ class LDAP implements ILDAPWrapper {
 
 	/**
 	 * Called after an ldap method is run to act on LDAP error if necessary
+	 * @throw \Exception
 	 */
 	private function postFunctionCall() {
 		if($this->isResource($this->curArgs[0])) {
