@@ -5,7 +5,6 @@ OC.L10N.register(
     "Simple file viewer with slideshow for media" : "Kyk maklik na lêers met skyfievertonings vir media",
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Wys die laaste vakansiefoto’s en video’s nes in die flieks, gee ’n kykie van die jongste roman direk vanaf Nextcloud, kies die beste GIF uit die versameling danksy die direkte voorskou van die gunstelinglêers, en nog wat!",
     "Your browser does not support the video tag." : "U blaaier ondersteun nie die video-etiket nie.",
-    "View" : "Bekyk",
-    "Share" : "Deel"
+    "View" : "Bekyk"
 },
 "nplurals=2; plural=(n != 1);");
