@@ -12,20 +12,54 @@ OC.L10N.register(
     "The given start time is invalid" : "El temps d'inici donat no és vàlid",
     "The given end time is invalid" : "El temps de finalització donat no és vàlid",
     "The given group does not exist" : "El grup donat no existeix",
+    "File" : "Fitxer",
+    "File created" : "Fitxer creat",
+    "File updated" : "Fitxer actualitzat",
+    "File renamed" : "Fitxer reanomenat",
+    "File deleted" : "Fitxer suprimit",
+    "File accessed" : "Fitxer accedit",
+    "File copied" : "Fitxer copiat",
+    "Tag assigned" : "Etiqueta assignada",
     "Operation #%s does not exist" : "L'operació #%s no existeix",
+    "Entity %s does not exist" : "L'entitat %s no existeix.",
+    "Entity %s is invalid" : "L'entitat %s no és vàlida.",
+    "No events are chosen." : "No s'ha triat cap esdeveniment.",
+    "Entity %s has no event %s" : "L'entitat %s no té cap esdeveniment %s",
     "Operation %s does not exist" : "L'operació %s no existeix",
     "Operation %s is invalid" : "L'operació %s no és vàlida",
     "Check %s does not exist" : "Comprovació %s no existeix",
     "Check %s is invalid" : "Comprovació %s no és vàlid",
+    "Check %s is not allowed with this entity" : "La comprovació de %s no es permet amb aquesta entitat.",
     "Check #%s does not exist" : "Comprovació #%s no existeix",
     "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
+    "Workflows" : "Fluxos de treball",
+    "Nextcloud workflow engine" : "Motor de flux de treball de Nextcloud",
+    "Select a filter" : "Seleccioneu un filtre",
+    "Select a comparator" : "Seleccioneu un comparador",
+    "Select a file type" : "Seleccioneu un tipus de fitxer",
+    "Images" : "Imatges",
+    "Office documents" : "Documents d'oficina",
+    "PDF documents" : "Documents PDF",
+    "Custom mimetype" : "Tipus mime personalitzat",
+    "No results" : "No hi ha resultats",
+    "%s (invisible)" : "%s (invisible)",
+    "%s (restricted)" : "%s (restringit)",
+    "Select a request URL" : "Seleccioneu un URL de petició",
     "Predefined URLs" : "URLs predefinits",
     "Files WebDAV" : "Fitxers WebDAV",
-    "Sync clients" : "Sincronitza les aplicacions clients",
+    "Others" : "Altres",
+    "Custom URL" : "URL personalitzat",
+    "Select a user agent" : "Seleccioneu un agent d'usuari",
     "Android client" : "Client android",
     "iOS client" : "Client iOS",
     "Desktop client" : "Client d'escriptori",
     "Thunderbird & Outlook addons" : "Complements de Thunderbird i Outlook",
+    "Custom user agent" : "Agent d'usuari personalitzat",
+    "When" : "Quan",
+    "and" : "i",
+    "The configuration is invalid" : "La configuració no és vàlida.",
+    "Show less" : "Mostra'n menys",
+    "Show more" : "Mostra'n més",
     "File name" : "Nom del fitxer",
     "is" : "és",
     "is not" : "no és",
@@ -68,6 +102,7 @@ OC.L10N.register(
     "Start" : "Comença",
     "End" : "Finalitza",
     "Select timezone…" : "Selecciona fus horari",
+    "Sync clients" : "Sincronitza les aplicacions clients",
     "Workflow" : "Flux de treball",
     "Files workflow engine" : "Fitxers del motor de flux de treball",
     "Open documentation" : "Obre la documentació",
