@@ -37,20 +37,22 @@ OC.L10N.register(
     "Select a filter" : "Filter auswählen",
     "Select a comparator" : "Wähle einen Komparator",
     "Select a file type" : "Dateityp auswählen",
+    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
     "Images" : "Bilder",
     "Office documents" : "Office Dokumente",
     "PDF documents" : "PDF-Dokumente",
     "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
+    "Select a tag" : "Schlagwort auswählen",
     "No results" : "Keine Ergebnisse",
     "%s (invisible)" : "%s(unsichtbar)",
     "%s (restricted)" : "%s (eingeschränkt)",
+    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
     "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
     "Predefined URLs" : "Vordefinierte URLs",
     "Files WebDAV" : "WebDAV für Dateien",
     "Others" : "Andere",
     "Custom URL" : "Benutzerdefinierte URL",
     "Select a user agent" : "User-Agenten auswählen",
-    "Sync clients" : "Sync-Clients",
     "Android client" : "Android-Client",
     "iOS client" : "iOS-Client",
     "Desktop client" : "Desktop-Client",
@@ -58,8 +60,8 @@ OC.L10N.register(
     "Custom user agent" : "Benutzerdefinierter User-Agent",
     "When" : "Wenn",
     "and" : "und",
-    "Cancel rule creation" : "Regelerstellung abbrechen",
-    "Remove rule" : "Regel entfernen",
+    "Cancel" : "Abbrechen",
+    "Delete" : "Löschen",
     "The configuration is invalid" : "Die Konfiguration ist ungültig",
     "Show less" : "Weniger anzeigen",
     "Show more" : "Mehr anzeigen",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Start" : "Start",
     "End" : "Ende",
     "Select timezone…" : "Wähle eine Zeitzone…",
+    "Sync clients" : "Sync-Clients",
     "Workflow" : "Arbeitsablauf",
     "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
     "Open documentation" : "Dokumentation öffnen",
