@@ -1,42 +1,54 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "File MIME type",
+    "The given operator is invalid" : "The given operator is invalid",
+    "The given regular expression is invalid" : "The given regular expression is invalid",
+    "The given file size is invalid" : "The given file size is invalid",
+    "The given tag id is invalid" : "The given tag id is invalid",
+    "The given IP range is invalid" : "The given IP range is invalid",
+    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
+    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
+    "The given time span is invalid" : "The given time span is invalid",
+    "The given start time is invalid" : "The given start time is invalid",
+    "The given end time is invalid" : "The given end time is invalid",
+    "The given group does not exist" : "The given group does not exist",
+    "Operation #%s does not exist" : "Operation #%s does not exist",
+    "Operation %s does not exist" : "Operation %s does not exist",
+    "Operation %s is invalid" : "Operation %s is invalid",
+    "Check %s does not exist" : "Check %s does not exist",
+    "Check %s is invalid" : "Check %s is invalid",
+    "Check #%s does not exist" : "Check #%s does not exist",
+    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
+    "Predefined URLs" : "Predefined URLs",
+    "Files WebDAV" : "Files WebDAV",
+    "Android client" : "Android client",
+    "iOS client" : "iOS client",
+    "Desktop client" : "Desktop client",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
+    "File name" : "File name",
     "is" : "is",
     "is not" : "is not",
     "matches" : "matches",
     "does not match" : "does not match",
-    "Example: {placeholder}" : "Example: {placeholder}",
-    "File name" : "File name",
+    "File MIME type" : "File MIME type",
     "File size (upload)" : "File size (upload)",
     "less" : "less",
     "less or equals" : "less or equals",
     "greater or equals" : "greater or equals",
     "greater" : "greater",
-    "File system tag" : "File system tag",
-    "is tagged with" : "is tagged with",
-    "is not tagged with" : "is not tagged with",
-    "Select tag…" : "Select tag…",
     "Request remote address" : "Request remote address",
     "matches IPv4" : "matches IPv4",
     "does not match IPv4" : "does not match IPv4",
     "matches IPv6" : "matches IPv6",
     "does not match IPv6" : "does not match IPv6",
+    "File system tag" : "File system tag",
+    "is tagged with" : "is tagged with",
+    "is not tagged with" : "is not tagged with",
+    "Request URL" : "Request URL",
     "Request time" : "Request time",
     "between" : "between",
     "not between" : "not between",
-    "Start" : "Start",
-    "End" : "End",
-    "Select timezone…" : "Select timezone…",
-    "Request URL" : "Request URL",
-    "Predefined URLs" : "Predefined URLs",
-    "Files WebDAV" : "Files WebDAV",
     "Request user agent" : "Request user agent",
-    "Sync clients" : "Sync clients",
-    "Android client" : "Android client",
-    "iOS client" : "iOS client",
-    "Desktop client" : "Desktop client",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
     "User group membership" : "User group membership",
     "is member of" : "is member of",
     "is not member of" : "is not member of",
@@ -50,28 +62,16 @@ OC.L10N.register(
     "Saved" : "Saved",
     "Saving failed:" : "Saving failed:",
     "Add rule group" : "Add rule group",
-    "The given operator is invalid" : "The given operator is invalid",
-    "The given regular expression is invalid" : "The given regular expression is invalid",
-    "The given file size is invalid" : "The given file size is invalid",
-    "The given tag id is invalid" : "The given tag id is invalid",
-    "The given IP range is invalid" : "The given IP range is invalid",
-    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
-    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
-    "The given time span is invalid" : "The given time span is invalid",
-    "The given start time is invalid" : "The given start time is invalid",
-    "The given end time is invalid" : "The given end time is invalid",
-    "The given group does not exist" : "The given group does not exist",
-    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
-    "Operation #%s does not exist" : "Operation #%s does not exist",
-    "Operation %s does not exist" : "Operation %s does not exist",
-    "Operation %s is invalid" : "Operation %s is invalid",
-    "Check %s does not exist" : "Check %s does not exist",
-    "Check %s is invalid" : "Check %s is invalid",
-    "Check #%s does not exist" : "Check #%s does not exist",
-    "Tag management" : "Tag management",
+    "Example: {placeholder}" : "Example: {placeholder}",
+    "Select tag…" : "Select tag…",
+    "Start" : "Start",
+    "End" : "End",
+    "Select timezone…" : "Select timezone…",
+    "Sync clients" : "Sync clients",
+    "Workflow" : "Workflow",
     "Files workflow engine" : "Files workflow engine",
     "Open documentation" : "Open documentation",
     "Loading…" : "Loading…",
-    "Workflow" : "Workflow"
+    "Tag management" : "Tag management"
 },
 "nplurals=2; plural=(n != 1);");
