@@ -12,20 +12,54 @@ OC.L10N.register(
     "The given start time is invalid" : "Tiu komenca horo ne validas",
     "The given end time is invalid" : "Tiu fina horo ne validas",
     "The given group does not exist" : "Tiu grupo ne ekzistas",
+    "File" : "Dosiero",
+    "File created" : "Dosiero kreita",
+    "File updated" : "Dosiero ĝisdatigita",
+    "File renamed" : "Dosiero alinomita",
+    "File deleted" : "Dosiero forigita",
+    "File accessed" : "Dosiero atingita",
+    "File copied" : "Dosiero kopiita",
+    "Tag assigned" : "Etikedo atribuita",
     "Operation #%s does not exist" : "Operacio n-ro %s ne ekzistas",
+    "Entity %s does not exist" : "Ento %s ne ekzistas",
+    "Entity %s is invalid" : "Ento %s ne validas",
+    "No events are chosen." : "Neniu okazaĵo elektita.",
+    "Entity %s has no event %s" : "Ento %s ne havas okazaĵon %s",
     "Operation %s does not exist" : "Operacio %s ne ekzistas",
     "Operation %s is invalid" : "Operacio %s ne validas",
     "Check %s does not exist" : "Kontrolo %s ne ekzistas",
     "Check %s is invalid" : "Kontrolo %s ne validas",
+    "Check %s is not allowed with this entity" : "La kontrolo %s ne estas permesita kun tiu ento",
     "Check #%s does not exist" : "Kontrolo n-ro %s ne ekzistas",
     "Check %s is invalid or does not exist" : "La kontrolo %s ne validas aŭ ne ekzistas",
+    "Workflows" : "Laborfluoj",
+    "Nextcloud workflow engine" : "Modulo de laborfluo de Nextcloud",
+    "Select a filter" : "Elekti filtrilon",
+    "Select a comparator" : "Elekti komparilon",
+    "Select a file type" : "Elekti dosierformon",
+    "Images" : "Bildoj",
+    "Office documents" : "Oficejaj dokumentoj",
+    "PDF documents" : "PDF-dokumentoj",
+    "Custom mimetype" : "Propra MIME-tipo",
+    "No results" : "Neniu rezulto",
+    "%s (invisible)" : "%s (nevidebla)",
+    "%s (restricted)" : "%s (limigita)",
+    "Select a request URL" : "Elekti petan retadreson",
     "Predefined URLs" : "Antaŭdifinitaj retadresoj",
     "Files WebDAV" : "Dosieroj WebDAV",
-    "Sync clients" : "Sinkronigaj klientoj",
+    "Others" : "Aliaj",
+    "Custom URL" : "Propra retadreso",
+    "Select a user agent" : "Elekti retumil-identigilo („user-agent“)",
     "Android client" : "Androida kliento",
     "iOS client" : "iOS-a kliento",
     "Desktop client" : "Labortabla kliento",
     "Thunderbird & Outlook addons" : "Thunderbird-a kaj Outlook-a aldonaĵo",
+    "Custom user agent" : "Propra retumil-identigilo („user-agent“)",
+    "When" : "Kiam",
+    "and" : "kaj",
+    "The configuration is invalid" : "La agordo ne validas",
+    "Show less" : "Montri malpli",
+    "Show more" : "Montri pli",
     "File name" : "Dosiernomo",
     "is" : "estas",
     "is not" : "ne estas",
@@ -57,7 +91,7 @@ OC.L10N.register(
     "Add rule" : "Aldoni regulon",
     "Reset" : "Restarigi",
     "Save" : "Konservi",
-    "Saving…" : "Konservante...",
+    "Saving…" : "Konservado...",
     "Group list is empty" : "Gruplisto malplenas",
     "Unable to retrieve the group list" : "Ne eblas ricevi grupliston",
     "Saved" : "Konservita",
@@ -68,10 +102,11 @@ OC.L10N.register(
     "Start" : "Komenco",
     "End" : "Fino",
     "Select timezone…" : "Elekti horzonon...",
+    "Sync clients" : "Sinkronigaj klientoj",
     "Workflow" : "Laborfluo",
     "Files workflow engine" : "Modulo de dosiera laborfluo",
     "Open documentation" : "Malfermi dokumentaron",
-    "Loading…" : "Ŝargante...",
+    "Loading…" : "Ŝargado...",
     "Tag management" : "Etikeda administrado"
 },
 "nplurals=2; plural=(n != 1);");
