@@ -37,20 +37,22 @@ OC.L10N.register(
     "Select a filter" : "Seleccione un filtro",
     "Select a comparator" : "Seleccione un comparador",
     "Select a file type" : "Selecciona un tipo de archivo",
+    "e.g. httpd/unix-directory" : "p.ej.. httpd/carpeta-unix",
     "Images" : "Imágenes",
     "Office documents" : "Documentos de oficina",
     "PDF documents" : "Documentos PDF",
     "Custom mimetype" : "Tipo MIME (mimetype) personalizado",
+    "Select a tag" : "Selecciona una etiqueta",
     "No results" : "Sin resultados",
     "%s (invisible)" : "%s (invisible)",
     "%s (restricted)" : "%s (restringido)",
+    "Please enter a valid time span" : "Por favor especifique un intervalo de tiempo válido",
     "Select a request URL" : "Selecciona una URL de petición",
     "Predefined URLs" : "URLs predefinidas",
     "Files WebDAV" : "Archivos WebDAV",
     "Others" : "Otros",
     "Custom URL" : "URL personalizada",
     "Select a user agent" : "Selecciona un agente de usuario",
-    "Sync clients" : "Clientes de sincronización",
     "Android client" : "Cliente Android",
     "iOS client" : "Cliente iOS",
     "Desktop client" : "Cliente de escritorio",
@@ -58,8 +60,8 @@ OC.L10N.register(
     "Custom user agent" : "Agente de usuario personalizado",
     "When" : "Cuando",
     "and" : "y",
-    "Cancel rule creation" : "Cancelar creación de la regla",
-    "Remove rule" : "Eliminar regla",
+    "Cancel" : "Cancelar",
+    "Delete" : "Eliminar",
     "The configuration is invalid" : "La configuración es incorrecta",
     "Show less" : "Ver menos",
     "Show more" : "Ver más",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Start" : "Inicio",
     "End" : "Final",
     "Select timezone…" : "Seleccionar zona horaria...",
+    "Sync clients" : "Clientes de sincronización",
     "Workflow" : "Flujo de trabajo",
     "Files workflow engine" : "Motor de flujo de trabajo de archivos",
     "Open documentation" : "Documentación abierta",
