@@ -1,55 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "סוג ה־MIME של הקובץ",
-    "is" : "הוא",
-    "is not" : "אינו",
-    "matches" : "תואם",
-    "does not match" : "אינו תואם",
-    "Example: {placeholder}" : "דוגמה: {placeholder}",
-    "File name" : "שם קובץ",
-    "File size (upload)" : "גודל קובץ (העלאה)",
-    "less" : "פחות",
-    "less or equals" : "פחות או שווה",
-    "greater or equals" : "גדול או שווה",
-    "greater" : "גדול",
-    "File system tag" : "תגית מערכת קבצים",
-    "is tagged with" : "עם התגית",
-    "is not tagged with" : "ללא התגית",
-    "Select tag…" : "בחירת תגית…",
-    "Request remote address" : "בקשת כתובת מרוחקת",
-    "matches IPv4" : "התאמת IPv4",
-    "does not match IPv4" : "ללא התאמת IPv4",
-    "matches IPv6" : "התאמת IPv6",
-    "does not match IPv6" : "ללא התאמת IPv6",
-    "Request time" : "זמן בקשה",
-    "between" : "בין",
-    "not between" : "לא בין",
-    "Start" : "התחלה",
-    "End" : "סיום",
-    "Select timezone…" : "בחירת אזור זמן…",
-    "Request URL" : "כתובת בקשה",
-    "Predefined URLs" : "כתובות שמוגדרות מראש",
-    "Files WebDAV" : "WebDAV קבצים",
-    "Request user agent" : "סוכן משתמש הבקשה",
-    "Sync clients" : "סנכרון לקוחות",
-    "Android client" : "לקוח Android",
-    "iOS client" : "לקוח iOS",
-    "Desktop client" : "לקוח שולחן עבודה",
-    "Thunderbird & Outlook addons" : "תוספות ל־Thunderbird ול־Outlook",
-    "User group membership" : "חברות בקבוצת משתמשים",
-    "is member of" : "חבר בקבוצה",
-    "is not member of" : "לא חבר בקבוצה",
-    "Short rule description" : "תיאור מקוצר לכלל",
-    "Add rule" : "הוספת כלל",
-    "Reset" : "איפוס",
-    "Save" : "שמירה",
-    "Saving…" : "בהליכי שמירה…",
-    "Group list is empty" : "רשימת הקבוצות ריקה",
-    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
-    "Saved" : "נשמרה",
-    "Saving failed:" : "השמירה נכשלה:",
-    "Add rule group" : "הוספת קבוצת כללים",
     "The given operator is invalid" : "הפעולה שצוינה שגויה",
     "The given regular expression is invalid" : "הביטוי הרגולרי שצוין שגוי",
     "The given file size is invalid" : "גודל הקובץ שצוין שגוי",
@@ -64,8 +15,57 @@ OC.L10N.register(
     "Operation #%s does not exist" : "פעולה מס׳ %s לא קיימת",
     "Operation %s does not exist" : "הפעולה %s לא קיימת",
     "Operation %s is invalid" : "הפעולה %s שגויה",
-    "Tag management" : "ניהול תגיות",
+    "Predefined URLs" : "כתובות שמוגדרות מראש",
+    "Files WebDAV" : "WebDAV קבצים",
+    "Android client" : "לקוח Android",
+    "iOS client" : "לקוח iOS",
+    "Desktop client" : "לקוח שולחן עבודה",
+    "Thunderbird & Outlook addons" : "תוספות ל־Thunderbird ול־Outlook",
+    "File name" : "שם קובץ",
+    "is" : "הוא",
+    "is not" : "אינו",
+    "matches" : "תואם",
+    "does not match" : "אינו תואם",
+    "File MIME type" : "סוג ה־MIME של הקובץ",
+    "File size (upload)" : "גודל קובץ (העלאה)",
+    "less" : "פחות",
+    "less or equals" : "פחות או שווה",
+    "greater or equals" : "גדול או שווה",
+    "greater" : "גדול",
+    "Request remote address" : "בקשת כתובת מרוחקת",
+    "matches IPv4" : "התאמת IPv4",
+    "does not match IPv4" : "ללא התאמת IPv4",
+    "matches IPv6" : "התאמת IPv6",
+    "does not match IPv6" : "ללא התאמת IPv6",
+    "File system tag" : "תגית מערכת קבצים",
+    "is tagged with" : "עם התגית",
+    "is not tagged with" : "ללא התגית",
+    "Request URL" : "כתובת בקשה",
+    "Request time" : "זמן בקשה",
+    "between" : "בין",
+    "not between" : "לא בין",
+    "Request user agent" : "סוכן משתמש הבקשה",
+    "User group membership" : "חברות בקבוצת משתמשים",
+    "is member of" : "חבר בקבוצה",
+    "is not member of" : "לא חבר בקבוצה",
+    "Short rule description" : "תיאור מקוצר לכלל",
+    "Add rule" : "הוספת כלל",
+    "Reset" : "איפוס",
+    "Save" : "שמירה",
+    "Saving…" : "בהליכי שמירה…",
+    "Group list is empty" : "רשימת הקבוצות ריקה",
+    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
+    "Saved" : "נשמרה",
+    "Saving failed:" : "השמירה נכשלה:",
+    "Add rule group" : "הוספת קבוצת כללים",
+    "Example: {placeholder}" : "דוגמה: {placeholder}",
+    "Select tag…" : "בחירת תגית…",
+    "Start" : "התחלה",
+    "End" : "סיום",
+    "Select timezone…" : "בחירת אזור זמן…",
+    "Sync clients" : "סנכרון לקוחות",
     "Open documentation" : "פתיחת תיעוד",
-    "Loading…" : "בטעינה…"
+    "Loading…" : "בטעינה…",
+    "Tag management" : "ניהול תגיות"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
