@@ -1,42 +1,54 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "MIME-skráartegund",
+    "The given operator is invalid" : "Uppgefinn virki er ógildur",
+    "The given regular expression is invalid" : "Uppgefin regluleg segð er ógild",
+    "The given file size is invalid" : "Uppgefin stærð er ógild",
+    "The given tag id is invalid" : "Uppgefið auðkenni merkis er ógilt",
+    "The given IP range is invalid" : "Uppgefna IP-vistfangasviðið er ógilt",
+    "The given IP range is not valid for IPv4" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv4",
+    "The given IP range is not valid for IPv6" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv6",
+    "The given time span is invalid" : "Uppgefið tímasvið er ógilt",
+    "The given start time is invalid" : "Uppgefinn upphafstími er ógildur",
+    "The given end time is invalid" : "Uppgefinn lokatími er ógildur",
+    "The given group does not exist" : "Uppgefinn hópur er ekki til",
+    "Operation #%s does not exist" : "Aðgerðin #%s er ekki til",
+    "Operation %s does not exist" : "Aðgerðin %s er ekki til",
+    "Operation %s is invalid" : "Aðgerðin %s er ógild",
+    "Check %s does not exist" : "Athugunin %s er ekki til",
+    "Check %s is invalid" : "Athugunin %s er ógild",
+    "Check #%s does not exist" : "Athugunin #%s er ekki til",
+    "Check %s is invalid or does not exist" : "Athugunin %s er ógild eða er ekki til",
+    "Predefined URLs" : "Forákvarðaðar slóðir",
+    "Files WebDAV" : "WebDAV skráa",
+    "Android client" : "Android-biðlari",
+    "iOS client" : "iOS-biðlari",
+    "Desktop client" : "Skjáborðsforrit",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook viðbætur",
+    "File name" : "Skráarheiti",
     "is" : "er",
     "is not" : "er ekki",
     "matches" : "samsvarar",
     "does not match" : "samsvarar ekki",
-    "Example: {placeholder}" : "Dæmi: {placeholder}",
-    "File name" : "Skráarheiti",
+    "File MIME type" : "MIME-skráartegund",
     "File size (upload)" : "Skráarstærð (innsending)",
     "less" : "minna en",
     "less or equals" : "minna eða jafnt",
     "greater or equals" : "stærra eða jafnt",
     "greater" : "meira en",
-    "File system tag" : "Skráakerfismerki",
-    "is tagged with" : "er merkt með",
-    "is not tagged with" : "er ekki merkt með",
-    "Select tag…" : "Veldu merki...",
     "Request remote address" : "Biðja um fjartengt vistfang",
     "matches IPv4" : "samsvarar IPv4",
     "does not match IPv4" : "samsvarar ekki IPv4",
     "matches IPv6" : "samsvarar IPv6",
     "does not match IPv6" : "samsvarar ekki IPv6",
+    "File system tag" : "Skráakerfismerki",
+    "is tagged with" : "er merkt með",
+    "is not tagged with" : "er ekki merkt með",
+    "Request URL" : "Slóð á beiðni",
     "Request time" : "Tími beiðnar",
     "between" : "á milli",
     "not between" : "er ekki á milli",
-    "Start" : "Byrjun",
-    "End" : "Endar",
-    "Select timezone…" : "Veldu tímabelti…",
-    "Request URL" : "Slóð á beiðni",
-    "Predefined URLs" : "Forákvarðaðar slóðir",
-    "Files WebDAV" : "WebDAV skráa",
     "Request user agent" : "Biðja um notandaforrit",
-    "Sync clients" : "Samstilla biðlara",
-    "Android client" : "Android-biðlari",
-    "iOS client" : "iOS-biðlari",
-    "Desktop client" : "Skjáborðsforrit",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook viðbætur",
     "User group membership" : "Notandi er meðlimur í hópum",
     "is member of" : "er meðlimur í ",
     "is not member of" : "er ekki meðlimur í",
@@ -50,28 +62,16 @@ OC.L10N.register(
     "Saved" : "Vistað",
     "Saving failed:" : "Vistun mistókst:",
     "Add rule group" : "Bæta við regluhópi",
-    "The given operator is invalid" : "Uppgefinn virki er ógildur",
-    "The given regular expression is invalid" : "Uppgefin regluleg segð er ógild",
-    "The given file size is invalid" : "Uppgefin stærð er ógild",
-    "The given tag id is invalid" : "Uppgefið auðkenni merkis er ógilt",
-    "The given IP range is invalid" : "Uppgefna IP-vistfangasviðið er ógilt",
-    "The given IP range is not valid for IPv4" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv4",
-    "The given IP range is not valid for IPv6" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv6",
-    "The given time span is invalid" : "Uppgefið tímasvið er ógilt",
-    "The given start time is invalid" : "Uppgefinn upphafstími er ógildur",
-    "The given end time is invalid" : "Uppgefinn lokatími er ógildur",
-    "The given group does not exist" : "Uppgefinn hópur er ekki til",
-    "Check %s is invalid or does not exist" : "Athugunin %s er ógild eða er ekki til",
-    "Operation #%s does not exist" : "Aðgerðin #%s er ekki til",
-    "Operation %s does not exist" : "Aðgerðin %s er ekki til",
-    "Operation %s is invalid" : "Aðgerðin %s er ógild",
-    "Check %s does not exist" : "Athugunin %s er ekki til",
-    "Check %s is invalid" : "Athugunin %s er ógild",
-    "Check #%s does not exist" : "Athugunin #%s er ekki til",
-    "Tag management" : "Sýsl með merki",
+    "Example: {placeholder}" : "Dæmi: {placeholder}",
+    "Select tag…" : "Veldu merki...",
+    "Start" : "Byrjun",
+    "End" : "Endar",
+    "Select timezone…" : "Veldu tímabelti…",
+    "Sync clients" : "Samstilla biðlara",
+    "Workflow" : "Vinnuferli",
     "Files workflow engine" : "Verkferlavél skráa",
     "Open documentation" : "Opna hjálparskjöl",
     "Loading…" : "Hleð inn...",
-    "Workflow" : "Vinnuferli"
+    "Tag management" : "Sýsl með merki"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
