@@ -1,42 +1,54 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "ファイルMIMEタイプ",
+    "The given operator is invalid" : "指定された演算子は無効",
+    "The given regular expression is invalid" : "指定の正規表現は無効",
+    "The given file size is invalid" : "指定されたファイルサイズは無効",
+    "The given tag id is invalid" : "指定されたIDタグは無効",
+    "The given IP range is invalid" : "指定されたIP範囲は無効",
+    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
+    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
+    "The given time span is invalid" : "指定された期間は無効です",
+    "The given start time is invalid" : "指定された開始時刻は無効です",
+    "The given end time is invalid" : "指定された終了時刻は無効です",
+    "The given group does not exist" : "指定されたグループは存在しません",
+    "Operation #%s does not exist" : "#%s 操作は存在しません",
+    "Operation %s does not exist" : "%s 操作は存在しません",
+    "Operation %s is invalid" : "%s 操作は無効です",
+    "Check %s does not exist" : "チェック %s は存在しません",
+    "Check %s is invalid" : "チェック %s は無効です",
+    "Check #%s does not exist" : "チェック #%s は存在しません",
+    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
+    "Predefined URLs" : "定義済みのURL",
+    "Files WebDAV" : "ファイルWebDAV",
+    "Android client" : "アンドロイドクライアント",
+    "iOS client" : "iOSクライアント",
+    "Desktop client" : "デスクトップクライアント",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
+    "File name" : "ファイル名",
     "is" : "は",
     "is not" : "は異なる",
     "matches" : "合致",
     "does not match" : "一致しない",
-    "Example: {placeholder}" : "例: {プレースホルダー}",
-    "File name" : "ファイル名",
+    "File MIME type" : "ファイルMIMEタイプ",
     "File size (upload)" : "ファイルサイズ（アップロード）",
     "less" : "より小さい",
     "less or equals" : "より小さいか等しい",
     "greater or equals" : "大きいか等しい",
     "greater" : "大きい",
-    "File system tag" : "ファイルシステムタグ",
-    "is tagged with" : "に次のタグが付いている",
-    "is not tagged with" : "に次のタグが付いていない",
-    "Select tag…" : "タグを選択...",
     "Request remote address" : "リクエスト リモートアドレス",
     "matches IPv4" : "次の IPv4アドレスに合致",
     "does not match IPv4" : "次の IPv4アドレスに合致しない",
     "matches IPv6" : "次の IPv6アドレスに合致",
     "does not match IPv6" : "次の IPv6アドレスに合致しない",
+    "File system tag" : "ファイルシステムタグ",
+    "is tagged with" : "に次のタグが付いている",
+    "is not tagged with" : "に次のタグが付いていない",
+    "Request URL" : "呼びだしたURL",
     "Request time" : "ルール適用の時刻",
     "between" : "間",
     "not between" : "間ではない",
-    "Start" : "開始",
-    "End" : "終了",
-    "Select timezone…" : "タイムゾーンを選択...",
-    "Request URL" : "呼びだしたURL",
-    "Predefined URLs" : "定義済みのURL",
-    "Files WebDAV" : "ファイルWebDAV",
     "Request user agent" : "リクエスト時のユーザーエージェント",
-    "Sync clients" : "同期クライアントタイプ",
-    "Android client" : "アンドロイドクライアント",
-    "iOS client" : "iOSクライアント",
-    "Desktop client" : "デスクトップクライアント",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
     "User group membership" : "ユーザーがグループのメンバーかどうか",
     "is member of" : "が次のグループのメンバーである",
     "is not member of" : "が次のグループのメンバーではない",
@@ -50,27 +62,16 @@ OC.L10N.register(
     "Saved" : "保存しました",
     "Saving failed:" : "保存に失敗しました：",
     "Add rule group" : "ルールグループを追加する",
-    "The given operator is invalid" : "指定された演算子は無効",
-    "The given regular expression is invalid" : "指定の正規表現は無効",
-    "The given file size is invalid" : "指定されたファイルサイズは無効",
-    "The given tag id is invalid" : "指定されたIDタグは無効",
-    "The given IP range is invalid" : "指定されたIP範囲は無効",
-    "The given IP range is not valid for IPv4" : "指定されたIPはIPv4の範囲ではありません",
-    "The given IP range is not valid for IPv6" : "指定されたIPはIPv6の範囲ではありません",
-    "The given time span is invalid" : "指定された期間は無効です",
-    "The given start time is invalid" : "指定された開始時刻は無効です",
-    "The given end time is invalid" : "指定された終了時刻は無効です",
-    "The given group does not exist" : "指定されたグループは存在しません",
-    "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
-    "Operation #%s does not exist" : "#%s 操作は存在しません",
-    "Operation %s does not exist" : "%s 操作は存在しません",
-    "Operation %s is invalid" : "%s 操作は無効です",
-    "Check %s does not exist" : "チェック %s は存在しません",
-    "Check %s is invalid" : "チェック %s は無効です",
-    "Check #%s does not exist" : "チェック #%s は存在しません",
+    "Example: {placeholder}" : "例: {プレースホルダー}",
+    "Select tag…" : "タグを選択...",
+    "Start" : "開始",
+    "End" : "終了",
+    "Select timezone…" : "タイムゾーンを選択...",
+    "Sync clients" : "同期クライアントタイプ",
+    "Workflow" : "ワークフロー",
     "Files workflow engine" : "ファイルワークフローエンジン",
     "Open documentation" : "ドキュメントを開く",
     "Loading…" : "読み込み中...",
-    "Workflow" : "ワークフロー"
+    "Tag management" : "タグ管理"
 },
 "nplurals=1; plural=0;");
