@@ -1,53 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "파일 MIME 형식",
-    "is" : "맞음",
-    "is not" : "아님",
-    "matches" : "일치함",
-    "does not match" : "일치하지 않음",
-    "Example: {placeholder}" : "예: {placeholder}",
-    "File size (upload)" : "파일 크기(업로드)",
-    "less" : "작음",
-    "less or equals" : "작거나 같음",
-    "greater or equals" : "크거나 같음",
-    "greater" : "큼",
-    "File system tag" : "파일 시스템 태그",
-    "is tagged with" : "다음으로 태그됨",
-    "is not tagged with" : "다음으로 태그되지 않음",
-    "Select tag…" : "태그 선택…",
-    "Request remote address" : "요청의 원격 주소",
-    "matches IPv4" : "IPv4와 일치함",
-    "does not match IPv4" : "IPv4와 일치하지 않음",
-    "matches IPv6" : "IPv6과 일치함",
-    "does not match IPv6" : "IPv6과 일치하지 않음",
-    "Request time" : "요청 시간",
-    "between" : "사이",
-    "not between" : "사이에 없음",
-    "Start" : "시작",
-    "End" : "끝",
-    "Select timezone…" : "시간대 선택…",
-    "Request URL" : "요청 URL",
-    "Predefined URLs" : "사전 정의된 URL",
-    "Files WebDAV" : "파일 WebDAV",
-    "Request user agent" : "요청 사용자 에이전트",
-    "Sync clients" : "동기화 클라이언트",
-    "Android client" : "Android 클라이언트",
-    "iOS client" : "iOS 클라이언트",
-    "Desktop client" : "데스크톱 클라이언트",
-    "User group membership" : "사용자 그룹 구성원",
-    "is member of" : "구성원임",
-    "is not member of" : "구성원이 아님",
-    "Short rule description" : "짧은 규칙 설명",
-    "Add rule" : "규칙 추가",
-    "Reset" : "초기화",
-    "Save" : "저장",
-    "Saving…" : "저장 중…",
-    "Group list is empty" : "그룹 목록이 비었습니다.",
-    "Unable to retrieve the group list" : "그룹 리스트를 받아올 수 없습니다.",
-    "Saved" : "저장됨",
-    "Saving failed:" : "저장 실패:",
-    "Add rule group" : "규칙 그룹 추가",
     "The given operator is invalid" : "지정한 연산자가 잘못됨",
     "The given regular expression is invalid" : "지정한 정규 표현식이 잘못됨",
     "The given file size is invalid" : "지정한 파일 크기가 잘못됨",
@@ -59,15 +12,66 @@ OC.L10N.register(
     "The given start time is invalid" : "지정한 시작 시간이 올바르지 않음",
     "The given end time is invalid" : "지정한 끝 시간이 올바르지 않음",
     "The given group does not exist" : "지정한 그룹이 존재히지 않음",
-    "Check %s is invalid or does not exist" : "검사 %s이(가) 올바르지 않거나 존재하지 않음",
     "Operation #%s does not exist" : "작업 #%s이(가) 존재하지 않음",
     "Operation %s does not exist" : "작업 %s이(가) 존재하지 않음",
     "Operation %s is invalid" : "작업 %s이(가) 잘못됨",
     "Check %s does not exist" : "검사 %s이(가) 존재하지 않음",
     "Check %s is invalid" : "검사 %s이(가) 잘못됨",
     "Check #%s does not exist" : "검사 #%s이(가) 존재하지 않음",
+    "Check %s is invalid or does not exist" : "검사 %s이(가) 올바르지 않거나 존재하지 않음",
+    "Predefined URLs" : "사전 정의된 URL",
+    "Files WebDAV" : "파일 WebDAV",
+    "Android client" : "Android 클라이언트",
+    "iOS client" : "iOS 클라이언트",
+    "Desktop client" : "데스크톱 클라이언트",
+    "Thunderbird & Outlook addons" : "Thunderbird와 Outlook 확장 기능",
+    "File name" : "파일 이름",
+    "is" : "맞음",
+    "is not" : "아님",
+    "matches" : "일치함",
+    "does not match" : "일치하지 않음",
+    "File MIME type" : "파일 MIME 형식",
+    "File size (upload)" : "파일 크기(업로드)",
+    "less" : "작음",
+    "less or equals" : "작거나 같음",
+    "greater or equals" : "크거나 같음",
+    "greater" : "큼",
+    "Request remote address" : "요청의 원격 주소",
+    "matches IPv4" : "IPv4와 일치함",
+    "does not match IPv4" : "IPv4와 일치하지 않음",
+    "matches IPv6" : "IPv6과 일치함",
+    "does not match IPv6" : "IPv6과 일치하지 않음",
+    "File system tag" : "파일 시스템 태그",
+    "is tagged with" : "다음으로 태그됨",
+    "is not tagged with" : "다음으로 태그되지 않음",
+    "Request URL" : "요청 URL",
+    "Request time" : "요청 시간",
+    "between" : "사이",
+    "not between" : "사이에 없음",
+    "Request user agent" : "요청 사용자 에이전트",
+    "User group membership" : "사용자 그룹 구성원",
+    "is member of" : "구성원임",
+    "is not member of" : "구성원이 아님",
+    "Short rule description" : "짧은 규칙 설명",
+    "Add rule" : "규칙 추가",
+    "Reset" : "초기화",
+    "Save" : "저장",
+    "Saving…" : "저장 중…",
+    "Group list is empty" : "그룹 목록이 비었음",
+    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
+    "Saved" : "저장됨",
+    "Saving failed:" : "저장 실패:",
+    "Add rule group" : "규칙 그룹 추가",
+    "Example: {placeholder}" : "예: {placeholder}",
+    "Select tag…" : "태그 선택…",
+    "Start" : "시작",
+    "End" : "끝",
+    "Select timezone…" : "시간대 선택…",
+    "Sync clients" : "동기화 클라이언트",
+    "Workflow" : "작업 흐름",
+    "Files workflow engine" : "파일 작업 흐름 엔진",
     "Open documentation" : "문서 열기",
     "Loading…" : "불러오는 중…",
-    "Workflow" : "작업 흐름"
+    "Tag management" : "태그 관리"
 },
 "nplurals=1; plural=0;");
