@@ -1,40 +1,52 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "Datnes MIME tips",
+    "The given operator is invalid" : "Norādītais operators ir nederīgs",
+    "The given regular expression is invalid" : "Norādītā regulārā izteiksme nav derīga.",
+    "The given file size is invalid" : "Norādītais datnes formāts nav derīgs",
+    "The given tag id is invalid" : "Norādītais birkas id ir nederīgs",
+    "The given IP range is invalid" : "Norādītais IP diapazons ir nederīgs",
+    "The given IP range is not valid for IPv4" : "Norādītais IP diapazons nav derīgs IPv4",
+    "The given IP range is not valid for IPv6" : "Norādītais IP diapazons nav derīgs IPv6",
+    "The given time span is invalid" : "Norādītais laiks nav derīgs.",
+    "The given start time is invalid" : "Dotais sākuma laiks ir nederīgs",
+    "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
+    "The given group does not exist" : "Norādītā grupa nepastāv.",
+    "Operation #%s does not exist" : "Operation #%s does not exist",
+    "Operation %s does not exist" : "Darbība %s neeksistē",
+    "Operation %s is invalid" : "Darbība %s ir nederīga",
+    "Check %s does not exist" : "Pārbaude %s nepastāv",
+    "Check %s is invalid" : "Pārbaude %s ir nederīga",
+    "Check #%s does not exist" : "Pārbaude #%s nepastāv",
+    "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
+    "Predefined URLs" : "Standarta URLs",
+    "Files WebDAV" : "WebDAV datnes",
+    "Android client" : "Android klients",
+    "iOS client" : "iOS klients",
+    "Desktop client" : "Darbvirsmas klients",
     "is" : "ir",
     "is not" : "nav",
     "matches" : "atbilst",
     "does not match" : "neatbilst",
-    "Example: {placeholder}" : "Piemērs: {placeholder}",
+    "File MIME type" : "Datnes MIME tips",
     "File size (upload)" : "Datnes lielums (augšupielādēt)",
     "less" : "mazāk",
     "less or equals" : "mazāks vai vienāds ar",
     "greater or equals" : "lielāks vai vienāds ar",
     "greater" : "lielāks",
-    "File system tag" : "Failu sistēmas atzīme",
-    "is tagged with" : "atzīmēts ar",
-    "is not tagged with" : "nav atzīmēts ar",
-    "Select tag…" : "Izvēlies atzīmi...",
     "Request remote address" : "Pieprasīt attālo adresi",
     "matches IPv4" : "atbilst IPv4",
     "does not match IPv4" : "neatbilst IPv4",
     "matches IPv6" : "atbilst IPv6",
     "does not match IPv6" : "neatbilst IPv6",
+    "File system tag" : "Failu sistēmas birka",
+    "is tagged with" : "atzīmēts ar",
+    "is not tagged with" : "nav atzīmēts ar",
+    "Request URL" : "Pieprasījuma URL",
     "Request time" : "Pieprasījuma laiks",
     "between" : "starp",
     "not between" : "nav starp",
-    "Start" : "Sākums",
-    "End" : "Beigas",
-    "Select timezone…" : "Izvēlieties laika joslu...",
-    "Request URL" : "Pieprasījuma URL",
-    "Predefined URLs" : "Standarta URLs",
-    "Files WebDAV" : "WebDAV datnes",
     "Request user agent" : "Nepieciešams lietotāja aģents",
-    "Sync clients" : "Sync klients",
-    "Android client" : "Android klients",
-    "iOS client" : "iOS klients",
-    "Desktop client" : "Darbvirsmas klients",
     "User group membership" : "Lietotāju grupas piederība",
     "is member of" : "ir biedrs",
     "is not member of" : "nav biedrs",
@@ -48,26 +60,14 @@ OC.L10N.register(
     "Saved" : "Saglabāts",
     "Saving failed:" : "Saglabāšana neizdevās:",
     "Add rule group" : "Pievienot kārtulu grupas",
-    "The given operator is invalid" : "Norādītais operators ir nederīgs",
-    "The given regular expression is invalid" : "Norādītā regulārā izteiksme nav derīga.",
-    "The given file size is invalid" : "Norādītais faila formāts nav derīgs",
-    "The given tag id is invalid" : "Norādītais birkas id ir nederīgs",
-    "The given IP range is invalid" : "Norādītais IP diapazons ir nederīgs",
-    "The given IP range is not valid for IPv4" : "Norādītais IP diapazons nav derīgs IPv4",
-    "The given IP range is not valid for IPv6" : "Norādītais IP diapazons nav derīgs IPv6",
-    "The given time span is invalid" : "Norādītais laiks nav derīgs.",
-    "The given start time is invalid" : "Dotais sākuma laiks ir nederīgs",
-    "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
-    "The given group does not exist" : "Norādītā grupa nepastāv.",
-    "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
-    "Operation #%s does not exist" : "Operation #%s does not exist",
-    "Operation %s does not exist" : "Darbība %s neeksistē",
-    "Operation %s is invalid" : "Darbība %s ir nederīga",
-    "Check %s does not exist" : "Pārbaude %s nepastāv",
-    "Check %s is invalid" : "Pārbaude %s ir nederīga",
-    "Check #%s does not exist" : "Pārbaude #%s nepastāv",
+    "Example: {placeholder}" : "Piemērs: {placeholder}",
+    "Select tag…" : "Izvēlies birku...",
+    "Start" : "Sākums",
+    "End" : "Beigas",
+    "Select timezone…" : "Izvēlieties laika joslu...",
+    "Sync clients" : "Sync klients",
+    "Workflow" : "Darbplūsma",
     "Open documentation" : "Atvērt dokumentāciju",
-    "Loading…" : "Ielādē …",
-    "Workflow" : "Darbplūsma"
+    "Loading…" : "Ielādē …"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
