@@ -37,20 +37,22 @@ OC.L10N.register(
     "Select a filter" : "Wybierz filtr",
     "Select a comparator" : "Wybierz komparator",
     "Select a file type" : "Wybierz typ pliku",
+    "e.g. httpd/unix-directory" : "np. httpd/unix-directory",
     "Images" : "Obrazy",
     "Office documents" : "Dokumenty biurowe",
     "PDF documents" : "Dokumenty PDF",
     "Custom mimetype" : "Niestandardowy typ MIME",
+    "Select a tag" : "Wybierz etykietę",
     "No results" : "Brak wyników",
     "%s (invisible)" : "%s (niewidoczny)",
     "%s (restricted)" : "%s (ograniczony)",
+    "Please enter a valid time span" : "Podaj prawidłowy przedział czasu",
     "Select a request URL" : "Wybierz adres URL żądania",
     "Predefined URLs" : "Przedefiniowanie URLs",
     "Files WebDAV" : "Pliki WebDAV",
     "Others" : "Inne",
     "Custom URL" : "Niestandardowy adres URL",
     "Select a user agent" : "Wybierz klienta użytkownika",
-    "Sync clients" : "Klienci synchronizacji",
     "Android client" : "Klient Android",
     "iOS client" : "Klient iOS",
     "Desktop client" : "Klient na komputer",
@@ -58,8 +60,8 @@ OC.L10N.register(
     "Custom user agent" : "Niestandardowy klient użytkownika",
     "When" : "Kiedy",
     "and" : "i",
-    "Cancel rule creation" : "Anuluj tworzenie reguły",
-    "Remove rule" : "Usuń regułę",
+    "Cancel" : "Anuluj",
+    "Delete" : "Usuń",
     "The configuration is invalid" : "Konfiguracja jest nieprawidłowa",
     "Show less" : "Pokaż mniej",
     "Show more" : "Pokaż więcej",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Start" : "Start",
     "End" : "Koniec",
     "Select timezone…" : "Wybierz strefę czasową…",
+    "Sync clients" : "Klienci synchronizacji",
     "Workflow" : "Workflow",
     "Files workflow engine" : "Pliki silnika workflow",
     "Open documentation" : "Otwórz dokumentację",
