@@ -1,41 +1,54 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "Vrsta MIME datoteke",
+    "The given operator is invalid" : "Podan operator ni veljaven.",
+    "The given regular expression is invalid" : "Podan logični izraz ni veljaven.",
+    "The given file size is invalid" : "Podana velikost datoteke ni veljavna.",
+    "The given tag id is invalid" : "Podan ID oznake ni veljaven.",
+    "The given IP range is invalid" : "Podan obseg IP ni veljaven.",
+    "The given IP range is not valid for IPv4" : "Podan obseg IP ni veljaven za IPv4.",
+    "The given IP range is not valid for IPv6" : "Podan obseg IP ni veljaven za IPv6.",
+    "The given time span is invalid" : "Podan časovni obseg ni veljaven.",
+    "The given start time is invalid" : "Podan čas začetka ni veljaven.",
+    "The given end time is invalid" : "Podan čas zaključka ni veljaven.",
+    "The given group does not exist" : "Podana skupina ne obstaja.",
+    "Operation #%s does not exist" : "Opravilo #%s ne obstaja.",
+    "Operation %s does not exist" : "Opravilo %s ne obstaja.",
+    "Operation %s is invalid" : "Opravilo %s ni veljavno.",
+    "Check %s does not exist" : "Preverba %s ne obstaja.",
+    "Check %s is invalid" : "Preverba %s ni veljavna.",
+    "Check #%s does not exist" : "Preverba #%s ne obstaja.",
+    "Check %s is invalid or does not exist" : "Preverba %s ne obstaja.",
+    "Predefined URLs" : "Določeni naslovi URL",
+    "Files WebDAV" : "Datoteke WebDAV",
+    "Android client" : "Odjemalec za Android",
+    "iOS client" : "Odjemalec za iOS",
+    "Desktop client" : "Odjemalec za namizne računalnike",
+    "Thunderbird & Outlook addons" : "Razširitve za Thunderbird in Outlook",
+    "File name" : "Ime datoteke",
     "is" : "je",
     "is not" : "ni",
     "matches" : "se sklada z",
     "does not match" : "se ne sklada z",
-    "Example: {placeholder}" : "Primer: {placeholder}",
+    "File MIME type" : "Vrsta MIME datoteke",
     "File size (upload)" : "Velikost datoteke (pošiljanje)",
     "less" : "je manjša",
     "less or equals" : "je manjša ali enaka",
     "greater or equals" : "je večja ali enaka",
     "greater" : "je večja",
-    "File system tag" : "Sistemska oznaka datoteke",
-    "is tagged with" : "je",
-    "is not tagged with" : "ni",
-    "Select tag…" : "Izbor oznake ...",
     "Request remote address" : "Oddaljeni naslov",
     "matches IPv4" : "se sklada z IPv4",
     "does not match IPv4" : "ni skladen z IPv4",
     "matches IPv6" : "se sklada z IPv6",
     "does not match IPv6" : "ni skladen z IPv6",
+    "File system tag" : "Sistemska oznaka datoteke",
+    "is tagged with" : "je",
+    "is not tagged with" : "ni",
+    "Request URL" : "Naslov URL za dostop",
     "Request time" : "Čas dostopa",
     "between" : "je dovoljen med",
     "not between" : "ni dovoljen med",
-    "Start" : "Začetek",
-    "End" : "Konec",
-    "Select timezone…" : "Časovni pas ...",
-    "Request URL" : "Naslov URL za dostop",
-    "Predefined URLs" : "Določeni naslovi URL",
-    "Files WebDAV" : "Datoteke WebDAV",
     "Request user agent" : "Uporabniški odjemalec",
-    "Sync clients" : "Odjemalci za usklajevanje",
-    "Android client" : "Odjemalec za Android",
-    "iOS client" : "Odjemalec za iOS",
-    "Desktop client" : "Odjemalec za namizne računalnike",
-    "Thunderbird & Outlook addons" : "Razširitve za Thunderbird in Outlook",
     "User group membership" : "Članstvo v uporabniških skupinah",
     "is member of" : "je v skupini",
     "is not member of" : "ni v skupini",
@@ -49,27 +62,16 @@ OC.L10N.register(
     "Saved" : "Shranjeno",
     "Saving failed:" : "Shranjevanje je spodletelo:",
     "Add rule group" : "Dodaj skupino pravil",
-    "The given operator is invalid" : "Podan operator ni veljaven.",
-    "The given regular expression is invalid" : "Podan logični izraz ni veljaven.",
-    "The given file size is invalid" : "Podana velikost datoteke ni veljavna.",
-    "The given tag id is invalid" : "Podan ID oznake ni veljaven.",
-    "The given IP range is invalid" : "Podan obseg IP ni veljaven.",
-    "The given IP range is not valid for IPv4" : "Podan obseg IP ni veljaven za IPv4.",
-    "The given IP range is not valid for IPv6" : "Podan obseg IP ni veljaven za IPv6.",
-    "The given time span is invalid" : "Podan časovni obseg ni veljaven.",
-    "The given start time is invalid" : "Podan čas začetka ni veljaven.",
-    "The given end time is invalid" : "Podan čas zaključka ni veljaven.",
-    "The given group does not exist" : "Podana skupina ne obstaja.",
-    "Check %s is invalid or does not exist" : "Preverba %s ne obstaja.",
-    "Operation #%s does not exist" : "Opravilo #%s ne obstaja.",
-    "Operation %s does not exist" : "Opravilo %s ne obstaja.",
-    "Operation %s is invalid" : "Opravilo %s ni veljavno.",
-    "Check %s does not exist" : "Preverba %s ne obstaja.",
-    "Check %s is invalid" : "Preverba %s ni veljavna.",
-    "Check #%s does not exist" : "Preverba #%s ne obstaja.",
+    "Example: {placeholder}" : "Primer: {placeholder}",
+    "Select tag…" : "Izbor oznake ...",
+    "Start" : "Začetek",
+    "End" : "Konec",
+    "Select timezone…" : "Časovni pas ...",
+    "Sync clients" : "Odjemalci za usklajevanje",
+    "Workflow" : "Delovni tok",
     "Files workflow engine" : "Delovni tok datotek",
     "Open documentation" : "Odpri dokumentacijo",
     "Loading…" : "Poteka nalaganje ...",
-    "Workflow" : "Delovni tok"
+    "Tag management" : "Upravljanje oznak"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
