@@ -1,42 +1,84 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "Filens MIME-typ",
+    "The given operator is invalid" : "Den valda operatören är felaktig",
+    "The given regular expression is invalid" : "Det valda vanliga uttrycket är felaktigt",
+    "The given file size is invalid" : "Den valda filstorleken är felaktig",
+    "The given tag id is invalid" : "Den valda taggen är felaktig",
+    "The given IP range is invalid" : "Det valda IP-spannet är felaktigt",
+    "The given IP range is not valid for IPv4" : "Det valda IP-spannet är felaktigt för IPv4",
+    "The given IP range is not valid for IPv6" : "Det valda IP-spannet är felaktigt för IPv6",
+    "The given time span is invalid" : "Det valda tidsspannet är felaktigt",
+    "The given start time is invalid" : "Den valda starttiden är felaktig",
+    "The given end time is invalid" : "Den valda sluttiden är felaktig",
+    "The given group does not exist" : "Den valda gruppen finns inte",
+    "File" : "Fil",
+    "File created" : "Fil skapad",
+    "File updated" : "Fil uppdaterad",
+    "File renamed" : "Fil omdöpt",
+    "File deleted" : "Fil raderad",
+    "File accessed" : "Fil öppnad",
+    "File copied" : "Fil kopierad",
+    "Tag assigned" : "Tagg tilldelad",
+    "Operation #%s does not exist" : "Operationen #%s existerar inte",
+    "No events are chosen." : "Inga händelser valda",
+    "Operation %s does not exist" : "Operationen %s existerar inte",
+    "Operation %s is invalid" : "Operationen %s är ogiltig",
+    "Check %s does not exist" : "Kontroll av %s existerar inte",
+    "Check %s is invalid" : "Kontroll av %s är ogiltig",
+    "Check #%s does not exist" : "Kontroll av #%s existerar inte",
+    "Check %s is invalid or does not exist" : "Kontroll av %s är ogiltig eller existerar inte",
+    "Workflows" : "Arbetsflöden",
+    "Select a filter" : "Välj ett filter",
+    "Select a comparator" : "Välj en jämförelse",
+    "Select a file type" : "Välj en filtyp",
+    "Images" : "Bilder",
+    "Office documents" : "Officedokument",
+    "PDF documents" : "PDF-dokument",
+    "Custom mimetype" : "Anpassad mimetyp",
+    "No results" : "Inga resultat",
+    "%s (invisible)" : "%s (osynlig)",
+    "%s (restricted)" : "%s (begränsad)",
+    "Select a request URL" : "Välj en webbadress för begäran",
+    "Predefined URLs" : "Förinställda webbadresser",
+    "Files WebDAV" : "Filer WebDAV",
+    "Others" : "Övriga",
+    "Custom URL" : "Anpassad webbadress",
+    "Select a user agent" : "Välj en användaragent",
+    "Android client" : "Android-klient",
+    "iOS client" : "iOS-klient",
+    "Desktop client" : "Skrivbordsklient",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook - tillägg",
+    "Custom user agent" : "Anpassad användaragent",
+    "When" : "När",
+    "and" : "och",
+    "The configuration is invalid" : "Konfigurationen är felaktig",
+    "Show less" : "Visa mindre",
+    "Show more" : "Visa mer",
+    "File name" : "Filnamn",
     "is" : "är",
     "is not" : "är inte",
     "matches" : "träffar",
     "does not match" : "matchar inte",
-    "Example: {placeholder}" : "Exempel: {placeholder}",
-    "File name" : "Filnamn",
+    "File MIME type" : "Filens MIME-typ",
     "File size (upload)" : "Filstorlek (uppladdning)",
     "less" : "mindre",
     "less or equals" : "mindre eller motsvarar",
     "greater or equals" : "större eller motsvarar",
     "greater" : "större",
-    "File system tag" : "Filens systemtagg",
-    "is tagged with" : "är taggad med",
-    "is not tagged with" : "är inte taggad med",
-    "Select tag…" : "Välj tagg...",
     "Request remote address" : "Begär extern adress",
     "matches IPv4" : "matchar IPv4",
     "does not match IPv4" : "matchar inte IPv4",
     "matches IPv6" : "matchar IPv6",
     "does not match IPv6" : "matchar inte IPv6",
+    "File system tag" : "Filens systemtagg",
+    "is tagged with" : "är taggad med",
+    "is not tagged with" : "är inte taggad med",
+    "Request URL" : "Begär webbadress",
     "Request time" : "Begärningstid",
     "between" : "mellan",
     "not between" : "inte mellan",
-    "Start" : "Början",
-    "End" : "Slutet",
-    "Select timezone…" : "Välj tidszon...",
-    "Request URL" : "Begär URL",
-    "Predefined URLs" : "Förinställda URL:er",
-    "Files WebDAV" : "Filer WebDAV",
     "Request user agent" : "Begär användaragent",
-    "Sync clients" : "Synkroniseringsklienter",
-    "Android client" : "Android-klient",
-    "iOS client" : "iOS-klient",
-    "Desktop client" : "Skrivbordsklient",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook - tillägg",
     "User group membership" : "Användargruppsmedlemskap",
     "is member of" : "är medlem i",
     "is not member of" : "är inte medlem i",
@@ -50,27 +92,15 @@ OC.L10N.register(
     "Saved" : "Sparad",
     "Saving failed:" : "Gick ej att spara: ",
     "Add rule group" : "Lägg till regelgrupp",
-    "The given operator is invalid" : "Den valda operatören är felaktig",
-    "The given regular expression is invalid" : "Det valda vanliga uttrycket är felaktigt",
-    "The given file size is invalid" : "Den valda filstorleken är felaktig",
-    "The given tag id is invalid" : "Den valda taggen är felaktig",
-    "The given IP range is invalid" : "Det valda IP-spannet är felaktigt",
-    "The given IP range is not valid for IPv4" : "Det valda IP-spannet är felaktigt för IPv4",
-    "The given IP range is not valid for IPv6" : "Det valda IP-spannet är felaktigt för IPv6",
-    "The given time span is invalid" : "Det valda tidsspannet är felaktigt",
-    "The given start time is invalid" : "Den valda starttiden är felaktig",
-    "The given end time is invalid" : "Den valda sluttiden är felaktig",
-    "The given group does not exist" : "Den valda gruppen finns inte",
-    "Check %s is invalid or does not exist" : "Kontroll av %s är ogiltig eller existerar inte",
-    "Operation #%s does not exist" : "Operationen #%s existerar inte",
-    "Operation %s does not exist" : "Operationen %s existerar inte",
-    "Operation %s is invalid" : "Operationen %s är ogiltig",
-    "Check %s does not exist" : "Kontroll av %s existerar inte",
-    "Check %s is invalid" : "Kontroll av %s är ogiltig",
-    "Check #%s does not exist" : "Kontroll av #%s existerar inte",
-    "Tag management" : "Tagghantering",
+    "Example: {placeholder}" : "Exempel: {placeholder}",
+    "Select tag…" : "Välj tagg...",
+    "Start" : "Början",
+    "End" : "Slutet",
+    "Select timezone…" : "Välj tidszon...",
+    "Sync clients" : "Synkroniseringsklienter",
+    "Workflow" : "Arbetsflöde",
     "Open documentation" : "Öppna dokumentation",
     "Loading…" : "Laddar...",
-    "Workflow" : "Arbetsflöde"
+    "Tag management" : "Tagghantering"
 },
 "nplurals=2; plural=(n != 1);");
