@@ -1,42 +1,89 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "File MIME type" : "Dosya MIME türü",
+    "The given operator is invalid" : "Belirtilen işlem geçersiz",
+    "The given regular expression is invalid" : "Belirtilen kurallı ifade geçersiz",
+    "The given file size is invalid" : "Belirtilen dosya boyutu geçersiz",
+    "The given tag id is invalid" : "Belirtilen etiket kodu geçersiz",
+    "The given IP range is invalid" : "Belirtilen IP adresi aralığı geçersiz",
+    "The given IP range is not valid for IPv4" : "Belirtilen IP adresi aralığı IPv4 için geçersiz",
+    "The given IP range is not valid for IPv6" : "Belirtilen IP adresi aralığı IPv6 için geçersiz",
+    "The given time span is invalid" : "Belirtilen zaman aralığı geçersiz",
+    "The given start time is invalid" : "Belirtilen başlangıç zamanı geçersiz",
+    "The given end time is invalid" : "Belirtilen bitiş zamanı geçersiz",
+    "The given group does not exist" : "Belirtilen grup bulunamadı",
+    "File" : "Dosya",
+    "File created" : "Dosya oluşturuldu",
+    "File updated" : "Dosya güncellendi",
+    "File renamed" : "Dosya yeniden adlandırıldı",
+    "File deleted" : "Dosya silindi",
+    "File accessed" : "Dosyaya erişildi",
+    "File copied" : "Dosya kopyalandı",
+    "Tag assigned" : "Etiket atandı",
+    "Operation #%s does not exist" : "#%s işlemi bulunamadı",
+    "Entity %s does not exist" : "%s varlığı bulunamadı",
+    "Entity %s is invalid" : "%s varlığı geçersiz",
+    "No events are chosen." : "Herhangi bir etkinlik seçilmemiş.",
+    "Entity %s has no event %s" : "%s varlığının herhangi bir etkinliği yok %s",
+    "Operation %s does not exist" : "%s işlemi bulunamadı",
+    "Operation %s is invalid" : "%s işlemi geçersiz",
+    "Check %s does not exist" : "%s denetimi bulunamadı",
+    "Check %s is invalid" : "%s denetimi geçersiz",
+    "Check %s is not allowed with this entity" : "Bu varlık için %s denetimi yapılamaz",
+    "Check #%s does not exist" : "#%s denetimi bulunamadı",
+    "Check %s is invalid or does not exist" : "%s denetimi geçersiz ya da bulunamadı",
+    "Workflows" : "İş akışları",
+    "Nextcloud workflow engine" : "Nextcloud iş akışı işleyici",
+    "Select a filter" : "Bir süzgeç seçin",
+    "Select a comparator" : "Bir karşılaştırıcı seçin",
+    "Select a file type" : "Bir dosya türü seçin",
+    "Images" : "Görseller",
+    "Office documents" : "Office belgeleri",
+    "PDF documents" : "PDF belgeleri",
+    "Custom mimetype" : "Özel MIME türü",
+    "No results" : "Herhangi bir sonuç bulunamadı",
+    "%s (invisible)" : "%s (görünmez)",
+    "%s (restricted)" : "%s (kısıtlı)",
+    "Select a request URL" : "Bir istek adresi seçin",
+    "Predefined URLs" : "Hazır Adresler",
+    "Files WebDAV" : "Dosya WebDAV",
+    "Others" : "Diğerleri",
+    "Custom URL" : "Özel adres",
+    "Select a user agent" : "Bir kullanıcı uygulaması seçin",
+    "Android client" : "Android istemcisi",
+    "iOS client" : "iOS istemcisi",
+    "Desktop client" : "Masaüstü istemcisi",
+    "Thunderbird & Outlook addons" : "Thunderbird ve Outlook eklentileri",
+    "Custom user agent" : "Özel kullanıcı uygulaması",
+    "When" : "Şu zamanda",
+    "and" : "ve",
+    "The configuration is invalid" : "Yapılandırma geçersiz",
+    "Show less" : "Daha az ayrıntı",
+    "Show more" : "Daha çok ayrıntı",
+    "File name" : "Dosya adı",
     "is" : "şu olan",
     "is not" : "şu olmayan",
     "matches" : "şuna uyan",
     "does not match" : "şuna uymayan",
-    "Example: {placeholder}" : "Örnek: {placeholder}",
-    "File name" : "Dosya adı",
+    "File MIME type" : "Dosya MIME türü",
     "File size (upload)" : "Dosya boyutu (yükleme)",
     "less" : "şundan küçük",
     "less or equals" : "şundan küçük ya da eşit",
     "greater or equals" : "şundan büyük ya da eşit",
     "greater" : "şundan büyük",
-    "File system tag" : "Dosya sistemi etiketi",
-    "is tagged with" : "şununla etiketlenmiş",
-    "is not tagged with" : "şununla etiketlenmemiş",
-    "Select tag…" : "Etiketi seçin...",
     "Request remote address" : "Uzak adres isteği",
     "matches IPv4" : "şu IPv4 adresine uyan",
     "does not match IPv4" : "şu IPv4 adresine uymayan",
     "matches IPv6" : "şu IPv6 adresine uyan",
     "does not match IPv6" : "şu IPv6 adresine uymayan",
+    "File system tag" : "Dosya sistemi etiketi",
+    "is tagged with" : "şununla etiketlenmiş",
+    "is not tagged with" : "şununla etiketlenmemiş",
+    "Request URL" : "İstek Adresi",
     "Request time" : "İstek zamanı",
     "between" : "şunların arasında olan",
     "not between" : "şunların arasında olmayan",
-    "Start" : "Başlangıç",
-    "End" : "Bitiş",
-    "Select timezone…" : "Saat dilimini seçin...",
-    "Request URL" : "İstek Adresi",
-    "Predefined URLs" : "Hazır Adresler",
-    "Files WebDAV" : "Dosya WebDAV",
-    "Request user agent" : "Kullanıcı yazılımı istensin",
-    "Sync clients" : "İstemciler eşitlensin",
-    "Android client" : "Android istemcisi",
-    "iOS client" : "iOS istemcisi",
-    "Desktop client" : "Masaüstü istemcisi",
-    "Thunderbird & Outlook addons" : "Thunderbird ve Outlook eklentileri",
+    "Request user agent" : "Kullanıcı uygulaması istensin",
     "User group membership" : "Kullanıcı grubu üyeliği",
     "is member of" : "şunun üyesi olan",
     "is not member of" : "şunun üyesi olmayan",
@@ -50,28 +97,16 @@ OC.L10N.register(
     "Saved" : "Kaydedildi",
     "Saving failed:" : "Kaydedilemedi:",
     "Add rule group" : "Kural grubu ekle",
-    "The given operator is invalid" : "Belirtilen işlem geçersiz",
-    "The given regular expression is invalid" : "Belirtilen kurallı ifade geçersiz",
-    "The given file size is invalid" : "Belirtilen dosya boyutu geçersiz",
-    "The given tag id is invalid" : "Belirtilen etiket kodu geçersiz",
-    "The given IP range is invalid" : "Belirtilen IP adresi aralığı geçersiz",
-    "The given IP range is not valid for IPv4" : "Belirtilen IP adresi aralığı IPv4 için geçersiz",
-    "The given IP range is not valid for IPv6" : "Belirtilen IP adresi aralığı IPv6 için geçersiz",
-    "The given time span is invalid" : "Belirtilen zaman aralığı geçersiz",
-    "The given start time is invalid" : "Belirtilen başlangıç zamanı geçersiz",
-    "The given end time is invalid" : "Belirtilen bitiş zamanı geçersiz",
-    "The given group does not exist" : "Belirtilen grup bulunamadı",
-    "Check %s is invalid or does not exist" : "%s denetimi geçersiz ya da bulunamadı",
-    "Operation #%s does not exist" : "#%s işlemi bulunamadı",
-    "Operation %s does not exist" : "%s işlemi bulunamadı",
-    "Operation %s is invalid" : "%s işlemi geçersiz",
-    "Check %s does not exist" : "%s denetimi bulunamadı",
-    "Check %s is invalid" : "%s denetimi geçersiz",
-    "Check #%s does not exist" : "#%s denetimi bulunamadı",
-    "Tag management" : "Etiket yönetimi",
+    "Example: {placeholder}" : "Örnek: {placeholder}",
+    "Select tag…" : "Etiketi seçin...",
+    "Start" : "Başlangıç",
+    "End" : "Bitiş",
+    "Select timezone…" : "Saat dilimini seçin...",
+    "Sync clients" : "İstemciler eşitlensin",
+    "Workflow" : "İş akışı",
     "Files workflow engine" : "Dosya iş akışı motoru",
     "Open documentation" : "Belgeleri aç",
     "Loading…" : "Yükleniyor...",
-    "Workflow" : "İş akışı"
+    "Tag management" : "Etiket yönetimi"
 },
 "nplurals=2; plural=(n > 1);");
