@@ -1,55 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "Short rule description" : "短规则说明",
-    "Add rule" : "添加规则",
-    "Reset" : "重置",
-    "Save" : "保存",
-    "Saving…" : "保存中...",
-    "Group list is empty" : "用户群组列表空",
-    "Unable to retrieve the group list" : "无法获取用户群组列表",
-    "Saved" : "已保存",
-    "Saving failed:" : "保存失败：",
-    "Add rule group" : "添加规则组",
-    "File MIME type" : "文件 MIME 类型",
-    "is" : "是",
-    "is not" : "不是",
-    "matches" : "匹配",
-    "does not match" : "不匹配",
-    "Example: {placeholder}" : "例子：{placeholder}",
-    "File name" : "文件名",
-    "File size (upload)" : "文件大小 (上传)",
-    "less" : "小于",
-    "less or equals" : "小于等于",
-    "greater or equals" : "大于等于",
-    "greater" : "大于",
-    "File system tag" : "文件系统标签",
-    "is tagged with" : "标记为",
-    "is not tagged with" : "未标记为",
-    "Select tag…" : "选择标签...",
-    "Request remote address" : "要求远程地址",
-    "matches IPv4" : "匹配 IPv4",
-    "does not match IPv4" : "不匹配 IPv4",
-    "matches IPv6" : "匹配 IPv6",
-    "does not match IPv6" : "不匹配 IPv6",
-    "Request time" : "请求时间",
-    "between" : "之间",
-    "not between" : "不在之间",
-    "Start" : "开始",
-    "End" : "结束",
-    "Select timezone…" : "选择时区...",
-    "Request URL" : "请求 URL",
-    "Predefined URLs" : "预定义 URL",
-    "Files WebDAV" : "文件 WebDAV",
-    "Request user agent" : "请求用户代理",
-    "Sync clients" : "同步客户端",
-    "Android client" : "Android 客户端",
-    "iOS client" : "iOS 客户端",
-    "Desktop client" : "桌面客户端",
-    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
-    "User group membership" : "用户组成员资格",
-    "is member of" : "是成员",
-    "is not member of" : "不是成员",
     "The given operator is invalid" : "给定的运算符无效",
     "The given regular expression is invalid" : "给定的正则表达式无效",
     "The given file size is invalid" : "给定的文件大小无效",
@@ -61,17 +12,101 @@ OC.L10N.register(
     "The given start time is invalid" : "给定的开始时间无效",
     "The given end time is invalid" : "输入的截止时间无效",
     "The given group does not exist" : "输入的群组不存在",
-    "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
+    "File" : "文件",
+    "File created" : "已创建的文件",
+    "File updated" : "文件已更新",
+    "File renamed" : "重命名的文件",
+    "File deleted" : "已删除文件",
+    "File accessed" : "已访问的文件",
+    "File copied" : "已复制的文件",
+    "Tag assigned" : "已指派的标签",
     "Operation #%s does not exist" : "操作 %s 不存在",
+    "Entity %s does not exist" : "实体%s不存在",
+    "Entity %s is invalid" : "实体%s是无效的",
+    "No events are chosen." : "没有事件被选中。",
+    "Entity %s has no event %s" : "实体%s没有事件%s",
     "Operation %s does not exist" : "操作 %s 不存在",
     "Operation %s is invalid" : "操作 %s 无效",
     "Check %s does not exist" : "检查 %s 不存在",
     "Check %s is invalid" : "检查%s是不可用",
+    "Check %s is not allowed with this entity" : "对于此实体，检查%s是不被允许的",
     "Check #%s does not exist" : "检查 #%s 不存在",
-    "Tag management" : "标签管理",
+    "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
+    "Workflows" : "工作流",
+    "Nextcloud workflow engine" : "Nextcloud工作流引擎",
+    "Select a filter" : "选择一个过滤器",
+    "Select a comparator" : "选择一个比较器",
+    "Select a file type" : "选择一个文件类型",
+    "Images" : "图片",
+    "Office documents" : "Office 文档",
+    "PDF documents" : "PDF文档",
+    "Custom mimetype" : "自定义MIME类型",
+    "No results" : "无结果",
+    "%s (invisible)" : "%s（不可见）",
+    "%s (restricted)" : "%s（受限）",
+    "Select a request URL" : "选择一个请求URL",
+    "Predefined URLs" : "预定义 URL",
+    "Files WebDAV" : "文件 WebDAV",
+    "Others" : "其它",
+    "Custom URL" : "自定义URL",
+    "Select a user agent" : "选择一个用户代理",
+    "Android client" : "Android 客户端",
+    "iOS client" : "iOS 客户端",
+    "Desktop client" : "桌面客户端",
+    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
+    "Custom user agent" : "自定义用户代理",
+    "When" : "时间",
+    "and" : "与",
+    "The configuration is invalid" : "此配置是无效的",
+    "Show less" : "显示更少",
+    "Show more" : "显示更多",
+    "File name" : "文件名",
+    "is" : "是",
+    "is not" : "不是",
+    "matches" : "匹配",
+    "does not match" : "不匹配",
+    "File MIME type" : "文件 MIME 类型",
+    "File size (upload)" : "文件大小 (上传)",
+    "less" : "小于",
+    "less or equals" : "小于等于",
+    "greater or equals" : "大于等于",
+    "greater" : "大于",
+    "Request remote address" : "要求远程地址",
+    "matches IPv4" : "匹配 IPv4",
+    "does not match IPv4" : "不匹配 IPv4",
+    "matches IPv6" : "匹配 IPv6",
+    "does not match IPv6" : "不匹配 IPv6",
+    "File system tag" : "文件系统标签",
+    "is tagged with" : "标记为",
+    "is not tagged with" : "未标记为",
+    "Request URL" : "请求 URL",
+    "Request time" : "请求时间",
+    "between" : "之间",
+    "not between" : "不在之间",
+    "Request user agent" : "请求用户代理",
+    "User group membership" : "用户组成员资格",
+    "is member of" : "是成员",
+    "is not member of" : "不是成员",
+    "Short rule description" : "短规则说明",
+    "Add rule" : "添加规则",
+    "Reset" : "重置",
+    "Save" : "保存",
+    "Saving…" : "保存中...",
+    "Group list is empty" : "用户群组列表空",
+    "Unable to retrieve the group list" : "无法获取用户群组列表",
+    "Saved" : "已保存",
+    "Saving failed:" : "保存失败：",
+    "Add rule group" : "添加规则组",
+    "Example: {placeholder}" : "例子：{placeholder}",
+    "Select tag…" : "选择标签...",
+    "Start" : "开始",
+    "End" : "结束",
+    "Select timezone…" : "选择时区...",
+    "Sync clients" : "同步客户端",
+    "Workflow" : "工作流",
     "Files workflow engine" : "文件工作流引擎",
     "Open documentation" : "打开文档",
     "Loading…" : "加载中...",
-    "Workflow" : "工作流"
+    "Tag management" : "标签管理"
 },
 "nplurals=1; plural=0;");
