@@ -60,19 +60,7 @@ class Application extends \OCP\AppFramework\App {
 				]);
 
 				script('workflowengine', [
-					'admin',
-					'templates',
-
-					// Check plugins
-					'filemimetypeplugin',
-					'filenameplugin',
-					'filesizeplugin',
-					'filesystemtagsplugin',
-					'requestremoteaddressplugin',
-					'requesttimeplugin',
-					'requesturlplugin',
-					'requestuseragentplugin',
-					'usergroupmembershipplugin',
+					'workflowengine',
 				]);
 			},
 			-100
