@@ -68,6 +68,29 @@ class FileMimeType extends AbstractStringCheck {
 		}
 	}
 
+	/**
+	 * The mimetype is only cached if the file exists. Otherwise files access
+	 * control will cache "application/octet-stream" for all the target node on:
+	 * rename, move, copy and all other methods which create a new item
+	 *
+	 * To check this:
+	 * 1. Add an automated tagging rule which tags on mimetype NOT "httpd/unix-directory"
+	 * 2. Add an access control rule which checks for any mimetype
+	 * 3. Create a folder and rename it, the folder should not be tagged, but it is
+	 *
+	 * @param string $storageId
+	 * @param string|null $path
+	 * @param string $mimeType
+	 * @return string
+	 */
+	protected function cacheAndReturnMimeType(string $storageId, ?string $path, string $mimeType): string {
+		if ($path !== null && $this->storage->file_exists($path)) {
+			$this->mimeType[$storageId][$path] = $mimeType;
+		}
+
+		return $mimeType;
+	}
+
 	/**
 	 * @return string
 	 */
@@ -76,17 +99,24 @@ class FileMimeType extends AbstractStringCheck {
 			return $this->mimeType[$this->storage->getId()][$this->path];
 		}
 
+		if ($this->storage->is_dir($this->path)) {
+			return $this->cacheAndReturnMimeType($this->storage->getId(), $this->path, 'httpd/unix-directory');
+		}
+
 		if ($this->isWebDAVRequest()) {
 			// Creating a folder
 			if ($this->request->getMethod() === 'MKCOL') {
-				$this->mimeType[$this->storage->getId()][$this->path] = 'httpd/unix-directory';
-				return $this->mimeType[$this->storage->getId()][$this->path];
+				return $this->cacheAndReturnMimeType($this->storage->getId(), $this->path, 'httpd/unix-directory');
 			}
 
-			if ($this->request->getMethod() === 'PUT') {
-				$path = $this->request->getPathInfo();
-				$this->mimeType[$this->storage->getId()][$this->path] = $this->mimeTypeDetector->detectPath($path);
-				return $this->mimeType[$this->storage->getId()][$this->path];
+			if ($this->request->getMethod() === 'PUT' || $this->request->getMethod() === 'MOVE') {
+				if ($this->request->getMethod() === 'MOVE') {
+					$mimeType = $this->mimeTypeDetector->detectPath($this->path);
+				} else {
+					$path = $this->request->getPathInfo();
+					$mimeType = $this->mimeTypeDetector->detectPath($path);
+				}
+				return $this->cacheAndReturnMimeType($this->storage->getId(), $this->path, $mimeType);
 			}
 		} else if ($this->isPublicWebDAVRequest()) {
 			if ($this->request->getMethod() === 'PUT') {
@@ -95,8 +125,8 @@ class FileMimeType extends AbstractStringCheck {
 					$path = substr($path, strlen('/webdav'));
 				}
 				$path = $this->path . $path;
-				$this->mimeType[$this->storage->getId()][$path] = $this->mimeTypeDetector->detectPath($path);
-				return $this->mimeType[$this->storage->getId()][$path];
+				$mimeType = $this->mimeTypeDetector->detectPath($path);
+				return $this->cacheAndReturnMimeType($this->storage->getId(), $path, $mimeType);
 			}
 		}
 
@@ -104,7 +134,7 @@ class FileMimeType extends AbstractStringCheck {
 			$files = $this->request->getUploadedFile('files');
 			if (isset($files['type'][0])) {
 				$mimeType = $files['type'][0];
-				if ($this->mimeType === 'application/octet-stream') {
+				if ($mimeType === 'application/octet-stream') {
 					// Maybe not...
 					$mimeTypeTest = $this->mimeTypeDetector->detectPath($files['name'][0]);
 					if ($mimeTypeTest !== 'application/octet-stream' && $mimeTypeTest !== false) {
@@ -116,17 +146,16 @@ class FileMimeType extends AbstractStringCheck {
 						}
 					}
 				}
-				$this->mimeType[$this->storage->getId()][$this->path] = $mimeType;
-				return $mimeType;
+				return $this->cacheAndReturnMimeType($this->storage->getId(), $this->path, $mimeType);
 			}
 		}
 
-		$this->mimeType[$this->storage->getId()][$this->path] = $this->storage->getMimeType($this->path);
-		if ($this->mimeType[$this->storage->getId()][$this->path] === 'application/octet-stream') {
-			$this->mimeType[$this->storage->getId()][$this->path] = $this->detectMimetypeFromPath();
+		$mimeType = $this->storage->getMimeType($this->path);
+		if ($mimeType === 'application/octet-stream') {
+			$mimeType = $this->detectMimetypeFromPath();
 		}
 
-		return $this->mimeType[$this->storage->getId()][$this->path];
+		return $this->cacheAndReturnMimeType($this->storage->getId(), $this->path, $mimeType);
 	}
 
 	/**
@@ -171,7 +200,9 @@ class FileMimeType extends AbstractStringCheck {
 			$this->request->getPathInfo() === '/webdav' ||
 			strpos($this->request->getPathInfo(), '/webdav/') === 0 ||
 			$this->request->getPathInfo() === '/dav/files' ||
-			strpos($this->request->getPathInfo(), '/dav/files/') === 0
+			strpos($this->request->getPathInfo(), '/dav/files/') === 0 ||
+			$this->request->getPathInfo() === '/dav/uploads' ||
+			strpos($this->request->getPathInfo(), '/dav/uploads/') === 0
 		);
 	}
 
