@@ -361,8 +361,8 @@
 						}
 						var moreResultsAvailable =
 							(
-								oc_config['sharing.maxAutocompleteResults'] > 0
-								&& Math.min(perPage, oc_config['sharing.maxAutocompleteResults'])
+								OC.config['sharing.maxAutocompleteResults'] > 0
+								&& Math.min(perPage, OC.config['sharing.maxAutocompleteResults'])
 									<= Math.max(
 										users.length + exactUsers.length,
 										groups.length + exactGroups.length,
@@ -622,23 +622,8 @@
 							}
 							previousUuid = grouped[i].uuid;
 						}
-						var moreResultsAvailable =
-							(
-								oc_config['sharing.maxAutocompleteResults'] > 0
-								&& Math.min(perPage, oc_config['sharing.maxAutocompleteResults'])
-								<= Math.max(
-									users.length + exactUsers.length,
-									groups.length + exactGroups.length,
-									remoteGroups.length + exactRemoteGroups.length,
-									remotes.length + exactRemotes.length,
-									emails.length + exactEmails.length,
-									circles.length + exactCircles.length,
-									rooms.length + exactRooms.length,
-									lookup.length
-								)
-							);
 
-						deferred.resolve(result, exactMatches, moreResultsAvailable);
+						deferred.resolve(result, exactMatches, false);
 					} else {
 						deferred.reject(result.ocs.meta.message);
 					}
@@ -690,7 +675,7 @@
 				$loading = this.$el.find('.shareWithLoading'),
 				$confirm = this.$el.find('.shareWithConfirm');
 
-			var count = oc_config['sharing.minSearchStringLength'];
+			var count = OC.config['sharing.minSearchStringLength'];
 			if (search.term.trim().length < count) {
 				var title = n('core',
 					'At least {count} character is needed for autocompletion',
@@ -719,7 +704,7 @@
 			$shareWithField.removeClass('error')
 				.tooltip('hide');
 
-			var perPage = parseInt(oc_config['sharing.maxAutocompleteResults'], 10) || 200;
+			var perPage = parseInt(OC.config['sharing.maxAutocompleteResults'], 10) || 200;
 			this._getSuggestions(
 				search.term.trim(),
 				perPage,
@@ -972,7 +957,7 @@
 				$shareWithField.focus();
 			};
 
-			var perPage = parseInt(oc_config['sharing.maxAutocompleteResults'], 10) || 200;
+			var perPage = parseInt(OC.config['sharing.maxAutocompleteResults'], 10) || 200;
 			this._getSuggestions(
 				$shareWithField.val(),
 				perPage,
@@ -1053,12 +1038,6 @@
 			this._toggleLoading(false);
 			if (!this._loadingOnce) {
 				this._loadingOnce = true;
-				// the first time, focus on the share field after the spinner disappeared
-				if (!OC.Util.isIE()) {
-					_.defer(function () {
-						self.$('.shareWithField').focus();
-					});
-				}
 			}
 		},
 
