@@ -19,7 +19,7 @@
 *
 */
 
-/* global oc_appconfig, sinon */
+/* global sinon, OC */
 describe('OC.Share.ShareDialogView', function() {
 	var $container;
 	var oldConfig;
@@ -41,12 +41,11 @@ describe('OC.Share.ShareDialogView', function() {
 		// horrible parameters
 		$('#testArea').append('<input id="allowShareWithLink" type="hidden" value="yes">');
 		$container = $('#shareContainer');
-		oldConfig = window.oc_config;
-		window.oc_config = window.oc_config || {};
-		window.oc_config['sharing.maxAutocompleteResults'] = 0;
+		oldConfig = OC.config;
+		OC.config['sharing.maxAutocompleteResults'] = 0;
 		/* jshint camelcase:false */
-		oldAppConfig = _.extend({}, oc_appconfig.core);
-		oc_appconfig.core.enforcePasswordForPublicLink = false;
+		oldAppConfig = _.extend({}, OC.appConfig.core);
+		OC.appConfig.core.enforcePasswordForPublicLink = false;
 
 		fetchStub = sinon.stub(OC.Share.ShareItemModel.prototype, 'fetch');
 		saveLinkShareStub = sinon.stub(OC.Share.ShareItemModel.prototype, 'saveLinkShare');
@@ -112,9 +111,9 @@ describe('OC.Share.ShareDialogView', function() {
 	});
 	afterEach(function() {
 		OC.currentUser = oldCurrentUser;
-		window.oc_config = oldConfig;
+		OC.config = oldConfig;
 		/* jshint camelcase:false */
-		oc_appconfig.core = oldAppConfig;
+		OC.appConfig.core = oldAppConfig;
 
 		dialog.remove();
 		fetchStub.restore();
@@ -350,7 +349,8 @@ describe('OC.Share.ShareDialogView', function() {
 						'groups': [],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true,
 					}
 				}
 			});
@@ -365,7 +365,11 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly([], [], false)).toEqual(true);
+			sinon.assert.calledWithExactly(doneStub, [{
+				label: t('core', 'Search globally'),
+				value: {},
+				lookup: true
+			}], [], false, true);
 			expect(failStub.called).toEqual(false);
 		});
 
@@ -401,7 +405,8 @@ describe('OC.Share.ShareDialogView', function() {
 						'groups': [],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true,
 					}
 				}
 			});
@@ -416,14 +421,20 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bobby',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'imbob'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(failStub.called).toEqual(false);
 		});
 		it('single exact match', function() {
@@ -458,7 +469,8 @@ describe('OC.Share.ShareDialogView', function() {
 						'groups': [],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true,
 					}
 				}
 			});
@@ -473,17 +485,23 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(failStub.called).toEqual(false);
 		});
 		it('mixed matches', function() {
@@ -549,7 +567,8 @@ describe('OC.Share.ShareDialogView', function() {
 						],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true
 					}
 				}
 			});
@@ -564,7 +583,7 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
@@ -580,6 +599,11 @@ describe('OC.Share.ShareDialogView', function() {
 				}, {
 					'label': 'bobfans',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'fans'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
@@ -588,13 +612,14 @@ describe('OC.Share.ShareDialogView', function() {
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'group1'}
 				}],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(failStub.called).toEqual(false);
 		});
 
 		it('capped mixed matches', function() {
-			window.oc_config['sharing.maxAutocompleteResults'] = 3;
+			OC.config['sharing.maxAutocompleteResults'] = 3;
 			var doneStub = sinon.stub();
 			var failStub = sinon.stub();
 
@@ -657,7 +682,8 @@ describe('OC.Share.ShareDialogView', function() {
 						],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true
 					}
 				}
 			});
@@ -672,7 +698,7 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
@@ -688,6 +714,11 @@ describe('OC.Share.ShareDialogView', function() {
 				}, {
 					'label': 'bobfans',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'fans'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
@@ -696,8 +727,9 @@ describe('OC.Share.ShareDialogView', function() {
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'group1'}
 				}],
+				true,
 				true
-			)).toEqual(true);
+			);
 			expect(failStub.called).toEqual(false);
 		});
 
@@ -733,7 +765,8 @@ describe('OC.Share.ShareDialogView', function() {
 						'groups': [],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true
 					}
 				}
 			});
@@ -752,11 +785,18 @@ describe('OC.Share.ShareDialogView', function() {
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
-				}], [{
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
+				}],
+				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}],
-				false
+				false,
+				true
 			)).toEqual(true);
 			expect(failStub.called).toEqual(false);
 
@@ -769,17 +809,23 @@ describe('OC.Share.ShareDialogView', function() {
 			expect(failStub.called).toEqual(false);
 
 			expect(done2Stub.calledOnce).toEqual(true);
-			expect(done2Stub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(fail2Stub.called).toEqual(false);
 		});
 
@@ -815,7 +861,8 @@ describe('OC.Share.ShareDialogView', function() {
 						'groups': [],
 						'remotes': [],
 						'remote_groups': [],
-						'lookup': []
+						'lookup': [],
+						'lookupEnabled': true
 					}
 				}
 			});
@@ -830,17 +877,23 @@ describe('OC.Share.ShareDialogView', function() {
 			);
 
 			expect(doneStub.calledOnce).toEqual(true);
-			expect(doneStub.calledWithExactly(
+			sinon.assert.calledWithExactly(doneStub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(failStub.called).toEqual(false);
 
 			var done2Stub = sinon.stub();
@@ -880,17 +933,23 @@ describe('OC.Share.ShareDialogView', function() {
 			expect(fail2Stub.called).toEqual(false);
 
 			expect(done3Stub.calledOnce).toEqual(true);
-			expect(done3Stub.calledWithExactly(
+			sinon.assert.calledWithExactly(done3Stub,
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
+				},
+				{
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
 				}],
 				[{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}],
-				false
-			)).toEqual(true);
+				false,
+				true
+			);
 			expect(fail3Stub.called).toEqual(false);
 		});
 	});
@@ -898,7 +957,7 @@ describe('OC.Share.ShareDialogView', function() {
 		var showTemporaryNotificationStub;
 
 		beforeEach(function() {
-			showTemporaryNotificationStub = sinon.stub(OC.Notification, 'show');
+			showTemporaryNotificationStub = sinon.stub(OC.Notification, 'showTemporary');
 		});
 
 		afterEach(function() {
@@ -944,7 +1003,8 @@ describe('OC.Share.ShareDialogView', function() {
 							'groups': [],
 							'remotes': [],
 							'remote_groups': [],
-							'lookup': []
+							'lookup': [],
+							'lookupEnabled': true
 						}
 					}
 				});
@@ -953,13 +1013,17 @@ describe('OC.Share.ShareDialogView', function() {
 					{'Content-Type': 'application/json'},
 					jsonData
 				);
-				expect(response.calledWithExactly([{
+				sinon.assert.calledWithExactly(response, [{
 					'label': 'bob',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'user1'}
 				}, {
 					'label': 'bobby',
 					'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'imbob'}
-				}])).toEqual(true);
+				}, {
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
+				}]);
 				expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
 			});
 
@@ -1001,7 +1065,8 @@ describe('OC.Share.ShareDialogView', function() {
 							],
 							'remotes': [],
 							'remote_groups': [],
-							'lookup': []
+							'lookup': [],
+							'lookupEnabled': true
 						}
 					}
 				});
@@ -1010,13 +1075,17 @@ describe('OC.Share.ShareDialogView', function() {
 					{'Content-Type': 'application/json'},
 					jsonData
 				);
-				expect(response.calledWithExactly([{
+				sinon.assert.calledWithExactly(response, [{
 					'label': 'group',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'group'}
 				}, {
 					'label': 'group2',
 					'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'group2'}
-				}])).toEqual(true);
+				}, {
+					label: t('core', 'Search globally'),
+					value: {},
+					lookup: true
+				}]);
 				expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
 			});
 
