@@ -47,64 +47,6 @@ OC.L10N.register(
     "Good password" : "Goeie wagwoord",
     "Strong password" : "Sterk wagwoord",
     "Error occurred while checking server setup" : "'n Fout het voorgekom tydens die nagaan van die bediener se konfigurasie",
-    "Shared" : "Gedeel",
-    "Shared with" : "Gedeel met",
-    "Shared by" : "Gedeel deur",
-    "Choose a password for the public link" : "Kies 'n wagwoord vir die publieke skakel",
-    "Choose a password for the public link or press the \"Enter\" key" : "Kies 'n wagwoord vir die publieke skakel, of druk die \"Enter\" sleutel",
-    "Copied!" : "Gekopieer!",
-    "Not supported!" : "Word nie ondersteun nie!",
-    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
-    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
-    "Copy" : "Kopieer",
-    "Resharing is not allowed" : "Herdeling word nie toegelaat nie",
-    "Link" : "Skakel",
-    "Password protect" : "Beskerm met 'n wagwoord",
-    "Password" : "Wagwoord",
-    "Allow editing" : "Laat redigering toe",
-    "Email link to person" : "Stuur die skakel per e-pos na die persoon",
-    "Send" : "Stuur",
-    "Allow upload and editing" : "Laat oplaai en redigering toe",
-    "Read only" : "Leesalleen",
-    "File drop (upload only)" : "Lêer val (slegs oplaai)",
-    "Set expiration date" : "Stel vervaldatum",
-    "Expiration" : "Verval",
-    "Expiration date" : "Vervaldatum",
-    "Unshare" : "Ontdeel",
-    "Share to {name}" : "Deel met {name}",
-    "Share link" : "Deel skakel",
-    "Could not unshare" : "Kon nie ontdeel nie",
-    "Shared with you and the group {group} by {owner}" : "Gedeel met u en die groep {group} deur {owner}",
-    "Shared with you by {owner}" : "Gedeel met u deur {owner}",
-    "Choose a password for the mail share" : "Kies 'n wagwoord vir die e-pos lêer deel ",
-    "group" : "groep",
-    "remote" : "afgeleë",
-    "email" : "e-pos",
-    "shared by {sharer}" : "gedeel deur {sharer}",
-    "Can reshare" : "Kan herdeel",
-    "Can edit" : "Kan redigeer",
-    "Can create" : "Kan skep",
-    "Can change" : "Kan verander",
-    "Can delete" : "Kan skrap",
-    "Access control" : "Toegangsbeheer",
-    "Error while sharing" : "Fout terwyl deel",
-    "Share details could not be loaded for this item." : "Deel besonderhede kon nie vir die item gelaai word nie.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Ten minste {count} karakter word benodig vir outomatiese aanvulling","Ten minste {count} karakters word benodig vir outomatiese aanvulling"],
-    "No users or groups found for {search}" : "Geen gebruikers of groepe gevind vir {search}",
-    "No users found for {search}" : "Geen gebruiker gevind vir {search}",
-    "An error occurred (\"{message}\"). Please try again" : "'n Fout het voorgekom (\"{message}\"). Probeer asseblief weer",
-    "An error occurred. Please try again" : "'n Fout het voorgekom. Probeer asseblief weer",
-    "Home" : "Tuis",
-    "Work" : "Werk",
-    "Other" : "Ander",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Deel",
-    "Name or email address..." : "Naam of e-posadres...",
-    "Name or federated cloud ID..." : "Naam of gefedereerde wolk-ID...",
-    "Name, federated cloud ID or email address..." : "Naam, gefedereerde wolk-ID of e-posadres...",
-    "Name..." : "Naam...",
-    "Error" : "Fout",
-    "Error removing share" : "Fout terwyl deel verwyder word",
     "Non-existing tag #{tag}" : "Merker #{tag} bestaan nie",
     "restricted" : "beperk",
     "invisible" : "onsigbaar",
@@ -131,6 +73,7 @@ OC.L10N.register(
     "An internal error occurred." : "'n Interne fout het voorgekom.",
     "Please try again or contact your administrator." : "Probeer asseblief weer of kontak jou administrateur.",
     "Username or email" : "Gebruikersnaam of e-pos",
+    "Password" : "Wagwoord",
     "Log in" : "Meld aan",
     "Logging in …" : "Meld tans aan …",
     "Reset password" : "Herstel wagwoord",
@@ -151,6 +94,7 @@ OC.L10N.register(
     "Yes" : "Ja",
     "No files in here" : "Geen lêers hier nie",
     "Choose" : "Kies",
+    "Copy" : "Kopieer",
     "Move" : "Skuif",
     "OK" : "OK",
     "read-only" : "lees-alleen",
@@ -183,6 +127,7 @@ OC.L10N.register(
     "Access forbidden" : "Toegang verbode",
     "File not found" : "Lêer nie gevind nie",
     "Back to %s" : "Terug na %s",
+    "Error" : "Fout",
     "Internal Server Error" : "Interne bedienerfout",
     "The server was unable to complete your request." : "Die bediener was nie in staat om u versoek te voltooi nie.",
     "More details can be found in the server log." : "Meer besonderhede kan in die bediener joernaal gevind word.",
@@ -234,23 +179,65 @@ OC.L10N.register(
     "Update needed" : "Bywerking benodig",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kon nie die herstel-e-pos stuur nie aangesien daar geen e-posadres met die gebruikersnaam geassosieer is nie. Kontak asseblief jou administrateur.",
     "Couldn't send reset email. Please make sure your username is correct." : "Kon nie die herstel e-pos stuur nie. Kontroleer jou gebruikersnaam.",
-    "Updated \"%s\" to %s" : "\"%s\" na %s bygewerk",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Daar was probleme met die nagaan van die kode integriteit. Meer inligting…</a>",
     "Dismiss" : "Ontslaan",
     "Sending email …" : "Stuur tans e-pos …",
-    "Copy URL" : "Kopieer URL",
-    "Enable" : "Aktiveer",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} gedeel via skakel",
-    "{sharee} (group)" : "{sharee} (groep)",
-    "{sharee} (remote)" : "{sharee} (afgeleë)",
-    "{sharee} (email)" : "{sharee} (e-pos)",
-    "The specified document has not been found on the server." : "Die gekose dokument was nie op die bediener gevind nie.",
-    "You can click here to return to %s." : "U kan hier klik om terug te keer na %s",
+    "Shared" : "Gedeel",
+    "Shared with" : "Gedeel met",
+    "Shared by" : "Gedeel deur",
+    "Choose a password for the public link" : "Kies 'n wagwoord vir die publieke skakel",
+    "Choose a password for the public link or press the \"Enter\" key" : "Kies 'n wagwoord vir die publieke skakel, of druk die \"Enter\" sleutel",
+    "Copied!" : "Gekopieer!",
+    "Not supported!" : "Word nie ondersteun nie!",
+    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
+    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
+    "Resharing is not allowed" : "Herdeling word nie toegelaat nie",
+    "Link" : "Skakel",
+    "Password protect" : "Beskerm met 'n wagwoord",
+    "Allow editing" : "Laat redigering toe",
+    "Email link to person" : "Stuur die skakel per e-pos na die persoon",
+    "Send" : "Stuur",
+    "Allow upload and editing" : "Laat oplaai en redigering toe",
+    "Read only" : "Leesalleen",
+    "File drop (upload only)" : "Lêer val (slegs oplaai)",
+    "Set expiration date" : "Stel vervaldatum",
+    "Expiration" : "Verval",
+    "Expiration date" : "Vervaldatum",
+    "Unshare" : "Ontdeel",
+    "Share to {name}" : "Deel met {name}",
+    "Share link" : "Deel skakel",
+    "Could not unshare" : "Kon nie ontdeel nie",
+    "Shared with you and the group {group} by {owner}" : "Gedeel met u en die groep {group} deur {owner}",
+    "Shared with you by {owner}" : "Gedeel met u deur {owner}",
+    "Choose a password for the mail share" : "Kies 'n wagwoord vir die e-pos lêer deel ",
+    "group" : "groep",
+    "remote" : "afgeleë",
+    "email" : "e-pos",
+    "shared by {sharer}" : "gedeel deur {sharer}",
+    "Can reshare" : "Kan herdeel",
+    "Can edit" : "Kan redigeer",
+    "Can create" : "Kan skep",
+    "Can change" : "Kan verander",
+    "Can delete" : "Kan skrap",
+    "Access control" : "Toegangsbeheer",
+    "Error while sharing" : "Fout terwyl deel",
+    "Share details could not be loaded for this item." : "Deel besonderhede kon nie vir die item gelaai word nie.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Ten minste {count} karakter word benodig vir outomatiese aanvulling","Ten minste {count} karakters word benodig vir outomatiese aanvulling"],
+    "No users or groups found for {search}" : "Geen gebruikers of groepe gevind vir {search}",
+    "No users found for {search}" : "Geen gebruiker gevind vir {search}",
+    "An error occurred (\"{message}\"). Please try again" : "'n Fout het voorgekom (\"{message}\"). Probeer asseblief weer",
+    "An error occurred. Please try again" : "'n Fout het voorgekom. Probeer asseblief weer",
+    "Home" : "Tuis",
+    "Work" : "Werk",
+    "Other" : "Ander",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Deel",
+    "Name or email address..." : "Naam of e-posadres...",
+    "Name or federated cloud ID..." : "Naam of gefedereerde wolk-ID...",
+    "Name, federated cloud ID or email address..." : "Naam, gefedereerde wolk-ID of e-posadres...",
+    "Name..." : "Naam...",
+    "Error removing share" : "Fout terwyl deel verwyder word",
     "SQLite will be used as database." : "SQLite sal as databasis gebruik word.",
     "Wrong password." : "Verkeerde wagwoord.",
-    "Redirecting …" : "Herlei …",
-    "New Password" : "Nuwe wagwoord",
-    "%s will be updated to version %s" : "%s sal na %s bygewerk word",
-    "Thank you for your patience." : "Dankie vir u geduld."
+    "New Password" : "Nuwe wagwoord"
 },
 "nplurals=2; plural=(n != 1);");
