@@ -55,65 +55,6 @@ OC.L10N.register(
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Някои индекси липсват в базата данни. Не са добавени защото процеса може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:add-missing-indices\". След добавянето на индексите заявките към изброените таблици ще минават много по-бързо.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Някои колони от базата данни не са конвертирани към \"big int\". Конвертирането не е осъществено защото може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:convert-filecache-bigint\". Но преди това инсталацията трябва да бъде в \"maintenance\" режим. За допълнителна информация <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">прочетете документацията</a>.",
     "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
-    "Shared" : "Споделено",
-    "Shared with" : "Споделено с",
-    "Shared by" : "Споделено от",
-    "Choose a password for the public link" : "Парола за публичната връзка",
-    "Copied!" : "Копирана!",
-    "Copy link" : "Копирай връзката",
-    "Not supported!" : "Не се поддържа!",
-    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
-    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
-    "Copy" : "Копирай",
-    "Resharing is not allowed" : "Повторното споделяне е забранено",
-    "Link" : "Връзка",
-    "Password protect" : "Защита с парола",
-    "Password" : "Парола",
-    "Allow editing" : "Възможност за редактиране",
-    "Email link to person" : "Изпрати чрез имейл връзката",
-    "Send" : "Изпрати",
-    "Allow upload and editing" : "За качване и редактиране",
-    "Read only" : "Само за четене",
-    "File drop (upload only)" : "Само за качване",
-    "Set expiration date" : "Срок на валидност",
-    "Expiration" : "Валидност",
-    "Expiration date" : "Дата на изтичане",
-    "Note to recipient" : "Бележка за получателя",
-    "Unshare" : "Прекрати споделянето",
-    "Delete share link" : "Изтрий споделената връзка",
-    "Add another link" : "Добави още една връзка",
-    "Share to {name}" : "Сподели с {name}",
-    "Share link" : "Връзка за споделяне",
-    "Could not unshare" : "Споделянето не може да бъде прекратено",
-    "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с вас и групата {group}",
-    "Shared with you in a conversation by {owner}" : "Споделено с вас в разговор от {owner}",
-    "Shared with you by {owner}" : "Споделено с вас от {owner}",
-    "group" : "група",
-    "remote" : "отдалечен",
-    "remote group" : "отдалечена група",
-    "email" : "имейл",
-    "conversation" : "разговор",
-    "shared by {sharer}" : "споделено от {sharer}",
-    "Can reshare" : "Може да споделя повторно",
-    "Can edit" : "Може да редактира",
-    "Can create" : "Може да създава",
-    "Can change" : "Може да променя",
-    "Can delete" : "Може да изтрива",
-    "Access control" : "Контрол на достъпа",
-    "Error while sharing" : "Грешка при споделяне",
-    "Share details could not be loaded for this item." : "Данните за споделяне не могат да бъдат заредени",
-    "No users or groups found for {search}" : "Няма потребители или групи за {search}",
-    "No users found for {search}" : "Няма потребители за {search}",
-    "An error occurred. Please try again" : "Възникна грешка. Моля, опитайте отново",
-    "{sharee} (remote group)" : "{sharee} (отдалечена група)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Споделяне",
-    "Name or email address..." : "Име или имейл адрес...",
-    "Name or federated cloud ID..." : "Име или Federated Cloud ID...",
-    "Name, federated cloud ID or email address..." : "Име, Federated Cloud ID или имейл адрес...",
-    "Name..." : "Име...",
-    "Error" : "Грешка",
-    "Error removing share" : "Грешка при изриване на споделяне",
     "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
     "restricted" : "ограничен",
     "invisible" : "невидим",
@@ -144,6 +85,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Опитайте отново или се свържете с администраотра.",
     "Username or email" : "Потребител или имейл",
     "Username or\temail" : "Потребител или имейл",
+    "Password" : "Парола",
     "Log in" : "Вписване",
     "Logging in …" : "Вписване ...",
     "Wrong username or password." : "Грешен потребител или парола",
@@ -167,6 +109,7 @@ OC.L10N.register(
     "No more subfolders in here" : "Няма подпапки",
     "{newName} already exists" : "{newName} вече съществува",
     "Choose" : "Избор",
+    "Copy" : "Копирай",
     "Move" : "Премести",
     "Error loading file picker template: {error}" : "Грешка при зареждането на шаблона за избор на файл: {error}",
     "OK" : "Добре",
@@ -203,6 +146,7 @@ OC.L10N.register(
     "Help" : "Помощ",
     "Access forbidden" : "Достъпът е забранен",
     "File not found" : "Файлът не е открит",
+    "Error" : "Грешка",
     "Internal Server Error" : "Вътрешно сървърна грешка",
     "The server was unable to complete your request." : "Сървърът не можа да изпълни заявката ви.",
     "If this happens again, please send the technical details below to the server administrator." : "Ако грешката се повтори, моля изпратете техническите данни на администратора.",
@@ -273,31 +217,70 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Имейлът за възстановяване на паролата  не може да бъде изпратен защо потребителят няма имейл адрес. Свържете се с администратора.",
     "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
-    "Updated \"%s\" to %s" : "Актуализирана \"%s\" до %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Проблем с инсталацията. Допълнителна информация…</a>",
     "Dismiss" : "Отхвърляне",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Връзката за възстановяване на паролата беше изпратена до вашия имейл. Ако не я получите в разумен период от време, проверете спам и junk папките.<br>Ако не я откривате и там, се свържете с администратора.",
     "Sending email …" : "Изпращане на имейл ...",
-    "Enable" : "Включена",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} споделен с връзка",
-    "{sharee} (group)" : "{sharee} (група)",
-    "{sharee} (remote)" : "{sharee} (отдалечен)",
-    "{sharee} (email)" : "{sharee} (имейл)",
-    "{sharee} (conversation)" : "{sharee} (разговор)",
-    "The specified document has not been found on the server." : "Избраният документ не е намерен на сървъра.",
-    "You can click here to return to %s." : "Можете да натиснете тук, за да се върнете на %s.",
+    "Shared" : "Споделено",
+    "Shared with" : "Споделено с",
+    "Shared by" : "Споделено от",
+    "Choose a password for the public link" : "Парола за публичната връзка",
+    "Copied!" : "Копирана!",
+    "Copy link" : "Копирай връзката",
+    "Not supported!" : "Не се поддържа!",
+    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
+    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
+    "Resharing is not allowed" : "Повторното споделяне е забранено",
+    "Link" : "Връзка",
+    "Password protect" : "Защита с парола",
+    "Allow editing" : "Възможност за редактиране",
+    "Email link to person" : "Изпрати чрез имейл връзката",
+    "Send" : "Изпрати",
+    "Allow upload and editing" : "За качване и редактиране",
+    "Read only" : "Само за четене",
+    "File drop (upload only)" : "Само за качване",
+    "Set expiration date" : "Срок на валидност",
+    "Expiration" : "Валидност",
+    "Expiration date" : "Дата на изтичане",
+    "Note to recipient" : "Бележка за получателя",
+    "Unshare" : "Прекрати споделянето",
+    "Delete share link" : "Изтрий споделената връзка",
+    "Add another link" : "Добави още една връзка",
+    "Share to {name}" : "Сподели с {name}",
+    "Share link" : "Връзка за споделяне",
+    "Could not unshare" : "Споделянето не може да бъде прекратено",
+    "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с вас и групата {group}",
+    "Shared with you in a conversation by {owner}" : "Споделено с вас в разговор от {owner}",
+    "Shared with you by {owner}" : "Споделено с вас от {owner}",
+    "group" : "група",
+    "remote" : "отдалечен",
+    "remote group" : "отдалечена група",
+    "email" : "имейл",
+    "conversation" : "разговор",
+    "shared by {sharer}" : "споделено от {sharer}",
+    "Can reshare" : "Може да споделя повторно",
+    "Can edit" : "Може да редактира",
+    "Can create" : "Може да създава",
+    "Can change" : "Може да променя",
+    "Can delete" : "Може да изтрива",
+    "Access control" : "Контрол на достъпа",
+    "Error while sharing" : "Грешка при споделяне",
+    "Share details could not be loaded for this item." : "Данните за споделяне не могат да бъдат заредени",
+    "No users or groups found for {search}" : "Няма потребители или групи за {search}",
+    "No users found for {search}" : "Няма потребители за {search}",
+    "An error occurred. Please try again" : "Възникна грешка. Моля, опитайте отново",
+    "{sharee} (remote group)" : "{sharee} (отдалечена група)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Споделяне",
+    "Name or email address..." : "Име или имейл адрес...",
+    "Name or federated cloud ID..." : "Име или Federated Cloud ID...",
+    "Name, federated cloud ID or email address..." : "Име, Federated Cloud ID или имейл адрес...",
+    "Name..." : "Име...",
+    "Error removing share" : "Грешка при изриване на споделяне",
     "SQLite will be used as database." : "Ще бъде използвана база данни SQLite.",
     "For larger installations we recommend to choose a different database backend." : "За големи инсталации е препоръчително ползването на друг тип база данни.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Използването на SQLite не се препоръчва, особено ако ползвате клиента за настолни компютри.",
     "Wrong password." : "Грешна парола",
-    "Please log in before granting %s access to your %s account." : "Необходимо е да се впишете, преди да дадете достъп на %s до вашия %s профил.",
-    "You are about to grant %s access to your %s account." : "Ще разрешите на %s да ползва вашия %sпрофил.",
-    "Redirecting …" : "Пренасочване ...",
     "New Password" : "Нова парола",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Повишената сигурност е активирана за профила ви. Моля удостоверете използвайки втори фактор.",
-    "%s will be updated to version %s" : "%s ще бъде актуализирана до версия %s",
-    "This page will refresh itself when the %s instance is available again." : "Страницата ще се зареди автоматично, когато %s е отново на линия.",
-    "Thank you for your patience." : "Благодарим ви за търпението.",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "До имейла на профила е изпратена връзка за възстановяване на паролата. Не забравяйте да проверете и спам/junk папката.<br> Свържете с администратора ако не получите имейла."
 },
 "nplurals=2; plural=(n != 1);");
