@@ -107,87 +107,6 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ neobsahuje „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP hlavička „{header}“ není nastavena na „{val1}“, „{val2}“, „{val3}“, „{val4}“ nebo „{val5}“. To může odhalovat referer informaci. Viz <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">doporučení W3C ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP hlavička „Strict-Transport-Security“ není nastavena na přinejmenším „{seconds}“ sekund. Pro lepší zabezpečení je doporučeno zapnout HSTS, jak je popsáno v <a href=\"{docUrl}\" rel=\"noreferrer noopener\">tipech pro zabezpečení ↗</a>.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Přistupujete přes nezabezpečené HTTP. Silně doporučujeme nastavit svůj server tak, aby vyžadoval namísto toho HTTPS, jak je popsáno v <a href=\"{docUrl}\">tipech pro zabezpečení ↗</a>.",
-    "Shared" : "Sdílené",
-    "Shared with" : "Sdíleno s",
-    "Shared by" : "Nasdílel",
-    "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
-    "Choose a password for the public link or press the \"Enter\" key" : "Zvolte heslo pro veřejný odkaz nebo stiskněte klávesu „Enter“",
-    "Copied!" : "Zkopírováno!",
-    "Copy link" : "Zkopírovat odkaz",
-    "Not supported!" : "Nepodporováno!",
-    "Press ⌘-C to copy." : "Zmáčknout ⌘-C pro kopírování.",
-    "Press Ctrl-C to copy." : "Zmáčknout Ctrl-C pro kopírování.",
-    "Copy" : "Zkopírovat",
-    "Unable to create a link share" : "Nedaří se vytvořit sdílení odkazu",
-    "Unable to toggle this option" : "Tuto volbu se nedaří přepnout",
-    "Resharing is not allowed" : "Sdílení už sdílené položky není povoleno",
-    "Link" : "Odkaz",
-    "Hide download" : "Skrýt stahování",
-    "Password protection enforced" : "Ochrana heslem vynucena",
-    "Password protect" : "Chránit heslem",
-    "Password" : "Heslo",
-    "Allow editing" : "Umožnit úpravy",
-    "Email link to person" : "Odeslat osobě odkaz e-mailem",
-    "Send" : "Odeslat",
-    "Allow upload and editing" : "Povolit nahrávání a úpravy",
-    "Read only" : "Pouze pro čtení",
-    "File drop (upload only)" : "Přetažení souboru (pouze nahrání)",
-    "Expiration date enforced" : "Datum skončení platnosti vynuceno",
-    "Set expiration date" : "Nastavit datum skončení platnosti",
-    "Expiration" : "Konec platnosti",
-    "Expiration date" : "Datum skončení platnosti",
-    "Note to recipient" : "Poznámka pro příjemce",
-    "Unshare" : "Zrušit sdílení",
-    "Delete share link" : "Smazat sdílecí odkaz",
-    "Add another link" : "Přidat další odkaz",
-    "Password protection for links is mandatory" : "Ochrana heslem je pro odkazy povinná",
-    "Share to {name}" : "Sdílet {name}",
-    "Share link" : "Odkaz pro sdílení",
-    "New share link" : "Nový sdílecí odkaz",
-    "Created on {time}" : "Vytvořeno {time}",
-    "Password protect by Talk" : "Ochrana heslem pomocí Talk",
-    "Could not unshare" : "Nelze zrušit sdílení",
-    "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
-    "Shared with you and {circle} by {owner}" : "Sdíleno s vámi a {circle} od {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Sdíleno {owner} s vámi a konverzací {conversation}",
-    "Shared with you in a conversation by {owner}" : "Sdílí s vámi {owner} v konverzaci",
-    "Shared with you by {owner}" : "S vámi sdílí {owner}",
-    "Choose a password for the mail share" : "Zvolte si heslo emailového sdílení",
-    "group" : "skupina",
-    "remote" : "vzdálený",
-    "remote group" : "vzdálená skupina",
-    "email" : "email",
-    "conversation" : "konverzace",
-    "shared by {sharer}" : "Sdílel {sharer}",
-    "Can reshare" : "Může znovu sdílet",
-    "Can edit" : "Může upravovat",
-    "Can create" : "Může vytvářet",
-    "Can change" : "Může měnit",
-    "Can delete" : "Může mazat",
-    "Access control" : "Řízení přístupu",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} nasdílel(a) prostřednictvím odkazu",
-    "Error while sharing" : "Chyba při sdílení",
-    "Share details could not be loaded for this item." : "Detaily sdílení pro tuto položku nelze načíst.",
-    "Search globally" : "Hledat globálně",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Alespoň {count} znak je vyžadován pro automatické doplňování","Alespoň {count} znaky jsou vyžadovány pro automatické doplňování","Alespoň {count} znaků je vyžadováno pro automatické doplňování","Alespoň {count} znaků je vyžadováno pro automatické doplňování"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Tento seznam je možná zkrácený – upřesněte vyhledávací výraz pro více výsledků.",
-    "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
-    "No users found for {search}" : "Nebyli nalezeni žádní uživatelé pro {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Došlo k chybě („{message}“). Zkuste to znovu",
-    "An error occurred. Please try again" : "Došlo k chybě. Zkuste to znovu",
-    "Home" : "Domů",
-    "Work" : "Práce",
-    "Other" : "Ostatní",
-    "{sharee} (remote group)" : "{sharee} (skupina na protějšku)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Sdílet",
-    "Name or email address..." : "Jméno nebo e-mailová adresa…",
-    "Name or federated cloud ID..." : "Jméno nebo identifikátor v rámci sdruženého cloudu…",
-    "Name, federated cloud ID or email address..." : "Jméno, identifikátor v rámci sdruženého cloudu, nebo e-mailová adresa…",
-    "Name..." : "Jméno…",
-    "Error" : "Chyba",
-    "Error removing share" : "Chyba při odstraňování sdílení",
     "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
     "restricted" : "omezeno",
     "invisible" : "neviditelný",
@@ -221,6 +140,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na svého správce.",
     "Username or email" : "Uživatelské jméno nebo email",
     "Username or\temail" : "Uživatelské jméno nebo\te-mail",
+    "Password" : "Heslo",
     "Log in" : "Přihlásit",
     "Logging in …" : "Přihlašování…",
     "Wrong username or password." : "Nesprávné uživatelské jméno nebo heslo.",
@@ -254,6 +174,7 @@ OC.L10N.register(
     "Modified" : "Upraveno",
     "{newName} already exists" : "{newName} už existuje",
     "Choose" : "Vybrat",
+    "Copy" : "Zkopírovat",
     "Move" : "Přesunout",
     "Error loading file picker template: {error}" : "Chyba při načítání šablony výběru souborů: {error}",
     "OK" : "OK",
@@ -303,6 +224,7 @@ OC.L10N.register(
     "File not found" : "Soubor nenalezen",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument se nepodařilo na serveru najít. Možná bylo sdílení smazáno nebo skončila jeho platnost?",
     "Back to %s" : "Zpět na %s",
+    "Error" : "Chyba",
     "Internal Server Error" : "Vnitřní chyba serveru",
     "The server was unable to complete your request." : "Server nemohl dokončit váš požadavek.",
     "If this happens again, please send the technical details below to the server administrator." : "Pokud se to stane znovu, pošlete níže uvedené technické detaily administrátorovi serveru.",
@@ -364,13 +286,13 @@ OC.L10N.register(
     "Account access" : "Přístup k účtu",
     "You are about to grant %1$s access to your %2$s account." : "Chystáte se udělit %1$s přístup ke svému %2$s účtu.",
     "Account connected" : "Účet připojen",
-    "Your client should now be connected! You can close this window." : "Váš klient by nyní měl být připojen. Toto okno už můžete zavřít.",
     "This share is password-protected" : "Toto sdílení je chráněno heslem",
     "The password is wrong. Try again." : "Chybné heslo. Zkuste to znovu.",
     "Two-factor authentication" : "Dvoufaktorové přihlášení",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Zvolte druhý faktor pro ověřování:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedaří se načíst ani jednu ze zapnutých metod dvouúrovňového ověřování. Obraťte se na svého správce.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Obraťte o pomoc na svého správce.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Pokračujte nastavením dvoufázového ověřování.",
     "Set up two-factor authentication" : "Nastavit dvoufázové ověřování",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Je vynucováno dvoufázové ověřování ale to pro váš účet není nastaveno. Přihlaste se použitím nějakého ze svých záložních kódů nebo se obraťte o pomoc na svého správce.",
     "Use backup code" : "Použít záložní kód",
@@ -400,36 +322,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje opakovaně nebo nečekaně, obraťte se správce systému.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nelze odeslat e-mail pro změnu hesla, protože u tohoto uživatelského jména není uvedena emailová adresa. Obraťte se na svého správce.",
     "Couldn't send reset email. Please make sure your username is correct." : "Nedaří se odeslat e-mail pro změnu hesla. Ujistěte se, že zadáváte správné uživatelské jméno.",
-    "Updated \"%s\" to %s" : "Aktualizováno z „%s“ na %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Došlo k problémům při kontrole integrity kódu. Více informací…</a>",
     "Dismiss" : "Zamítnout",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na vaši emailovou adresu. Pokud jej v krátké době neobdržíte, zkontrolujte nevyžádanou poštu a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše soubory jsou šifrovány. Po vyresetování vašeho hesla nebudete moc získat data zpět.<br/>Pokud si nejste jisti tím co děláte, předtím než budete pokračovat, kontaktujte vašeho administrátora.<br/>Opravdu chcete pokračovat?",
     "Sending email …" : "Odesílání e-mailu…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "Je nainstalovaná {name} starší verze než {version}. Z důvodu stability a výkonu je doporučeno aktualizovat na novější verzi {name}.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom není pro PHP přístupné pro čtení, což je silně nedoporučeno z důvodu zabezpečení. Další informace jsou k nalezení v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaci</a>.",
-    "Copy URL" : "Kopírovat URL",
-    "Enable" : "Povolit",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} sdílí pomocí odkazu",
-    "{sharee} (group)" : "{sharee} (skupina)",
-    "{sharee} (remote)" : "{sharee} (na protějšku)",
-    "{sharee} (email)" : "{sharee} (email)",
-    "{sharee} (conversation)" : "{sharee} (konverzace)",
-    "The specified document has not been found on the server." : "Požadovaný dokument nebyl na serveru nalezen.",
-    "You can click here to return to %s." : "Klikněte zde pro návrat na %s.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Přistupujete přes nezabezpečené HTTP. Silně doporučujeme nastavit svůj server tak, aby vyžadoval namísto toho HTTPS, jak je popsáno v <a href=\"{docUrl}\">tipech pro zabezpečení ↗</a>.",
+    "Shared" : "Sdílené",
+    "Shared with" : "Sdíleno s",
+    "Shared by" : "Nasdílel",
+    "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
+    "Choose a password for the public link or press the \"Enter\" key" : "Zvolte heslo pro veřejný odkaz nebo stiskněte klávesu „Enter“",
+    "Copied!" : "Zkopírováno!",
+    "Copy link" : "Zkopírovat odkaz",
+    "Not supported!" : "Nepodporováno!",
+    "Press ⌘-C to copy." : "Zmáčknout ⌘-C pro kopírování.",
+    "Press Ctrl-C to copy." : "Zmáčknout Ctrl-C pro kopírování.",
+    "Unable to create a link share" : "Nedaří se vytvořit sdílení odkazu",
+    "Unable to toggle this option" : "Tuto volbu se nedaří přepnout",
+    "Resharing is not allowed" : "Sdílení už sdílené položky není povoleno",
+    "Link" : "Odkaz",
+    "Hide download" : "Skrýt stahování",
+    "Password protection enforced" : "Ochrana heslem vynucena",
+    "Password protect" : "Chránit heslem",
+    "Allow editing" : "Umožnit úpravy",
+    "Email link to person" : "Odeslat osobě odkaz e-mailem",
+    "Send" : "Odeslat",
+    "Allow upload and editing" : "Povolit nahrávání a úpravy",
+    "Read only" : "Pouze pro čtení",
+    "File drop (upload only)" : "Přetažení souboru (pouze nahrání)",
+    "Expiration date enforced" : "Datum skončení platnosti vynuceno",
+    "Set expiration date" : "Nastavit datum skončení platnosti",
+    "Expiration" : "Konec platnosti",
+    "Expiration date" : "Datum skončení platnosti",
+    "Note to recipient" : "Poznámka pro příjemce",
+    "Unshare" : "Zrušit sdílení",
+    "Delete share link" : "Smazat sdílecí odkaz",
+    "Add another link" : "Přidat další odkaz",
+    "Password protection for links is mandatory" : "Ochrana heslem je pro odkazy povinná",
+    "Share to {name}" : "Sdílet {name}",
+    "Share link" : "Odkaz pro sdílení",
+    "New share link" : "Nový sdílecí odkaz",
+    "Created on {time}" : "Vytvořeno {time}",
+    "Password protect by Talk" : "Ochrana heslem pomocí Talk",
+    "Could not unshare" : "Nelze zrušit sdílení",
+    "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
+    "Shared with you and {circle} by {owner}" : "Sdíleno s vámi a {circle} od {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Sdíleno {owner} s vámi a konverzací {conversation}",
+    "Shared with you in a conversation by {owner}" : "Sdílí s vámi {owner} v konverzaci",
+    "Shared with you by {owner}" : "S vámi sdílí {owner}",
+    "Choose a password for the mail share" : "Zvolte si heslo emailového sdílení",
+    "group" : "skupina",
+    "remote" : "vzdálený",
+    "remote group" : "vzdálená skupina",
+    "email" : "email",
+    "conversation" : "konverzace",
+    "shared by {sharer}" : "Sdílel {sharer}",
+    "Can reshare" : "Může znovu sdílet",
+    "Can edit" : "Může upravovat",
+    "Can create" : "Může vytvářet",
+    "Can change" : "Může měnit",
+    "Can delete" : "Může mazat",
+    "Access control" : "Řízení přístupu",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} nasdílel(a) prostřednictvím odkazu",
+    "Error while sharing" : "Chyba při sdílení",
+    "Share details could not be loaded for this item." : "Detaily sdílení pro tuto položku nelze načíst.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Alespoň {count} znak je vyžadován pro automatické doplňování","Alespoň {count} znaky jsou vyžadovány pro automatické doplňování","Alespoň {count} znaků je vyžadováno pro automatické doplňování","Alespoň {count} znaků je vyžadováno pro automatické doplňování"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Tento seznam je možná zkrácený – upřesněte vyhledávací výraz pro více výsledků.",
+    "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
+    "No users found for {search}" : "Nebyli nalezeni žádní uživatelé pro {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Došlo k chybě („{message}“). Zkuste to znovu",
+    "An error occurred. Please try again" : "Došlo k chybě. Zkuste to znovu",
+    "Home" : "Domů",
+    "Work" : "Práce",
+    "Other" : "Ostatní",
+    "{sharee} (remote group)" : "{sharee} (skupina na protějšku)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Sdílet",
+    "Name or email address..." : "Jméno nebo e-mailová adresa…",
+    "Name or federated cloud ID..." : "Jméno nebo identifikátor v rámci sdruženého cloudu…",
+    "Name, federated cloud ID or email address..." : "Jméno, identifikátor v rámci sdruženého cloudu, nebo e-mailová adresa…",
+    "Name..." : "Jméno…",
+    "Error removing share" : "Chyba při odstraňování sdílení",
     "SQLite will be used as database." : "Bude použita SQLite databáze.",
     "For larger installations we recommend to choose a different database backend." : "Pro větší instalace doporučujeme zvolit jiné databázové řešení.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Obzvláště při používání klientské aplikace pro synchronizaci s desktopem není SQLite doporučeno.",
     "Wrong password." : "Chybné heslo.",
-    "Please log in before granting %s access to your %s account." : "Přihlaste se před udělením %s přístupu k vašemu %s účtu.",
-    "You are about to grant %s access to your %s account." : "Chystáte se povolit %s přístup k vašemu %s účtu.",
-    "Redirecting …" : "Přesměrovávání…",
     "New Password" : "Nové heslo",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Přihlaste se za použití druhého faktoru.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Více informací o tom, jak toto nastavit, jsou k dispozici v%sdokumentaci%s.",
-    "%s will be updated to version %s" : "%s bude aktualizován na verzi %s",
-    "This page will refresh itself when the %s instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude instance %s opět dostupná .",
-    "Thank you for your patience." : "Děkujeme za vaši trpělivost.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na e-mailovou adresu, uvedenou pro tento účet. Pokud jej v krátké době neobdržíte, zkontrolujte nevyžádanou poštu a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na e-mailovou adresu, uvedenou pro tento účet. Pokud jej v krátké době neobdržíte, zkontrolujte nevyžádanou poštu a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému.",
+    "Search globally" : "Hledat globálně",
+    "Your client should now be connected! You can close this window." : "Váš klient by nyní měl být připojen. Toto okno už můžete zavřít."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
