@@ -70,62 +70,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
-    "Shared" : "Shared",
-    "Shared with" : "Shared with",
-    "Shared by" : "Shared by",
-    "Choose a password for the public link" : "Choose a password for the public link",
-    "Choose a password for the public link or press the \"Enter\" key" : "Choose a password for the public link or press the \"Enter\" key",
-    "Copied!" : "Copied!",
-    "Not supported!" : "Not supported!",
-    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
-    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
-    "Copy" : "Copy",
-    "Resharing is not allowed" : "Resharing is not allowed",
-    "Link" : "Link",
-    "Password protect" : "Password protect",
-    "Password" : "Password",
-    "Allow editing" : "Allow editing",
-    "Email link to person" : "Email link to person",
-    "Send" : "Send",
-    "Allow upload and editing" : "Allow upload and editing",
-    "Read only" : "Read only",
-    "File drop (upload only)" : "File drop (upload only)",
-    "Set expiration date" : "Set expiration date",
-    "Expiration" : "Expiration",
-    "Expiration date" : "Expiration date",
-    "Unshare" : "Unshare",
-    "Share to {name}" : "Share to {name}",
-    "Share link" : "Share link",
-    "Could not unshare" : "Could not unshare",
-    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
-    "Shared with you by {owner}" : "Shared with you by {owner}",
-    "Choose a password for the mail share" : "Choose a password for the mail share",
-    "group" : "group",
-    "remote" : "remote",
-    "email" : "email",
-    "shared by {sharer}" : "shared by {sharer}",
-    "Can reshare" : "Can reshare",
-    "Can edit" : "Can edit",
-    "Can create" : "Can create",
-    "Can change" : "Can change",
-    "Can delete" : "Can delete",
-    "Access control" : "Access control",
-    "Error while sharing" : "Error whilst sharing",
-    "Share details could not be loaded for this item." : "Share details could not be loaded for this item.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["At least {count} character is needed for autocompletion","At least {count} characters are needed for autocompletion"],
-    "This list is maybe truncated - please refine your search term to see more results." : "This list is maybe truncated - please refine your search term to see more results.",
-    "No users or groups found for {search}" : "No users or groups found for {search}",
-    "No users found for {search}" : "No users found for {search}",
-    "An error occurred (\"{message}\"). Please try again" : "An error occurred (\"{message}\"). Please try again",
-    "An error occurred. Please try again" : "An error occurred. Please try again",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Share",
-    "Name or email address..." : "Name or email address...",
-    "Name or federated cloud ID..." : "Name or federated cloud ID...",
-    "Name, federated cloud ID or email address..." : "Name, federated cloud ID or email address...",
-    "Name..." : "Name...",
-    "Error" : "Error",
-    "Error removing share" : "Error removing share",
     "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
     "restricted" : "restricted",
     "invisible" : "invisible",
@@ -158,6 +102,7 @@ OC.L10N.register(
     "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Username or email" : "Username or email",
+    "Password" : "Password",
     "Log in" : "Log in",
     "Logging in …" : "Logging in …",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
@@ -179,6 +124,7 @@ OC.L10N.register(
     "Yes" : "Yes",
     "No files in here" : "No files in here",
     "Choose" : "Choose",
+    "Copy" : "Copy",
     "Move" : "Move",
     "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
     "OK" : "OK",
@@ -215,6 +161,7 @@ OC.L10N.register(
     "Help" : "Help",
     "Access forbidden" : "Access denied",
     "File not found" : "File not found",
+    "Error" : "Error",
     "Internal Server Error" : "Internal Server Error",
     "The server was unable to complete your request." : "The server was unable to complete your request.",
     "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
@@ -287,31 +234,67 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Could not send reset email because there is no email address for this username. Please contact your administrator.",
     "Couldn't send reset email. Please make sure your username is correct." : "Couldn't send reset email. Please make sure your username is correct.",
-    "Updated \"%s\" to %s" : "Updated \"%s\" to %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>",
     "Dismiss" : "Dismiss",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
     "Sending email …" : "Sending email …",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} shared via link",
-    "{sharee} (group)" : "{sharee} (group)",
-    "{sharee} (remote)" : "{sharee} (remote)",
-    "{sharee} (email)" : "{sharee} (email)",
-    "The specified document has not been found on the server." : "The specified document has not been found on the server.",
-    "You can click here to return to %s." : "You can click here to return to %s.",
+    "Shared" : "Shared",
+    "Shared with" : "Shared with",
+    "Shared by" : "Shared by",
+    "Choose a password for the public link" : "Choose a password for the public link",
+    "Choose a password for the public link or press the \"Enter\" key" : "Choose a password for the public link or press the \"Enter\" key",
+    "Copied!" : "Copied!",
+    "Not supported!" : "Not supported!",
+    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
+    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
+    "Resharing is not allowed" : "Resharing is not allowed",
+    "Link" : "Link",
+    "Password protect" : "Password protect",
+    "Allow editing" : "Allow editing",
+    "Email link to person" : "Email link to person",
+    "Send" : "Send",
+    "Allow upload and editing" : "Allow upload and editing",
+    "Read only" : "Read only",
+    "File drop (upload only)" : "File drop (upload only)",
+    "Set expiration date" : "Set expiration date",
+    "Expiration" : "Expiration",
+    "Expiration date" : "Expiration date",
+    "Unshare" : "Unshare",
+    "Share to {name}" : "Share to {name}",
+    "Share link" : "Share link",
+    "Could not unshare" : "Could not unshare",
+    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
+    "Shared with you by {owner}" : "Shared with you by {owner}",
+    "Choose a password for the mail share" : "Choose a password for the mail share",
+    "group" : "group",
+    "remote" : "remote",
+    "email" : "email",
+    "shared by {sharer}" : "shared by {sharer}",
+    "Can reshare" : "Can reshare",
+    "Can edit" : "Can edit",
+    "Can create" : "Can create",
+    "Can change" : "Can change",
+    "Can delete" : "Can delete",
+    "Access control" : "Access control",
+    "Error while sharing" : "Error whilst sharing",
+    "Share details could not be loaded for this item." : "Share details could not be loaded for this item.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["At least {count} character is needed for autocompletion","At least {count} characters are needed for autocompletion"],
+    "This list is maybe truncated - please refine your search term to see more results." : "This list is maybe truncated - please refine your search term to see more results.",
+    "No users or groups found for {search}" : "No users or groups found for {search}",
+    "No users found for {search}" : "No users found for {search}",
+    "An error occurred (\"{message}\"). Please try again" : "An error occurred (\"{message}\"). Please try again",
+    "An error occurred. Please try again" : "An error occurred. Please try again",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Share",
+    "Name or email address..." : "Name or email address...",
+    "Name or federated cloud ID..." : "Name or federated cloud ID...",
+    "Name, federated cloud ID or email address..." : "Name, federated cloud ID or email address...",
+    "Name..." : "Name...",
+    "Error removing share" : "Error removing share",
     "SQLite will be used as database." : "SQLite will be used as database.",
     "For larger installations we recommend to choose a different database backend." : "For larger installations we recommend to choose a different database backend.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
     "Wrong password." : "Wrong password.",
-    "Please log in before granting %s access to your %s account." : "Please log in before granting %s access to your %s account.",
-    "You are about to grant %s access to your %s account." : "You are about to grant %s access to your %s account.",
-    "Redirecting …" : "Redirecting …",
-    "New Password" : "New Password",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Enhanced security is enabled for your account. Please authenticate using a second factor.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Further information how to configure this can be found in the %sdocumentation%s.",
-    "%s will be updated to version %s" : "%s will be updated to version %s",
-    "This page will refresh itself when the %s instance is available again." : "This page will refresh itself when the %s instance is available again.",
-    "Thank you for your patience." : "Thank you for your patience."
+    "New Password" : "New Password"
 },
 "nplurals=2; plural=(n != 1);");
