@@ -67,61 +67,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
-    "Shared" : "Compartido",
-    "Shared with" : "Compartido con",
-    "Shared by" : "Compartido por",
-    "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
-    "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No está soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Copy" : "Copiar",
-    "Resharing is not allowed" : "No se permite volver a compartir",
-    "Link" : "Liga",
-    "Password protect" : "Proteger con contraseña",
-    "Password" : "Contraseña",
-    "Allow editing" : "Permitir editar",
-    "Email link to person" : "Enviar la liga por correo electrónico a una persona",
-    "Send" : "Enviar",
-    "Allow upload and editing" : "Permitir carga y edición",
-    "Read only" : "Sólo lectura",
-    "File drop (upload only)" : "Permitir carga",
-    "Set expiration date" : "Selecciona la vigencia de tu archivo",
-    "Expiration" : "Expiración",
-    "Expiration date" : "Fecha de expiración",
-    "Unshare" : "Dejar de compartir",
-    "Share to {name}" : "Compartir con {name}",
-    "Share link" : "Compartir liga",
-    "Could not unshare" : "No fue posible dejar de compartir",
-    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
-    "Shared with you by {owner}" : "Compartido contigo por {owner}",
-    "Choose a password for the mail share" : "Elige una contraseña para el elemento compartido por correo",
-    "group" : "grupo",
-    "remote" : "remoto",
-    "email" : "correo electrónico",
-    "shared by {sharer}" : "compartido por {sharer}",
-    "Can reshare" : "Puede volver a compartir",
-    "Can edit" : "Puede editar",
-    "Can create" : "Puede crear",
-    "Can change" : "Puede cambiar",
-    "Can delete" : "Puede borrar",
-    "Access control" : "Control de acceso",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - por favor refina tus términos de búsqueda para poder ver más resultados. ",
-    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
-    "No users found for {search}" : "No se encontraron usuarios para {search}",
-    "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Compartir",
-    "Name or email address..." : "Nombre o dirección de correo electrónico",
-    "Name or federated cloud ID..." : "Nombre...",
-    "Name, federated cloud ID or email address..." : "Nombre o dirección de correo electrónico...",
-    "Name..." : "Nombre...",
-    "Error" : "Error",
-    "Error removing share" : "Se presentó un error al dejar de compartir",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
     "restricted" : "restringido",
     "invisible" : "invisible",
@@ -154,6 +99,7 @@ OC.L10N.register(
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
     "Username or email" : "Usuario o correo electrónico",
+    "Password" : "Contraseña",
     "Log in" : "Ingresar",
     "Logging in …" : "Iniciando sesión ...",
     "Reset password" : "Restablecer contraseña",
@@ -172,6 +118,7 @@ OC.L10N.register(
     "Yes" : "Sí",
     "No files in here" : "No hay archivos aquí",
     "Choose" : "Seleccionar",
+    "Copy" : "Copiar",
     "Move" : "Mover",
     "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
     "OK" : "OK",
@@ -208,6 +155,7 @@ OC.L10N.register(
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
     "File not found" : "Archivo no encontrado",
+    "Error" : "Error",
     "Internal Server Error" : "Error interno del servidor",
     "The server was unable to complete your request." : "El servidor no pudo completar tu solicitud.",
     "If this happens again, please send the technical details below to the server administrator." : "Si esto vuelve a suceder, por favor envia los detalles tecnicos siguientes al adminsitrador del sistema.",
@@ -276,29 +224,66 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Por favor contacta a tu adminsitrador. ",
     "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Por favor asegurarte de que tu nombre de usuario sea correcto. ",
-    "Updated \"%s\" to %s" : "Actualizando \"%s\" a %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Se presentaron problemas con la verificación de integridad del código. Más información ...</a>",
     "Dismiss" : "Descartar",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La liga para restablecer tu contraseña ha sido enviada a tu correo electrónico. Si no lo recibes dentro de un tiempo razonable, verifica las carpetas de spam/basura.<br>Si no la encuentras consulta a tu adminstrador local.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tus archivos están encriptados. No habrá manera de recuperar tus datos una vez que restablezca tu contraseña. <br />Si no estás seguro de qué hacer, por favor contacta a tu administrador antes de continuar. <br />¿Realmente deseas continuar?",
     "Sending email …" : "Enviando correo electrónico ...",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP no puede leer /dev/urandom y no se recomienda por razones de seguridad. Puedes encontrar más información en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} ha compartido mediante una liga",
-    "{sharee} (group)" : "{sharee} (grupo)",
-    "{sharee} (remote)" : "{sharee} (remoto)",
-    "{sharee} (email)" : "{sharee} (correo electrónico)",
-    "The specified document has not been found on the server." : "El documento especificado no ha sido encontrado en el servidor. ",
-    "You can click here to return to %s." : "Puedes hacer click aquí para regresar a %s.",
+    "Shared" : "Compartido",
+    "Shared with" : "Compartido con",
+    "Shared by" : "Compartido por",
+    "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
+    "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
+    "Copied!" : "¡Copiado!",
+    "Not supported!" : "¡No está soportado!",
+    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "Resharing is not allowed" : "No se permite volver a compartir",
+    "Link" : "Liga",
+    "Password protect" : "Proteger con contraseña",
+    "Allow editing" : "Permitir editar",
+    "Email link to person" : "Enviar la liga por correo electrónico a una persona",
+    "Send" : "Enviar",
+    "Allow upload and editing" : "Permitir carga y edición",
+    "Read only" : "Sólo lectura",
+    "File drop (upload only)" : "Permitir carga",
+    "Set expiration date" : "Selecciona la vigencia de tu archivo",
+    "Expiration" : "Expiración",
+    "Expiration date" : "Fecha de expiración",
+    "Unshare" : "Dejar de compartir",
+    "Share to {name}" : "Compartir con {name}",
+    "Share link" : "Compartir liga",
+    "Could not unshare" : "No fue posible dejar de compartir",
+    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
+    "Shared with you by {owner}" : "Compartido contigo por {owner}",
+    "Choose a password for the mail share" : "Elige una contraseña para el elemento compartido por correo",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "email" : "correo electrónico",
+    "shared by {sharer}" : "compartido por {sharer}",
+    "Can reshare" : "Puede volver a compartir",
+    "Can edit" : "Puede editar",
+    "Can create" : "Puede crear",
+    "Can change" : "Puede cambiar",
+    "Can delete" : "Puede borrar",
+    "Access control" : "Control de acceso",
+    "Error while sharing" : "Se presentó un error al compartir",
+    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - por favor refina tus términos de búsqueda para poder ver más resultados. ",
+    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
+    "No users found for {search}" : "No se encontraron usuarios para {search}",
+    "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Compartir",
+    "Name or email address..." : "Nombre o dirección de correo electrónico",
+    "Name or federated cloud ID..." : "Nombre...",
+    "Name, federated cloud ID or email address..." : "Nombre o dirección de correo electrónico...",
+    "Name..." : "Nombre...",
+    "Error removing share" : "Se presentó un error al dejar de compartir",
     "SQLite will be used as database." : "SQLite será usado como la base de datos.",
     "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes te recomendamos elegir un backend de base de datos diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
     "Wrong password." : "Contraseña inválida. ",
-    "You are about to grant %s access to your %s account." : "Estas a punto de otorgar acceso de %s a tu cuenta %s.",
-    "Redirecting …" : "Redireccionando ... ",
-    "New Password" : "Nueva Contraseña",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "La seguridad mejorada está habilitada para tu cuenta. Favor de autenticarte usando un segundo factor. ",
-    "%s will be updated to version %s" : "%s será actualizado a la versión %s",
-    "This page will refresh itself when the %s instance is available again." : "Esta página se actualizará sola cuando la instancia %s esté disponible de nuevo. ",
-    "Thank you for your patience." : "Gracias por tu paciencia."
+    "New Password" : "Nueva Contraseña"
 },
 "nplurals=2; plural=(n != 1);");
