@@ -53,59 +53,6 @@ OC.L10N.register(
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
-    "Shared" : "Compartido",
-    "Choose a password for the public link" : "Seleccione una contraseña para el link público",
-    "Choose a password for the public link or press the \"Enter\" key" : "Favor de elegir una contraseña para el link público o presione  \"Intro\"",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No está soportado!",
-    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
-    "Copy" : "Copiar",
-    "Resharing is not allowed" : "No se permite volver a compartir",
-    "Link" : "Link",
-    "Password protect" : "Proteger con contraseña",
-    "Password" : "Contraseña",
-    "Allow editing" : "Permitir editar",
-    "Email link to person" : "Enviar el link por correo electrónico a una persona",
-    "Send" : "Enviar",
-    "Allow upload and editing" : "Permitir cargar y editar",
-    "Read only" : "Solo lectura",
-    "File drop (upload only)" : "Soltar archivo (solo para carga)",
-    "Set expiration date" : "Establecer la fecha de expiración",
-    "Expiration" : "Expiración",
-    "Expiration date" : "Fecha de expiración",
-    "Unshare" : "Dejar de compartir",
-    "Share to {name}" : "Compartir con {name}",
-    "Share link" : "Compartir link",
-    "Could not unshare" : "No fue posible dejar de compartir",
-    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
-    "Shared with you by {owner}" : "Compartido con usted por {owner}",
-    "Choose a password for the mail share" : "Establecer una contraseña para el elemento compartido por correo",
-    "group" : "grupo",
-    "remote" : "remoto",
-    "email" : "correo electrónico",
-    "shared by {sharer}" : "compartido por {sharer}",
-    "Can reshare" : "Puede volver a compartir",
-    "Can edit" : "Puede editar",
-    "Can create" : "Puede crear",
-    "Can change" : "Puede cambiar",
-    "Can delete" : "Puede borrar",
-    "Access control" : "Control de acceso",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - favor de refinar sus términos de búsqueda para poder ver más resultados. ",
-    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
-    "No users found for {search}" : "No se encontraron usuarios para {search}",
-    "An error occurred. Please try again" : "Se presentó un error. Favor de volver a intentar",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Compartir",
-    "Name or email address..." : "Nombre o dirección de correo electrónico",
-    "Name or federated cloud ID..." : "Nombre o ID de nube federada...",
-    "Name, federated cloud ID or email address..." : "Nombre, ID de nube federada o dirección de correo electrónico...",
-    "Name..." : "Nombre...",
-    "Error" : "Error",
-    "Error removing share" : "Se presentó un error al dejar de compartir",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
     "restricted" : "restringido",
     "invisible" : "invisible",
@@ -138,6 +85,7 @@ OC.L10N.register(
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Favor de volver a intentarlo o contacte a su adminsitrador. ",
     "Username or email" : "Nombre de usuario o contraseña",
+    "Password" : "Contraseña",
     "Log in" : "Ingresar",
     "Logging in …" : "Ingresando ...",
     "Reset password" : "Restablecer contraseña",
@@ -155,6 +103,7 @@ OC.L10N.register(
     "Yes" : "Sí",
     "No files in here" : "No hay archivos aquí",
     "Choose" : "Seleccionar",
+    "Copy" : "Copiar",
     "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
     "OK" : "OK",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
@@ -188,6 +137,7 @@ OC.L10N.register(
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso denegado",
     "File not found" : "Archivo no encontrado",
+    "Error" : "Error",
     "Internal Server Error" : "Error interno del servidor",
     "More details can be found in the server log." : "Puede consultar más detalles en la bitácora del servidor. ",
     "Technical details" : "Detalles técnicos",
@@ -246,27 +196,63 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte a su administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Favor de contactar a su adminsitrador. ",
     "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Favor de asegurarse que su nombre de usuario sea correcto. ",
-    "Updated \"%s\" to %s" : "Actualizando \"%s\" a %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Se presentaron problemas con la verificación de integridad del código. Mayor información ...</a>",
     "Dismiss" : "Descartar",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "El link para restablecer su contraseña ha sido enviada a su correo electrónico. Si no lo recibe dentro de un tiempo razonable, verifique las carpetas de spam/basura.<br>Si no la encuentra consulte a su adminstrador local.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sus archivos están encriptados. No habrá manera de recuperar sus datos una vez que restablezca su contraseña. <br />Si no está seguro de qué hacer, favor de contactar a su administrador antes de continuar. <br />¿Realmente desea continuar?",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} ha compatido mediante un link",
-    "{sharee} (group)" : "{sharee} (grupo)",
-    "{sharee} (remote)" : "{sharee} (remoto)",
-    "{sharee} (email)" : "{sharee} (correo electrónico)",
-    "The specified document has not been found on the server." : "El documento especificado no ha sido encontrado en el servidor. ",
-    "You can click here to return to %s." : "Puede hacer click aquí para regresar a %s.",
+    "Shared" : "Compartido",
+    "Choose a password for the public link" : "Seleccione una contraseña para el link público",
+    "Choose a password for the public link or press the \"Enter\" key" : "Favor de elegir una contraseña para el link público o presione  \"Intro\"",
+    "Copied!" : "¡Copiado!",
+    "Not supported!" : "¡No está soportado!",
+    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
+    "Resharing is not allowed" : "No se permite volver a compartir",
+    "Link" : "Link",
+    "Password protect" : "Proteger con contraseña",
+    "Allow editing" : "Permitir editar",
+    "Email link to person" : "Enviar el link por correo electrónico a una persona",
+    "Send" : "Enviar",
+    "Allow upload and editing" : "Permitir cargar y editar",
+    "Read only" : "Solo lectura",
+    "File drop (upload only)" : "Soltar archivo (solo para carga)",
+    "Set expiration date" : "Establecer la fecha de expiración",
+    "Expiration" : "Expiración",
+    "Expiration date" : "Fecha de expiración",
+    "Unshare" : "Dejar de compartir",
+    "Share to {name}" : "Compartir con {name}",
+    "Share link" : "Compartir link",
+    "Could not unshare" : "No fue posible dejar de compartir",
+    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
+    "Shared with you by {owner}" : "Compartido con usted por {owner}",
+    "Choose a password for the mail share" : "Establecer una contraseña para el elemento compartido por correo",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "email" : "correo electrónico",
+    "shared by {sharer}" : "compartido por {sharer}",
+    "Can reshare" : "Puede volver a compartir",
+    "Can edit" : "Puede editar",
+    "Can create" : "Puede crear",
+    "Can change" : "Puede cambiar",
+    "Can delete" : "Puede borrar",
+    "Access control" : "Control de acceso",
+    "Error while sharing" : "Se presentó un error al compartir",
+    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - favor de refinar sus términos de búsqueda para poder ver más resultados. ",
+    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
+    "No users found for {search}" : "No se encontraron usuarios para {search}",
+    "An error occurred. Please try again" : "Se presentó un error. Favor de volver a intentar",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Compartir",
+    "Name or email address..." : "Nombre o dirección de correo electrónico",
+    "Name or federated cloud ID..." : "Nombre o ID de nube federada...",
+    "Name, federated cloud ID or email address..." : "Nombre, ID de nube federada o dirección de correo electrónico...",
+    "Name..." : "Nombre...",
+    "Error removing share" : "Se presentó un error al dejar de compartir",
     "SQLite will be used as database." : "SQLite será usado como la base de datos.",
     "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes le recomendamos elegir un backend de base de datos diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
     "Wrong password." : "Contraseña inválida. ",
-    "You are about to grant %s access to your %s account." : "Está a punto de concederle a \"%s\" acceso a su cuenta %s.",
-    "Redirecting …" : "Redireccionando ... ",
-    "New Password" : "Nueva Contraseña",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "La seguridad mejorada está habilitada para su cuenta. Favor de autenticarse usando un segundo factor. ",
-    "%s will be updated to version %s" : "%s será actualizado a la versión %s",
-    "This page will refresh itself when the %s instance is available again." : "Esta página se actualizará sola cuando la instancia %s esté disponible de nuevo. ",
-    "Thank you for your patience." : "Gracias por su paciencia."
+    "New Password" : "Nueva Contraseña"
 },
 "nplurals=2; plural=(n != 1);");
