@@ -53,60 +53,6 @@ OC.L10N.register(
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sinu veebiserver pole veel piisavalt korralikult seadistatud, et lubada failide sünkroniseerimist, kuna WebDAV liides paistab olevat katki.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Sinu veebiserver pole veel piisavalt korralikult seadistatud, et lahendada aadressi \"{url}\". Lisateavet leiate meie <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\"> dokumentatsioonist </a>.",
     "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
-    "Shared" : "Jagatud",
-    "Shared with" : "Jagatud",
-    "Shared by" : "Jagas",
-    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
-    "Choose a password for the public link or press the \"Enter\" key" : "Vali avaliku lingi jaoks parool või vajuta klahvi \"Enter\"",
-    "Copied!" : "Kopeeritud!",
-    "Not supported!" : "Pole toetatud!",
-    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
-    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
-    "Copy" : "Kopeeri",
-    "Resharing is not allowed" : "Edasijagamine pole lubatud",
-    "Link" : "Link",
-    "Password protect" : "Parooliga kaitstud",
-    "Password" : "Parool",
-    "Allow editing" : "Luba muutmine",
-    "Email link to person" : "Saada link isikule e-postiga",
-    "Send" : "Saada",
-    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
-    "Read only" : "kirjutuskaitstud",
-    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
-    "Set expiration date" : "Määra aegumise kuupäev",
-    "Expiration" : "Aegumine",
-    "Expiration date" : "Aegumise kuupäev",
-    "Unshare" : "Lõpeta jagamine",
-    "Share to {name}" : "Jaga kasutajale {name}",
-    "Share link" : "Jaga linki",
-    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
-    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
-    "Shared with you by {owner}" : "Sinuga jagas {owner}",
-    "Choose a password for the mail share" : "Vali parool e-postiga jagamisel",
-    "group" : "grupp",
-    "remote" : "kaug",
-    "email" : "e-post",
-    "shared by {sharer}" : "jagatud kasutajalt {sharer}",
-    "Can reshare" : "Võib edasi jagada",
-    "Can edit" : "Võib redigeerida",
-    "Can create" : "Võib luua",
-    "Can change" : "Võib muuta",
-    "Can delete" : "Võib kustutada",
-    "Access control" : "Ligipääsukontroll",
-    "Error while sharing" : "Viga jagamisel",
-    "Share details could not be loaded for this item." : "Selle üksuse jagamise detaile ei õnnestunud laadida.",
-    "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
-    "No users or groups found for {search}" : "Otsingu {search} põhjal kasutajaid ega gruppe ei leitud",
-    "No users found for {search}" : "Otsingu {search} põhjal kasutajaid ei leitud",
-    "An error occurred. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Jaga",
-    "Name or email address..." : "Nimi või e-posti aadress",
-    "Name or federated cloud ID..." : "Liitpilve nimi või ID...",
-    "Name, federated cloud ID or email address..." : "Liitpilve nimi, ID või e-posti aadress...",
-    "Name..." : "Nimi...",
-    "Error" : "Viga",
-    "Error removing share" : "Viga jagamise eemaldamisel",
     "Non-existing tag #{tag}" : "Olematu silt #{tag}",
     "restricted" : "piiratud",
     "invisible" : "nähtamatu",
@@ -136,6 +82,7 @@ OC.L10N.register(
     "An internal error occurred." : "Tekkis sisemine tõrge.",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
     "Username or email" : "Kasutajanimi või e-posti aadress",
+    "Password" : "Parool",
     "Log in" : "Logi sisse",
     "Logging in …" : "Sisselogimine ...",
     "Reset password" : "Lähtesta parool",
@@ -155,6 +102,7 @@ OC.L10N.register(
     "Yes" : "Jah",
     "No files in here" : "Siin ei ole faile",
     "Choose" : "Vali",
+    "Copy" : "Kopeeri",
     "Move" : "Liiguta",
     "Error loading file picker template: {error}" : "Viga failivalija malli laadimisel:  {error}",
     "OK" : "OK",
@@ -191,6 +139,7 @@ OC.L10N.register(
     "Help" : "Abiinfo",
     "Access forbidden" : "Ligipääs on keelatud",
     "File not found" : "Faili ei leitud",
+    "Error" : "Viga",
     "Internal Server Error" : "Serveri sisemine viga",
     "The server was unable to complete your request." : "Server ei suutnud sinu päringut lõpetada.",
     "If this happens again, please send the technical details below to the server administrator." : "Kui see veel kord juhtub, saada tehnilised detailid allpool serveri administraatorile.",
@@ -255,28 +204,65 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ei saanud saata lähtestamise e-kirja kuna antud kasutajal puudub e-posti aadress. Palun kontakteeruge administraatoriga ",
     "Couldn't send reset email. Please make sure your username is correct." : "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
-    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Koodi terviklikkuse kontrollis ilmnes viga. Rohkem infot …</a>",
     "Dismiss" : "Jäta vahele",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Andmete taaastaamine ei ole pärast parooli lähtestaamist enam võimalik. <br />Kui Sa ei ole kindel mida teha, kontakteeru palun enne jätkamist administraatoriga. <br />Kas Sa kindlasti soovid jätkata?",
     "Sending email …" : "Saadan kirja ...",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} lingiga jagatud",
-    "{sharee} (group)" : "{sharee} (grupp)",
-    "{sharee} (remote)" : "{sharee} (mujal serveris)",
-    "{sharee} (email)" : "{sharee} (e-post)",
-    "The specified document has not been found on the server." : "Määratud dokumenti serverist ei leitud.",
-    "You can click here to return to %s." : "%s tagasi minemiseks võid sa siia klikkida.",
+    "Shared" : "Jagatud",
+    "Shared with" : "Jagatud",
+    "Shared by" : "Jagas",
+    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
+    "Choose a password for the public link or press the \"Enter\" key" : "Vali avaliku lingi jaoks parool või vajuta klahvi \"Enter\"",
+    "Copied!" : "Kopeeritud!",
+    "Not supported!" : "Pole toetatud!",
+    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
+    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
+    "Resharing is not allowed" : "Edasijagamine pole lubatud",
+    "Link" : "Link",
+    "Password protect" : "Parooliga kaitstud",
+    "Allow editing" : "Luba muutmine",
+    "Email link to person" : "Saada link isikule e-postiga",
+    "Send" : "Saada",
+    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
+    "Read only" : "kirjutuskaitstud",
+    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
+    "Set expiration date" : "Määra aegumise kuupäev",
+    "Expiration" : "Aegumine",
+    "Expiration date" : "Aegumise kuupäev",
+    "Unshare" : "Lõpeta jagamine",
+    "Share to {name}" : "Jaga kasutajale {name}",
+    "Share link" : "Jaga linki",
+    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
+    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
+    "Shared with you by {owner}" : "Sinuga jagas {owner}",
+    "Choose a password for the mail share" : "Vali parool e-postiga jagamisel",
+    "group" : "grupp",
+    "remote" : "kaug",
+    "email" : "e-post",
+    "shared by {sharer}" : "jagatud kasutajalt {sharer}",
+    "Can reshare" : "Võib edasi jagada",
+    "Can edit" : "Võib redigeerida",
+    "Can create" : "Võib luua",
+    "Can change" : "Võib muuta",
+    "Can delete" : "Võib kustutada",
+    "Access control" : "Ligipääsukontroll",
+    "Error while sharing" : "Viga jagamisel",
+    "Share details could not be loaded for this item." : "Selle üksuse jagamise detaile ei õnnestunud laadida.",
+    "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
+    "No users or groups found for {search}" : "Otsingu {search} põhjal kasutajaid ega gruppe ei leitud",
+    "No users found for {search}" : "Otsingu {search} põhjal kasutajaid ei leitud",
+    "An error occurred. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Jaga",
+    "Name or email address..." : "Nimi või e-posti aadress",
+    "Name or federated cloud ID..." : "Liitpilve nimi või ID...",
+    "Name, federated cloud ID or email address..." : "Liitpilve nimi, ID või e-posti aadress...",
+    "Name..." : "Nimi...",
+    "Error removing share" : "Viga jagamise eemaldamisel",
     "SQLite will be used as database." : "Andmebaasina kasutatakse SQLite",
     "For larger installations we recommend to choose a different database backend." : "Suuremate paigalduste jaoks soovitame valida teise andmebaasi.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Eriti kui tasutad töölaua rakendust failide sünkroonimiseks on SQLite andmebaas ebasoovitav.",
     "Wrong password." : "Vale parool.",
-    "You are about to grant %s access to your %s account." : "Sa oled andmas %s ligipääsu oma %s kontole.",
-    "Redirecting …" : "Ümbersuunamine ...",
-    "New Password" : "Uus parool",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Täiustatud turvalisus on teie konto jaoks lubatud. Palun autentida teise teguri abil.",
-    "%s will be updated to version %s" : "%s uuendatakse versioonile %s",
-    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval.",
-    "Thank you for your patience." : "Täname kannatlikkuse eest."
+    "New Password" : "Uus parool"
 },
 "nplurals=2; plural=(n != 1);");
