@@ -53,59 +53,6 @@ OC.L10N.register(
     "Good password" : "رمز عبور خوب",
     "Strong password" : "رمز عبور قوی",
     "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
-    "Shared" : "اشتراک گذاشته شده",
-    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
-    "Choose a password for the public link or press the \"Enter\" key" : "یک رمز عبور برای لینک عمومی انتخاب کنید یا کلید \"Enter\" را فشار دهید",
-    "Copied!" : "کپی انجام شد!",
-    "Not supported!" : "پشتیبانی وجود ندارد!",
-    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
-    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
-    "Copy" : "کپی",
-    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
-    "Link" : "لینک",
-    "Password protect" : "نگهداری کردن رمز عبور",
-    "Password" : "گذرواژه",
-    "Allow editing" : "اجازه‌ی ویرایش",
-    "Email link to person" : "پیوند ایمیل برای شخص.",
-    "Send" : "ارسال",
-    "Allow upload and editing" : "اجازه آپلود و ویرایش",
-    "Read only" : "فقط خواندنی",
-    "File drop (upload only)" : "انداختن فایل (فقط آپلود)",
-    "Set expiration date" : "تنظیم تاریخ انقضا",
-    "Expiration" : "تاریخ انقضا",
-    "Expiration date" : "تاریخ انقضا",
-    "Unshare" : "لغو اشتراک",
-    "Share to {name}" : "به اشتراک گذاشتن برای {name}",
-    "Share link" : "اشتراک گذاشتن لینک",
-    "Could not unshare" : "اشتراک گذاری بازگردانده نشد",
-    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
-    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
-    "Choose a password for the mail share" : "یک رمز عبور برای اشتراک ایمیل انتخاب کنید",
-    "group" : "گروه",
-    "remote" : "از راه دور",
-    "email" : "ایمیل",
-    "shared by {sharer}" : "اشتراک گذاشته شده توسط  {sharer}",
-    "Can reshare" : "می توان مجددا به اشتراک گذاشت",
-    "Can edit" : "می توان ویرایش کرد",
-    "Can create" : "میتوان ایجاد کرد",
-    "Can change" : "می توان تغییر داد",
-    "Can delete" : "می توان حذف کرد",
-    "Access control" : "کنترل دسترسی",
-    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
-    "Share details could not be loaded for this item." : "جزئیات اشتراک گذاری برای این مورد قابل بارگذاری نیست.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد","برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد"],
-    "This list is maybe truncated - please refine your search term to see more results." : "این فهرست ممکن است کامل نباشد - لطفا نتایج جستجوی خود را ریفرش کنید تا نتایج بیشتری ببینید.",
-    "No users or groups found for {search}" : "هیچ کاربری یا گروهی یافت نشد {search}",
-    "No users found for {search}" : "هیچ کاربری با جستجوی {search} یافت نشد",
-    "An error occurred. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "اشتراک‌گذاری",
-    "Name or email address..." : "نام یا آدرس ایمیل ...",
-    "Name or federated cloud ID..." : "نام یا شناسه Federated Cloud ...",
-    "Name, federated cloud ID or email address..." : "نام, آدرس ایمیل یا شناسه Federated Cloud ...",
-    "Name..." : "نام...",
-    "Error" : "خطا",
-    "Error removing share" : "خطا در حذف اشتراک گذاری",
     "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
     "restricted" : "محدود",
     "invisible" : "غیر قابل مشاهده",
@@ -138,6 +85,7 @@ OC.L10N.register(
     "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
     "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
     "Username or email" : "نام کاربری یا ایمیل",
+    "Password" : "گذرواژه",
     "Log in" : "ورود",
     "Logging in …" : "ورود به سیستم ...",
     "Reset password" : "تنظیم مجدد رمز عبور",
@@ -155,6 +103,7 @@ OC.L10N.register(
     "Yes" : "بله",
     "No files in here" : "هیچ فایلی اینجا وجود ندارد",
     "Choose" : "انتخاب کردن",
+    "Copy" : "کپی",
     "Move" : "انتقال",
     "Error loading file picker template: {error}" : "خطا در بارگذاری قالب انتخاب فایل : {error}",
     "OK" : "تایید",
@@ -191,6 +140,7 @@ OC.L10N.register(
     "Help" : "راه‌نما",
     "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
     "File not found" : "فایل یافت نشد",
+    "Error" : "خطا",
     "Internal Server Error" : "خطای داخلی سرور",
     "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
     "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
@@ -240,22 +190,62 @@ OC.L10N.register(
     "Update needed" : "نیاز به روز رسانی دارد",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "ایمیل بازنشانی ارسال نشد, زیرا هیچ نشانی ایمیل برای این نام کاربری وجود ندارد. لطفا با ادمین خود تماس بگیرید.",
     "Couldn't send reset email. Please make sure your username is correct." : "پست الکترونیکی بازنشانی نشد, لطفا مطمئن شوید که نام کاربری شما درست است",
-    "Updated \"%s\" to %s" : "\"%s\" به %s بروزرسانی شد",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>",
     "Dismiss" : "پنهان کن",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "لینک تنظیم مجدد رمز عبور به ایمیل شما ارسال شده است.<br>اگر آن رادر یک زمان مشخصی دریافت نکرده اید، لطفا هرزنامه/ پوشه های ناخواسته را بررسی کنید.<br>در صورت نبودن از مدیر خود بپرسید.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "فایل های شما رمزگذاری می شوند پس از بازنشانی گذرواژه شما هیچ راهی برای بازگرداندن اطلاعات نخواهید داشت. <br /> اگر مطمئن نیستید که چه کاری باید انجام دهید، قبل از ادامه دادن، با ادمین خود تماس بگیرید. <br />واقعا می خواهید ادامه دهید؟ ",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} به اشتراک گذاشته شده از طریق لینک",
-    "{sharee} (group)" : "{sharee} (group)",
-    "{sharee} (remote)" : "{sharee} (remote)",
-    "{sharee} (email)" : "{sharee} (email)",
-    "The specified document has not been found on the server." : "مستند مورد نظر در سرور یافت نشد.",
-    "You can click here to return to %s." : "شما می‎توانید برای بازگشت به  %s اینجا کلیک کنید.",
+    "Shared" : "اشتراک گذاشته شده",
+    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
+    "Choose a password for the public link or press the \"Enter\" key" : "یک رمز عبور برای لینک عمومی انتخاب کنید یا کلید \"Enter\" را فشار دهید",
+    "Copied!" : "کپی انجام شد!",
+    "Not supported!" : "پشتیبانی وجود ندارد!",
+    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
+    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
+    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
+    "Link" : "لینک",
+    "Password protect" : "نگهداری کردن رمز عبور",
+    "Allow editing" : "اجازه‌ی ویرایش",
+    "Email link to person" : "پیوند ایمیل برای شخص.",
+    "Send" : "ارسال",
+    "Allow upload and editing" : "اجازه آپلود و ویرایش",
+    "Read only" : "فقط خواندنی",
+    "File drop (upload only)" : "انداختن فایل (فقط آپلود)",
+    "Set expiration date" : "تنظیم تاریخ انقضا",
+    "Expiration" : "تاریخ انقضا",
+    "Expiration date" : "تاریخ انقضا",
+    "Unshare" : "لغو اشتراک",
+    "Share to {name}" : "به اشتراک گذاشتن برای {name}",
+    "Share link" : "اشتراک گذاشتن لینک",
+    "Could not unshare" : "اشتراک گذاری بازگردانده نشد",
+    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
+    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
+    "Choose a password for the mail share" : "یک رمز عبور برای اشتراک ایمیل انتخاب کنید",
+    "group" : "گروه",
+    "remote" : "از راه دور",
+    "email" : "ایمیل",
+    "shared by {sharer}" : "اشتراک گذاشته شده توسط  {sharer}",
+    "Can reshare" : "می توان مجددا به اشتراک گذاشت",
+    "Can edit" : "می توان ویرایش کرد",
+    "Can create" : "میتوان ایجاد کرد",
+    "Can change" : "می توان تغییر داد",
+    "Can delete" : "می توان حذف کرد",
+    "Access control" : "کنترل دسترسی",
+    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
+    "Share details could not be loaded for this item." : "جزئیات اشتراک گذاری برای این مورد قابل بارگذاری نیست.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد","برای تکمیل خودکار لازم است حداقل {count} کاراکتر وجود داشته باشد"],
+    "This list is maybe truncated - please refine your search term to see more results." : "این فهرست ممکن است کامل نباشد - لطفا نتایج جستجوی خود را ریفرش کنید تا نتایج بیشتری ببینید.",
+    "No users or groups found for {search}" : "هیچ کاربری یا گروهی یافت نشد {search}",
+    "No users found for {search}" : "هیچ کاربری با جستجوی {search} یافت نشد",
+    "An error occurred. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "اشتراک‌گذاری",
+    "Name or email address..." : "نام یا آدرس ایمیل ...",
+    "Name or federated cloud ID..." : "نام یا شناسه Federated Cloud ...",
+    "Name, federated cloud ID or email address..." : "نام, آدرس ایمیل یا شناسه Federated Cloud ...",
+    "Name..." : "نام...",
+    "Error removing share" : "خطا در حذف اشتراک گذاری",
     "SQLite will be used as database." : "SQLite به عنوان پایگاه‎داده استفاده خواهد شد.",
     "For larger installations we recommend to choose a different database backend." : "برای نصب و راه اندازی بزرگتر توصیه می کنیم یک پایگاه داده متفاوتی را انتخاب کنید.",
     "Wrong password." : "گذرواژه اشتباه.",
-    "New Password" : "رمزعبور جدید",
-    "%s will be updated to version %s" : "%s به نسخه‌ی %s بروزرسانی خواهد شد",
-    "Thank you for your patience." : "از صبر شما متشکریم"
+    "New Password" : "رمزعبور جدید"
 },
 "nplurals=2; plural=(n > 1);");
