@@ -14,7 +14,9 @@ OC.L10N.register(
     "No crop data provided" : "Leikkaustietoa ei annettu",
     "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
     "Crop is not square" : "Leikkaus ei ole neliö",
+    "State token does not match" : "Tilapoletti ei täsmää",
     "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
+    "Your login token is invalid or has expired" : "Kirjautumispolettisi on virheellinen tai se on vanhentunut",
     "Password reset is disabled" : "Salasanan palautus poistettu käytöstä",
     "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa, koska valtuutus on virheellinen",
     "Couldn't reset password because the token is expired" : "Salasanaa ei voitu palauttaa, koska valtuutus on vanhentunut",
@@ -81,6 +83,208 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data-hakemisto ja tiedostot ovat luultavasti käytettävissä suoraan Internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään HTTP-palvelimen asetukset siten, ettei data-hakemisto ole suoraan käytettävissä Internetistä tai siirtämään data-hakemiston HTTP-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten on suositeltavaa muuttaa asetuksen arvoa.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Jotkin toiminnot eivät vättämättä toimi oikein, joten on suositeltavaa muuttaa asetuksen arvoa.",
+    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
+    "restricted" : "rajoitettu",
+    "invisible" : "näkymätön",
+    "({scope})" : "({scope})",
+    "Delete" : "Poista",
+    "Rename" : "Nimeä uudelleen",
+    "Collaborative tags" : "Yhteistyölliset tunnisteet",
+    "No tags found" : "Tunnisteita ei löytynyt",
+    "unknown text" : "tuntematon teksti",
+    "Hello world!" : "Hei maailma!",
+    "sunny" : "aurinkoinen",
+    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
+    "Hello {name}" : "Hei {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
+    "new" : "uusi",
+    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
+    "Update to {version}" : "Päivitä versioon {version}",
+    "An error occurred." : "Tapahtui virhe.",
+    "Please reload the page." : "Päivitä sivu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
+    "Continue to Nextcloud" : "Jatka Nextcloudiin",
+    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua.","Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua."],
+    "Searching other places" : "Etsitään muista paikoista",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
+    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
+    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
+    "An internal error occurred." : "Tapahtui sisäinen virhe.",
+    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
+    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
+    "Username or\temail" : "Käyttäjätunnus tai\tsähköposti",
+    "Password" : "Salasana",
+    "Log in" : "Kirjaudu sisään",
+    "Logging in …" : "Kirjaudutaan sisään...",
+    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
+    "User disabled" : "Käyttäjä poistettu käytöstä",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
+    "Reset password" : "Palauta salasana",
+    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
+    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
+    "Back to login" : "Palaa kirjautumiseen",
+    "New password" : "Uusi salasana",
+    "I know what I'm doing" : "Tiedän mitä teen",
+    "Forgot password?" : "Unohditko salasanasi?",
+    "Settings" : "Asetukset",
+    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
+    "Search contacts …" : "Etsi yhteystietoja…",
+    "No contacts found" : "Yhteystietoja ei löytynyt",
+    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
+    "Install the Contacts app" : "Asenna Yhteystiedot-sovellus",
+    "Loading your contacts …" : "Ladataan yhteystietojasi…",
+    "Looking for {term} …" : "Etsii {term} …",
+    "No" : "Ei",
+    "Yes" : "Kyllä",
+    "No files in here" : "Täällä ei ole tiedostoja",
+    "New folder" : "Uusi kansio",
+    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
+    "Name" : "Nimi",
+    "Size" : "Koko",
+    "Modified" : "Muokattu",
+    "{newName} already exists" : "{newName} on jo olemassa",
+    "Choose" : "Valitse",
+    "Copy" : "Kopioi",
+    "Move" : "Siirrä",
+    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
+    "OK" : "OK",
+    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
+    "read-only" : "vain luku",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
+    "One file conflict" : "Yhden tiedoston ristiriita",
+    "New Files" : "Uudet tiedostot",
+    "Already existing files" : "Jo olemassa olevat tiedostot",
+    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
+    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
+    "Cancel" : "Peruuta",
+    "Continue" : "Jatka",
+    "(all selected)" : "(kaikki valittu)",
+    "({count} selected)" : "({count} valittu)",
+    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
+    "Pending" : "Odottaa",
+    "Copy to {folder}" : "Kopioi kansioon {folder}",
+    "Move to {folder}" : "Siirrä kansioon {folder}",
+    "Saving..." : "Tallennetaan...",
+    "Authentication required" : "Tunnistautuminen vaaditaan",
+    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
+    "Confirm" : "Vahvista",
+    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
+    "seconds ago" : "sekunteja sitten",
+    "Connection to server lost" : "Yhteys palvelimelle katkesi",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
+    "Add to a project" : "Lisää projektiin",
+    "Show details" : "Näytä tiedot",
+    "Hide details" : "Piilota tiedot",
+    "Rename project" : "Nimeä projekti uudelleen",
+    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
+    "Failed to create a project" : "Projektin luominen epäonnistui",
+    "Failed to add the item to the project" : "Kohteen lisääminen projektiin epäonnistui",
+    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
+    "New in" : "Uutta versiossa",
+    "View changelog" : "Katso muutosloki",
+    "No action available" : "Toimintoa ei saatavilla",
+    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
+    "Personal" : "Henkilökohtainen",
+    "Users" : "Käyttäjät",
+    "Apps" : "Sovellukset",
+    "Admin" : "Ylläpito",
+    "Help" : "Ohje",
+    "Access forbidden" : "Pääsy estetty",
+    "File not found" : "Tiedostoa ei löytynyt",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
+    "Error" : "Virhe",
+    "Internal Server Error" : "Sisäinen palvelinvirhe",
+    "The server was unable to complete your request." : "Palvelin ei kyennyt käsittelemään pyyntöäsi.",
+    "If this happens again, please send the technical details below to the server administrator." : "Jos tämä tapahtuu uudelleen, lähetä alla olevat tekniset tiedot palvelimen ylläpitäjälle.",
+    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
+    "Technical details" : "Tekniset tiedot",
+    "Remote Address: %s" : "Etäosoite: %s",
+    "Request ID: %s" : "Pyynnön tunniste: %s",
+    "Type: %s" : "Tyyppi: %s",
+    "Code: %s" : "Koodi: %s",
+    "Message: %s" : "Viesti: %s",
+    "File: %s" : "Tiedosto: %s",
+    "Line: %s" : "Rivi: %s",
+    "Trace" : "Jälki",
+    "Security warning" : "Turvallisuusvaroitus",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
+    "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
+    "Username" : "Käyttäjätunnus",
+    "Storage & database" : "Tallennus ja tietokanta",
+    "Data folder" : "Datakansio",
+    "Configure the database" : "Määritä tietokanta",
+    "Only %s is available." : "Vain %s on käytettävissä.",
+    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
+    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
+    "Database user" : "Tietokannan käyttäjä",
+    "Database password" : "Tietokannan salasana",
+    "Database name" : "Tietokannan nimi",
+    "Database tablespace" : "Tietokannan taulukkotila",
+    "Database host" : "Tietokantapalvelin",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
+    "Performance warning" : "Suorituskykyvaroitus",
+    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
+    "Finish setup" : "Viimeistele asennus",
+    "Finishing …" : "Viimeistellään…",
+    "Need help?" : "Tarvitsetko apua?",
+    "See the documentation" : "Tutustu ohjeisiin",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
+    "Get your own free account" : "Hanki ilmainen tili itsellesi",
+    "Skip to main content" : "Siirry pääsisältöön",
+    "More apps" : "Lisää sovelluksia",
+    "More" : "Lisää",
+    "Search" : "Etsi",
+    "Reset search" : "Tyhjennä haku",
+    "Contacts" : "Yhteystiedot",
+    "Contacts menu" : "Yhteystietovalikko",
+    "Settings menu" : "Asetusvalikko",
+    "Confirm your password" : "Vahvista salasanasi",
+    "Connect to your account" : "Yhdistä tiliisi",
+    "App token" : "Sovellusvaltuutus",
+    "Grant access" : "Myönnä pääsy",
+    "Alternative log in using app token" : "Vaihtoehtoinen kirjautuminen käyttäen sovelluspolettia",
+    "Account access" : "Tilin käyttö",
+    "Account connected" : "Tili yhdistetty",
+    "This share is password-protected" : "Jako on salasanasuojattu",
+    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
+    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
+    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
+    "Use backup code" : "Käytä varakoodia",
+    "Cancel log in" : "Peru kirjautuminen",
+    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
+    "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
+    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
+    "App update required" : "Sovelluksen päivittäminen vaaditaan",
+    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
+    "These apps will be updated:" : "Nämä sovellukset päivitetään:",
+    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
+    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
+    "Start update" : "Käynnistä päivitys",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
+    "Detailed logs" : "Yksityiskohtainen loki",
+    "Update needed" : "Päivitys vaaditaan",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Käytä komentorivipäivitintä, koska käyttäjiä on yli 50.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
+    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
+    "Maintenance mode" : "Huoltotila",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
+    "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusviestiä ei voitu lähettää sähköpostitse, koska käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
+    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
+    "Dismiss" : "Hylkää",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostiisi. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi ovat salattuja. Salasanan palauttamisen jälkeen niitä ei ole mahdollista palauttaa.<br />Jos et ole varma, mitä tehdä, ole yhteydessä ylläpitäjään ennen kuin jatkat.<br />Haluatko varmasti jatkaa?",
+    "Sending email …" : "Lähetetään sähköpostia ...",
+    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versiota {version} on asennettu. Vakauteen ja suorituskykyyn liittyvistä syistä suosittelemme, että {name} päivitetään uudempaan versioon.",
     "Shared" : "Jaettu",
     "Shared with" : "Jaettu",
     "Shared by" : "Jaettu",
@@ -91,14 +295,12 @@ OC.L10N.register(
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Copy" : "Kopioi",
     "Unable to create a link share" : "Linkkijaon tekeminen ei onnistunut",
     "Resharing is not allowed" : "Jakaminen uudelleen ei ole sallittu",
     "Link" : "Linkki",
     "Hide download" : "Piilota lataus",
     "Password protection enforced" : "Salasanasuojaus pakotettu",
     "Password protect" : "Suojaa salasanalla",
-    "Password" : "Salasana",
     "Allow editing" : "Salli muokkaus",
     "Email link to person" : "Lähetä linkki sähköpostitse",
     "Send" : "Lähetä",
@@ -150,203 +352,7 @@ OC.L10N.register(
     "Name or federated cloud ID..." : "Nimi tai federoidun pilven tunniste...",
     "Name, federated cloud ID or email address..." : "Nimi, federoidun pilven tunniste tai sähköpostiosoite...",
     "Name..." : "Nimi...",
-    "Error" : "Virhe",
     "Error removing share" : "Virhe jakoa poistaessa",
-    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
-    "restricted" : "rajoitettu",
-    "invisible" : "näkymätön",
-    "({scope})" : "({scope})",
-    "Delete" : "Poista",
-    "Rename" : "Nimeä uudelleen",
-    "Collaborative tags" : "Yhteistyölliset tunnisteet",
-    "No tags found" : "Tunnisteita ei löytynyt",
-    "unknown text" : "tuntematon teksti",
-    "Hello world!" : "Hei maailma!",
-    "sunny" : "aurinkoinen",
-    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
-    "Hello {name}" : "Hei {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
-    "new" : "uusi",
-    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
-    "Update to {version}" : "Päivitä versioon {version}",
-    "An error occurred." : "Tapahtui virhe.",
-    "Please reload the page." : "Päivitä sivu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
-    "Continue to Nextcloud" : "Jatka Nextcloudiin",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua.","Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua."],
-    "Searching other places" : "Etsitään muista paikoista",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
-    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
-    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
-    "An internal error occurred." : "Tapahtui sisäinen virhe.",
-    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
-    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
-    "Username or\temail" : "Käyttäjätunnus tai\tsähköposti",
-    "Log in" : "Kirjaudu sisään",
-    "Logging in …" : "Kirjaudutaan sisään...",
-    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
-    "User disabled" : "Käyttäjä poistettu käytöstä",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
-    "Reset password" : "Palauta salasana",
-    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Back to login" : "Palaa kirjautumiseen",
-    "New password" : "Uusi salasana",
-    "I know what I'm doing" : "Tiedän mitä teen",
-    "Forgot password?" : "Unohditko salasanasi?",
-    "Settings" : "Asetukset",
-    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
-    "Search contacts …" : "Etsi yhteystietoja…",
-    "No contacts found" : "Yhteystietoja ei löytynyt",
-    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
-    "Loading your contacts …" : "Ladataan yhteystietojasi…",
-    "Looking for {term} …" : "Etsii {term} …",
-    "No" : "Ei",
-    "Yes" : "Kyllä",
-    "No files in here" : "Täällä ei ole tiedostoja",
-    "New folder" : "Uusi kansio",
-    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
-    "Name" : "Nimi",
-    "Size" : "Koko",
-    "Modified" : "Muokattu",
-    "{newName} already exists" : "{newName} on jo olemassa",
-    "Choose" : "Valitse",
-    "Move" : "Siirrä",
-    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
-    "OK" : "OK",
-    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
-    "read-only" : "vain luku",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
-    "One file conflict" : "Yhden tiedoston ristiriita",
-    "New Files" : "Uudet tiedostot",
-    "Already existing files" : "Jo olemassa olevat tiedostot",
-    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
-    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
-    "Cancel" : "Peruuta",
-    "Continue" : "Jatka",
-    "(all selected)" : "(kaikki valittu)",
-    "({count} selected)" : "({count} valittu)",
-    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
-    "Pending" : "Odottaa",
-    "Copy to {folder}" : "Kopioi kansioon {folder}",
-    "Move to {folder}" : "Siirrä kansioon {folder}",
-    "Saving..." : "Tallennetaan...",
-    "Authentication required" : "Tunnistautuminen vaaditaan",
-    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
-    "Confirm" : "Vahvista",
-    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
-    "seconds ago" : "sekunteja sitten",
-    "Connection to server lost" : "Yhteys palvelimelle katkesi",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
-    "Add to a project" : "Lisää projektiin",
-    "Show details" : "Näytä tiedot",
-    "Hide details" : "Piilota tiedot",
-    "Rename project" : "Nimeä projekti uudelleen",
-    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
-    "Failed to create a project" : "Projektin luominen epäonnistui",
-    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
-    "New in" : "Uutta versiossa",
-    "View changelog" : "Katso muutosloki",
-    "No action available" : "Toimintoa ei saatavilla",
-    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
-    "Personal" : "Henkilökohtainen",
-    "Users" : "Käyttäjät",
-    "Apps" : "Sovellukset",
-    "Admin" : "Ylläpito",
-    "Help" : "Ohje",
-    "Access forbidden" : "Pääsy estetty",
-    "File not found" : "Tiedostoa ei löytynyt",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
-    "Internal Server Error" : "Sisäinen palvelinvirhe",
-    "The server was unable to complete your request." : "Palvelin ei kyennyt käsittelemään pyyntöäsi.",
-    "If this happens again, please send the technical details below to the server administrator." : "Jos tämä tapahtuu uudelleen, lähetä alla olevat tekniset tiedot palvelimen ylläpitäjälle.",
-    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
-    "Technical details" : "Tekniset tiedot",
-    "Remote Address: %s" : "Etäosoite: %s",
-    "Request ID: %s" : "Pyynnön tunniste: %s",
-    "Type: %s" : "Tyyppi: %s",
-    "Code: %s" : "Koodi: %s",
-    "Message: %s" : "Viesti: %s",
-    "File: %s" : "Tiedosto: %s",
-    "Line: %s" : "Rivi: %s",
-    "Trace" : "Jälki",
-    "Security warning" : "Turvallisuusvaroitus",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
-    "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
-    "Username" : "Käyttäjätunnus",
-    "Storage & database" : "Tallennus ja tietokanta",
-    "Data folder" : "Datakansio",
-    "Configure the database" : "Määritä tietokanta",
-    "Only %s is available." : "Vain %s on käytettävissä.",
-    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
-    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
-    "Database user" : "Tietokannan käyttäjä",
-    "Database password" : "Tietokannan salasana",
-    "Database name" : "Tietokannan nimi",
-    "Database tablespace" : "Tietokannan taulukkotila",
-    "Database host" : "Tietokantapalvelin",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
-    "Performance warning" : "Suorituskykyvaroitus",
-    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
-    "Finish setup" : "Viimeistele asennus",
-    "Finishing …" : "Viimeistellään…",
-    "Need help?" : "Tarvitsetko apua?",
-    "See the documentation" : "Tutustu ohjeisiin",
-    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
-    "Get your own free account" : "Hanki ilmainen tili itsellesi",
-    "Skip to main content" : "Siirry pääsisältöön",
-    "More apps" : "Lisää sovelluksia",
-    "Search" : "Etsi",
-    "Reset search" : "Tyhjennä haku",
-    "Contacts" : "Yhteystiedot",
-    "Contacts menu" : "Yhteystietovalikko",
-    "Settings menu" : "Asetusvalikko",
-    "Confirm your password" : "Vahvista salasanasi",
-    "Connect to your account" : "Yhdistä tiliisi",
-    "App token" : "Sovellusvaltuutus",
-    "Grant access" : "Myönnä pääsy",
-    "Account access" : "Tilin käyttö",
-    "Account connected" : "Tili yhdistetty",
-    "This share is password-protected" : "Jako on salasanasuojattu",
-    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
-    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
-    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
-    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
-    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
-    "Use backup code" : "Käytä varakoodia",
-    "Cancel log in" : "Peru kirjautuminen",
-    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
-    "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
-    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
-    "App update required" : "Sovelluksen päivittäminen vaaditaan",
-    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
-    "These apps will be updated:" : "Nämä sovellukset päivitetään:",
-    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
-    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
-    "Start update" : "Käynnistä päivitys",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
-    "Detailed logs" : "Yksityiskohtainen loki",
-    "Update needed" : "Päivitys vaaditaan",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Käytä komentorivipäivitintä, koska käyttäjiä on yli 50.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
-    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
-    "Maintenance mode" : "Huoltotila",
-    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
-    "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusviestiä ei voitu lähettää sähköpostitse, koska käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
-    "Dismiss" : "Hylkää",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostiisi. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi ovat salattuja. Salasanan palauttamisen jälkeen niitä ei ole mahdollista palauttaa.<br />Jos et ole varma, mitä tehdä, ole yhteydessä ylläpitäjään ennen kuin jatkat.<br />Haluatko varmasti jatkaa?",
-    "Sending email …" : "Lähetetään sähköpostia ...",
-    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versiota {version} on asennettu. Vakauteen ja suorituskykyyn liittyvistä syistä suosittelemme, että {name} päivitetään uudempaan versioon.",
     "SQLite will be used as database." : "SQLitea käytetään tietokantana.",
     "For larger installations we recommend to choose a different database backend." : "Suuria asennuksia varten suositellaan muun tietokannan käyttöä.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Varsinkin työpöytäsovelluksen tiedostosynkronointia käyttäessä SQLiten käyttö ei ole suositeltavaa.",
