@@ -95,85 +95,6 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. מדובר בפרצת אבטחה או פרטיות, מומלץ להתאים את ההגדרה הזאת בהתאם.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. יתכן שחלק מהתכונות לא תעבודנה כראוי, מומלץ להתאים את ההגדרה הזאת בהתאם.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "כותרת ה־HTTP בשם „Strict-Transport-Security” אינה מוגדרת עד לפחות „{seconds}” שניות. לטובת אבטחה מוגברת אנו ממליצים להפעיל HSTS כפי שמתואר ב<a href=\"{docUrl}\" rel=\"noreferrer noopener\">עצות האבטחה ↖️</a> שלנו.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "גישה בלתי מאובטחת לאתר עם HTTP. מומלץ בחום להגדיר את השרת שלך כדי לדרוש HTTPS במקום, כפי שמתואר ב<a href=\"{docUrl}\">עצות האבטחה ↖️</a>.",
-    "Shared" : "שותף",
-    "Shared with" : "משותף עם",
-    "Shared by" : "שותף על ידי",
-    "Choose a password for the public link" : "נא לבחור ססמה לקישור הציבורי",
-    "Choose a password for the public link or press the \"Enter\" key" : "יש לבחור ססמה עבור הקישור הציבורי או ללחוץ על המקש „Enter”",
-    "Copied!" : "מועתק!",
-    "Copy link" : "העתקת קישור",
-    "Not supported!" : "אין תמיכה!",
-    "Press ⌘-C to copy." : "יש להקיש ‎⌘-C כדי להעתיק.",
-    "Press Ctrl-C to copy." : "יש להקיש Ctrl-C כדי להעתיק.",
-    "Copy" : "העתקה",
-    "Unable to create a link share" : "לא ניתן ליצור קישור לשיתוף",
-    "Unable to toggle this option" : "לא ניתן להפעיל/לכבות אפשרות זו",
-    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
-    "Link" : "קישור",
-    "Hide download" : "הסתרת הורדה",
-    "Password protection enforced" : "נאכפת הגנה בססמה",
-    "Password protect" : "הגנה בססמה",
-    "Password" : "ססמה",
-    "Allow editing" : "אישור עריכה",
-    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
-    "Send" : "שליחה",
-    "Allow upload and editing" : "לאפשר העלאה ועריכה",
-    "Read only" : "קריאה בלבד",
-    "File drop (upload only)" : "השלכת קבצים (העלאה בלבד)",
-    "Expiration date enforced" : "נאכף מועד תפוגה",
-    "Set expiration date" : "הגדרת תאריך תפוגה",
-    "Expiration" : "תפוגה",
-    "Expiration date" : "תאריך התפוגה",
-    "Note to recipient" : "מסר לנמען",
-    "Unshare" : "הסר שיתוף",
-    "Delete share link" : "מחיקת קישור שיתוף",
-    "Add another link" : "הוספת קישור נוסף",
-    "Password protection for links is mandatory" : "חובה להשתמש בססמאות לקישורים",
-    "Share to {name}" : "שיתוף עם {name}",
-    "Share link" : "קישור לשיתוף",
-    "New share link" : "קישור שיתוף חדש",
-    "Created on {time}" : "נוצר ב־{time}",
-    "Password protect by Talk" : "הגנה בססמה על ידי Talk",
-    "Could not unshare" : "לא ניתן לבטל שיתוף",
-    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
-    "Shared with you and {circle} by {owner}" : "משותף אתך ועם {circle} על ידי {owner}",
-    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
-    "Choose a password for the mail share" : "נא לבחור ססמה עבור השיתוף בדוא״ל",
-    "group" : "קבוצה",
-    "remote" : "נשלט מרחוק",
-    "remote group" : "קבוצה מרוחקת",
-    "email" : "דוא״ל",
-    "conversation" : "דיון",
-    "shared by {sharer}" : "שותף ע״י {sharer}",
-    "Can reshare" : "ניתן לשתף מחדש",
-    "Can edit" : "ניתן לערוך",
-    "Can create" : "ניתן ליצור",
-    "Can change" : "ניתן לשנות",
-    "Can delete" : "ניתן למחוק",
-    "Access control" : "בקרת גישה",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} שותף דרך קישור",
-    "Error while sharing" : "שגיאה במהלך השיתוף",
-    "Share details could not be loaded for this item." : "לא ניתן היה לטעון מידע שיתוף לפריט זה",
-    "Search globally" : "חיפוש גלובלי",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["נדרש לפחות תו אחד להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית"],
-    "This list is maybe truncated - please refine your search term to see more results." : "יתכן שזו רשימה מקוצרת - נא למקד את ביטוי החיפוש שלך כדי להציג תוצאות נוספות.",
-    "No users or groups found for {search}" : "לא אותרו משתמשים או קבוצות עבור {search}",
-    "No users found for {search}" : "לא אותרו משתמשים עבור {search}",
-    "An error occurred (\"{message}\"). Please try again" : "אירעה שגיאה (\"{message}\"). נא לנסות שוב",
-    "An error occurred. Please try again" : "אירעה שגיאה. יש לנסות שנית",
-    "Home" : "בית",
-    "Work" : "עבודה",
-    "Other" : "אחר",
-    "{sharee} (remote group)" : "{sharee} (קבוצה מרוחקת)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "שתף",
-    "Name or email address..." : "שם או כתובת דוא״ל…",
-    "Name or federated cloud ID..." : "שם או מזהה ענן מאוגד…",
-    "Name, federated cloud ID or email address..." : "שם, מזהה ענן מאוגד או כתובת דוא״ל…",
-    "Name..." : "שם…",
-    "Error" : "שגיאה",
-    "Error removing share" : "שגיאה בזמן הסרת שיתוף",
     "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
     "restricted" : "מוגבל",
     "invisible" : "בלתי גלוי",
@@ -206,6 +127,7 @@ OC.L10N.register(
     "An internal error occurred." : "אירעה שגיאה פנימית.",
     "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
     "Username or email" : "שם משתמש או דואר אלקטרוני",
+    "Password" : "ססמה",
     "Log in" : "כניסה",
     "Logging in …" : "מתבצעת כניסה…",
     "Wrong username or password." : "שם המשתמש או הססמה שגויים.",
@@ -235,6 +157,7 @@ OC.L10N.register(
     "Modified" : "מועד שינוי",
     "{newName} already exists" : "{newName} כבר קיים",
     "Choose" : "בחירה",
+    "Copy" : "העתקה",
     "Move" : "העברה",
     "Error loading file picker template: {error}" : "שגיאה בטעינת תבנית בחירת הקבצים: {error}",
     "OK" : "אישור",
@@ -275,6 +198,7 @@ OC.L10N.register(
     "File not found" : "קובץ לא נמצא",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "לא ניתן למצוא את המסמך בשרת. יכול להיות שהשיתוף נמחק או פג?",
     "Back to %s" : "חזרה אל %s",
+    "Error" : "שגיאה",
     "Internal Server Error" : "שגיאה פנימית בשרת",
     "The server was unable to complete your request." : "השרת לא הצליח להשלים את הבקשה שלך.",
     "If this happens again, please send the technical details below to the server administrator." : "אם דבר כזה קורה שוב, נא לשלוח את הפרטים הטכניים שלהלן למנהל השרת.",
@@ -333,7 +257,6 @@ OC.L10N.register(
     "Account access" : "גישה לחשבון",
     "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך.",
     "Account connected" : "חשבון מחובר",
-    "Your client should now be connected! You can close this window." : "הלקוח שלך אמור להיות מחובר עכשיו! ניתן לסגור את החלון הזה.",
     "This share is password-protected" : "שיתוף זה מוגן בססמה",
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
     "Two-factor authentication" : "אימות דו־שלבי",
@@ -345,7 +268,6 @@ OC.L10N.register(
     "Use backup code" : "שימוש בקוד גיבוי",
     "Cancel log in" : "ביטול כניסה",
     "Setup two-factor authentication" : "הגדרת אימות דו־שלבי",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "אבטחה משופרת נאכפת על החשבון שלך. נא לבחור איזה ספק להגדיר:",
     "Error while validating your second factor" : "שגיאה בעת אימות הגורם השני",
     "Access through untrusted domain" : "גישה דרך שם מתחם בלתי מהימן",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "נא ליצור קשר עם מנהל השרת שלך. אם הרשאות ניהול השרת הן בידיך, יש לערוך את ההגדרה „trusted_domains” בתוך config/config.php כמו הדוגמה שבתוך ",
@@ -370,36 +292,93 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני כיוון שלא מוגדר דואר אלקטרוני למשתמש זה. יש ליצור קשר עם מנהל.",
     "Couldn't send reset email. Please make sure your username is correct." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לוודא ששם המשתמש נכון.",
-    "Updated \"%s\" to %s" : "מעדכן \"%s\" ל- %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">קיימות בעיות עם בדיקת תקינות קוד. למידע נוסף…</a>",
     "Dismiss" : "שחרור",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "הקישור לאיפוס הססמה שלך נשלח אליך בדוא״ל. אם לא קיבלת את הקישור תוך זמן סביר, מוטב לבדוק את תיבת דואר הזבל/ספאם שלך.<br>אם ההודעה אינה שם, יש לשאול את המנהל המקומי שלך .",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "הקבצים שלך מוצפנים. לא תהיה דרך לשחזר את הקבצים שלך בחזרה לאחר איפוס הססמה שלך.<br />אם השלכות מעשיך אינן ברורות לך לחלוטין מוטב ליצור קשר עם מנהל השרת בטרם המשך התהליך.<br />להמשיך בתהליך?",
     "Sending email …" : "דוא״ל נשלח …",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "ההתקנה של {name} היא בגרסה מתחת ל־{version}, מטעמי יציבות וביצועים מומלץ לעדכן לגרסה עדכנית יותר של {name}.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ל־PHP אין אפשרות לקרוא את /dev/urandom שזה מצב די מומלץ יחסית מטעמי אבטחה. ניתן למצוא מידע נוסף ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">תיעוד</a>.",
-    "Copy URL" : "העתקת כתובת",
-    "Enable" : "הפעלה",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} שותף על ידי קישור",
-    "{sharee} (group)" : "{sharee} (קבוצה)",
-    "{sharee} (remote)" : "{sharee} (מרוחק)",
-    "{sharee} (email)" : "{sharee} (דוא״ל)",
-    "{sharee} (conversation)" : "{sharee} (דיון)",
-    "The specified document has not been found on the server." : "המסמך המבוקש לא נמצא על השרת.",
-    "You can click here to return to %s." : "ניתן ללחוץ כאן לחזרה אל %s.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "גישה בלתי מאובטחת לאתר עם HTTP. מומלץ בחום להגדיר את השרת שלך כדי לדרוש HTTPS במקום, כפי שמתואר ב<a href=\"{docUrl}\">עצות האבטחה ↖️</a>.",
+    "Shared" : "שותף",
+    "Shared with" : "משותף עם",
+    "Shared by" : "שותף על ידי",
+    "Choose a password for the public link" : "נא לבחור ססמה לקישור הציבורי",
+    "Choose a password for the public link or press the \"Enter\" key" : "יש לבחור ססמה עבור הקישור הציבורי או ללחוץ על המקש „Enter”",
+    "Copied!" : "מועתק!",
+    "Copy link" : "העתקת קישור",
+    "Not supported!" : "אין תמיכה!",
+    "Press ⌘-C to copy." : "יש להקיש ‎⌘-C כדי להעתיק.",
+    "Press Ctrl-C to copy." : "יש להקיש Ctrl-C כדי להעתיק.",
+    "Unable to create a link share" : "לא ניתן ליצור קישור לשיתוף",
+    "Unable to toggle this option" : "לא ניתן להפעיל/לכבות אפשרות זו",
+    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
+    "Link" : "קישור",
+    "Hide download" : "הסתרת הורדה",
+    "Password protection enforced" : "נאכפת הגנה בססמה",
+    "Password protect" : "הגנה בססמה",
+    "Allow editing" : "אישור עריכה",
+    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
+    "Send" : "שליחה",
+    "Allow upload and editing" : "לאפשר העלאה ועריכה",
+    "Read only" : "קריאה בלבד",
+    "File drop (upload only)" : "השלכת קבצים (העלאה בלבד)",
+    "Expiration date enforced" : "נאכף מועד תפוגה",
+    "Set expiration date" : "הגדרת תאריך תפוגה",
+    "Expiration" : "תפוגה",
+    "Expiration date" : "תאריך התפוגה",
+    "Note to recipient" : "מסר לנמען",
+    "Unshare" : "הסר שיתוף",
+    "Delete share link" : "מחיקת קישור שיתוף",
+    "Add another link" : "הוספת קישור נוסף",
+    "Password protection for links is mandatory" : "חובה להשתמש בססמאות לקישורים",
+    "Share to {name}" : "שיתוף עם {name}",
+    "Share link" : "קישור לשיתוף",
+    "New share link" : "קישור שיתוף חדש",
+    "Created on {time}" : "נוצר ב־{time}",
+    "Password protect by Talk" : "הגנה בססמה על ידי Talk",
+    "Could not unshare" : "לא ניתן לבטל שיתוף",
+    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
+    "Shared with you and {circle} by {owner}" : "משותף אתך ועם {circle} על ידי {owner}",
+    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
+    "Choose a password for the mail share" : "נא לבחור ססמה עבור השיתוף בדוא״ל",
+    "group" : "קבוצה",
+    "remote" : "נשלט מרחוק",
+    "remote group" : "קבוצה מרוחקת",
+    "email" : "דוא״ל",
+    "conversation" : "דיון",
+    "shared by {sharer}" : "שותף ע״י {sharer}",
+    "Can reshare" : "ניתן לשתף מחדש",
+    "Can edit" : "ניתן לערוך",
+    "Can create" : "ניתן ליצור",
+    "Can change" : "ניתן לשנות",
+    "Can delete" : "ניתן למחוק",
+    "Access control" : "בקרת גישה",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} שותף דרך קישור",
+    "Error while sharing" : "שגיאה במהלך השיתוף",
+    "Share details could not be loaded for this item." : "לא ניתן היה לטעון מידע שיתוף לפריט זה",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["נדרש לפחות תו אחד להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית","נדרשים לפחות {count} תווים להשלמה אוטומטית"],
+    "This list is maybe truncated - please refine your search term to see more results." : "יתכן שזו רשימה מקוצרת - נא למקד את ביטוי החיפוש שלך כדי להציג תוצאות נוספות.",
+    "No users or groups found for {search}" : "לא אותרו משתמשים או קבוצות עבור {search}",
+    "No users found for {search}" : "לא אותרו משתמשים עבור {search}",
+    "An error occurred (\"{message}\"). Please try again" : "אירעה שגיאה (\"{message}\"). נא לנסות שוב",
+    "An error occurred. Please try again" : "אירעה שגיאה. יש לנסות שנית",
+    "Home" : "בית",
+    "Work" : "עבודה",
+    "Other" : "אחר",
+    "{sharee} (remote group)" : "{sharee} (קבוצה מרוחקת)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "שתף",
+    "Name or email address..." : "שם או כתובת דוא״ל…",
+    "Name or federated cloud ID..." : "שם או מזהה ענן מאוגד…",
+    "Name, federated cloud ID or email address..." : "שם, מזהה ענן מאוגד או כתובת דוא״ל…",
+    "Name..." : "שם…",
+    "Error removing share" : "שגיאה בזמן הסרת שיתוף",
     "SQLite will be used as database." : "יעשה שימוש ב־SQLite כמסד נתונים.",
     "For larger installations we recommend to choose a different database backend." : "להתקנות נרחבות אנו ממליצים לבחור מסד נתונים אחר לצד השרת.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "במיוחד כאשר משתמשים במחשב שולחני לסנכרון קבצים השימוש ב SQLite אינו מומלץ.",
     "Wrong password." : "ססמה שגויה.",
-    "Please log in before granting %s access to your %s account." : "נא להיכנס בטרם מתן הרשאת %s לחשבון שלך ב־%s.",
-    "You are about to grant %s access to your %s account." : "פעולה זו תעניק הרשאת %s לחשבון שלך ב־%s.",
-    "Redirecting …" : "מתבצעת הפניה…",
     "New Password" : "ססמה חדשה",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "על החשבון שלך מופעלת אבטחה מוגברת. נא לאמת בעזרת גורם שני.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "ניתן למצוא מידע נוסף כיצד להגדיר ב%sתיעוד%s.",
-    "%s will be updated to version %s" : "%s יעודכן לגרסה %s",
-    "This page will refresh itself when the %s instance is available again." : "עמוד זה ירענן את עצמו כשהפעלת %s תהיה זמינה שוב.",
-    "Thank you for your patience." : "תודה על הסבלנות.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "שלחנו הודעת דוא״ל לאיפוס ססמה לכתובת הדוא״ל שאנו מכירים לחשבון זה. אם לא קיבלת את ההודעה תוך זמן סביר, מומלץ לחפש בתיקיות הספאם/זבל שלך.<br>אם היא לא שם כדאי לשאול את מנהל הרשת המקומית."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "שלחנו הודעת דוא״ל לאיפוס ססמה לכתובת הדוא״ל שאנו מכירים לחשבון זה. אם לא קיבלת את ההודעה תוך זמן סביר, מומלץ לחפש בתיקיות הספאם/זבל שלך.<br>אם היא לא שם כדאי לשאול את מנהל הרשת המקומית.",
+    "Search globally" : "חיפוש גלובלי",
+    "Your client should now be connected! You can close this window." : "הלקוח שלך אמור להיות מחובר עכשיו! ניתן לסגור את החלון הזה."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
