@@ -44,43 +44,6 @@ OC.L10N.register(
     "Good password" : "Kata sandi baik",
     "Strong password" : "Kata sandi kuat",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
-    "Shared" : "Dibagikan",
-    "Choose a password for the public link" : "Tetapkan kata sandi untuk tautan publik",
-    "Copied!" : "Tersalin!",
-    "Not supported!" : "Tidak didukung!",
-    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
-    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
-    "Copy" : "Salin",
-    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
-    "Link" : "Tautan",
-    "Password protect" : "Lindungi dengan kata sandi",
-    "Password" : "Kata Sandi",
-    "Allow editing" : "Izinkan penyuntingan",
-    "Email link to person" : "Emailkan tautan ini ke orang",
-    "Send" : "Kirim",
-    "Allow upload and editing" : "Izinkan pengunggahan dan penyuntingan",
-    "File drop (upload only)" : "Berkas jatuh (hanya unggah)",
-    "Set expiration date" : "Atur tanggal kedaluwarsa",
-    "Expiration" : "Kedaluwarsa",
-    "Expiration date" : "Tanggal kedaluwarsa",
-    "Unshare" : "Batalkan berbagi",
-    "Share link" : "Bagikan tautan",
-    "Could not unshare" : "Tidak dapat membatalkan pembagian",
-    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
-    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
-    "group" : "grup",
-    "remote" : "remote",
-    "email" : "surel",
-    "Error while sharing" : "Kesalahan saat membagikan",
-    "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Sekurangnya {count} karakter dibutuhkan untuk autocompletion"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Daftar ini mungkin terpotong - harap sari kata pencarian anda untuk melihat hasil yang lebih.",
-    "No users or groups found for {search}" : "Tidak ada pengguna atau grup ditemukan untuk {search}",
-    "No users found for {search}" : "Tidak ada pengguna ditemukan untuk {search}",
-    "An error occurred. Please try again" : "Terjadi kesalahan. Silakan coba lagi",
-    "Share" : "Bagikan",
-    "Error" : "Kesalahan",
-    "Error removing share" : "Terjadi kesalahan saat menghapus pembagian",
     "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
     "restricted" : "terbatas",
     "invisible" : "tersembunyi",
@@ -110,6 +73,7 @@ OC.L10N.register(
     "An internal error occurred." : "Terjadi kesalahan internal.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
     "Username or email" : "Nama pengguna atau email",
+    "Password" : "Kata Sandi",
     "Log in" : "Masuk",
     "Logging in …" : "Log masuk...",
     "Reset password" : "Setel ulang kata sandi",
@@ -122,6 +86,7 @@ OC.L10N.register(
     "Yes" : "Ya",
     "No files in here" : "Tidak ada berkas disini",
     "Choose" : "Pilih",
+    "Copy" : "Salin",
     "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
     "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
     "read-only" : "hanya-baca",
@@ -152,6 +117,7 @@ OC.L10N.register(
     "Help" : "Bantuan",
     "Access forbidden" : "Akses ditolak",
     "File not found" : "Berkas tidak ditemukan",
+    "Error" : "Kesalahan",
     "Internal Server Error" : "Kesalahan Server Internal",
     "More details can be found in the server log." : "Rincian lebih lengkap dapat ditemukan di log server.",
     "Technical details" : "Rincian teknis",
@@ -204,25 +170,47 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Tidak dapat mengirim email karena tidak ada alamat email untuk nama pengguna ini. Silahkan hubungi administrator Anda.",
     "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
-    "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Ada permasalahan dengan pengecekan integrasi kode. Informasi selanjutnya…</a>",
     "Dismiss" : "Buang",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Sebuah tautan untuk setel ulang kata sandi Anda telah dikirim ke email Anda. Jika Anda tidak menerima dalam jangka waktu yang wajar, periksa folder spam/sampah Anda.<br>Jika tidak ada, tanyakan pada administrator Anda.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Berkas anda terenkripsi. Tidak ada jalan untuk mendapatkan kembali data anda setelah kata sandi disetel ulang.<br />Jika anda tidak yakin, harap hubungi administrator anda sebelum melanjutkannya. <br />Apa anda ingin melanjutkannya?",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} dibagikan lewat tautan",
-    "{sharee} (group)" : "{sharee} (grup)",
-    "{sharee} (remote)" : "{sharee} (remote)",
-    "{sharee} (email)" : "{sharee} (surel)",
-    "The specified document has not been found on the server." : "Dokumen yang diminta tidak tersedia pada server.",
-    "You can click here to return to %s." : "Anda dapat klik disini unutk kembali ke %s.",
+    "Shared" : "Dibagikan",
+    "Choose a password for the public link" : "Tetapkan kata sandi untuk tautan publik",
+    "Copied!" : "Tersalin!",
+    "Not supported!" : "Tidak didukung!",
+    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
+    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
+    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
+    "Link" : "Tautan",
+    "Password protect" : "Lindungi dengan kata sandi",
+    "Allow editing" : "Izinkan penyuntingan",
+    "Email link to person" : "Emailkan tautan ini ke orang",
+    "Send" : "Kirim",
+    "Allow upload and editing" : "Izinkan pengunggahan dan penyuntingan",
+    "File drop (upload only)" : "Berkas jatuh (hanya unggah)",
+    "Set expiration date" : "Atur tanggal kedaluwarsa",
+    "Expiration" : "Kedaluwarsa",
+    "Expiration date" : "Tanggal kedaluwarsa",
+    "Unshare" : "Batalkan berbagi",
+    "Share link" : "Bagikan tautan",
+    "Could not unshare" : "Tidak dapat membatalkan pembagian",
+    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
+    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
+    "group" : "grup",
+    "remote" : "remote",
+    "email" : "surel",
+    "Error while sharing" : "Kesalahan saat membagikan",
+    "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Sekurangnya {count} karakter dibutuhkan untuk autocompletion"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Daftar ini mungkin terpotong - harap sari kata pencarian anda untuk melihat hasil yang lebih.",
+    "No users or groups found for {search}" : "Tidak ada pengguna atau grup ditemukan untuk {search}",
+    "No users found for {search}" : "Tidak ada pengguna ditemukan untuk {search}",
+    "An error occurred. Please try again" : "Terjadi kesalahan. Silakan coba lagi",
+    "Share" : "Bagikan",
+    "Error removing share" : "Terjadi kesalahan saat menghapus pembagian",
     "SQLite will be used as database." : "SQLite akan digunakan sebagai basis data.",
     "For larger installations we recommend to choose a different database backend." : "Untuk instalasi yang lebih besar, kami menyarankan untuk memilih backend basis data yang berbeda.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Terutama saat menggunakan klien desktop untuk sinkronisasi berkas, penggunaan SQLite tidak disarankan.",
     "Wrong password." : "Sandi salah.",
-    "New Password" : "Kata sandi Baru",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Keamanan tambahan diaktifkan untuk akun anda. Harap otentikasi menggunakan faktor kedua.",
-    "%s will be updated to version %s" : "%s akan diperbaarui ke versi %s",
-    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali.",
-    "Thank you for your patience." : "Terima kasih atas kesabaran anda."
+    "New Password" : "Kata sandi Baru"
 },
 "nplurals=1; plural=0;");
