@@ -100,87 +100,6 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\". Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C mælir með ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum ↗ </a>.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum okkar ↗</a>.",
-    "Shared" : "Deilt",
-    "Shared with" : "Deilt með",
-    "Shared by" : "Deilt af",
-    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
-    "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
-    "Copied!" : "Afritað!",
-    "Copy link" : "Afrita tengil",
-    "Not supported!" : "Óstutt!",
-    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
-    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
-    "Copy" : "Afrita",
-    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
-    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
-    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
-    "Link" : "Tengill",
-    "Hide download" : "Fela niðurhal",
-    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
-    "Password protect" : "Verja með lykilorði",
-    "Password" : "Lykilorð",
-    "Allow editing" : "Leyfa breytingar",
-    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
-    "Send" : "Senda",
-    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
-    "Read only" : "Skrifvarið",
-    "File drop (upload only)" : "Slepping skráa (einungis innsending)",
-    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
-    "Set expiration date" : "Setja gildistíma",
-    "Expiration" : "Rennur út",
-    "Expiration date" : "Gildir til",
-    "Note to recipient" : "Minnispunktur til viðtakanda",
-    "Unshare" : "Hætta deilingu",
-    "Delete share link" : "Eyða tengli á sameign",
-    "Add another link" : "Bæta við öðrum tengli",
-    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
-    "Share to {name}" : "Deila til {name}",
-    "Share link" : "Deila tengli",
-    "New share link" : "Nýr tengill á sameign",
-    "Created on {time}" : "Búið til {time}",
-    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
-    "Could not unshare" : "Gat ekki hætt deilingu",
-    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
-    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
-    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
-    "Shared with you by {owner}" : "Deilt með þér af {owner}",
-    "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
-    "group" : "hópur",
-    "remote" : "fjartengt",
-    "remote group" : "fjartengdur hópur",
-    "email" : "tölvupóstur",
-    "conversation" : "samtal",
-    "shared by {sharer}" : "deilt af {sharer}",
-    "Can reshare" : "Getur endurdeilt",
-    "Can edit" : "Getur breytt",
-    "Can create" : "Getur búið til",
-    "Can change" : "Getur skipt um",
-    "Can delete" : "Getur eytt",
-    "Access control" : "Aðgangsstýring",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
-    "Error while sharing" : "Villa við deilingu",
-    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
-    "Search globally" : "Leita allstaðar",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
-    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
-    "No users found for {search}" : "Engir notendur fundust með {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
-    "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
-    "Home" : "Heima",
-    "Work" : "Vinna",
-    "Other" : "Annað",
-    "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Deila",
-    "Name or email address..." : "Nafn eða tölvupóstfang...",
-    "Name or federated cloud ID..." : "Nafn eða skýjasambandsauðkenni (Federated Cloud ID)...",
-    "Name, federated cloud ID or email address..." : "Nafn, skýjasambandsauðkenni eða tölvupóstfang...",
-    "Name..." : "Nafn...",
-    "Error" : "Villa",
-    "Error removing share" : "Villa við að fjarlægja sameign",
     "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
     "restricted" : "takmarkaður aðgangur",
     "invisible" : "ósýnilegt",
@@ -214,6 +133,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Username or email" : "Notandanafn eða tölvupóstur",
     "Username or\temail" : "Notandanafn eða\ttölvupóstur",
+    "Password" : "Lykilorð",
     "Log in" : "Skrá inn",
     "Logging in …" : "Skrái inn …",
     "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
@@ -245,6 +165,7 @@ OC.L10N.register(
     "Modified" : "Breytt",
     "{newName} already exists" : "{newName} er þegar til",
     "Choose" : "Veldu",
+    "Copy" : "Afrita",
     "Move" : "Færa",
     "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
     "OK" : "Í lagi",
@@ -292,6 +213,7 @@ OC.L10N.register(
     "File not found" : "Skrá finnst ekki",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Skjalið fannst ekki á þjóninum. Hugsanlega hefur sameigninni verið eytt eða sé útrunnin?",
     "Back to %s" : "Til baka í %s",
+    "Error" : "Villa",
     "Internal Server Error" : "Innri villa",
     "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
     "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
@@ -351,7 +273,6 @@ OC.L10N.register(
     "Account access" : "Aðgangur að notandaaðgangi",
     "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
     "Account connected" : "Aðgangur er tengdur",
-    "Your client should now be connected! You can close this window." : "Biðlaraforritið þitt ætti núna að vera tengt! Þú mátt loka þessum glugga.",
     "This share is password-protected" : "Þessi sameign er varin með lykilorði",
     "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
     "Two-factor authentication" : "Tveggja-þrepa auðkenning",
@@ -364,7 +285,6 @@ OC.L10N.register(
     "Use backup code" : "Nota öryggisafritskóða",
     "Cancel log in" : "Hætta við innskráningu",
     "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu hvaða auðkenningarveitu eigi að nota til auðkenningar:",
     "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
     "Access through untrusted domain" : "Tenging frá ótreystu léni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
@@ -389,36 +309,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti því það er ekkert gilt tölvupóstfang fyrir þennan notanda. Hafðu samband við kerfisstjóra.",
     "Couldn't send reset email. Please make sure your username is correct." : "Gat ekki sent endurstillingu í tölvupósti. Gakktu úr skugga um að notandanafn þitt sé rétt.",
-    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
     "Dismiss" : "Hafna",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
     "Sending email …" : "Sendi tölvupóst ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} eldra en útgáfa {version} er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa {name} verði sett upp.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom er ekki lesanlegt af PHP sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
-    "Copy URL" : "Afrita slóð",
-    "Enable" : "Virkja",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} deildi með tengli",
-    "{sharee} (group)" : "{sharee} (hópur)",
-    "{sharee} (remote)" : "{sharee} (fjartengdur)",
-    "{sharee} (email)" : "{sharee} (tölvupóstur)",
-    "{sharee} (conversation)" : "{sharee} (samtal)",
-    "The specified document has not been found on the server." : "Tiltekið skjal hefur ekki fundist á þjóninum.",
-    "You can click here to return to %s." : "Þú getur smellt hér til að fara aftur á %s.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum okkar ↗</a>.",
+    "Shared" : "Deilt",
+    "Shared with" : "Deilt með",
+    "Shared by" : "Deilt af",
+    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
+    "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
+    "Copied!" : "Afritað!",
+    "Copy link" : "Afrita tengil",
+    "Not supported!" : "Óstutt!",
+    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
+    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
+    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
+    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
+    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
+    "Link" : "Tengill",
+    "Hide download" : "Fela niðurhal",
+    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
+    "Password protect" : "Verja með lykilorði",
+    "Allow editing" : "Leyfa breytingar",
+    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
+    "Send" : "Senda",
+    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
+    "Read only" : "Skrifvarið",
+    "File drop (upload only)" : "Slepping skráa (einungis innsending)",
+    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
+    "Set expiration date" : "Setja gildistíma",
+    "Expiration" : "Rennur út",
+    "Expiration date" : "Gildir til",
+    "Note to recipient" : "Minnispunktur til viðtakanda",
+    "Unshare" : "Hætta deilingu",
+    "Delete share link" : "Eyða tengli á sameign",
+    "Add another link" : "Bæta við öðrum tengli",
+    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
+    "Share to {name}" : "Deila til {name}",
+    "Share link" : "Deila tengli",
+    "New share link" : "Nýr tengill á sameign",
+    "Created on {time}" : "Búið til {time}",
+    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
+    "Could not unshare" : "Gat ekki hætt deilingu",
+    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
+    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
+    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
+    "Shared with you by {owner}" : "Deilt með þér af {owner}",
+    "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
+    "group" : "hópur",
+    "remote" : "fjartengt",
+    "remote group" : "fjartengdur hópur",
+    "email" : "tölvupóstur",
+    "conversation" : "samtal",
+    "shared by {sharer}" : "deilt af {sharer}",
+    "Can reshare" : "Getur endurdeilt",
+    "Can edit" : "Getur breytt",
+    "Can create" : "Getur búið til",
+    "Can change" : "Getur skipt um",
+    "Can delete" : "Getur eytt",
+    "Access control" : "Aðgangsstýring",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
+    "Error while sharing" : "Villa við deilingu",
+    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
+    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
+    "No users found for {search}" : "Engir notendur fundust með {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
+    "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
+    "Home" : "Heima",
+    "Work" : "Vinna",
+    "Other" : "Annað",
+    "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Deila",
+    "Name or email address..." : "Nafn eða tölvupóstfang...",
+    "Name or federated cloud ID..." : "Nafn eða skýjasambandsauðkenni (Federated Cloud ID)...",
+    "Name, federated cloud ID or email address..." : "Nafn, skýjasambandsauðkenni eða tölvupóstfang...",
+    "Name..." : "Nafn...",
+    "Error removing share" : "Villa við að fjarlægja sameign",
     "SQLite will be used as database." : "SQLite verður notað sem gagnagrunnur.",
     "For larger installations we recommend to choose a different database backend." : "Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sérstaklega þegar verið er að nota skjáborðsforritið til að samræma skrár, þá er ekki mælt með notkun SQLite.",
     "Wrong password." : "Rangt lykilorð.",
-    "Please log in before granting %s access to your %s account." : "Skráði þig inn áður en þú leyfir %s aðgang að %s notandaaðgangnum þínum.",
-    "You are about to grant %s access to your %s account." : "Þú ert að fara að leyfa %s aðgang að %s notandaaðgangnum þínum.",
-    "Redirecting …" : "Endurbeini ...",
     "New Password" : "Nýtt lykilorð",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Aukið öryggi var virkjað fyrir aðganginn þinn. Auðkenndu þig með aukaþrepi.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %shjálparskjölunum%s.",
-    "%s will be updated to version %s" : "%s verður uppfært í útgáfu %s.",
-    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
-    "Thank you for your patience." : "Þakka þér fyrir biðlundina.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
+    "Search globally" : "Leita allstaðar",
+    "Your client should now be connected! You can close this window." : "Biðlaraforritið þitt ætti núna að vera tengt! Þú mátt loka þessum glugga."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
