@@ -41,13 +41,13 @@ OC.L10N.register(
     "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
     "Updating database schema" : "データベースのスキーマを更新",
     "Updated database" : "データベース更新済み",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマーがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
     "Checked database schema update" : "指定データベースのスキーマを更新",
     "Checking updates of apps" : "アプリの更新をチェックしています。",
     "Checking for update of app \"%s\" in appstore" : "アプリストアで \"%s\" アプリのアップデートを確認しています",
     "Update app \"%s\" from appstore" : "アプリストアから \"%s\" アプリをアップデートする",
     "Checked for update of app \"%s\" in appstore" : "アプリストアで \"%s\" アプリのアップデートを確認済",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマー %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマ %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
     "Checked database schema update for apps" : "アプリの指定データベースのスキーマを更新",
     "Updated \"%1$s\" to %2$s" : "%1$sを%2$sに更新しました",
     "Set log level to debug" : "ログをデバッグレベルに設定",
@@ -107,87 +107,6 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーに \"{expected}\"が含まれていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "\"{header}\" HTTPヘッダーが \"{val1}\"、 \"{val2}\"、 \"{val3}\"、 \"{val4}\"、または \"{val5}\"に設定されていません。 これにより、参照元情報が漏れる可能性があります。 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C勧告↗</a>を参照してください。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTPヘッダが最低でも \"{seconds}\" 秒に設定されていません。セキュリティを強化するには、<a href=\"{docUrl}\" rel=\"noreferrer noopener\">セキュリティTips ↗</a>で解説しているHSTSを有効にすることを推奨します。",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "セキュアではないHTTP経由でアクセスしています。<a href=\"{docUrl}\">セキュリティTips ↗</a>で述べているように、代わりにHTTPSを必要とするようサーバーを設定することを強くおすすめします。",
-    "Shared" : "共有中",
-    "Shared with" : "と共有",
-    "Shared by" : "共有者",
-    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
-    "Choose a password for the public link or press the \"Enter\" key" : "公開リンクのパスワードを入力、または、\"エンター\"のみを叩く",
-    "Copied!" : "コピーしました！",
-    "Copy link" : "リンクをコピー",
-    "Not supported!" : "サポートされていません！",
-    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
-    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
-    "Copy" : "コピー",
-    "Unable to create a link share" : "リンク共有を作成できません",
-    "Unable to toggle this option" : "このオプションを切り替えることができません",
-    "Resharing is not allowed" : "再共有は許可されていません",
-    "Link" : "リンク",
-    "Hide download" : "ダウンロードを隠す",
-    "Password protection enforced" : "パスワード保護が強制される",
-    "Password protect" : "パスワード保護を有効化",
-    "Password" : "パスワード",
-    "Allow editing" : "編集を許可",
-    "Email link to person" : "電子メールリンク",
-    "Send" : "送信",
-    "Allow upload and editing" : "アップロードと編集を許可する",
-    "Read only" : "読み取り専用",
-    "File drop (upload only)" : "ファイルドロップ(アップロードのみ)",
-    "Expiration date enforced" : "有効期限が強制される",
-    "Set expiration date" : "有効期限を設定",
-    "Expiration" : "期限切れ",
-    "Expiration date" : "有効期限",
-    "Note to recipient" : "受取人への注意",
-    "Unshare" : "共有解除",
-    "Delete share link" : "共有リンクを削除",
-    "Add another link" : "別のリンクを追加",
-    "Password protection for links is mandatory" : "リンクのパスワード保護は必須です",
-    "Share to {name}" : "{name} に共有する",
-    "Share link" : "URLで共有",
-    "New share link" : "新しい共有リンク",
-    "Created on {time}" : "作成日：{time}",
-    "Password protect by Talk" : "トークによるパスワード保護",
-    "Could not unshare" : "共有の解除ができませんでした",
-    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
-    "Shared with you and {circle} by {owner}" : "{owner} が{circle}で共有中",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner}のスレッド{conversation}であなたと共有しました",
-    "Shared with you in a conversation by {owner}" : "{owner}のスレッドであなたと共有しました",
-    "Shared with you by {owner}" : "{owner} より共有中",
-    "Choose a password for the mail share" : "メール共有のパスワードを選択",
-    "group" : "グループ",
-    "remote" : "リモート",
-    "remote group" : "リモートグループ",
-    "email" : "メール",
-    "conversation" : "会話",
-    "shared by {sharer}" : "共有した人 {sharer}",
-    "Can reshare" : "再共有可能",
-    "Can edit" : "編集可能",
-    "Can create" : "作成可能",
-    "Can change" : "変更可能",
-    "Can delete" : "削除可能",
-    "Access control" : "アクセス制御",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} がリンク経由で共有",
-    "Error while sharing" : "共有でエラーが発生しました",
-    "Share details could not be loaded for this item." : "共有の詳細はこのアイテムによりロードできませんでした。",
-    "Search globally" : "グローバルに検索",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["オートコンプリートには{count}文字以上必要です"],
-    "This list is maybe truncated - please refine your search term to see more results." : "このリストは切り捨てられている可能性があります - 検索語句を絞り込んで検索結果を表示してください。",
-    "No users or groups found for {search}" : "{search} の検索でユーザー、グループが見つかりません",
-    "No users found for {search}" : "{search} のユーザーはいませんでした",
-    "An error occurred (\"{message}\"). Please try again" : "エラーが発生しました(\"{message}\")。 もう一度お試しください",
-    "An error occurred. Please try again" : "エラーが発生しました。もう一度実行してください。",
-    "Home" : "ホーム",
-    "Work" : "職場",
-    "Other" : "その他",
-    "{sharee} (remote group)" : "{sharee} (リモートグループ)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "共有",
-    "Name or email address..." : "名前またはメールアドレス",
-    "Name or federated cloud ID..." : "ユーザー名または、クラウド共有ID...",
-    "Name, federated cloud ID or email address..." : "ユーザー名、クラウド共有ID、またはメールアドレス",
-    "Name..." : "ユーザー名...",
-    "Error" : "エラー",
-    "Error removing share" : "共有の削除エラー",
     "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
     "restricted" : "制限済",
     "invisible" : "不可視",
@@ -221,6 +140,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "もう一度試してみるか、管理者に問い合わせてください。",
     "Username or email" : "ユーザー名またはメールアドレス",
     "Username or\temail" : "ユーザー名または\tメールアドレス",
+    "Password" : "パスワード",
     "Log in" : "ログイン",
     "Logging in …" : "ログイン中...",
     "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
@@ -255,6 +175,7 @@ OC.L10N.register(
     "Modified" : "更新日時",
     "{newName} already exists" : "{newName} はすでに存在します",
     "Choose" : "選択",
+    "Copy" : "コピー",
     "Move" : "移動",
     "Error loading file picker template: {error}" : "ファイル選択テンプレートの読み込みエラー: {error}",
     "OK" : "OK",
@@ -290,7 +211,7 @@ OC.L10N.register(
     "Failed to create a project" : "プロジェクトの作成に失敗",
     "Failed to add the item to the project" : "プロジェクトへのアイテムの追加に失敗",
     "Connect items to a project to make them easier to find" : "アイテムをプロジェクトに接続して見つけやすくする",
-    "Type to search for existing projects" : "既存のプロジェクトを検索するためのタイプ",
+    "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
     "New in" : "新機能",
     "View changelog" : "変更履歴を確認する",
     "No action available" : "操作できません",
@@ -304,6 +225,7 @@ OC.L10N.register(
     "File not found" : "ファイルが見つかりません",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ドキュメントはサーバー上に見つかりませんでした。 共有が削除されたか、期限が切れている可能性がありますか？",
     "Back to %s" : "%s に戻る",
+    "Error" : "エラー",
     "Internal Server Error" : "内部サーバーエラー",
     "The server was unable to complete your request." : "サーバーは要求を完了できませんでした。",
     "If this happens again, please send the technical details below to the server administrator." : "再びこのようなことが起こった場合は、以下の技術情報をサーバー管理者に送ってください。",
@@ -365,7 +287,6 @@ OC.L10N.register(
     "Account access" : "アカウントによるアクセス許可",
     "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
     "Account connected" : "アカウント接続済",
-    "Your client should now be connected! You can close this window." : "あなたのクライアントは接続されているはずです。 このウィンドウは閉じても構いません。",
     "This share is password-protected" : "この共有はパスワードで保護されています",
     "The password is wrong. Try again." : "パスワードが違います。再入力してください",
     "Two-factor authentication" : "二要素認証",
@@ -378,7 +299,6 @@ OC.L10N.register(
     "Use backup code" : "バックアップコードを使用する",
     "Cancel log in" : "ログインをキャンセルする",
     "Setup two-factor authentication" : "二要素認証を設定",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "セキュリティの強化があなたのアカウントに強制的に適用されました:",
     "Error while validating your second factor" : "第二要素の検証でエラーが発生しました",
     "Access through untrusted domain" : "信頼できないドメインを介したアクセス",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "管理者に連絡してください。 管理者の場合は、config.sample.phpを参照して config/config.phpの \"trusted_domains\" を設定してください。",
@@ -403,36 +323,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "このユーザー名に紐付けられたメールアドレスがないため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
-    "Updated \"%s\" to %s" : "\"%s\" を %s にアップデートしました。",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">コード整合性の確認で問題が発生しました。詳しくはこちら…</a>",
     "Dismiss" : "閉じる",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "パスワードをリセットするリンクをクリックしたので、メールを送信しました。しばらくたってもメールが届かなかった場合は、スパム/ジャンクフォルダーを確認してください。<br>それでも見つからなかった場合は、管理者に問合わせてください。",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ファイルが暗号化されています。パスワードをリセットした場合、データを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に問い合わせてください。<br />続けてよろしいでしょうか?",
     "Sending email …" : "メールを送信中 ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{version} よりも古いバージョンの {name} がインストールされています。安定した稼働とパフォーマンスの観点から、新しいバージョンの {name} にアップデートすることをお勧めします。",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom を PHP から読み取ることができません。この状態はセキュリティの観点からおすすめできません。より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>を参照ください。",
-    "Copy URL" : "URL をコピー",
-    "Enable" : "有効にする",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} がリンク経由で共有",
-    "{sharee} (group)" : "{sharee} (グループ)",
-    "{sharee} (remote)" : "{sharee} (リモート)",
-    "{sharee} (email)" : "{sharee} (メール)",
-    "{sharee} (conversation)" : "{sharee}（会話）",
-    "The specified document has not been found on the server." : "サーバーに指定されたファイルが見つかりませんでした。",
-    "You can click here to return to %s." : "ここをクリックすると、 %s に戻れます。",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "セキュアではないHTTP経由でアクセスしています。<a href=\"{docUrl}\">セキュリティTips ↗</a>で述べているように、代わりにHTTPSを必要とするようサーバーを設定することを強くおすすめします。",
+    "Shared" : "共有中",
+    "Shared with" : "と共有",
+    "Shared by" : "共有者",
+    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
+    "Choose a password for the public link or press the \"Enter\" key" : "公開リンクのパスワードを入力、または、\"エンター\"のみを叩く",
+    "Copied!" : "コピーしました！",
+    "Copy link" : "リンクをコピー",
+    "Not supported!" : "サポートされていません！",
+    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
+    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
+    "Unable to create a link share" : "リンク共有を作成できません",
+    "Unable to toggle this option" : "このオプションを切り替えることができません",
+    "Resharing is not allowed" : "再共有は許可されていません",
+    "Link" : "リンク",
+    "Hide download" : "ダウンロードを隠す",
+    "Password protection enforced" : "パスワード保護が強制される",
+    "Password protect" : "パスワード保護を有効化",
+    "Allow editing" : "編集を許可",
+    "Email link to person" : "電子メールリンク",
+    "Send" : "送信",
+    "Allow upload and editing" : "アップロードと編集を許可する",
+    "Read only" : "読み取り専用",
+    "File drop (upload only)" : "ファイルドロップ(アップロードのみ)",
+    "Expiration date enforced" : "有効期限が強制される",
+    "Set expiration date" : "有効期限を設定",
+    "Expiration" : "期限切れ",
+    "Expiration date" : "有効期限",
+    "Note to recipient" : "受取人への注意",
+    "Unshare" : "共有解除",
+    "Delete share link" : "共有リンクを削除",
+    "Add another link" : "別のリンクを追加",
+    "Password protection for links is mandatory" : "リンクのパスワード保護は必須です",
+    "Share to {name}" : "{name} に共有する",
+    "Share link" : "URLで共有",
+    "New share link" : "新しい共有リンク",
+    "Created on {time}" : "作成日：{time}",
+    "Password protect by Talk" : "トークによるパスワード保護",
+    "Could not unshare" : "共有の解除ができませんでした",
+    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
+    "Shared with you and {circle} by {owner}" : "{owner} が{circle}で共有中",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner}のスレッド{conversation}であなたと共有しました",
+    "Shared with you in a conversation by {owner}" : "{owner}のスレッドであなたと共有しました",
+    "Shared with you by {owner}" : "{owner} より共有中",
+    "Choose a password for the mail share" : "メール共有のパスワードを選択",
+    "group" : "グループ",
+    "remote" : "リモート",
+    "remote group" : "リモートグループ",
+    "email" : "メール",
+    "conversation" : "会話",
+    "shared by {sharer}" : "共有した人 {sharer}",
+    "Can reshare" : "再共有可能",
+    "Can edit" : "編集可能",
+    "Can create" : "作成可能",
+    "Can change" : "変更可能",
+    "Can delete" : "削除可能",
+    "Access control" : "アクセス制御",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} がリンク経由で共有",
+    "Error while sharing" : "共有でエラーが発生しました",
+    "Share details could not be loaded for this item." : "共有の詳細はこのアイテムによりロードできませんでした。",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["オートコンプリートには{count}文字以上必要です"],
+    "This list is maybe truncated - please refine your search term to see more results." : "このリストは切り捨てられている可能性があります - 検索語句を絞り込んで検索結果を表示してください。",
+    "No users or groups found for {search}" : "{search} の検索でユーザー、グループが見つかりません",
+    "No users found for {search}" : "{search} のユーザーはいませんでした",
+    "An error occurred (\"{message}\"). Please try again" : "エラーが発生しました(\"{message}\")。 もう一度お試しください",
+    "An error occurred. Please try again" : "エラーが発生しました。もう一度実行してください。",
+    "Home" : "ホーム",
+    "Work" : "職場",
+    "Other" : "その他",
+    "{sharee} (remote group)" : "{sharee} (リモートグループ)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "共有",
+    "Name or email address..." : "名前またはメールアドレス",
+    "Name or federated cloud ID..." : "ユーザー名または、クラウド共有ID...",
+    "Name, federated cloud ID or email address..." : "ユーザー名、クラウド共有ID、またはメールアドレス",
+    "Name..." : "ユーザー名...",
+    "Error removing share" : "共有の削除エラー",
     "SQLite will be used as database." : "SQLiteをデータベースとして使用しています。",
     "For larger installations we recommend to choose a different database backend." : "大規模な運用では別のデータベースを選択することをお勧めします。",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特にデスクトップクライアントをファイル同期に使用する場合，SQLiteは非推奨です.",
     "Wrong password." : "パスワードが間違っています。",
-    "Please log in before granting %s access to your %s account." : "あなたの %s アカウントに %s アクセスを許可する前にログインしてください。",
-    "You are about to grant %s access to your %s account." : "%s アカウントに あなたのアカウント %s へのアクセスを許可",
-    "Redirecting …" : "転送中...",
     "New Password" : "新しいパスワード",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "このアカウントは強化セキュリティが適用されています。二要素認証を行ってください。",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "これを構成する方法の詳細は、%sドキュメント%sにあります。",
-    "%s will be updated to version %s" : "%s は バーション %s にアップデートされます",
-    "This page will refresh itself when the %s instance is available again." : "この画面は、サーバー %s の再起動後に自動的に更新されます。",
-    "Thank you for your patience." : "しばらくお待ちください。",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "このアカウントのパスワードをリセットするEメールを、登録されているアドレスに送信しました。 あなたが妥当な時間内にそれを受け取れないならば、あなたのスパム/ジャンクフォルダーをチェックしてください。<br>そこにもない場合はサーバー管理者に確認して下さい。"
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "このアカウントのパスワードをリセットするためのメールを、登録されているアドレスに送信しました。 あなたが妥当な時間内にメールを受け取れない場合は、スパム/ジャンクフォルダーをチェックしてください。<br>そこにもない場合は、サーバー管理者に確認してください。",
+    "Search globally" : "グローバルに検索",
+    "Your client should now be connected! You can close this window." : "あなたのクライアントは接続されているはずです。 このウィンドウは閉じても構いません。"
 },
 "nplurals=1; plural=0;");
