@@ -68,61 +68,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "თქვენი data დირექტორია და ფაილები ალბათ წვდომადია ინტერნეტიდან. .htaccess ფაილი არ მუშაობს. მკაცრად რეკომენდირებულია ისე გაუწიოთ თქვენს ვებ-სერვერს კონფიგურაცია, რომ data დირექტორია აღარ იყოს წვდომადი, ან გაიტანოთ ის ვებ-სერვერის root დირექტორიიდან.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP დასათაურება \"{header}\" არაა კონფიგურირებული უტოლდებოდეს \"{expected}\"-ს. ეს პოტენციური უსაფრთხოების და კონფიდენციალურობის რისკია, რეკომენდირებულია ამ პარამეტრის გამოსწორება.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP დასათაურება \"{header}\" არაა კონფიგურირებული უტოლდებოდეს \"{expected}\"-ს. ზოგიერთმა ფუნქციამ შეიძლება არ იმუშაოს სწორად და რეკომენდირებულია ამ პარამეტრის რეგულაცია.",
-    "Shared" : "გაზიარებული",
-    "Shared with" : "გაზიარებულია",
-    "Shared by" : "გამზიარებელი",
-    "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
-    "Choose a password for the public link or press the \"Enter\" key" : "აირჩიეთ პაროლი საზოგადო ბმულისთვის ან დააჭირეთ \"Enter\"-ს",
-    "Copied!" : "კოპირებულია!",
-    "Not supported!" : "არაა მხარდაჭერილი!",
-    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
-    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
-    "Copy" : "კოპირება",
-    "Resharing is not allowed" : "ხელახალი გაზიარება არაა დაშვებული",
-    "Link" : "ბმული",
-    "Password protect" : "პაროლით დაცვა",
-    "Password" : "პაროლი",
-    "Allow editing" : "ცვლილების უფლების მინიჭება",
-    "Email link to person" : "ბმულის პიროვნების ელ-მისამართზე გაგზავნა",
-    "Send" : "გაგზავნა",
-    "Allow upload and editing" : "ატვირთვისა და ცვლილების უფლებების მინიჭება",
-    "Read only" : "მხოლოდ-კითხვადი",
-    "File drop (upload only)" : "ფაილის ჩაგდება (მხოლოდ ატვირთვა)",
-    "Set expiration date" : "მიუთითეთ ვადის გასვლის დრო",
-    "Expiration" : "ვადის გასვლა",
-    "Expiration date" : "ვადის გასვლის დრო",
-    "Unshare" : "გაზიარების შეწყვეტა",
-    "Share to {name}" : "გაუზიარეთ მომხმარებელს {name}",
-    "Share link" : "გააზიარეთ ბმული",
-    "Could not unshare" : "გაზიარების შეწყვეტა ვერ მოხერხდა",
-    "Shared with you and the group {group} by {owner}" : "თქვენ და {group} ჯგუფს გაგიზიარდათ მომხმარებლისგან {owner}",
-    "Shared with you by {owner}" : "თქვენთან გაზიარდა მომხმარებლისგან {owner}",
-    "Choose a password for the mail share" : "აირჩიეთ პაროლი ელ-ფოსტით გაზიარებისთვის",
-    "group" : "ჯგუფი",
-    "remote" : "დისტანციური",
-    "email" : "ელ-ფოსტა",
-    "shared by {sharer}" : "გააზიარა მომხმარებელმა {sharer}",
-    "Can reshare" : "შეუძლია ხელახალი გაზიარება",
-    "Can edit" : "შეუძლია შეცვლა",
-    "Can create" : "შეუძლია შექმნა",
-    "Can change" : "შეუძლია ცვლილება",
-    "Can delete" : "შეუძლია გაუქმება",
-    "Access control" : "დაშვების კონტროლი",
-    "Error while sharing" : "შეცდომა გაზიარების დროს",
-    "Share details could not be loaded for this item." : "ამ ობიექტისთვის გაზიარების დეტალები ვერ ჩაიტვირთა.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო","ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო"],
-    "This list is maybe truncated - please refine your search term to see more results." : "ეს სია შეიძლება იყოს წაკვეთილი - მეტი შედეგისთვის, გთხოვთ გაწმინდოთ თქვენი საძიებო სიტყვა.",
-    "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის არ იქნა ნაპოვნი",
-    "No users found for {search}" : "მომხმარებლები {search}-ისთვის არ იქნა ნაპოვნი",
-    "An error occurred. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "გაზიარება",
-    "Name or email address..." : "სახელი ან ელ-ფოსტის მისამართი...",
-    "Name or federated cloud ID..." : "სახელი ან ფედერალური ქლაუდ ID",
-    "Name, federated cloud ID or email address..." : "სახელი, ფედერალური ქლაუდ ID ან ელ-ფოსტის მისამართი",
-    "Name..." : "სახელი...",
-    "Error" : "შეცდომა",
-    "Error removing share" : "გაზიარების გაუქმებისას წარმოიშვა შეცდომა",
     "Non-existing tag #{tag}" : "ტეგი #{tag} არ არსებობს",
     "restricted" : "აკრძალული",
     "invisible" : "უჩინარი",
@@ -155,6 +100,7 @@ OC.L10N.register(
     "An internal error occurred." : "გამოჩნდა შიდა შეცდომა.",
     "Please try again or contact your administrator." : "გთხოვთ სცადოთ ახლიდან ან დაუკავშირდეთ თქვენს ადმინისტრატორს.",
     "Username or email" : "მომხმარებლის სახელი ან ელ-ფოსტა",
+    "Password" : "პაროლი",
     "Log in" : "შესვლა",
     "Logging in …" : "შესვლა ...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "თქვენი IP მისამართით შევნიშნეთ არაერთი წარუმატებელი ავტორიზაციის მცდელობა. აქედან გამომდინარე თქვენი შემდეგი ავტორიზაციის მცდელობა შეიზღუდება დაახლოებით 30 წამით.",
@@ -175,6 +121,7 @@ OC.L10N.register(
     "Yes" : "კი",
     "No files in here" : "აქ ფაილები არაა",
     "Choose" : "არჩევა",
+    "Copy" : "კოპირება",
     "Move" : "გადატანა",
     "Error loading file picker template: {error}" : "შეცდომა ფაილის შაბლონის ჩატვირთვისას: {error}",
     "OK" : "კარგი",
@@ -211,6 +158,7 @@ OC.L10N.register(
     "Help" : "დახმარება",
     "Access forbidden" : "წვდომა აკრძალულია",
     "File not found" : "ფაილი ვერ იქნა ნაპოვნი",
+    "Error" : "შეცდომა",
     "Internal Server Error" : "შიდა სერვერის შეცდომა",
     "The server was unable to complete your request." : "სერვერმა ვერ დაასრულა თქვენი მოთხოვნა.",
     "If this happens again, please send the technical details below to the server administrator." : "თუ ეს განმეორდება, გთხოვთ გაუგზავნოთ ქვემოთ აღწერილი ტექნიკური დეტალები თქვენი სერვერის ადმინისრატორს.",
@@ -277,29 +225,66 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "თუ ეს წერილი გამოჩნდა მოულოდნელად ან მისი გამოჩენა გრძელდება, დაუკავშირდით სისტემის ადმინისტრატორს.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "ამ მომხმარებლისთვის ელ-ფოსტის მისამართი არაა დაყენებული, შესაბამისად აღდგენის ელ-წერილი ვერ გაიგზავნა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
     "Couldn't send reset email. Please make sure your username is correct." : "აღდგენის ელ-წერილი ვერ გაიგზავნა. დარწმუნდით, რომ მომხმარებლის სახელი სწორია.",
-    "Updated \"%s\" to %s" : "\"%s\" განახლდა %s-ზე",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">კოდის მთლიანობის შემოწმებასთან წარმოიქმა შეცდომები. მეტი ინფორმაცია…</a>",
     "Dismiss" : "დათხოვნა",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ბმული პაროლის აღდგენით თქვენს ელ-ფოსტაზე გაგზავნილია. თუ გავიდა გარკვეული დრო და მაინც არ მოგსვლიათ, შეამოწმეთ სპამის დირექტორიაც.<br>თუ მაინც ვერ მიაგენით მიმართეთ ლოკალურ ადმინისტრატორს.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ფაილები კოდირებულია. პაროლის აღდგენის შემდეგ ვერანაირად ვერ დაიბრუნებთ მონაცემებს.<br />თუ არ ხართ დარწმუნებული რა გააკეთოთ, გაგრძელებამდე მიმართეთ თქვენს ადმინისტრატორს.<br />დარწმუნებული ხართ, რომ გსურთ გაგრძელება?",
     "Sending email …" : "წერილი იგზავნება ...",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom PHP-ს მიერ ვერ იკითხება, რაც უსაფრთოხების მიზნებიდან გამომდინარე უკიდურესად არა-რეკომენდირებულია. შეგიძლიათ მეტი ინფორმაცია მიიღოთ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციიდან</a>.",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} მომხმარებელმა გააზიარა ბმულით",
-    "{sharee} (group)" : "{sharee} (ჯგუფი)",
-    "{sharee} (remote)" : "{sharee} (დისტანციური)",
-    "{sharee} (email)" : "{sharee} (ელ-ფოსტა)",
-    "The specified document has not been found on the server." : "მითითებული დოკუმენტი სერვერზე ვერ იქნა ნაპოვნი.",
-    "You can click here to return to %s." : "%s-ზე დასაბრუნებლად შეგიძლიათ დააწკაპუნოთ აქ.",
+    "Shared" : "გაზიარებული",
+    "Shared with" : "გაზიარებულია",
+    "Shared by" : "გამზიარებელი",
+    "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
+    "Choose a password for the public link or press the \"Enter\" key" : "აირჩიეთ პაროლი საზოგადო ბმულისთვის ან დააჭირეთ \"Enter\"-ს",
+    "Copied!" : "კოპირებულია!",
+    "Not supported!" : "არაა მხარდაჭერილი!",
+    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
+    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
+    "Resharing is not allowed" : "ხელახალი გაზიარება არაა დაშვებული",
+    "Link" : "ბმული",
+    "Password protect" : "პაროლით დაცვა",
+    "Allow editing" : "ცვლილების უფლების მინიჭება",
+    "Email link to person" : "ბმულის პიროვნების ელ-მისამართზე გაგზავნა",
+    "Send" : "გაგზავნა",
+    "Allow upload and editing" : "ატვირთვისა და ცვლილების უფლებების მინიჭება",
+    "Read only" : "მხოლოდ-კითხვადი",
+    "File drop (upload only)" : "ფაილის ჩაგდება (მხოლოდ ატვირთვა)",
+    "Set expiration date" : "მიუთითეთ ვადის გასვლის დრო",
+    "Expiration" : "ვადის გასვლა",
+    "Expiration date" : "ვადის გასვლის დრო",
+    "Unshare" : "გაზიარების შეწყვეტა",
+    "Share to {name}" : "გაუზიარეთ მომხმარებელს {name}",
+    "Share link" : "გააზიარეთ ბმული",
+    "Could not unshare" : "გაზიარების შეწყვეტა ვერ მოხერხდა",
+    "Shared with you and the group {group} by {owner}" : "თქვენ და {group} ჯგუფს გაგიზიარდათ მომხმარებლისგან {owner}",
+    "Shared with you by {owner}" : "თქვენთან გაზიარდა მომხმარებლისგან {owner}",
+    "Choose a password for the mail share" : "აირჩიეთ პაროლი ელ-ფოსტით გაზიარებისთვის",
+    "group" : "ჯგუფი",
+    "remote" : "დისტანციური",
+    "email" : "ელ-ფოსტა",
+    "shared by {sharer}" : "გააზიარა მომხმარებელმა {sharer}",
+    "Can reshare" : "შეუძლია ხელახალი გაზიარება",
+    "Can edit" : "შეუძლია შეცვლა",
+    "Can create" : "შეუძლია შექმნა",
+    "Can change" : "შეუძლია ცვლილება",
+    "Can delete" : "შეუძლია გაუქმება",
+    "Access control" : "დაშვების კონტროლი",
+    "Error while sharing" : "შეცდომა გაზიარების დროს",
+    "Share details could not be loaded for this item." : "ამ ობიექტისთვის გაზიარების დეტალები ვერ ჩაიტვირთა.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო","ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო"],
+    "This list is maybe truncated - please refine your search term to see more results." : "ეს სია შეიძლება იყოს წაკვეთილი - მეტი შედეგისთვის, გთხოვთ გაწმინდოთ თქვენი საძიებო სიტყვა.",
+    "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის არ იქნა ნაპოვნი",
+    "No users found for {search}" : "მომხმარებლები {search}-ისთვის არ იქნა ნაპოვნი",
+    "An error occurred. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "გაზიარება",
+    "Name or email address..." : "სახელი ან ელ-ფოსტის მისამართი...",
+    "Name or federated cloud ID..." : "სახელი ან ფედერალური ქლაუდ ID",
+    "Name, federated cloud ID or email address..." : "სახელი, ფედერალური ქლაუდ ID ან ელ-ფოსტის მისამართი",
+    "Name..." : "სახელი...",
+    "Error removing share" : "გაზიარების გაუქმებისას წარმოიშვა შეცდომა",
     "SQLite will be used as database." : "მონაცემთა ბაზად მოხმარებულ იქნება SQLite.",
     "For larger installations we recommend to choose a different database backend." : "უფრო დიდი ინსტალაციებისთვის რეკომენდაციას გიწევთ აირჩიოთ სხვა მონაცემთა ბაზა.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite-ის გამოყენება არაა რეკომედირებული განსაკუთრებით მაშინ, როდესაც ფაილების სინქრონიზაციისთვის იყენებთ დესკტოპ-კლიენტს.",
     "Wrong password." : "არასწორი პაროლი.",
-    "You are about to grant %s access to your %s account." : "თქვენ აპირებთ წვდომის უფლებები მიანიჭოთ %s-ს თქვენს %s ანგარიშზე.",
-    "Redirecting …" : "გადამისამართება ...",
-    "New Password" : "ახლი პაროლი",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "თქვენს ანგარიშზე გაუმჯობესებული თავდაცვა ჩართულია. გთხოვთ გაიაროთ აუტენტიფიკაცია მეორე ფაქტორით.",
-    "%s will be updated to version %s" : "%s განახლდება ვერსიაზე %s",
-    "This page will refresh itself when the %s instance is available again." : "გვერდი ავტომატურად განახლდება, როდესაც %s ინსტანცია იქნება ხელმისაწვდომელი.",
-    "Thank you for your patience." : "მადლობთ მოთმინებისთვის."
+    "New Password" : "ახლი პაროლი"
 },
 "nplurals=2; plural=(n!=1);");
