@@ -25,6 +25,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "아래 단추를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "아래 링크를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
     "Reset your password" : "내 암호 재설정",
+    "Nextcloud Server" : "Nextcloud 서버",
     "Some of your link shares have been removed" : "일부 링크 공유가 삭제됨",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
     "Preparing update" : "업데이트 준비 중",
@@ -106,87 +107,6 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"을(를) 포함하고 있지 않습니다. 잠재적인 정보 유출 및 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "\"{header}\" HTTP 헤더가 \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" 또는 \"{val5}\"(으)로 설정되어 있지 않습니다. 추가 정보가 유출될 수 있습니다. 자세한 사항은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C 추천 ↗</a>을 참조하십시오.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP 헤더가 \"{seconds}\"초 이상으로 설정되어 있지 않습니다. <a href=\"{docUrl}\" rel=\"noreferrer noopener\">보안 팁</a>에서 제안하는 것처럼 HSTS를 활성화하는 것을 추천합니다.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "사이트에 HTTP를 통해서 보안 없이 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁↗</a>에서 제안하는 것처럼 HTTPS를 설정하는 것을 추천합니다.",
-    "Shared" : "공유됨",
-    "Shared with" : "다음 사용자와 공유함",
-    "Shared by" : "다음 사용자가 공유함",
-    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
-    "Choose a password for the public link or press the \"Enter\" key" : "공개 림크 암호를 입력하거나 \"Enter\" 키를 누르십시오",
-    "Copied!" : "복사 성공!",
-    "Copy link" : "링크 복사",
-    "Not supported!" : "지원하지 않음!",
-    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
-    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
-    "Copy" : "복사",
-    "Unable to create a link share" : "공유 링크를 만들 수 없습니다.",
-    "Unable to toggle this option" : "이 설정을 전환할 수 없음",
-    "Resharing is not allowed" : "다시 공유할 수 없음",
-    "Link" : "링크",
-    "Hide download" : "다운로드 숨기기",
-    "Password protection enforced" : "암호 보호 적용",
-    "Password protect" : "암호 보호",
-    "Password" : "암호",
-    "Allow editing" : "편집 허용",
-    "Email link to person" : "이메일 주소",
-    "Send" : "전송",
-    "Allow upload and editing" : "업로드 및 편집 허용",
-    "Read only" : "읽기 전용",
-    "File drop (upload only)" : "파일 보관소(업로드만 허용)",
-    "Expiration date enforced" : "만료 날짜 적용",
-    "Set expiration date" : "만료 날짜 설정",
-    "Expiration" : "만료",
-    "Expiration date" : "만료 날짜",
-    "Note to recipient" : "받는 사람 메모",
-    "Unshare" : "공유 해제",
-    "Delete share link" : "공유 링크 삭제",
-    "Add another link" : "다른 링크 추가",
-    "Password protection for links is mandatory" : "링크 암호 보호는 필수입니다",
-    "Share to {name}" : "{name} 님에게 공유",
-    "Share link" : "링크 공유",
-    "New share link" : "새 공유 링크",
-    "Created on {time}" : "{time}에 생성됨",
-    "Password protect by Talk" : "토크에서 암호로 보호됨",
-    "Could not unshare" : "공유 해제할 수 없음",
-    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유함",
-    "Shared with you and {circle} by {owner}" : "{owner} 님이 여러분과 {circle}와(과) 공유함",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 님이 여러분과 대화 {conversation}와(과) 공유함",
-    "Shared with you in a conversation by {owner}" : "{owner} 님이 대화에서 여러분과 공유함",
-    "Shared with you by {owner}" : "{owner} 님이 여러분과 공유함",
-    "Choose a password for the mail share" : "이메일 공유 암호 입력",
-    "group" : "그룹",
-    "remote" : "원격",
-    "remote group" : "원격 그룹",
-    "email" : "이메일",
-    "conversation" : "대화",
-    "shared by {sharer}" : "{sharer} 님이 공유함",
-    "Can reshare" : "재공유 가능",
-    "Can edit" : "편집 가능",
-    "Can create" : "생성 가능",
-    "Can change" : "변경 가능",
-    "Can delete" : "삭제 가능",
-    "Access control" : "접근 제어",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 님이 링크로 공유함",
-    "Error while sharing" : "공유하는 중 오류 발생",
-    "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
-    "Search globally" : "전역 검색",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["자동 완성을 시작하려면 최소 {count}글자를 입력해야 합니다"],
-    "This list is maybe truncated - please refine your search term to see more results." : "결과 목록이 잘렸을 수도 있습니다. 검색할 단어를 더 정확히 입력해서 더 많은 결과를 보십시오.",
-    "No users or groups found for {search}" : "{search} 사용자나 그룹을 찾을 수 없음",
-    "No users found for {search}" : "{search} 사용자를 찾을 수 없음",
-    "An error occurred (\"{message}\"). Please try again" : "오류가 발생했습니다(\"{message}\"). 다시 시도하십시오",
-    "An error occurred. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
-    "Home" : "홈",
-    "Work" : "작업",
-    "Other" : "기타",
-    "{sharee} (remote group)" : "{sharee}(원격 그룹)",
-    "{sharee} ({type}, {owner})" : "{sharee}({type}, {owner})",
-    "Share" : "공유",
-    "Name or email address..." : "이름이나 이메일 주소...",
-    "Name or federated cloud ID..." : "이름이나 연합 클라우드 ID...",
-    "Name, federated cloud ID or email address..." : "이름, 연합 클라우드 ID 및 이메일 주소...",
-    "Name..." : "이름...",
-    "Error" : "오류",
-    "Error removing share" : "공유 삭제 중 오류 발생",
     "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
     "restricted" : "제한됨",
     "invisible" : "보이지 않음",
@@ -219,6 +139,7 @@ OC.L10N.register(
     "An internal error occurred." : "내부 오류가 발생했습니다.",
     "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
     "Username or email" : "사용자 이름 또는 이메일",
+    "Password" : "암호",
     "Log in" : "로그인",
     "Logging in …" : "로그인 중 …",
     "Wrong username or password." : "사용자 이름이나 암호가 잘못되었습니다.",
@@ -248,6 +169,7 @@ OC.L10N.register(
     "Modified" : "수정한 날짜",
     "{newName} already exists" : "{newName}이(가) 이미 존재함",
     "Choose" : "선택",
+    "Copy" : "복사",
     "Move" : "이동",
     "Error loading file picker template: {error}" : "파일 선택 템플릿을 불러오는 중 오류 발생: {error}",
     "OK" : "확인",
@@ -288,6 +210,7 @@ OC.L10N.register(
     "File not found" : "파일을 찾을 수 없음",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
     "Back to %s" : "%s(으)로 돌아가기",
+    "Error" : "오류",
     "Internal Server Error" : "내부 서버 오류",
     "The server was unable to complete your request." : "서버에서 요청을 처리할 수 없습니다.",
     "If this happens again, please send the technical details below to the server administrator." : "만약 이 오류가 다시 발생하면 서버 관리자에게 다음 기술 정보를 알려 주십시오.",
@@ -349,7 +272,6 @@ OC.L10N.register(
     "Account access" : "계정 접근",
     "You are about to grant %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려고 합니다.",
     "Account connected" : "계정 연결됨",
-    "Your client should now be connected! You can close this window." : "클라이언트가 연동되었습니다! 이제 창을 닫으셔도 됩니다.",
     "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다.",
     "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
     "Two-factor authentication" : "2단계 인증",
@@ -362,7 +284,6 @@ OC.L10N.register(
     "Use backup code" : "백업 코드 사용",
     "Cancel log in" : "로그인 취소",
     "Setup two-factor authentication" : "2단계 인증 설정",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "현재 계정에 향상된 보안이 켜져 있습니다. 인증 공급자를 선택하십시오:",
     "Error while validating your second factor" : "2단계 인증을 검증하는 중 오류 발생",
     "Access through untrusted domain" : "신뢰하지 않는 도메인으로 접근",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 시스템 관리자라면 config/config.php의 \"trusted_domains\" 설정을 config.sample.php를 참조하여 편집하십시오.",
@@ -387,36 +308,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "이 사용자 이름과 연결된 이메일 주소가 없어서 초기화 메일을 보낼 수 없습니다. 시스템 관리자에게 연락하십시오.",
     "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
-    "Updated \"%s\" to %s" : "\"%s\"을(를) %s(으)로 업데이트함",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">코드 무결성 검사 중 오류가 발생했습니다. 더 많은 정보를 보려면 누르십시오…</a>",
     "Dismiss" : "닫기",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 포함하고 있는 이메일을 보냈습니다. 이메일이 도착하지 않은 경우 스팸함을 확인해 보십시오.<br>스팸함에도 없는 경우 로컬 관리자에게 문의하십시오.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 암호를 초기화하면 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 시스템 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
     "Sending email …" : "이메일 보내는 중…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name}의 버전 {version} 미만이 설치되어 있습니다. 안정성과 성능을 위해 {name}의 새로운 버전으로 업데이트하는 것을 권장합니다.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP에서 안전한 난수 발생기(/dev/urandom)를 사용할 수 없어 보안에 취약합니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
-    "Copy URL" : "URL 복사",
-    "Enable" : "활성화",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} 님이 링크를 통해 공유",
-    "{sharee} (group)" : "{sharee}(그룹)",
-    "{sharee} (remote)" : "{sharee}(원격)",
-    "{sharee} (email)" : "{sharee}(이메일)",
-    "{sharee} (conversation)" : "{sharee}(대화)",
-    "The specified document has not been found on the server." : "지정한 문서를 서버에서 찾을 수 없습니다.",
-    "You can click here to return to %s." : "%s(으)로 돌아가려면 여기를 누르십시오.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "사이트에 HTTP를 통해서 보안 없이 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁↗</a>에서 제안하는 것처럼 HTTPS를 설정하는 것을 추천합니다.",
+    "Shared" : "공유됨",
+    "Shared with" : "다음 사용자와 공유함",
+    "Shared by" : "다음 사용자가 공유함",
+    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
+    "Choose a password for the public link or press the \"Enter\" key" : "공개 림크 암호를 입력하거나 \"Enter\" 키를 누르십시오",
+    "Copied!" : "복사 성공!",
+    "Copy link" : "링크 복사",
+    "Not supported!" : "지원하지 않음!",
+    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
+    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
+    "Unable to create a link share" : "공유 링크를 만들 수 없습니다.",
+    "Unable to toggle this option" : "이 설정을 전환할 수 없음",
+    "Resharing is not allowed" : "다시 공유할 수 없음",
+    "Link" : "링크",
+    "Hide download" : "다운로드 숨기기",
+    "Password protection enforced" : "암호 보호 적용",
+    "Password protect" : "암호 보호",
+    "Allow editing" : "편집 허용",
+    "Email link to person" : "이메일 주소",
+    "Send" : "전송",
+    "Allow upload and editing" : "업로드 및 편집 허용",
+    "Read only" : "읽기 전용",
+    "File drop (upload only)" : "파일 보관소(업로드만 허용)",
+    "Expiration date enforced" : "만료 날짜 적용",
+    "Set expiration date" : "만료 날짜 설정",
+    "Expiration" : "만료",
+    "Expiration date" : "만료 날짜",
+    "Note to recipient" : "받는 사람 메모",
+    "Unshare" : "공유 해제",
+    "Delete share link" : "공유 링크 삭제",
+    "Add another link" : "다른 링크 추가",
+    "Password protection for links is mandatory" : "링크 암호 보호는 필수입니다",
+    "Share to {name}" : "{name} 님에게 공유",
+    "Share link" : "링크 공유",
+    "New share link" : "새 공유 링크",
+    "Created on {time}" : "{time}에 생성됨",
+    "Password protect by Talk" : "토크에서 암호로 보호됨",
+    "Could not unshare" : "공유 해제할 수 없음",
+    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유함",
+    "Shared with you and {circle} by {owner}" : "{owner} 님이 여러분과 {circle}와(과) 공유함",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 님이 여러분과 대화 {conversation}와(과) 공유함",
+    "Shared with you in a conversation by {owner}" : "{owner} 님이 대화에서 여러분과 공유함",
+    "Shared with you by {owner}" : "{owner} 님이 여러분과 공유함",
+    "Choose a password for the mail share" : "이메일 공유 암호 입력",
+    "group" : "그룹",
+    "remote" : "원격",
+    "remote group" : "원격 그룹",
+    "email" : "이메일",
+    "conversation" : "대화",
+    "shared by {sharer}" : "{sharer} 님이 공유함",
+    "Can reshare" : "재공유 가능",
+    "Can edit" : "편집 가능",
+    "Can create" : "생성 가능",
+    "Can change" : "변경 가능",
+    "Can delete" : "삭제 가능",
+    "Access control" : "접근 제어",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 님이 링크로 공유함",
+    "Error while sharing" : "공유하는 중 오류 발생",
+    "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["자동 완성을 시작하려면 최소 {count}글자를 입력해야 합니다"],
+    "This list is maybe truncated - please refine your search term to see more results." : "결과 목록이 잘렸을 수도 있습니다. 검색할 단어를 더 정확히 입력해서 더 많은 결과를 보십시오.",
+    "No users or groups found for {search}" : "{search} 사용자나 그룹을 찾을 수 없음",
+    "No users found for {search}" : "{search} 사용자를 찾을 수 없음",
+    "An error occurred (\"{message}\"). Please try again" : "오류가 발생했습니다(\"{message}\"). 다시 시도하십시오",
+    "An error occurred. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
+    "Home" : "홈",
+    "Work" : "작업",
+    "Other" : "기타",
+    "{sharee} (remote group)" : "{sharee}(원격 그룹)",
+    "{sharee} ({type}, {owner})" : "{sharee}({type}, {owner})",
+    "Share" : "공유",
+    "Name or email address..." : "이름이나 이메일 주소...",
+    "Name or federated cloud ID..." : "이름이나 연합 클라우드 ID...",
+    "Name, federated cloud ID or email address..." : "이름, 연합 클라우드 ID 및 이메일 주소...",
+    "Name..." : "이름...",
+    "Error removing share" : "공유 삭제 중 오류 발생",
     "SQLite will be used as database." : "데이터베이스로 SQLite를 사용할 것입니다.",
     "For larger installations we recommend to choose a different database backend." : "대규모 파일을 관리하려고 한다면 다른 데이터베이스 백엔드를 선택할 것을 권장합니다.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면 SQLite를 사용하지 않는 것이 좋습니다.",
     "Wrong password." : "암호가 잘못되었습니다.",
-    "Please log in before granting %s access to your %s account." : "%s에서 내 %s 계정에 접근하는 것을 허용하려면 로그인해야 합니다.",
-    "You are about to grant %s access to your %s account." : "\"%s\"에 접근하기 위해서 %s 계정을 사용하려고 합니다.",
-    "Redirecting …" : "전환 중 …",
     "New Password" : "새 암호",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "현재 계정에 향상된 보안이 켜져 있습니다. 2단계 인증으로 인증하십시오.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "설정하는 방법에 대한 정보는 %s문서%s에서 찾을 수 있습니다.",
-    "%s will be updated to version %s" : "%s 앱을 버전 %s(으)로 업데이트합니다",
-    "This page will refresh itself when the %s instance is available again." : "%s 인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
-    "Thank you for your patience." : "기다려 주셔서 감사합니다.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 이 계정에 연결된 이메일 주소로 보냈습니다. 일정 시간이 지난 후에도 이메일을 받지 못했다면 스팸 메일함을 확인해 보십시오.<br>스팸 메일함에도 링크가 없다면 시스템 관리자에게 문의하십시오."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 이 계정에 연결된 이메일 주소로 보냈습니다. 일정 시간이 지난 후에도 이메일을 받지 못했다면 스팸 메일함을 확인해 보십시오.<br>스팸 메일함에도 링크가 없다면 시스템 관리자에게 문의하십시오.",
+    "Search globally" : "전역 검색",
+    "Your client should now be connected! You can close this window." : "클라이언트가 연동되었습니다! 이제 창을 닫으셔도 됩니다."
 },
 "nplurals=1; plural=0;");
