@@ -61,92 +61,13 @@ OC.L10N.register(
     "Strong password" : "Stiprus slaptažodis",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Jūsų svetainės serveris nėra sukonfiguruotas atpažinti \"{url}\". Daugiau informacijos rasite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
     "Last background job execution ran {relativeTime}. Something seems wrong." : "Paskutinis foninis užduočių vykdymas buvo paleistas {relativeTime}. Atrodo, kad kažkas nutiko.",
     "Check the background job settings" : "Peržiūrėkite fone veikiančių užduočių nustatymus",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Kai kurie failai nepraėjo vientisumo patikrinimo. Tolimesnę informaciją apie tai, kaip išspręsti šią problemą, galima rasti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Neteisingų failų sąrašas…</a> / <a href=\"{rescanEndpoint}\">Peržiūrėti iš naujo…</a>)",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
     "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
     "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
-    "Shared" : "Bendrinama",
-    "Shared with" : "Bendrinama su",
-    "Shared by" : "Bendrina",
-    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
-    "Choose a password for the public link or press the \"Enter\" key" : "Įrašykite slaptažodį viešai nuorodai ir spustelėkite „Enter“ klavišą",
-    "Copied!" : "Nukopijuota!",
-    "Copy link" : "Kopijuoti nuorodą",
-    "Not supported!" : "Nepalaikoma!",
-    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Press Ctrl-C to copy." : "Norėdami nukopijuoti, paspauskite Ctrl-C.",
-    "Copy" : "Kopijuoti",
-    "Unable to create a link share" : "Nepavyko sukurti dalinimosi nuorodos",
-    "Unable to toggle this option" : "Nepavyko perjungti pasirinkimo",
-    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
-    "Link" : "Nuoroda",
-    "Hide download" : "Slėpti atsisiuntimo galimybę",
-    "Password protection enforced" : "Aktyvuota apsauga slaptažodžiu",
-    "Password protect" : "Apsaugotas slaptažodžiu",
-    "Password" : "Slaptažodis",
-    "Allow editing" : "Leisti redaguoti",
-    "Email link to person" : "Nusiųsti nuorodą paštu",
-    "Send" : "Siųsti",
-    "Allow upload and editing" : "Leisti įkėlimą ir redagavimą",
-    "Read only" : "Leidžiama tik skaityti",
-    "File drop (upload only)" : "Tempti rinkmeną čia (veikia tik įkeliant)",
-    "Expiration date enforced" : "Aktyvuotas galiojimo laikas",
-    "Set expiration date" : "Nustatykite veikimo pabaigos datą",
-    "Expiration" : "Veikimo pabaiga",
-    "Expiration date" : "Galiojimo pabaiga",
-    "Note to recipient" : "Pastaba gavėjui",
-    "Unshare" : "Nustoti bendrinti",
-    "Delete share link" : "Naikinti dalinimosi nuorodą",
-    "Add another link" : "Pridėti dar vieną nuorodą",
-    "Password protection for links is mandatory" : "Nuorodoms privaloma apsauga slaptažodžiu ",
-    "Share to {name}" : "Parodyti asmeniui vardu {name}",
-    "Share link" : "Siųsti nuorodą",
-    "New share link" : "Nauja dalinimosi nuoroda",
-    "Created on {time}" : "Sukurta {time}",
-    "Password protect by Talk" : "„Talk“ apsauga slaptažodžiu",
-    "Could not unshare" : "Nepavyko nustoti bendrinti",
-    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
-    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
-    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
-    "Choose a password for the mail share" : "Pasirinkite slaptažodį pasidalinimui per elektroninį paštą",
-    "group" : "grupė",
-    "remote" : "nuotolinis",
-    "remote group" : "nuotolinė grupė",
-    "email" : "elektroninis paštas",
-    "conversation" : "pokalbis",
-    "shared by {sharer}" : "pasidalino {sharer}",
-    "Can reshare" : "Gali pakartotinai dalintis",
-    "Can edit" : "Galima redaguoti",
-    "Can create" : "Galima kurti nauja",
-    "Can change" : "Galima keisti",
-    "Can delete" : "Galima trinti",
-    "Access control" : "Prieigos valdymas",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} pasidalino nuoroda",
-    "Error while sharing" : "Klaida bendrinant",
-    "Share details could not be loaded for this item." : "Dalinimosi detalės negali būti atskleistos šiai bylai",
-    "Search globally" : "Ieškoti visur",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Sąrašas galimai sutrumpintas - prašome patikslinti paiešką, norint matyti daugiau rezultatų.",
-    "No users or groups found for {search}" : "Nerasta vartotojų ar grupių pagal paieškos kriterijų: {search}",
-    "No users found for {search}" : "Nerasta vartotojų pagal paieškos kriterijų: {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
-    "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
-    "Home" : "Namų",
-    "Work" : "Darbo",
-    "Other" : "Kitas",
-    "{sharee} (remote group)" : "{sharee} (išorinė grupė) ",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Dalintis",
-    "Name or email address..." : "Vardas arba elektroninio pašto adresas...",
-    "Name or federated cloud ID..." : "Vardas ar federacinės debesijos ID...",
-    "Name, federated cloud ID or email address..." : "Vardas, federacinės debesijos ID arba el. pašto adresas...",
-    "Name..." : "Vardas...",
-    "Error" : "Klaida",
-    "Error removing share" : "Klaida šalinant viešinį",
     "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
     "restricted" : "apribota",
     "invisible" : "nematoma",
@@ -179,6 +100,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Username or email" : "Naudotojo vardas ar el. paštas",
     "Username or\temail" : "Naudotojo vardas ar\tel. paštas",
+    "Password" : "Slaptažodis",
     "Log in" : "Prisijungti",
     "Logging in …" : "Prisijungiama …",
     "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
@@ -208,6 +130,7 @@ OC.L10N.register(
     "Modified" : "Pakeista",
     "{newName} already exists" : "{newName} jau yra",
     "Choose" : "Pasirinkti",
+    "Copy" : "Kopijuoti",
     "Move" : "Perkelti",
     "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
     "OK" : "Gerai",
@@ -251,6 +174,7 @@ OC.L10N.register(
     "File not found" : "Failas nerastas",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko rasti dokumento serveryje. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
     "Back to %s" : "Atgal į %s",
+    "Error" : "Klaida",
     "Internal Server Error" : "Vidinė serverio klaida",
     "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
     "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųskite administratoriui žemiau esančią informaciją .",
@@ -308,7 +232,6 @@ OC.L10N.register(
     "Account access" : "Paskyros prieiga",
     "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
     "Account connected" : "Paskyra prijungta",
-    "Your client should now be connected! You can close this window." : "Klientas jau turi būti prijungtas! Langą galite užverti.",
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
     "Two-factor authentication" : "Dviejų žingsnių prisijungimas",
@@ -336,31 +259,91 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško dėl to, kad šiam naudotojo vardui nėra nustatytas joks el. pašto adresas. Susisiekite su savo administratoriumi.",
     "Couldn't send reset email. Please make sure your username is correct." : "Nepavyko išsiųsti atstatymo el. laiško. Prašome įsitikinti, kad jūsų naudotojo vardas yra teisingas.",
-    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Buvo problemų su kodo vientisumo patikrinimu. Daugiau informacijos…</a>",
     "Dismiss" : "Atmesti",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Slaptažodžio atkūrimo nuoroda buvo išsiųsta nurodytu elektroninio pašto adresu. Jei greitu laiku negausite laiško, patikrinkite \"šlamšto\" skyrių elektroniniame pašte. <br> Jei laiško vis tiek nerandate, susiekite su sistemos administratoriumi.",
     "Sending email …" : "Siunčiamas el. laiškas ...",
-    "Copy URL" : "Kopijuoti URL",
-    "Enable" : "Įjungti",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} pasidalino per nuorodą",
-    "{sharee} (group)" : "{sharee} (grupė)",
-    "{sharee} (remote)" : "{sharee} (nuotolinis)",
-    "{sharee} (email)" : "{sharee} (elektroninis paštas)",
-    "{sharee} (conversation)" : "{sharee} (pokalbis) ",
-    "The specified document has not been found on the server." : "Ieškotas dokumentas nerastas sistemoje.",
-    "You can click here to return to %s." : "Paspauskite čia norėdami grįžti į %s.",
+    "Shared" : "Bendrinama",
+    "Shared with" : "Bendrinama su",
+    "Shared by" : "Bendrina",
+    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
+    "Choose a password for the public link or press the \"Enter\" key" : "Įrašykite slaptažodį viešai nuorodai ir spustelėkite „Enter“ klavišą",
+    "Copied!" : "Nukopijuota!",
+    "Copy link" : "Kopijuoti nuorodą",
+    "Not supported!" : "Nepalaikoma!",
+    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
+    "Press Ctrl-C to copy." : "Norėdami nukopijuoti, paspauskite Ctrl-C.",
+    "Unable to create a link share" : "Nepavyko sukurti dalinimosi nuorodos",
+    "Unable to toggle this option" : "Nepavyko perjungti pasirinkimo",
+    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
+    "Link" : "Nuoroda",
+    "Hide download" : "Slėpti atsisiuntimo galimybę",
+    "Password protection enforced" : "Aktyvuota apsauga slaptažodžiu",
+    "Password protect" : "Apsaugotas slaptažodžiu",
+    "Allow editing" : "Leisti redaguoti",
+    "Email link to person" : "Nusiųsti nuorodą paštu",
+    "Send" : "Siųsti",
+    "Allow upload and editing" : "Leisti įkėlimą ir redagavimą",
+    "Read only" : "Leidžiama tik skaityti",
+    "File drop (upload only)" : "Tempti rinkmeną čia (veikia tik įkeliant)",
+    "Expiration date enforced" : "Aktyvuotas galiojimo laikas",
+    "Set expiration date" : "Nustatykite veikimo pabaigos datą",
+    "Expiration" : "Veikimo pabaiga",
+    "Expiration date" : "Galiojimo pabaiga",
+    "Note to recipient" : "Pastaba gavėjui",
+    "Unshare" : "Nustoti bendrinti",
+    "Delete share link" : "Naikinti dalinimosi nuorodą",
+    "Add another link" : "Pridėti dar vieną nuorodą",
+    "Password protection for links is mandatory" : "Nuorodoms privaloma apsauga slaptažodžiu ",
+    "Share to {name}" : "Parodyti asmeniui vardu {name}",
+    "Share link" : "Siųsti nuorodą",
+    "New share link" : "Nauja dalinimosi nuoroda",
+    "Created on {time}" : "Sukurta {time}",
+    "Password protect by Talk" : "„Talk“ apsauga slaptažodžiu",
+    "Could not unshare" : "Nepavyko nustoti bendrinti",
+    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
+    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
+    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
+    "Choose a password for the mail share" : "Pasirinkite slaptažodį pasidalinimui per elektroninį paštą",
+    "group" : "grupė",
+    "remote" : "nuotolinis",
+    "remote group" : "nuotolinė grupė",
+    "email" : "elektroninis paštas",
+    "conversation" : "pokalbis",
+    "shared by {sharer}" : "pasidalino {sharer}",
+    "Can reshare" : "Gali pakartotinai dalintis",
+    "Can edit" : "Galima redaguoti",
+    "Can create" : "Galima kurti nauja",
+    "Can change" : "Galima keisti",
+    "Can delete" : "Galima trinti",
+    "Access control" : "Prieigos valdymas",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} pasidalino nuoroda",
+    "Error while sharing" : "Klaida bendrinant",
+    "Share details could not be loaded for this item." : "Dalinimosi detalės negali būti atskleistos šiai bylai",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Sąrašas galimai sutrumpintas - prašome patikslinti paiešką, norint matyti daugiau rezultatų.",
+    "No users or groups found for {search}" : "Nerasta vartotojų ar grupių pagal paieškos kriterijų: {search}",
+    "No users found for {search}" : "Nerasta vartotojų pagal paieškos kriterijų: {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
+    "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
+    "Home" : "Namų",
+    "Work" : "Darbo",
+    "Other" : "Kitas",
+    "{sharee} (remote group)" : "{sharee} (išorinė grupė) ",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Dalintis",
+    "Name or email address..." : "Vardas arba elektroninio pašto adresas...",
+    "Name or federated cloud ID..." : "Vardas ar federacinės debesijos ID...",
+    "Name, federated cloud ID or email address..." : "Vardas, federacinės debesijos ID arba el. pašto adresas...",
+    "Name..." : "Vardas...",
+    "Error removing share" : "Klaida šalinant viešinį",
     "SQLite will be used as database." : "SQLite bus naudojama kaip duomenų bazė.",
     "For larger installations we recommend to choose a different database backend." : "Didesnei sistemai įdiegti rekomenduojame pasirinkti kitą duomenų bazę.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite naudojimas yra nerekomenduotinas, kai duomenų sinchronizacijai naudojamas darbalaukio klientas.",
     "Wrong password." : "Neteisingas slaptažodis.",
-    "You are about to grant %s access to your %s account." : "Jūs ketinate suteikti %s prieigą prie savo %s paskyros.",
-    "Redirecting …" : "Nukreipiama...",
     "New Password" : "Naujas slaptažodis",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Jūsų paskyros saugumas yra sustiprintas. Prašome prisijungti naudojant antrą prisijungimo variantą.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Tolimesnę informaciją apie tai, kaip tai konfigūruoti, galite rasti %sdokumentacijoje%s.",
-    "%s will be updated to version %s" : "%s bus atnaujintas iki %s versijos",
-    "This page will refresh itself when the %s instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai %s egzempliorius bus ir vėl prieinamas.",
-    "Thank you for your patience." : "Dėkojame už jūsų kantrumą."
+    "Search globally" : "Ieškoti visur",
+    "Your client should now be connected! You can close this window." : "Klientas jau turi būti prijungtas! Langą galite užverti."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
