@@ -15,6 +15,8 @@ OC.L10N.register(
     "No valid crop data provided" : "Nu există informație validă pentru operațiunea crop",
     "Crop is not square" : "Selecția nu este pătrată",
     "State token does not match" : "Statusul token-ului nu se potrivește",
+    "Could not complete login" : "Nu am putut efectua autentificarea",
+    "Your login token is invalid or has expired" : "Tokenul tău de autentificare este invalid sau a expirat",
     "Password reset is disabled" : "Resetarea parolei este dezactivată.",
     "Couldn't reset password because the token is invalid" : "Parola nu a putut fi resetată deoarece token-ul este invalid",
     "Couldn't reset password because the token is expired" : "Parola nu a putut fi resetată deoarece token-ul este expirat",
@@ -23,6 +25,8 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați butonul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați link-ul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Reset your password" : "Resetați-vă parola",
+    "Nextcloud Server" : "Nextcloud Server",
+    "Some of your link shares have been removed" : "Unele dintre link-urile tale partajate au fost șterse",
     "Preparing update" : "Se pregătește actualizarea",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Utilizează actualizarea din linie de comandă, pentru că actualizarea automată este dezactivată în config.php.",
@@ -40,6 +44,7 @@ OC.L10N.register(
     "Checked for update of app \"%s\" in appstore" : "S-a verificat dacă sunt actualizări pentru aplicația \"%s\" în magazinul de aplicații",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Se verifică dacă schema bazei de date pentru %s poate fi actualizată (poate dura un timp îndelungat, în funcție de dimensiunea bazei de date)",
     "Checked database schema update for apps" : "S-a verificat actualizarea schemei bazei de date pentru aplicații",
+    "Updated \"%1$s\" to %2$s" : "Actualizat \"%1$s\" la %2$s",
     "Set log level to debug" : "Setează nivelul de logare la \"debug\"",
     "Reset log level" : "Resetează nivelul de logare",
     "Starting code integrity check" : "Începe verificarea integrității codului",
@@ -52,60 +57,10 @@ OC.L10N.register(
     "So-so password" : "Parolă medie",
     "Good password" : "Parolă bună",
     "Strong password" : "Parolă puternică",
+    "Check the background job settings" : "Verificați setările jobului de fundal",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Lipsește indexul \"{indexName}\" in tabela \"{tableName}\".",
+    "The PHP memory limit is below the recommended value of 512MB." : "Limita memoriei PHP este sub valoarea recomandată de 512MB.",
     "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
-    "Shared" : "Partajat",
-    "Choose a password for the public link" : "Alege o parolă pentru acest link public",
-    "Choose a password for the public link or press the \"Enter\" key" : "Alege o parolă pentru link-ul public sau apasă \"Enter\"",
-    "Copied!" : "S-a copiat!",
-    "Not supported!" : "Nu este suportat!",
-    "Press ⌘-C to copy." : "Apasă ⌘-C pentru a copia.",
-    "Press Ctrl-C to copy." : "Apasă Ctrl+C pentru a copia.",
-    "Copy" : "Copiază",
-    "Resharing is not allowed" : "Repartajarea nu este permisă",
-    "Link" : "Legătură",
-    "Password protect" : "Protejare cu parolă",
-    "Password" : "Parolă",
-    "Allow editing" : "Permite editarea",
-    "Email link to person" : "Expediază legătura prin poșta electronică",
-    "Send" : "Trimite",
-    "Allow upload and editing" : "Permite încărcarea și editarea",
-    "Read only" : "Doar citire",
-    "File drop (upload only)" : "Aruncă fișierul (numai încărcare)",
-    "Set expiration date" : "Specifică data expirării",
-    "Expiration" : "Expira",
-    "Expiration date" : "Data expirării",
-    "Unshare" : "Anulare partajare",
-    "Share to {name}" : "Distribuie către {name}",
-    "Share link" : "Partajează link-ul",
-    "Could not unshare" : "Nu s-a putut elimina partajarea",
-    "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
-    "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
-    "Choose a password for the mail share" : "Alege o parolă pentru partajare prin email",
-    "group" : "grup",
-    "remote" : "de la distanță",
-    "email" : "email",
-    "shared by {sharer}" : "partajat de {sharer}",
-    "Can reshare" : "Poate repartaja",
-    "Can edit" : "Poate edita",
-    "Can create" : "Poate crea",
-    "Can change" : "Poate schimba",
-    "Can delete" : "Poate șterge",
-    "Access control" : "Control acces",
-    "Error while sharing" : "Eroare la partajare",
-    "Share details could not be loaded for this item." : "Nu s-au putut încărca detaliile de partajare pentru acest element.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Este necesar cel puțin un caracter pentru autocompletare","Sunt necesare cel puțin {count} caractere pentru autocompletare","Sunt necesare cel puțin {count} caractere pentru autocompletare"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Această listă este probabil trunchiată - te rugăm să revizuiești termenii de căutare pentru a obține mai multe rezultate.",
-    "No users or groups found for {search}" : "Nu au fost găsiți utilizatori sau grupuri pentru {search}",
-    "No users found for {search}" : "Nu au fost găsiți utilizatori pentru {search}",
-    "An error occurred. Please try again" : "A apărut o eroare. Încearcă din nou",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Partajează",
-    "Name or email address..." : "Nume sau adresă de email...",
-    "Name or federated cloud ID..." : "Nume sau ID de cloud federalizat...",
-    "Name, federated cloud ID or email address..." : "Nume, ID de cloud federalizat sau adresă de email...",
-    "Name..." : "Nume ...",
-    "Error" : "Eroare",
-    "Error removing share" : "Eroare la înlăturarea elementului partajat",
     "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
     "restricted" : "restricționat",
     "invisible" : "invizibil",
@@ -137,24 +92,39 @@ OC.L10N.register(
     "An internal error occurred." : "A apărut o eroare internă.",
     "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
     "Username or email" : "Nume de utilizator sau adresă email",
+    "Username or\temail" : "Utilizator sau\temail",
+    "Password" : "Parolă",
     "Log in" : "Autentificare",
     "Logging in …" : "Se autentifică...",
+    "Wrong username or password." : "Utilizator sau parolă greșite",
+    "User disabled" : "Utilizator dezactivat",
     "Reset password" : "Resetează parola",
     "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
     "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificată. Vă rugăm să contactați administratorul dvs.",
+    "Back to login" : "Înapoi la autentificare",
     "New password" : "Noua parolă",
-    "I know what I'm doing" : "Eu știu ce fac",
+    "I know what I'm doing" : "Știu ce fac",
+    "Resetting password" : "Resetez parola",
     "Forgot password?" : "Ai uitat parola?",
     "Settings" : "Setări",
-    "Search contacts …" : "Cauta contacte ...",
+    "Could not load your contacts" : "Nu pot încarca contactele",
+    "Search contacts …" : "Caută contacte ...",
     "No contacts found" : "Nu s-au găsit contacte",
-    "Show all contacts …" : "Arata toate contactele ...",
+    "Show all contacts …" : "Arată toate contactele ...",
+    "Install the Contacts app" : "Instalează aplicația Contacte",
     "Loading your contacts …" : "Se încarcă contactele ...",
     "Looking for {term} …" : "Se caută  {term} …",
     "No" : "Nu",
     "Yes" : "Da",
     "No files in here" : "Nu există fișiere aici",
+    "New folder" : "Director nou",
+    "No more subfolders in here" : "Nu mai sunt subdirectoare aici",
+    "Name" : "Nume",
+    "Size" : "Mărime",
+    "Modified" : "Modificat",
+    "{newName} already exists" : "{newName} există deja",
     "Choose" : "Alege",
+    "Copy" : "Copiază",
     "Move" : "Mută",
     "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
     "OK" : "OK",
@@ -182,6 +152,14 @@ OC.L10N.register(
     "seconds ago" : "secunde în urmă",
     "Connection to server lost" : "S-a pierdut conexiunea la server",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
+    "Add to a project" : "Adaugă la un proiect",
+    "Show details" : "Arată detaliile",
+    "Hide details" : "Ascunde detaliile",
+    "Rename project" : "Redenumește proiectul",
+    "Failed to rename the project" : "Redenumirea proiectului a eșuat",
+    "Failed to create a project" : "Creearea proiectului a eșuat",
+    "New in" : "Nou în",
+    "View changelog" : "Vezi changelog",
     "No action available" : "Nici o acțiune disponibilă",
     "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
     "Personal" : "Personal",
@@ -191,6 +169,9 @@ OC.L10N.register(
     "Help" : "Ajutor",
     "Access forbidden" : "Acces restricționat",
     "File not found" : "Fișierul nu a fost găsit",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Documentul nu poate fi găsit pe server.Poate partajarea a fost ștearsă sau a expirat?",
+    "Back to %s" : "Înapoi la %s",
+    "Error" : "Eroare",
     "Internal Server Error" : "Eroare internă a serverului",
     "The server was unable to complete your request." : "Serverul nu a reușit să proceseze cererea ta.",
     "If this happens again, please send the technical details below to the server administrator." : "Dacă se repetă, te rugăm trimite detaliile tehnice către administratorul de server.",
@@ -227,17 +208,33 @@ OC.L10N.register(
     "See the documentation" : "Vezi documentația",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Această aplicație necesită JavaScript pentru a funcționa corect. {linkstart}Activează JavaScript{linkend} și reîncarcă pagina.",
     "More apps" : "Mai multe aplicatii",
+    "More" : "Mai mult",
+    "More apps menu" : "Meniu mai multe aplicații",
     "Search" : "Căutare",
+    "Reset search" : "Resetează căutarea",
+    "Contacts" : "Contacte",
+    "Contacts menu" : "Meniu contacte",
+    "Settings menu" : "Meniul Setări",
     "Confirm your password" : "Confirmă parola:",
+    "Connect to your account" : "Conectează-te la contul tău",
     "App token" : "Token aplicație",
+    "Grant access" : "Permite accesul",
+    "Alternative log in using app token" : "Conectare alternativă folosind token-ul aplicației",
     "Account access" : "Acces cont",
+    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău.",
+    "Account connected" : "Cont conectat",
+    "This share is password-protected" : "Această partajare este protejată cu parolă",
+    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
     "Two-factor authentication" : "Autentificare în doi-factori",
+    "Set up two-factor authentication" : "Setează autentificarea cu doi factori",
     "Use backup code" : "Folosește un cod de backup",
     "Cancel log in" : "Anulează conectarea",
+    "Setup two-factor authentication" : "Setează autentificarea cu doi factori",
     "Error while validating your second factor" : "Eroare la validarea celui de-al doilea factor",
     "Access through untrusted domain" : "Acces printr-un domeniu nesigur",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vă rugăm contactați administratorul. Dacă sunteți administrator, editați setarea \"trusted_domains\" în config/config.php la fel ca în exemplul din config.sample.php",
     "App update required" : "E necesară o actualizare a aplicației",
+    "%1$s will be updated to version %2$s" : "%1$sva fi actualizat la versiunea %2$s",
     "These apps will be updated:" : "Aceste aplicații vor fi actualizate:",
     "These incompatible apps will be disabled:" : "Aceste aplicații incompatibile vor fi dezactivate:",
     "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
@@ -249,6 +246,7 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance with more than 50 users." : "Vă rugăm folosiți actualizarea din linia de comandă pentru că aveți o sesiune mare cu mai mult de 50 de utilizatori.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Înțeleg că dacă continui să folosesc actualizarea din interfața web, există riscul ca cererea să expire și să cauzeze pierderi de date, dar am un backup și știu cum sa restaurez sesiunea în caz de eșec.",
     "Upgrade via web on my own risk" : "Actualizare prin interfața web pe riscul meu",
+    "Maintenance mode" : "Mod mentenanță",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nu a putut fi trimis un email pentru resetare deoarece nu există o adresă de email pentru acest utilizator. Vă rugăm contactați administratorul.",
@@ -256,10 +254,88 @@ OC.L10N.register(
     "Dismiss" : "Înlătură",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkul de resetare a parolei a fost trimis pe emailul tău. Dacă nu primești mesajul într-un timp rezonabil, verifică folderele SPAM/JUNK.<br />Dacă nu este nici acolo, întreabă-l pe administratorul tău de rețea.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Fișierele tale sunt criptate. Nu îți vei putea recupera informațiile după resetarea parolei.<br />Dacă nu ești sigur ce să faci, contactează administratorul de rețea înainte de a continua. <br />Sigur vrei să continui?",
+    "Sending email …" : "Se trimite email ...",
+    "Shared" : "Partajat",
+    "Shared with" : "Partajat cu",
+    "Shared by" : "Partajat de",
+    "Choose a password for the public link" : "Alege o parolă pentru acest link public",
+    "Choose a password for the public link or press the \"Enter\" key" : "Alege o parolă pentru link-ul public sau apasă \"Enter\"",
+    "Copied!" : "S-a copiat!",
+    "Copy link" : "Copiză link",
+    "Not supported!" : "Nu este suportat!",
+    "Press ⌘-C to copy." : "Apasă ⌘-C pentru a copia.",
+    "Press Ctrl-C to copy." : "Apasă Ctrl+C pentru a copia.",
+    "Unable to create a link share" : "Nu s-a putut crea linkul de partajare",
+    "Unable to toggle this option" : "Nu se poate comuta această opțiune",
+    "Resharing is not allowed" : "Repartajarea nu este permisă",
+    "Link" : "Legătură",
+    "Hide download" : "Ascunde descărcarea",
+    "Password protection enforced" : "Protejare cu parolă impusă",
+    "Password protect" : "Protejare cu parolă",
+    "Allow editing" : "Permite editarea",
+    "Email link to person" : "Expediază legătura prin poșta electronică",
+    "Send" : "Trimite",
+    "Allow upload and editing" : "Permite încărcarea și editarea",
+    "Read only" : "Doar citire",
+    "File drop (upload only)" : "Aruncă fișierul (numai încărcare)",
+    "Expiration date enforced" : "Data expirării impusă",
+    "Set expiration date" : "Specifică data expirării",
+    "Expiration" : "Expiră",
+    "Expiration date" : "Data expirării",
+    "Note to recipient" : "Notă către destinatar",
+    "Unshare" : "Anulare partajare",
+    "Delete share link" : "Șterge linkul partajat",
+    "Add another link" : "Adaugă un alt link",
+    "Password protection for links is mandatory" : "Protecția cu parolă pentru linkuri este obligatorie",
+    "Share to {name}" : "Distribuie către {name}",
+    "Share link" : "Partajează link-ul",
+    "New share link" : "Nou link partajat",
+    "Created on {time}" : "Creat la {time}",
+    "Password protect by Talk" : "Protejat cu parolă de Talk",
+    "Could not unshare" : "Nu s-a putut elimina partajarea",
+    "Shared with you and the group {group} by {owner}" : "Partajat cu tine si cu grupul {group} de {owner}",
+    "Shared with you and {circle} by {owner}" : "Partajat cu tine și {circle} de {owner} ",
+    "Shared with you and the conversation {conversation} by {owner}" : "Partajat cu tine si conversația {conversation} de {owner}",
+    "Shared with you in a conversation by {owner}" : "Partajat cu tine în o conversație {owner}",
+    "Shared with you by {owner}" : "Partajat cu tine de {owner}",
+    "Choose a password for the mail share" : "Alege o parolă pentru partajare prin email",
+    "group" : "grup",
+    "remote" : "de la distanță",
+    "remote group" : "grup la distanță",
+    "email" : "email",
+    "conversation" : "conversație",
+    "shared by {sharer}" : "partajat de {sharer}",
+    "Can reshare" : "Poate repartaja",
+    "Can edit" : "Poate edita",
+    "Can create" : "Poate crea",
+    "Can change" : "Poate schimba",
+    "Can delete" : "Poate șterge",
+    "Access control" : "Control acces",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} partajat prin link",
+    "Error while sharing" : "Eroare la partajare",
+    "Share details could not be loaded for this item." : "Nu s-au putut încărca detaliile de partajare pentru acest element.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Este necesar cel puțin {count} caracter pentru autocompletare","Sunt necesare cel puțin {count} caractere pentru autocompletare","Sunt necesare cel puțin {count} caractere pentru autocompletare"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Această listă este probabil trunchiată - te rugăm să revizuiești termenii de căutare pentru a obține mai multe rezultate.",
+    "No users or groups found for {search}" : "Nu au fost găsiți utilizatori sau grupuri pentru {search}",
+    "No users found for {search}" : "Nu au fost găsiți utilizatori pentru {search}",
+    "An error occurred (\"{message}\"). Please try again" : "A apărut o eroare (\"{message}\"). Te rugăm să încerci din nou",
+    "An error occurred. Please try again" : "A apărut o eroare. Încearcă din nou",
+    "Home" : "Acasă",
+    "Work" : "Serviciu",
+    "Other" : "Altele",
+    "{sharee} (remote group)" : "{sharee} (remote group)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Partajează",
+    "Name or email address..." : "Nume sau adresă de email...",
+    "Name or federated cloud ID..." : "Nume sau ID de cloud federalizat...",
+    "Name, federated cloud ID or email address..." : "Nume, ID de cloud federalizat sau adresă de email...",
+    "Name..." : "Nume ...",
+    "Error removing share" : "Eroare la înlăturarea elementului partajat",
     "SQLite will be used as database." : "SQLite va fi folosit ca bază de date.",
     "For larger installations we recommend to choose a different database backend." : "Pentru instalări mai mari recomandăm folosirea altei baze de date ca backend.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
     "Wrong password." : "Parolă greșită.",
-    "New Password" : "Noua Parolă"
+    "New Password" : "Noua Parolă",
+    "Search globally" : "Caută global"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
