@@ -25,6 +25,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúce tlačidlo. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúci odkaz. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
     "Reset your password" : "Vytvoriť nové heslo",
+    "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Niektoré odkazy sprístupnenia boli odstránené.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre sprístupnenie. Pre viac informácií nasledujte tento link.",
     "Preparing update" : "Pripravuje sa aktualizácia",
@@ -106,87 +107,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" neobsahuje \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP hlavička \"{header}\" nie je nastavená na \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" alebo \"{val5}\". Môže to spôsobiť únik referer informácie. Pozrite si <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C odporúčania</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "Hlavička HTTP \"Strict-Transport-Security\" nie je nakonfigurovaná aspoň na \"{seconds}\" sekúnd. Pre zvýšenie bezpečnosti odporúčame povoliť HSTS tak, ako je to popísané v našich <a href=\"{docUrl}\" rel=\"noreferrer noopener\">bezpečnostných tipoch</a>.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Prístup na túto stránku sa uskutočňuje prostredníctvom nezabezpečeného protokolu HTTP. Dôrazne odporúčame, aby ste namiesto toho nakonfigurovali server tak, aby vyžadoval použitie HTTPS, ako je to popísané v našich <a href=\"{docUrl}\">bezpečnostných tipoch</a>.",
-    "Shared" : "Sprístupnené",
-    "Shared with" : "Sprístupnené používateľovi",
-    "Shared by" : "Sprístupnené používateľom",
-    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
-    "Choose a password for the public link or press the \"Enter\" key" : "Zvoľte heslo pre verejný link alebo stlačte klávesu \"Enter\"",
-    "Copied!" : "Skopírované!",
-    "Copy link" : "Kopíruj odkaz",
-    "Not supported!" : "Nie je podporované!",
-    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
-    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
-    "Copy" : "Kopírovať",
-    "Unable to create a link share" : "Nie je možné vytvoriť odkaz pre sprístupnenie",
-    "Unable to toggle this option" : "Túto voľbu nie je možné prepnúť",
-    "Resharing is not allowed" : "Sprístupnenie už sprístupnenej položky nie je povolené",
-    "Link" : "Odkaz",
-    "Hide download" : "Skryť sťahovanie",
-    "Password protection enforced" : "Vynútená ochrana heslom",
-    "Password protect" : "Chrániť heslom",
-    "Password" : "Heslo",
-    "Allow editing" : "Povoliť úpravy",
-    "Email link to person" : "Odoslať odkaz emailom",
-    "Send" : "Odoslať",
-    "Allow upload and editing" : "Povoliť nahratie a úpravy",
-    "Read only" : "Len na čítanie",
-    "File drop (upload only)" : "Odovzdávanie súborov (len nahrávanie)",
-    "Expiration date enforced" : "Vynútený dátum ukončenia platnosti",
-    "Set expiration date" : "Nastaviť dátum expirácie",
-    "Expiration" : "Koniec platnosti",
-    "Expiration date" : "Dátum expirácie",
-    "Note to recipient" : "Poznámka pre príjemcu",
-    "Unshare" : "Zneprístupniť",
-    "Delete share link" : "Zmazať sprístupnený odkaz",
-    "Add another link" : "Pridať ďalší odkaz",
-    "Password protection for links is mandatory" : "Ochrana heslom je pre odkazy povinná",
-    "Share to {name}" : "Zdieľať s {name}",
-    "Share link" : "Sprístupniť odkaz",
-    "New share link" : "Nový odkaz na sprístupnenie",
-    "Created on {time}" : "Vytvorené {time}",
-    "Password protect by Talk" : "Chránené heslom apkou Talk",
-    "Could not unshare" : "Nepodarilo sa zrušiť sprístupnenie",
-    "Shared with you and the group {group} by {owner}" : "Sprístupnené vám a skupine {group} používateľom {owner}",
-    "Shared with you and {circle} by {owner}" : "Sprístupnené vám a {circle} od {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Sprístupnené vám a rozhovoru {conversation} od {owner}",
-    "Shared with you in a conversation by {owner}" : "Sprístupnené vám vrámci rozhovoru s {owner}",
-    "Shared with you by {owner}" : "Sprístupnené vám používateľom {owner}",
-    "Choose a password for the mail share" : "Zvoľte heslo pre zdieľanie pošty",
-    "group" : "skupina",
-    "remote" : "vzdialený",
-    "remote group" : "vzdialená skupina",
-    "email" : "E-mail",
-    "conversation" : "rozhovor",
-    "shared by {sharer}" : "zdieľal {sharer}",
-    "Can reshare" : "Môže opätovne zdieľať",
-    "Can edit" : "Môže upravovať",
-    "Can create" : "Môže vytvárať",
-    "Can change" : "Môže meniť",
-    "Can delete" : "Môže odstraňovať",
-    "Access control" : "Prístupové práva",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} zdieľal pomocou odkazu",
-    "Error while sharing" : "Chyba počas sprístupňovania",
-    "Share details could not be loaded for this item." : "Nebolo možné načítať údaje o sprístupnení tejto položky.",
-    "Search globally" : "Hľadať globálne",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Najmenej {count} znak je potrebný pre autodopĺňanie","Najmenej {count} znaky sú potrebné pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Tento zoznam môže byť skrátený - upresnite hľadaný výraz, aby ste získali viac výsledkov.",
-    "No users or groups found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ ani skupina",
-    "No users found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ",
-    "An error occurred (\"{message}\"). Please try again" : "Nastala chyba (\"{message}\"). Prosím, skúste znova",
-    "An error occurred. Please try again" : "Nastala chyba. Skúste to prosím znovu",
-    "Home" : "Domov",
-    "Work" : "Práca",
-    "Other" : "Iné",
-    "{sharee} (remote group)" : "{sharee} (vzdialená skupina)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Sprístupniť",
-    "Name or email address..." : "Meno alebo e-mailová adresa...",
-    "Name or federated cloud ID..." : "Meno alebo federatívny cloud ID...",
-    "Name, federated cloud ID or email address..." : "Meno, federatívny cloud ID alebo e-mailová adresa...",
-    "Name..." : "Meno...",
-    "Error" : "Chyba",
-    "Error removing share" : "Chyba pri rušení sprístupnenia",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Stránku ste načítali cez nezabezpečene spojenie pomocou protokolu HTTP. Dôrazne sa odporúča nastaviť server tak, aby vyžadoval zabezpečené spojenie pomocou protokolu HTTPS. Viac sa dočítate v bezpečnostných tipoch <a href=\"{docUrl}\"> ↗</a>.",
     "Non-existing tag #{tag}" : "Neexistujúca značka #{tag}",
     "restricted" : "obmedzený",
     "invisible" : "neviditeľný",
@@ -220,6 +141,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Username or email" : "používateľské meno alebo e-mail",
     "Username or\temail" : "Používateľské meno alebo \t email",
+    "Password" : "Heslo",
     "Log in" : "Prihlásiť sa",
     "Logging in …" : "Prihlasujem ...",
     "Wrong username or password." : "Neprávne používateľské meno alebo heslo.",
@@ -227,17 +149,21 @@ OC.L10N.register(
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z Vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
     "Reset password" : "Obnovenie hesla",
     "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Správa s informáciami na zmenu hesla bola zaslaná na email uvedený v tomto účte. Ak tam nie je, skontrolujte si priečinok nevyžiadanej pošty a kôš, alebo požiadajte svojho administrátora o pomoc.",
+    "If it is not there ask your local administrator." : "Ak tam nie je, pýtajte sa vášho lokálneho administrátora.",
     "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "Password can not be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
     "Back to login" : "Späť na prihlásenie",
     "New password" : "Nové heslo",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
     "I know what I'm doing" : "Viem, čo robím",
+    "Resetting password" : "Obnovuje sa heslo",
     "Forgot password?" : "Zabudli ste heslo?",
     "Settings" : "Nastavenia",
     "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
     "Search contacts …" : "Prehľadať kontakty...",
     "No contacts found" : "Kontakty nenájdené",
     "Show all contacts …" : "Zobraziť všetky kontakty...",
+    "Install the Contacts app" : "Inštalovaťa aplikáciu Kontakty",
     "Loading your contacts …" : "Otvárajú sa kontakty...",
     "Looking for {term} …" : "Hľadá sa výraz {term}...",
     "No" : "Nie",
@@ -250,6 +176,7 @@ OC.L10N.register(
     "Modified" : "Upravené",
     "{newName} already exists" : "{newName} už existuje",
     "Choose" : "Vybrať",
+    "Copy" : "Kopírovať",
     "Move" : "Presunúť",
     "Error loading file picker template: {error}" : "Chyba pri nahrávaní šablóny výberu súborov: {error}",
     "OK" : "Ok",
@@ -277,6 +204,15 @@ OC.L10N.register(
     "seconds ago" : "pred sekundami",
     "Connection to server lost" : "Stratené spojenie so serverom",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
+    "Add to a project" : "Pridať do projektu",
+    "Show details" : "Zobraziť podrobnosti",
+    "Hide details" : "Skryť podrobnosti",
+    "Rename project" : "Premenovať projekt",
+    "Failed to rename the project" : "Nepodarilo sa premenovať projekt",
+    "Failed to create a project" : "Nepodarilo sa vytvoriť projekt",
+    "Failed to add the item to the project" : "Nepodarilo sa pridať položku do projektu",
+    "Connect items to a project to make them easier to find" : "Priradiť položky do projektu, aby sa ľahšie hľadali",
+    "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
     "New in" : "Nové v",
     "View changelog" : "Zobraziť súhrn zmien",
     "No action available" : "NIe sú dostupné žiadne akcie",
@@ -290,6 +226,7 @@ OC.L10N.register(
     "File not found" : "Súbor nenájdený",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nebol nájdený na servri.  Je možné že zdieľanie bolo vymazané alebo expirovalo?",
     "Back to %s" : "Späť na %s",
+    "Error" : "Chyba",
     "Internal Server Error" : "Vnútorná chyba servera",
     "The server was unable to complete your request." : "Server nebol schopný dokončiť vašu žiadosť.",
     "If this happens again, please send the technical details below to the server administrator." : "Ak sa to stane opäť, nižšie zašlite technické podrobnosti správcovi servera.",
@@ -351,7 +288,8 @@ OC.L10N.register(
     "Account access" : "Prístup k účtu",
     "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
     "Account connected" : "Účet pripojený",
-    "Your client should now be connected! You can close this window." : "Váš klient by mal byť pripojený. Toto okno už môžete zatvoriť.",
+    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
+    "You can close this window." : "Toto okno už môžete zatvoriť.",
     "This share is password-protected" : "Toto sprístupnenie je chránené heslom",
     "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
     "Two-factor authentication" : "Dvojzložkové overovanie",
@@ -364,7 +302,7 @@ OC.L10N.register(
     "Use backup code" : "Použiť záložný kód",
     "Cancel log in" : "Zrušiť prihlásenie",
     "Setup two-factor authentication" : "Nastaviť dvojzložkové overovanie",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Vo vašom účte sa vynucuje zvýšená bezpečnosť. Vyberte poskytovateľa, ktorého chcete nastaviť:",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Pre váš účet je vynútená zvýšená bezpečnosť. Vyberte si poskytovateľa, ktorého chcete nastaviť:",
     "Error while validating your second factor" : "Chyba počas overovania druhého faktora",
     "Access through untrusted domain" : "Prístup cez nedôveryhodnú doménu",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontaktujte svojho správcu. Ak ste administrátorom vy, upravte nastavenie \"trusted_domains\" v config/config.php ako napríklad v config.sample.php.",
@@ -389,36 +327,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nemožno poslať email pre obnovu, lebo pre zadaného používateľa neexistuje emailová adresa. Kontaktujte prosím vášho administrátora.",
     "Couldn't send reset email. Please make sure your username is correct." : "Nemožno poslať email pre obnovu. Uistite sa, či vkladáte správne používateľské meno.",
-    "Updated \"%s\" to %s" : "Aktualizované \"%s\" na %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pri kontrole integrity kódu sa vyskytli chyby. Viac informácií…</a>",
     "Dismiss" : "Odmietnuť",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovu hesla bol odoslaný na váš email. Pokiaľ ho neobdržíte v primeranom čase, skontrolujte spam / priečinok nevyžiadanej pošty. <br> Ak tam nie je, kontaktujte svojho administrátora.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše súbory sú zašifrované. Po zresetovaní vášho hesla nebude možné vaše dáta obnoviť.<br />Ak si nie ste istý, pred pokračovaním kontaktujte administrátora.<br />Skutočne si prajete pokračovať?",
     "Sending email …" : "Posielam email …",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} s verziou nižšou ako {version} nainštalovaný, z dôvodu stability a výkonu sa odporúča aktualizovať na novšiu {name} verziu.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom nie je prístupný na čítanie procesom PHP, čo z bezpečnostných dôvodov nie je vôbec odporúčané. Viac informácií nájdete v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentácii</a>.",
-    "Copy URL" : "Kopírovať URL",
-    "Enable" : "Povoliť",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} zdieľal pomocou odkazu",
-    "{sharee} (group)" : "{sharee} (skupina)",
-    "{sharee} (remote)" : "{sharee} (vzdialene)",
-    "{sharee} (email)" : "{sharee} (pošta)",
-    "{sharee} (conversation)" : "{sharee} (rozhovor)",
-    "The specified document has not been found on the server." : "Zadaný dokument nebol nájdený na serveri.",
-    "You can click here to return to %s." : "Kliknite tu pre návrat do %s.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Prístup na túto stránku sa uskutočňuje prostredníctvom nezabezpečeného protokolu HTTP. Dôrazne odporúčame, aby ste namiesto toho nakonfigurovali server tak, aby vyžadoval použitie HTTPS, ako je to popísané v našich <a href=\"{docUrl}\">bezpečnostných tipoch</a>.",
+    "Shared" : "Sprístupnené",
+    "Shared with" : "Sprístupnené používateľovi",
+    "Shared by" : "Sprístupnené používateľom",
+    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
+    "Choose a password for the public link or press the \"Enter\" key" : "Zvoľte heslo pre verejný link alebo stlačte klávesu \"Enter\"",
+    "Copied!" : "Skopírované!",
+    "Copy link" : "Kopíruj odkaz",
+    "Not supported!" : "Nie je podporované!",
+    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
+    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
+    "Unable to create a link share" : "Nie je možné vytvoriť odkaz pre sprístupnenie",
+    "Unable to toggle this option" : "Túto voľbu nie je možné prepnúť",
+    "Resharing is not allowed" : "Sprístupnenie už sprístupnenej položky nie je povolené",
+    "Link" : "Odkaz",
+    "Hide download" : "Skryť sťahovanie",
+    "Password protection enforced" : "Vynútená ochrana heslom",
+    "Password protect" : "Chrániť heslom",
+    "Allow editing" : "Povoliť úpravy",
+    "Email link to person" : "Odoslať odkaz emailom",
+    "Send" : "Odoslať",
+    "Allow upload and editing" : "Povoliť nahratie a úpravy",
+    "Read only" : "Len na čítanie",
+    "File drop (upload only)" : "Odovzdávanie súborov (len nahrávanie)",
+    "Expiration date enforced" : "Vynútený dátum ukončenia platnosti",
+    "Set expiration date" : "Nastaviť dátum expirácie",
+    "Expiration" : "Koniec platnosti",
+    "Expiration date" : "Dátum expirácie",
+    "Note to recipient" : "Poznámka pre príjemcu",
+    "Unshare" : "Zneprístupniť",
+    "Delete share link" : "Zmazať sprístupnený odkaz",
+    "Add another link" : "Pridať ďalší odkaz",
+    "Password protection for links is mandatory" : "Ochrana heslom je pre odkazy povinná",
+    "Share to {name}" : "Zdieľať s {name}",
+    "Share link" : "Sprístupniť odkaz",
+    "New share link" : "Nový odkaz na sprístupnenie",
+    "Created on {time}" : "Vytvorené {time}",
+    "Password protect by Talk" : "Chránené heslom apkou Talk",
+    "Could not unshare" : "Nepodarilo sa zrušiť sprístupnenie",
+    "Shared with you and the group {group} by {owner}" : "Sprístupnené vám a skupine {group} používateľom {owner}",
+    "Shared with you and {circle} by {owner}" : "Sprístupnené vám a {circle} od {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Sprístupnené vám a rozhovoru {conversation} od {owner}",
+    "Shared with you in a conversation by {owner}" : "Sprístupnené vám vrámci rozhovoru s {owner}",
+    "Shared with you by {owner}" : "Sprístupnené vám používateľom {owner}",
+    "Choose a password for the mail share" : "Zvoľte heslo pre zdieľanie pošty",
+    "group" : "skupina",
+    "remote" : "vzdialený",
+    "remote group" : "vzdialená skupina",
+    "email" : "E-mail",
+    "conversation" : "rozhovor",
+    "shared by {sharer}" : "zdieľal {sharer}",
+    "Can reshare" : "Môže opätovne zdieľať",
+    "Can edit" : "Môže upravovať",
+    "Can create" : "Môže vytvárať",
+    "Can change" : "Môže meniť",
+    "Can delete" : "Môže odstraňovať",
+    "Access control" : "Prístupové práva",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} zdieľal pomocou odkazu",
+    "Error while sharing" : "Chyba počas sprístupňovania",
+    "Share details could not be loaded for this item." : "Nebolo možné načítať údaje o sprístupnení tejto položky.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Najmenej {count} znak je potrebný pre autodopĺňanie","Najmenej {count} znaky sú potrebné pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie","Najmenej {count} znakov je potrebných pre autodopĺňanie"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Tento zoznam môže byť skrátený - upresnite hľadaný výraz, aby ste získali viac výsledkov.",
+    "No users or groups found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ ani skupina",
+    "No users found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ",
+    "An error occurred (\"{message}\"). Please try again" : "Nastala chyba (\"{message}\"). Prosím, skúste znova",
+    "An error occurred. Please try again" : "Nastala chyba. Skúste to prosím znovu",
+    "Home" : "Domov",
+    "Work" : "Práca",
+    "Other" : "Iné",
+    "{sharee} (remote group)" : "{sharee} (vzdialená skupina)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Sprístupniť",
+    "Name or email address..." : "Meno alebo e-mailová adresa...",
+    "Name or federated cloud ID..." : "Meno alebo federatívny cloud ID...",
+    "Name, federated cloud ID or email address..." : "Meno, federatívny cloud ID alebo e-mailová adresa...",
+    "Name..." : "Meno...",
+    "Error removing share" : "Chyba pri rušení sprístupnenia",
     "SQLite will be used as database." : "Bude použitá SQLite databáza.",
     "For larger installations we recommend to choose a different database backend." : "Pre veľké inštalácie odporúčame vybrať si iné databázové riešenie.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Najmä pri používaní klientských aplikácií na synchronizáciu s desktopom neodporúčame používať SQLite.",
     "Wrong password." : "Nesprávne heslo.",
-    "Please log in before granting %s access to your %s account." : "Skôr než udelíte prístup pre %s do vášho účtu %s je potrebné sa prihlásiť.",
-    "You are about to grant %s access to your %s account." : "Chystáte sa udeliť %s prístup k svojmu %s účtu.",
-    "Redirecting …" : "Presmerovanie...",
     "New Password" : "Nové heslo",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Vylepšená bezpečnosť je pre váš účet povolená. Overenie pomocou druhého faktora.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Viac informácií o konfigurácii je možné nájsť v %sdokumentácii%s.",
-    "%s will be updated to version %s" : "%s bude zaktualizovaný na verziu %s.",
-    "This page will refresh itself when the %s instance is available again." : "Táto stránka sa obnoví sama hneď ako bude %s inštancia znovu dostupná.",
-    "Thank you for your patience." : "Ďakujeme za Vašu trpezlivosť.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovenie hesla bol odoslaný na e-mailovú adresu uvedenú pre tento účet. Ak ho v krátkej dobe neobdržíte, skontrolujte si priečinok nevyžiadanej pošty a kôš.<br>Ak ho nenájdete, kontaktujte svojho správcu systému."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovenie hesla bol odoslaný na e-mailovú adresu uvedenú pre tento účet. Ak ho v krátkej dobe neobdržíte, skontrolujte si priečinok nevyžiadanej pošty a kôš.<br>Ak ho nenájdete, kontaktujte svojho správcu systému.",
+    "Search globally" : "Hľadať globálne",
+    "Your client should now be connected! You can close this window." : "Váš klient by mal byť pripojený. Toto okno už môžete zatvoriť."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
