@@ -14,6 +14,7 @@ OC.L10N.register(
     "No crop data provided" : "Ni podanih podatkov obreza",
     "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
     "Crop is not square" : "Obrez ni pravokoten",
+    "State token does not match" : "Žeton stanja ni skladen",
     "Could not complete login" : "Prijave ni mogoče dokončati",
     "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
     "Couldn't reset password because the token is invalid" : "Zaradi neustreznega žetona ni mogoče ponastaviti gesla.",
@@ -21,10 +22,15 @@ OC.L10N.register(
     "%s password reset" : "Ponastavitev gesla %s",
     "Password reset" : "Ponastavitev gesla",
     "Reset your password" : "Ponastavi geslo",
+    "Nextcloud Server" : "Strežnik Nextcloud",
     "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
     "Preparing update" : "Poteka pripravljanje posodobitve",
     "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Korak popravila:",
+    "Repair info:" : "Podrobnosti popravila:",
+    "Repair warning:" : "Opozorilo popravila:",
+    "Repair error:" : "Napaka popravila:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Posodobitev sistema je treba izvesti prek ukazne vrstice, ker je nastavitev samodejne posodobitve v config.php onemogočena.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
     "Turned on maintenance mode" : "Vzdrževalni način je omogočen",
@@ -35,8 +41,8 @@ OC.L10N.register(
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke mogoče posodobiti (zaradi velikosti je lahko opravilo dolgotrajno).",
     "Checked database schema update" : "Izbrana posodobitev sheme podatkovne zbirke",
     "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
-    "Checking for update of app \"%s\" in appstore" : "Preverjam posodobitev za aplikacijo \"%s\" v trgovini",
-    "Update app \"%s\" from appstore" : "Posodobi aplikacijo \"%s\" iz trgovine",
+    "Checking for update of app \"%s\" in appstore" : "Poteka preverjanje posodobitev za program »%s« v trgovini",
+    "Update app \"%s\" from appstore" : "Posodobi program »%s« iz trgovine",
     "Checked for update of app \"%s\" in appstore" : "Preverjena posodobitev za \"%s\" v trgovini",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
     "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
@@ -53,71 +59,18 @@ OC.L10N.register(
     "So-so password" : "Slabo geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je vmesnik WebDAV videti okvarjen.",
+    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Spletni strežnik ni ustrezno nastavljen za razreševanje naslova »{url}«. Več podrobnosti je zapisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
+    "Check the background job settings" : "Preverite nastavitve ozadnjih opravil",
+    "The PHP memory limit is below the recommended value of 512MB." : "Omejitev pomnilnika PHP je pod priporočljivo vrednostjo 512 MB.",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
-    "Shared" : "V souporabi",
-    "Shared with" : "V skupni rabi z",
-    "Shared by" : "V souporabi od",
-    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
-    "Choose a password for the public link or press the \"Enter\" key" : "Izberite geslo za javno povezavo ali pritisnite \"Enter\"",
-    "Copied!" : "Naslov je kopiran!",
-    "Copy link" : "Kopiraj povezavo",
-    "Not supported!" : "Ni podprto!",
-    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
-    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
-    "Copy" : "Kopiraj",
-    "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
-    "Link" : "Povezava",
-    "Password protect" : "Zaščiti z geslom",
-    "Password" : "Geslo",
-    "Allow editing" : "Dovoli urejanje",
-    "Email link to person" : "Posreduj povezavo po elektronski pošti",
-    "Send" : "Pošlji",
-    "Allow upload and editing" : "Dovoli pošiljanje in urejanje",
-    "Read only" : "Samo branje",
-    "File drop (upload only)" : "Povleci datoteke (samo nalaganje)",
-    "Set expiration date" : "Nastavi datum preteka",
-    "Expiration" : "Datum preteka",
-    "Expiration date" : "Datum preteka",
-    "Note to recipient" : "Pošlji opombo prejemniku",
-    "Unshare" : "Prekliči souporabo",
-    "Add another link" : "Dodaj novo povezavo",
-    "Share to {name}" : "Deli z {name}",
-    "Share link" : "Povezava do mape souporabe",
-    "Could not unshare" : "Ni mogoče preklicati souporabe",
-    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
-    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
-    "group" : "skupina",
-    "remote" : "oddaljeno",
-    "remote group" : "oddaljena skupina",
-    "email" : "elektronska pošta",
-    "conversation" : "pogovor",
-    "shared by {sharer}" : "deli {sharer}",
-    "Can reshare" : "Lahko deli naprej",
-    "Can edit" : "Lahko ureja",
-    "Can create" : "Lahko ustvari",
-    "Can change" : "Lahko spremeni",
-    "Can delete" : "Lahko izbriše",
-    "Access control" : "Nadzor dostopa",
-    "Error while sharing" : "Napaka med omogočanjem souporabe",
-    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
-    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
-    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
-    "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Souporaba",
-    "Name or email address..." : "Ime ali e-poštni naslov...",
-    "Name or federated cloud ID..." : "Ime ali ID oblaka...",
-    "Name, federated cloud ID or email address..." : "Ime, ID oblaka ali e-poštni naslov...",
-    "Name..." : "Ime ...",
-    "Error" : "Napaka",
-    "Error removing share" : "Napaka odstranjevanja souporabe",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
     "restricted" : "omejeno",
     "invisible" : "nevidno",
     "({scope})" : "({scope})",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
-    "Collaborative tags" : "Oznake sodelovanja",
+    "Collaborative tags" : "Sodelovalne oznake",
     "No tags found" : "Ni najdenih oznak",
     "unknown text" : "neznano besedilo",
     "Hello world!" : "Pozdravljen svet!",
@@ -134,18 +87,28 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
     "Continue to Nextcloud" : "Nadaljuj na Nextcloud",
     "Searching other places" : "Poteka iskanje na drugih mestih",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} rezultat v drugih mapah","{count} rezultata v drugih mapah","{count} rezultatov v drugih mapah","{count} rezultatov v drugih mapah"],
     "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
     "An internal error occurred." : "Prišlo je do notranje napake.",
     "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
     "Username or email" : "Uporabniško ime ali elektronski naslov",
+    "Username or\temail" : "Uporabniško ime ali\telektronski naslov",
+    "Password" : "Geslo",
     "Log in" : "Prijava",
-    "Logging in …" : "Prijava...",
+    "Logging in …" : "Poteka prijavljanje v sistem ...",
+    "Wrong username or password." : "Napačno uporabniško ime oziroma geslo",
+    "User disabled" : "Uporabnik je onemogočen",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
     "Reset password" : "Ponastavi geslo",
+    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Sporočilo za ponastavitev gesla je bila poslana na elektronski naslov računa. Če sporočila v kratkem ne prejmete, preverite mape neželene pošte ali pa za pomoč prosite krajevnega skrbnika sistema.",
+    "If it is not there ask your local administrator." : "Če sporočila ni, stopite v stik s skrbnikom sistema.",
     "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev. Stopite v stik s skrbnikom sistema.",
     "Password can not be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
+    "Back to login" : "Nazaj na prijavo",
     "New password" : "Novo geslo",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
     "I know what I'm doing" : "Vem, kaj delam!",
     "Forgot password?" : "Ali ste pozabili geslo?",
     "Settings" : "Nastavitve",
@@ -153,16 +116,20 @@ OC.L10N.register(
     "Search contacts …" : "Poišči med stiki ...",
     "No contacts found" : "Ni najdenih stikov",
     "Show all contacts …" : "Prikaži vse stike ...",
+    "Install the Contacts app" : "Namesti program Stiki",
     "Loading your contacts …" : "Poteka nalaganje stikov ...",
     "Looking for {term} …" : "Poteka iskanje {term} …",
     "No" : "Ne",
     "Yes" : "Da",
-    "No files in here" : "Tukaj ni datotek",
+    "No files in here" : "Na tem mestu še ni datotek",
+    "New folder" : "Nova mapa",
+    "No more subfolders in here" : "V mapi ni več podrejenih map",
     "Name" : "Ime",
     "Size" : "Velikost",
     "Modified" : "Spremenjeno",
     "{newName} already exists" : "{newName} že obstaja",
     "Choose" : "Izbor",
+    "Copy" : "Kopiraj",
     "Move" : "Premakni",
     "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
     "OK" : "V redu",
@@ -186,10 +153,19 @@ OC.L10N.register(
     "Authentication required" : "Opravilo zahteva overitev!",
     "This action requires you to confirm your password" : "Opravilo zahteva potrditev z vpisom skrbniškega gesla.",
     "Confirm" : "Potrdi",
-    "Failed to authenticate, try again" : "Napaka pri preverjanju prisotnosti, poskusi znova",
+    "Failed to authenticate, try again" : "Med overjanjem je prišlo do napake, poskusite znova.",
     "seconds ago" : "pred nekaj sekundami",
-    "Connection to server lost" : "Povezava s strežnikom spodletela",
-    "View changelog" : "Ogled dnevnika sprememb",
+    "Connection to server lost" : "Povezava s strežnikom je izgubljena",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
+    "Add to a project" : "Dodaj k projektu",
+    "Show details" : "Pokaži podrobnosti",
+    "Hide details" : "Skrij podrobnosti",
+    "Rename project" : "Preimenuj projekt",
+    "Failed to rename the project" : "Preimenovanje projekta je spodletelo.",
+    "Failed to create a project" : "Ustvarjanje projekta je spodletelo",
+    "Failed to add the item to the project" : "Dodajanje predmeta k projektu je spodletelo.",
+    "Connect items to a project to make them easier to find" : "Povežite predmete s projektom, da jih bo lažje najti.",
+    "View changelog" : "Poglej dnevnik sprememb",
     "No action available" : "Ni razpoložljivih dejanj",
     "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Personal" : "Osebno",
@@ -199,7 +175,8 @@ OC.L10N.register(
     "Help" : "Pomoč",
     "Access forbidden" : "Dostop je prepovedan",
     "File not found" : "Datoteke ni mogoče najti",
-    "Internal Server Error" : "Notranja  napaka strežnika",
+    "Error" : "Napaka",
+    "Internal Server Error" : "Notranja napaka strežnika",
     "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniški datoteki strežnika.",
     "Technical details" : "Tehnične podrobnosti",
     "Remote Address: %s" : "Oddaljen naslov: %s",
@@ -211,7 +188,7 @@ OC.L10N.register(
     "Line: %s" : "Vrstica: %s",
     "Trace" : "Sledenje povezav",
     "Security warning" : "Varnostno opozorilo",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni preko interneta, saj datoteka .htaccess ni ustrezno nastavljena.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni prek omrežja, ker datoteka .htaccess ni ustrezno nastavljena.",
     "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
     "Username" : "Uporabniško ime",
     "Storage & database" : "Shramba in podatkovna zbirka",
@@ -232,15 +209,26 @@ OC.L10N.register(
     "See the documentation" : "Preverite dokumentacijo",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
     "More apps" : "Več programov",
+    "More" : "Več",
+    "More apps menu" : "Meni več programov",
     "Search" : "Poišči",
     "Reset search" : "Ponastavi iskanje",
+    "Contacts" : "Stiki",
+    "Contacts menu" : "Meni Stiki",
     "Settings menu" : "Meni nastavitev",
     "Confirm your password" : "Potrdi svoje geslo",
+    "Connect to your account" : "Povežite z računom",
     "App token" : "Ključ aplikacije",
     "Grant access" : "Odobri dostop",
+    "Account access" : "Dostop do računa",
+    "Account connected" : "Račun je povezan",
+    "This share is password-protected" : "To mesto je zaščiteno z geslom",
+    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
     "Two-factor authentication" : "Dvo-stopenjska overitev",
-    "Use backup code" : "Uporabi rezervno šifro",
+    "Set up two-factor authentication" : "Nastavitev dvostopenjske overitve",
+    "Use backup code" : "Uporabi varnostno kopijo šifre",
     "Cancel log in" : "Prekini prijavo",
+    "Setup two-factor authentication" : "Nastavite dvostopenjsko overitev",
     "Error while validating your second factor" : "Napaka med preverjanjem drugega koraka",
     "App update required" : "Zahtevana je posodobitev programa",
     "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
@@ -253,32 +241,81 @@ OC.L10N.register(
     "Detailed logs" : "Podrobni dnevniški zapisi",
     "Update needed" : "Zahtevana je posodobitev",
     "Upgrade via web on my own risk" : "Posodobi preko spleta na moje tveganje",
+    "Maintenance mode" : "Vzdrževalni način",
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko zadrži izvajanje postopka.",
+    "This page will refresh itself when the instance is available again." : "Stran bo osvežena, ko bo vsebina spet na voljo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev gesla, ker ni navedenega elektronskega naslova. Stopite v stik s skrbnikom sistema.",
     "Couldn't send reset email. Please make sure your username is correct." : "Ni mogoče poslati elektronskega sporočila. Prepričajte se, da je uporabniško ime pravilno.",
-    "Updated \"%s\" to %s" : "Datoteka \"%s\" je posodobljena na %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Med preverjanjem celovitosti kode je prišlo do napak. Več podrobnosti …</a>",
     "Dismiss" : "Opusti",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na naveden elektronski naslov. V kolikor sporočila ne prejmete v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Datoteke so šifrirane. Po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
     "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
-    "Copy URL" : "Kopiraj naslov URL",
-    "Enable" : "Omogoči",
-    "{sharee} (group)" : "{sharee} (skupina)",
-    "{sharee} (remote)" : "{sharee} (oddaljeno)",
-    "{sharee} (email)" : "{sharee} (email)",
-    "The specified document has not been found on the server." : "Navedenega dokumenta na strežniku ni mogoče najti.",
-    "You can click here to return to %s." : "S klikom na povezavo boste vrnjeni na %s.",
-    "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Do spletišča je omogočen dostop prek protokola HTTP. Priporočljivo je omogočiti podporo za varni protokol HTTPS, kot je to opisano med <a href=\"{docUrl}\">varnostnimi namigi</a>.",
+    "Shared" : "V souporabi",
+    "Shared with" : "V skupni rabi z",
+    "Shared by" : "V souporabi od",
+    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
+    "Choose a password for the public link or press the \"Enter\" key" : "Izberite geslo za javno povezavo ali pritisnite tipko »Enter«.",
+    "Copied!" : "Naslov je kopiran!",
+    "Copy link" : "Kopiraj povezavo",
+    "Not supported!" : "Opravilo ni podprto!",
+    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
+    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
+    "Unable to toggle this option" : "Ni mogoče preklopiti možnosti",
+    "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
+    "Link" : "Povezava",
+    "Hide download" : "Skrij prejem",
+    "Password protection enforced" : "Zaščita z geslom je vsiljeno omogočena",
+    "Password protect" : "Zaščiti z geslom",
+    "Allow editing" : "Dovoli urejanje",
+    "Email link to person" : "Posreduj povezavo po elektronski pošti",
+    "Send" : "Pošlji",
+    "Allow upload and editing" : "Dovoli pošiljanje in urejanje",
+    "Read only" : "Le za branje",
+    "File drop (upload only)" : "Povleci datoteke (samo nalaganje)",
+    "Expiration date enforced" : "Datum preteka je vsiljeno omogočen",
+    "Set expiration date" : "Nastavi datum preteka",
+    "Expiration" : "Datum preteka",
+    "Expiration date" : "Datum preteka",
+    "Note to recipient" : "Pošlji opombo prejemniku",
+    "Unshare" : "Prekliči souporabo",
+    "Add another link" : "Dodaj novo povezavo",
+    "Share to {name}" : "Omogoči souporabo z uporabnikom {name}",
+    "Share link" : "Povezava do mape souporabe",
+    "New share link" : "Nova povezava za souporabo",
+    "Could not unshare" : "Ni mogoče preklicati souporabe",
+    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
+    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
+    "group" : "skupina",
+    "remote" : "oddaljeno",
+    "remote group" : "oddaljena skupina",
+    "email" : "elektronska pošta",
+    "conversation" : "pogovor",
+    "shared by {sharer}" : "souporabo je omogočil uporabnik {sharer}",
+    "Can reshare" : "Lahko omogoči souporabo naprej",
+    "Can edit" : "Lahko ureja",
+    "Can create" : "Lahko ustvari",
+    "Can change" : "Lahko spremeni",
+    "Can delete" : "Lahko izbriše",
+    "Access control" : "Nadzor dostopa",
+    "Error while sharing" : "Napaka med omogočanjem souporabe",
+    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
+    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
+    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
+    "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Souporaba",
+    "Name or email address..." : "Ime ali elektronski naslov ...",
+    "Name or federated cloud ID..." : "Ime ali ID oblaka...",
+    "Name, federated cloud ID or email address..." : "Ime, ID oblaka ali e-poštni naslov...",
+    "Name..." : "Ime ...",
+    "Error removing share" : "Napaka odstranjevanja souporabe",
+    "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
     "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drug ozadnji program zbirke podatkov.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
     "Wrong password." : "Napačno geslo!",
-    "Redirecting …" : "Poteka preusmerjanje ...",
     "New Password" : "Novo geslo",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Na tvojem računu je vključena napredna varnost. Prosim, prijavi se z drugim korakom.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Podrobnosti o nastavitvah je mogoče najti v %sdokumentaciji%s.",
-    "%s will be updated to version %s" : "Okolje %s bo posodobljeno na različico %s.",
-    "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena, ko bo %s spet na voljo.",
-    "Thank you for your patience." : "Hvala za potrpežljivost!"
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na nam poznan elektronski naslov za ta račun. V kolikor sporočila ne prejmete v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
