@@ -53,62 +53,6 @@ OC.L10N.register(
     "Good password" : "Fjalëkalim i mirë",
     "Strong password" : "Fjalëkalim i fortë",
     "Error occurred while checking server setup" : "Ndodhi një gabim gjatë kontrollit të rregullimit të shërbyesit",
-    "Shared" : "Ndarë",
-    "Shared with" : "Ndarë me",
-    "Shared by" : "Shpërndarë nga",
-    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
-    "Choose a password for the public link or press the \"Enter\" key" : "Zgjidhni një fjalëkalim për lidhjen publike ose shtypni butonin \"Enter\"",
-    "Copied!" : "U kopjua!",
-    "Not supported!" : "Jo i përshtatshëm!",
-    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
-    "Press Ctrl-C to copy." : "Shtypni Ctrl-C për të kopjuar.",
-    "Copy" : "Kopjo",
-    "Resharing is not allowed" : "Nuk lejohen rindarjet",
-    "Link" : "Lidhje",
-    "Password protect" : "Mbroje me fjalëkalim",
-    "Password" : "Fjalëkalim",
-    "Allow editing" : "Lejo përpunim",
-    "Email link to person" : "Dërgoja personit lidhjen me email",
-    "Send" : "Dërgo",
-    "Allow upload and editing" : "Lejo ngarkim dhe editim",
-    "Read only" : "Vetëm i lexueshëm",
-    "File drop (upload only)" : "Lësho skedar (vetëm ngarkim)",
-    "Set expiration date" : "Caktoni datë skadimi",
-    "Expiration" : "Skadim",
-    "Expiration date" : "Datë skadimi",
-    "Unshare" : "Hiqe ndarjen",
-    "Share to {name}" : "Ndaj tek {name}",
-    "Share link" : "Lidhje ndarjeje",
-    "Could not unshare" : "S’e shndau dot",
-    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
-    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
-    "Choose a password for the mail share" : "Zgjidh një fjalëkalim për shpërndarjen e mail-it",
-    "group" : "grup",
-    "remote" : "i largët",
-    "email" : "postë elektronike",
-    "conversation" : "bisedë",
-    "shared by {sharer}" : "ndarë nga {ndarësi}",
-    "Can reshare" : "Mund të rishpërdajë",
-    "Can edit" : "Mund të editojë",
-    "Can create" : "Mund të krijoni",
-    "Can change" : "Mund të ndryshojë",
-    "Can delete" : "Mund të fshijë",
-    "Access control" : "Kontrolli i aksesit",
-    "Error while sharing" : "Gabim gjatë ndarjes",
-    "Share details could not be loaded for this item." : "Për këtë objekt s’u ngarkuan dot hollësi ndarjeje.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje","Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Kjo listë ndoshta është e prerë - ju lutemi të përmirësoni termat e kërkimit tuaj për të parë më shumë rezultate.",
-    "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
-    "No users found for {search}" : "S’u gjet përdorues për {search}",
-    "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Ndaje",
-    "Name or email address..." : "Emri ose adresa e email-it",
-    "Name or federated cloud ID..." : "Emri ose ID e resë të fedferuar",
-    "Name, federated cloud ID or email address..." : "Emri, ID e resë të federuar ose adresën e email-it...",
-    "Name..." : "Emër",
-    "Error" : "Gabim",
-    "Error removing share" : "Gabim në heqjen e ndarjes",
     "Non-existing tag #{tag}" : "Etiketë #{tag} që s’ekziston",
     "restricted" : "e kufizuar",
     "invisible" : "e padukshme",
@@ -141,6 +85,7 @@ OC.L10N.register(
     "An internal error occurred." : "Ndodhi një gabim i brendshëm.",
     "Please try again or contact your administrator." : "Ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj.",
     "Username or email" : "Emër përdoruesi ose email",
+    "Password" : "Fjalëkalim",
     "Log in" : "Hyni",
     "Logging in …" : "Duke u loguar ...",
     "User disabled" : "Përdorues i çaktivizuar",
@@ -160,6 +105,7 @@ OC.L10N.register(
     "Yes" : "Po",
     "No files in here" : "Jo skedar këtu",
     "Choose" : "Zgjidhni",
+    "Copy" : "Kopjo",
     "Move" : "Lëvize",
     "Error loading file picker template: {error}" : "Gabim në ngarkimin e gjedhes së marrësit të kartelave: {error}",
     "OK" : "OK",
@@ -195,6 +141,7 @@ OC.L10N.register(
     "Help" : "Ndihmë",
     "Access forbidden" : "Ndalohet hyrja",
     "File not found" : "S’u gjet kartelë",
+    "Error" : "Gabim",
     "Internal Server Error" : "Gabim i Brendshëm Shërbyesi",
     "More details can be found in the server log." : "Më tepër hollësi mund të gjenden në regjistrin e shërbyesit.",
     "Technical details" : "Hollësi teknike",
@@ -257,27 +204,66 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Nëse ky mesazh shfaqet vazhdimisht ose u shfaq papritmas, lidhuni me përgjegjësin e sistemit.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "S’u dërgua dot email ricaktimi, ngaqë s’ka adresë email për këtë përdoruesi. Ju lutemi, lidhuni me përgjegjësin tuaj.",
     "Couldn't send reset email. Please make sure your username is correct." : "S’u dërgua dot email ricaktimi. Ju lutemi, sigurohuni që emri juaj i përdoruesit është i saktë.",
-    "Updated \"%s\" to %s" : "U përditësua \"%s\" në %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pati probleme me kontrollin e integritetit të kodit. Më tepër të dhëna…</a>",
     "Dismiss" : "Mos e merr parasysh",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lidhja për ricaktimin e fjalëkalimi tuaj u dërgua tek email-i juaj. Nëse nuk e merrni brenda një kohe të arsyeshme, kontrolloni dosjet e postës së padëshirueshme/postës së pavlerë.<br>Nëse s’është as aty, pyetni përgjegjësin tuaj lokal.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skedarët tuaj janë të enkriptuar. Nuk do ketë asnjë mënyrë për ti rimarrë të dhënat pasi fjalëkalimi juaj të rivendoset. <br>Nëse nuk jeni të sigurt se çfarë duhet të bëni, ju lutemi flisni me administratorin tuaj para se të vazhdoni. <br /> Doni vërtet të vazhdoni?",
-    "Enable" : "Aktivizo",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shpërndaEmrinEShfaqurTëNismëtarit}} shpërnda nëpërmjet linkut",
-    "{sharee} (group)" : "{sharee} (grup)",
-    "{sharee} (remote)" : "{sharee} (i largët)",
-    "{sharee} (email)" : "{sharee} (email)",
-    "The specified document has not been found on the server." : "Dokumenti i përcaktuar s’u gjet në shërbyes.",
-    "You can click here to return to %s." : "Mund të klikoni këtu për t’u kthyer te %s.",
+    "Shared" : "Ndarë",
+    "Shared with" : "Ndarë me",
+    "Shared by" : "Shpërndarë nga",
+    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
+    "Choose a password for the public link or press the \"Enter\" key" : "Zgjidhni një fjalëkalim për lidhjen publike ose shtypni butonin \"Enter\"",
+    "Copied!" : "U kopjua!",
+    "Not supported!" : "Jo i përshtatshëm!",
+    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
+    "Press Ctrl-C to copy." : "Shtypni Ctrl-C për të kopjuar.",
+    "Resharing is not allowed" : "Nuk lejohen rindarjet",
+    "Link" : "Lidhje",
+    "Password protect" : "Mbroje me fjalëkalim",
+    "Allow editing" : "Lejo përpunim",
+    "Email link to person" : "Dërgoja personit lidhjen me email",
+    "Send" : "Dërgo",
+    "Allow upload and editing" : "Lejo ngarkim dhe editim",
+    "Read only" : "Vetëm i lexueshëm",
+    "File drop (upload only)" : "Lësho skedar (vetëm ngarkim)",
+    "Set expiration date" : "Caktoni datë skadimi",
+    "Expiration" : "Skadim",
+    "Expiration date" : "Datë skadimi",
+    "Unshare" : "Hiqe ndarjen",
+    "Share to {name}" : "Ndaj tek {name}",
+    "Share link" : "Lidhje ndarjeje",
+    "Could not unshare" : "S’e shndau dot",
+    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
+    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
+    "Choose a password for the mail share" : "Zgjidh një fjalëkalim për shpërndarjen e mail-it",
+    "group" : "grup",
+    "remote" : "i largët",
+    "email" : "postë elektronike",
+    "conversation" : "bisedë",
+    "shared by {sharer}" : "ndarë nga {ndarësi}",
+    "Can reshare" : "Mund të rishpërdajë",
+    "Can edit" : "Mund të editojë",
+    "Can create" : "Mund të krijoni",
+    "Can change" : "Mund të ndryshojë",
+    "Can delete" : "Mund të fshijë",
+    "Access control" : "Kontrolli i aksesit",
+    "Error while sharing" : "Gabim gjatë ndarjes",
+    "Share details could not be loaded for this item." : "Për këtë objekt s’u ngarkuan dot hollësi ndarjeje.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje","Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Kjo listë ndoshta është e prerë - ju lutemi të përmirësoni termat e kërkimit tuaj për të parë më shumë rezultate.",
+    "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
+    "No users found for {search}" : "S’u gjet përdorues për {search}",
+    "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Ndaje",
+    "Name or email address..." : "Emri ose adresa e email-it",
+    "Name or federated cloud ID..." : "Emri ose ID e resë të fedferuar",
+    "Name, federated cloud ID or email address..." : "Emri, ID e resë të federuar ose adresën e email-it...",
+    "Name..." : "Emër",
+    "Error removing share" : "Gabim në heqjen e ndarjes",
     "SQLite will be used as database." : "Si bazë të dhënash do të përdoret SQLite.",
     "For larger installations we recommend to choose a different database backend." : "Për instalime më të mëdha këshillojmë të zgjidhni një tjetër program shërbyesi baze të dhënash.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Përdorimi i SQLite-it shkëshillohet veçanërisht, kur për njëkohësim kartelash përdoret klienti desktop.",
     "Wrong password." : "Fjalëkalim i gabuar.",
-    "Redirecting …" : "Duke ju lidhur...",
-    "New Password" : "Fjalëkalim i Ri",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Rrit sigurinë për llogarin tuaj. Ju lutem bëni verifikimin duke përdorur një element të dytë.",
-    "%s will be updated to version %s" : "%s do të përditësohet me versionin %s",
-    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati.",
-    "Thank you for your patience." : "Ju faleminderit për durimin."
+    "New Password" : "Fjalëkalim i Ri"
 },
 "nplurals=2; plural=(n != 1);");
