@@ -107,87 +107,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP заглавље \"{header}\" није постављено на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Овиме могу процурети информације о рефералу. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C препоруке↗</a>",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP заглавље није подешено да буде бар \"{seconds}\" секунди. За додатну сигурност, предлаже се да омогућите HSTS као што је описано у <a href=\"{docUrl}\" rel=\"noreferrer noopener\">сигурносним саветима↗</a>.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
-    "Shared" : "Дељено",
-    "Shared with" : "Дељено са",
-    "Shared by" : "Поделио",
-    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
-    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
-    "Copied!" : "Копирано!",
-    "Copy link" : "Копирај везу",
-    "Not supported!" : "Није подржано!",
-    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
-    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
-    "Copy" : "Копирај",
-    "Unable to create a link share" : "Не могу да направим везу дељења",
-    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
-    "Resharing is not allowed" : "Поновно дељење није дозвољено",
-    "Link" : "Веза",
-    "Hide download" : "Сакриј скидање",
-    "Password protection enforced" : "Захтевана заштита лозинком",
-    "Password protect" : "Заштићено лозинком",
-    "Password" : "Лозинка",
-    "Allow editing" : "Дозволи уређивање",
-    "Email link to person" : "Пошаљи е-поштом",
-    "Send" : "Пошаљи",
-    "Allow upload and editing" : "Дозволи отпремање и уређивање",
-    "Read only" : "Само за читање",
-    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
-    "Expiration date enforced" : "Захтевано постављање датума истека",
-    "Set expiration date" : "Постави датум истека",
-    "Expiration" : "Истиче",
-    "Expiration date" : "Датум истека",
-    "Note to recipient" : "Белешка примаоцу",
-    "Unshare" : "Укини дељење",
-    "Delete share link" : "Обриши везу дељења",
-    "Add another link" : "Додај још једну везу",
-    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
-    "Share to {name}" : "Подели са {name}",
-    "Share link" : "Веза дељења",
-    "New share link" : "Нова веза дељења",
-    "Created on {time}" : "Направљено {time}",
-    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
-    "Could not unshare" : "Не могу да укинем дељење",
-    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
-    "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
-    "Shared with you by {owner}" : "{owner} дели са вама",
-    "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
-    "group" : "група",
-    "remote" : "удаљени",
-    "remote group" : "удаљена група",
-    "email" : "е-пошта",
-    "conversation" : "разговор",
-    "shared by {sharer}" : "поделио је {sharer}",
-    "Can reshare" : "Може да дели даље",
-    "Can edit" : "Може да мења",
-    "Can create" : "Може да направи",
-    "Can change" : "Може да мења",
-    "Can delete" : "Може да брише",
-    "Access control" : "Контрола приступа",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
-    "Error while sharing" : "Грешка при дељењу",
-    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
-    "Search globally" : "Претражите глобално",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
-    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
-    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
-    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
-    "Home" : "Почетна",
-    "Work" : "Посао",
-    "Other" : "Остало",
-    "{sharee} (remote group)" : "{sharee} (удаљена група)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Дели",
-    "Name or email address..." : "Име или адреса е-поште...",
-    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
-    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
-    "Name..." : "Име...",
-    "Error" : "Грешка",
-    "Error removing share" : "Грешка при уклањању дељења",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Снажна препорука је да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
     "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
     "restricted" : "ограничен",
     "invisible" : "невидљив",
@@ -221,6 +141,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
     "Username or email" : "Корисничко име или адреса е-поште",
     "Username or\temail" : "Корисничко име или\tадреса е-поште",
+    "Password" : "Лозинка",
     "Log in" : "Пријава",
     "Logging in …" : "Пријављивање ...",
     "Wrong username or password." : "Погрешно корисничко име или лозинка",
@@ -233,7 +154,9 @@ OC.L10N.register(
     "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора.",
     "Back to login" : "Назад на пријаву",
     "New password" : "Нова лозинка",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује. Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите. Да ли стварно желите да наставите?",
     "I know what I'm doing" : "Знам шта радим",
+    "Resetting password" : "Ресетуј лозинку",
     "Forgot password?" : "Заборавили сте лозинку?",
     "Settings" : "Поставке",
     "Could not load your contacts" : "Не могу да учитам Ваше контакте",
@@ -253,6 +176,7 @@ OC.L10N.register(
     "Modified" : "Измењен",
     "{newName} already exists" : "{newName} већ постоји",
     "Choose" : "Изаберите",
+    "Copy" : "Копирај",
     "Move" : "Премести",
     "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
     "OK" : "У реду",
@@ -302,6 +226,7 @@ OC.L10N.register(
     "File not found" : "Фајл није нађен",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
     "Back to %s" : "Назад на %s",
+    "Error" : "Грешка",
     "Internal Server Error" : "Унутрашња грешка сервера",
     "The server was unable to complete your request." : "Сервер не може да обради Ваш захтев.",
     "If this happens again, please send the technical details below to the server administrator." : "Ако се ово понови, пошаљите техниче детаље испод администратору овог сервера.",
@@ -363,7 +288,6 @@ OC.L10N.register(
     "Account access" : "Приступ налогу",
     "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
     "Account connected" : "Налог повезан",
-    "Your client should now be connected! You can close this window." : "Ваш клијент сада треба да је повезан! Можете затворити овај прозор.",
     "This share is password-protected" : "Ово дељење је заштићено лозинком",
     "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
     "Two-factor authentication" : "Двофакторска провера идентитета",
@@ -376,7 +300,7 @@ OC.L10N.register(
     "Use backup code" : "Користите резервни кôд",
     "Cancel log in" : "Поништите пријаву",
     "Setup two-factor authentication" : "Подеси двофакторску проверу идентитета",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
     "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
     "Access through untrusted domain" : "Приступ кроз небезбедни домен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
@@ -401,36 +325,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Није могуће послати е-пошту за ресетовање лозинке јер није подешена адреса е-поште за овог корисника. Контактирајте администратора.",
     "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање. Проверите да ли је корисничко име исправно.",
-    "Updated \"%s\" to %s" : "„%s“ ажуриран на %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Догодила се грешка приликом провере интегритета кода. Више информација...</a>",
     "Dismiss" : "Откажи",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Веза за ресетовање лозинке је послата на вашу е-пошту. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује.<br /> Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите.<br /> Да ли стварно желите да наставите?",
     "Sending email …" : "Слање е-поште…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} испод верзије {version} је инсталиран. Због стабилности и перформанси, препоручује се ажурирање на новију, {name} верзију.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита /dev/urandom. Ово се баш не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
-    "Copy URL" : "Копирај URL",
-    "Enable" : "Укључи",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} је поделио преко везе",
-    "{sharee} (group)" : "{sharee} (група)",
-    "{sharee} (remote)" : "{sharee} (удаљено)",
-    "{sharee} (email)" : "{sharee} (е-пошта)",
-    "{sharee} (conversation)" : "{sharee} (разговор)",
-    "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
-    "You can click here to return to %s." : "Кликните овде да се вратите на %s.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
+    "Shared" : "Дељено",
+    "Shared with" : "Дељено са",
+    "Shared by" : "Поделио",
+    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
+    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
+    "Copied!" : "Копирано!",
+    "Copy link" : "Копирај везу",
+    "Not supported!" : "Није подржано!",
+    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
+    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
+    "Unable to create a link share" : "Не могу да направим везу дељења",
+    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
+    "Resharing is not allowed" : "Поновно дељење није дозвољено",
+    "Link" : "Веза",
+    "Hide download" : "Сакриј скидање",
+    "Password protection enforced" : "Захтевана заштита лозинком",
+    "Password protect" : "Заштићено лозинком",
+    "Allow editing" : "Дозволи уређивање",
+    "Email link to person" : "Пошаљи е-поштом",
+    "Send" : "Пошаљи",
+    "Allow upload and editing" : "Дозволи отпремање и уређивање",
+    "Read only" : "Само за читање",
+    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
+    "Expiration date enforced" : "Захтевано постављање датума истека",
+    "Set expiration date" : "Постави датум истека",
+    "Expiration" : "Истиче",
+    "Expiration date" : "Датум истека",
+    "Note to recipient" : "Белешка примаоцу",
+    "Unshare" : "Укини дељење",
+    "Delete share link" : "Обриши везу дељења",
+    "Add another link" : "Додај још једну везу",
+    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
+    "Share to {name}" : "Подели са {name}",
+    "Share link" : "Веза дељења",
+    "New share link" : "Нова веза дељења",
+    "Created on {time}" : "Направљено {time}",
+    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
+    "Could not unshare" : "Не могу да укинем дељење",
+    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
+    "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
+    "Shared with you by {owner}" : "{owner} дели са вама",
+    "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
+    "group" : "група",
+    "remote" : "удаљени",
+    "remote group" : "удаљена група",
+    "email" : "е-пошта",
+    "conversation" : "разговор",
+    "shared by {sharer}" : "поделио је {sharer}",
+    "Can reshare" : "Може да дели даље",
+    "Can edit" : "Може да мења",
+    "Can create" : "Може да направи",
+    "Can change" : "Може да мења",
+    "Can delete" : "Може да брише",
+    "Access control" : "Контрола приступа",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
+    "Error while sharing" : "Грешка при дељењу",
+    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
+    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
+    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
+    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
+    "Home" : "Почетна",
+    "Work" : "Посао",
+    "Other" : "Остало",
+    "{sharee} (remote group)" : "{sharee} (удаљена група)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Дели",
+    "Name or email address..." : "Име или адреса е-поште...",
+    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
+    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
+    "Name..." : "Име...",
+    "Error removing share" : "Грешка при уклањању дељења",
     "SQLite will be used as database." : "СКуЛајт ће бити коришћен за базу података.",
     "For larger installations we recommend to choose a different database backend." : "За веће инсталације препоручујемо да изаберете другу базу података.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Нарочито ако се користи клијент у десктоп окружењу, коришћење СКуЛајта није препоручљиво.",
     "Wrong password." : "Погрешна лозинка.",
-    "Please log in before granting %s access to your %s account." : "Прво се пријавите пре него што одобрите привилегију %s приступ Вашем налогу %s.",
-    "You are about to grant %s access to your %s account." : "Управо ћете одобрити %s приступ Вашем %s налогу.",
-    "Redirecting …" : "Преусмеравање ...",
     "New Password" : "Нова лозинка",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Повећана сигурност је омогућена за овај налог. Проверите идентитет и другим фактором.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Више информација о томе како ово подесити можете да нађете у %s документацији%s.",
-    "%s will be updated to version %s" : "%s ће бити ажурирана на верзију %s",
-    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
-    "Thank you for your patience." : "Хвала Вам на стрпљењу.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Послали смо Вам е-пошту за ресетовање лозинке на е-мејл адресу која је повезана са овим налогом. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Послали смо Вам е-пошту за ресетовање лозинке на е-мејл адресу која је повезана са овим налогом. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
+    "Search globally" : "Претражите глобално",
+    "Your client should now be connected! You can close this window." : "Ваш клијент сада треба да је повезан! Можете затворити овај прозор."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
