@@ -1,7 +1,7 @@
 OC.L10N.register(
     "core",
     {
-    "Please select a file." : "Välj en fil.",
+    "Please select a file." : "Vänligen välj en fil.",
     "File is too big" : "Filen är för stor",
     "The selected file is not an image." : "Den valda filen är ingen bild.",
     "The selected file cannot be read." : "Den valda filen kan inte läsas.",
@@ -9,7 +9,7 @@ OC.L10N.register(
     "No image or file provided" : "Ingen bild eller fil har tillhandahållits",
     "Unknown filetype" : "Okänd filtyp",
     "Invalid image" : "Ogiltig bild",
-    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
+    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Vänligen kontakta din administratör.",
     "No temporary profile picture available, try again" : "Ingen temporär profilbild finns tillgänglig, försök igen",
     "No crop data provided" : "Ingen beskärningsdata har angivits",
     "No valid crop data provided" : "Ingen giltig beskärningsdata tillhandahölls",
@@ -44,9 +44,9 @@ OC.L10N.register(
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
     "Checked database schema update" : "Kontrollerade uppdatering av databasschemat",
     "Checking updates of apps" : "Kontrollerar uppdatering av appar",
-    "Checking for update of app \"%s\" in appstore" : "Letar efter uppdatering av appen \"%s\" i app-butiken",
-    "Update app \"%s\" from appstore" : "Uppdatera appen \"%s\" från app-butiken",
-    "Checked for update of app \"%s\" in appstore" : "Letade efter uppdatering av appen \"%s\" i app-butiken",
+    "Checking for update of app \"%s\" in appstore" : "Letar efter uppdatering av appen \"%s\" i appbutiken",
+    "Update app \"%s\" from appstore" : "Uppdatera appen \"%s\" från appbutiken",
+    "Checked for update of app \"%s\" in appstore" : "Letade efter uppdatering av appen \"%s\" i appbutiken",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema för %s kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
     "Checked database schema update for apps" : "Kontrollerade uppdatering av databasschemat för applikationer",
     "Updated \"%1$s\" to %2$s" : "Uppdaterade \"%1$s\" till %2$s",
@@ -69,97 +69,24 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Inget minnescache har konfigurerats. För att förbättra prestanda, konfigurera en memcache, om tillgänglig. Ytterligare information finns i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du kör för närvarande PHP {version}. Uppgradera din PHP-version för att dra nytta av <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">prestanda och säkerhetsuppdateringar som tillhandahålls av PHP-gruppen</a> så snart din distribution stöder den.",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Du kör för närvarande PHP 5.6. Den nuvarande omfattande versionen av Nextcloud är den sista som stöds på PHP 5.6. Det rekommenderas att uppgradera PHP-versionen till 7.0+ för att kunna uppgradera till Nextcloud 14.",
+    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Den omvända proxyrubrik-konfigurationen är felaktig, eller så du kommer åt Nextcloud från en betrodd proxy. Om inte, detta är ett säkerhetsproblem och kan tillåta en angripare att förfalska sin IP-adress som synlig för Nextcloud. Ytterligare information finns i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached är konfigurerad som distribuerad cache, men fel PHP-modul \"memcache\" är installerat. \\OC\\Memcache\\Memcached stöder endast \"memcached\" och inte \"memcache\". Se<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki om båda modulerna</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Vissa filer har inte passerat integritetskontrollen. Ytterligare information om hur du löser problemet kan du hitta i vår <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista över ogiltiga filer…</a> / <a href=\"{rescanEndpoint}\">Skanna igen…</a>)",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache är inte korrekt konfigurerad. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">För bättre prestanda rekommenderas</a> att använda följande inställningar i <code>php.ini</code>:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Saknar index \"{indexName}\" i tabellen \"{tableName}\".",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instansen saknar några rekommenderade PHP-moduler. För förbättrad prestanda och kompatibilitet är det starkt rekommenderat att installera dem.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "För att migrera till en annan databas använd kommandoradsverktyget: \"occ db:convert-type\", eller se <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen ↗</a>.",
+    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Användning av den inbyggda php mailer stöds inte längre. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Vänligen uppdatera inställningarna för din e-postserver ↗<a/>.",
     "The PHP memory limit is below the recommended value of 512MB." : "Minnesgränsen för PHP är under det rekommenderade värdet på 512 MB.",
     "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Din datakatalog och filer är förmodligen tillgängliga från Internet. .htaccess-filen fungerar inte. Det rekommenderas starkt att du konfigurerar din webbserver så att datakatalogen inte längre är tillgänglig eller flyttar datakatalogen utanför dokument root för webbservern.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Detta är en potentiell säkerhets- eller sekretessrisk, eftersom det rekommenderas att justera denna inställning i enlighet med detta.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Vissa funktioner kanske inte fungerar korrekt, eftersom det rekommenderas att justera den här inställningen i enlighet med detta.",
-    "Shared" : "Delad",
-    "Shared with" : "Delad med",
-    "Shared by" : "Delad av",
-    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
-    "Choose a password for the public link or press the \"Enter\" key" : "Välj ett lösenord för den publika länken eller tryck Enter",
-    "Copied!" : "Kopierad!",
-    "Copy link" : "Kopiera länk",
-    "Not supported!" : "Stöds ej!",
-    "Press ⌘-C to copy." : "Tryck ned ⌘-C för att kopiera.",
-    "Press Ctrl-C to copy." : "Tryck ned Ctrl-C för att kopiera.",
-    "Copy" : "Kopiera",
-    "Unable to create a link share" : "Kan inte skapa länkdelning",
-    "Unable to toggle this option" : "Kan inte växla om det här alternativet",
-    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
-    "Link" : "Länk",
-    "Hide download" : "Dölj nedladdning",
-    "Password protection enforced" : "Lösenordsskydd obligatorisk",
-    "Password protect" : "Lösenordsskydda",
-    "Password" : "Lösenord",
-    "Allow editing" : "Tillåt redigering",
-    "Email link to person" : "Skicka länken som e-postmeddelande",
-    "Send" : "Skicka",
-    "Allow upload and editing" : "Tillåt uppladdning och redigering",
-    "Read only" : "Läsbehörigheter",
-    "File drop (upload only)" : "Göm fillista (endast uppladdning)",
-    "Expiration date enforced" : "Förfallodatum obligatorisk",
-    "Set expiration date" : "Välj utgångsdatum",
-    "Expiration" : "Upphör",
-    "Expiration date" : "Utgångsdatum",
-    "Note to recipient" : "Notering till mottagare",
-    "Unshare" : "Sluta dela",
-    "Delete share link" : "Radera delad länk",
-    "Add another link" : "Lägg till en annan länk",
-    "Password protection for links is mandatory" : "Lösenordsskydd för länkar är obligatoriskt",
-    "Share to {name}" : "Dela till {name}",
-    "Share link" : "Dela länk",
-    "New share link" : "Ny delad länk",
-    "Created on {time}" : "Skapades {time}",
-    "Password protect by Talk" : "Lösenordsskydda med Talk",
-    "Could not unshare" : "Kunde inte ta bort delning",
-    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
-    "Shared with you and {circle} by {owner}" : "Delad med dig och {circle} av {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Delad med dig och konversation {conversation} av {owner}",
-    "Shared with you in a conversation by {owner}" : "Delad med dig i en konversation av {owner}",
-    "Shared with you by {owner}" : "Delad med dig av {owner}",
-    "Choose a password for the mail share" : "Välj ett lösenord för delning via e-post",
-    "group" : "Grupp",
-    "remote" : "extern",
-    "remote group" : "Fjärrgrupp",
-    "email" : "e-post",
-    "conversation" : "Konversation",
-    "shared by {sharer}" : "delat av {sharer}",
-    "Can reshare" : "Kan dela vidare",
-    "Can edit" : "Kan redigera",
-    "Can create" : "Kan skapa",
-    "Can change" : "Kan ändra",
-    "Can delete" : "Kan radera",
-    "Access control" : "Åtkomstkontroll",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} delad via länk",
-    "Error while sharing" : "Fel vid delning",
-    "Share details could not be loaded for this item." : "Delningsdetaljer kunde inte laddas för detta objekt.",
-    "Search globally" : "Sök globalt",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Minst {count} tecken krävs för automatisk ifyllning","Minst {count} tecken krävs för automatisk ifyllning"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Denna lista kan vara trunkerad - var god förfina dina söktermer för att se fler resultat",
-    "No users or groups found for {search}" : "Inga användare eller grupper funna för {search}",
-    "No users found for {search}" : "Inga användare funna för {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Ett fel uppstod (\"{message}\"). Försök igen",
-    "An error occurred. Please try again" : "Ett fel uppstod. Vänligen försök igen",
-    "Home" : "Hem",
-    "Work" : "Arbete",
-    "Other" : "Annan",
-    "{sharee} (remote group)" : "{sharee} (remote group)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Dela",
-    "Name or email address..." : "Namn eller e-postadress",
-    "Name or federated cloud ID..." : "Namn eller federerat moln-ID",
-    "Name, federated cloud ID or email address..." : "Namn, federerat moln-ID eller e-postadress...",
-    "Name..." : "Namn...",
-    "Error" : "Fel",
-    "Error removing share" : "Fel uppstod när delning försökte tas bort",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" innehåller inte \"{expected}\". Det innebär en potentiell säkerhetsrisk. Det är rekommenderat att ändra inställningen.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-rubriken \"{header}\" är inte satt till \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eller \"{val5}\". Det kan orsaka informationsläckage om hänvisningar. Se <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C-rekommendationen ↗</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP-rubriken \"Strict-Transport-Security\" är inte satt till minst \"{seconds}\" sekunder. För ökad säkerhet är det rekommenderat att slå på HSTS som det beskrivs under <a href=\"{docUrl}\" rel=\"noreferrer noopener\">säkerhetstips ↗</a>.",
     "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
     "restricted" : "begränsad",
     "invisible" : "osynlig",
@@ -175,12 +102,12 @@ OC.L10N.register(
     "Hello {name}" : "Hej {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Detta är ditt sökresultat<script>alert(1)</script></strong>",
     "new" : "ny",
-    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Ladda ned %n filer"],
+    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Hämta %n filer"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppdateringen pågår, om sidan lämnas kan uppdateringen misslyckas. ",
     "Update to {version}" : "Uppdatera till {version}",
     "An error occurred." : "Ett fel inträffade.",
-    "Please reload the page." : "Vänligen ladda om sidan.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppdateringen misslyckades. För mer information <a href=\"{url}\">kolla vår forumpost</a> angående problemet.",
+    "Please reload the page." : "Vänligen uppdatera sidan.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppdateringen misslyckades. För mer information <a href=\"{url}\">se vår forumpost</a> angående problemet.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppdateringen misslyckades. Vänligen rapportera felet till <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
     "Continue to Nextcloud" : "Fortsätt till Nextcloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Uppdateringen lyckades. Omdirigerar dig till molnet om %n sekund.","Uppdateringen lyckades. Omdirigerar dig till molnet om %n sekunder."],
@@ -188,11 +115,12 @@ OC.L10N.register(
     "No search results in other folders for {tag}{filter}{endtag}" : "Inget sökresultat i andra mappar för {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} sökresultat i en annan mapp","{count} sökresultat i andra mappar"],
     "Server side authentication failed!" : "Servern misslyckades med autentisering!",
-    "Please contact your administrator." : "Kontakta din administratör.",
+    "Please contact your administrator." : "Vänligen kontakta din administratör.",
     "An internal error occurred." : "Ett internt fel uppstod.",
     "Please try again or contact your administrator." : "Vänligen försök igen eller kontakta din administratör.",
     "Username or email" : "Användarnamn eller e-post",
     "Username or\temail" : "Användarnamn eller\te-post",
+    "Password" : "Lösenord",
     "Log in" : "Logga in",
     "Logging in …" : "Loggar in ...",
     "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
@@ -227,6 +155,7 @@ OC.L10N.register(
     "Modified" : "Ändrad",
     "{newName} already exists" : "{newName} existerar redan",
     "Choose" : "Välj",
+    "Copy" : "Kopiera",
     "Move" : "Flytta",
     "Error loading file picker template: {error}" : "Fel uppstod för filväljarmall: {error}",
     "OK" : "OK",
@@ -276,6 +205,7 @@ OC.L10N.register(
     "File not found" : "Filen kunde inte hittas",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentet kunde inte hittas på servern. Kanske var delningen raderad eller har gått ut?",
     "Back to %s" : "Tillbaka till %s",
+    "Error" : "Fel",
     "Internal Server Error" : "Internt serverfel",
     "The server was unable to complete your request." : "Servern kunde inte slutföra din begäran.",
     "If this happens again, please send the technical details below to the server administrator." : "Om det händer igen, vänligen skicka de tekniska detaljerna nedan till din serveradministratör.",
@@ -299,20 +229,20 @@ OC.L10N.register(
     "Configure the database" : "Konfigurera databasen",
     "Only %s is available." : "Endast %s är tillgänglig.",
     "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
-    "For more details check out the documentation." : "För mer detaljer kolla dokumentationen",
+    "For more details check out the documentation." : "För mer detaljer se dokumentationen",
     "Database user" : "Databasanvändare",
     "Database password" : "Lösenord till databasen",
     "Database name" : "Databasnamn",
     "Database tablespace" : "Databas tabellutrymme",
     "Database host" : "Databasserver",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med hostnamnet (t.ex. localhost:5432).",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
     "Performance warning" : "Prestandavarning",
     "You chose SQLite as database." : "Du valde SQLite som databas.",
     "Finish setup" : "Slutför installationen",
     "Finishing …" : "Avslutar ...",
     "Need help?" : "Behöver du hjälp?",
     "See the documentation" : "Läs dokumentationen",
-    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. Var god {linkstart}aktivera JavaScript{linkend} och ladda om sidan.",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. Vänligen {linkstart}aktivera JavaScript{linkend} och ladda om sidan.",
     "Get your own free account" : "Skaffa ett eget gratiskonto",
     "Skip to main content" : "Skippa till huvudinnehållet",
     "Skip to navigation of app" : "Skippa till navigering av app",
@@ -327,13 +257,14 @@ OC.L10N.register(
     "Confirm your password" : "Bekräfta ditt lösenord",
     "Connect to your account" : "Anslut ditt konto",
     "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
-    "App token" : "App-polett",
+    "App token" : "Apptoken",
     "Grant access" : "Tillåt åtkomst",
-    "Alternative log in using app token" : "Alternativ inloggning med app-token",
+    "Alternative log in using app token" : "Alternativ inloggning med apptoken",
     "Account access" : "Kontoåtkomst",
     "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto.",
     "Account connected" : "Konto anslutet",
-    "Your client should now be connected! You can close this window." : "Din klient ska nu vara ansluten! Du kan stänga det här fönstret.",
+    "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
+    "You can close this window." : "Du kan stänga det här fönstret.",
     "This share is password-protected" : "Denna delning är lösenordsskyddad",
     "The password is wrong. Try again." : "Felaktigt lösenord. Försök igen.",
     "Two-factor authentication" : "Tvåfaktorsautentisering",
@@ -346,7 +277,7 @@ OC.L10N.register(
     "Use backup code" : "Använd reservkod",
     "Cancel log in" : "Avbryt inloggning",
     "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
     "Error while validating your second factor" : "Fel vid verifiering av tvåfaktorsautentisering.",
     "Access through untrusted domain" : "Åtkomst genom obetrodd domän",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vänligen kontakta din administratör. Om du är en administratör, ändra \"trusted_domains\"-inställningen i config/config.php likt exemplet i config.sample.php.",
@@ -369,38 +300,96 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
     "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kunde inte skicka e-postmeddelande för återställning eftersom det saknas e-postadress för denna användare. Kontakta din administratör",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kunde inte skicka e-postmeddelande för återställning eftersom det saknas e-postadress för denna användare. Vänligen kontakta din administratör",
     "Couldn't send reset email. Please make sure your username is correct." : "Kunde inte skicka återställningsmejl. Vänligen kontrollera att ditt användarnamn är korrekt.",
-    "Updated \"%s\" to %s" : "Uppdaterade \"%s\" till %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Ett problem uppstod under integritetskontrollen av koden. Mer information ... </a>",
     "Dismiss" : "Avfärda",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Länken för att återställa ditt lösenord har skickats till din e-post. Om du inte mottar något inom kort, kontrollera spam/skräpkorgen.<br>Om det inte finns något där, vänligen kontakta din lokala administratör.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord om ditt lösenord återställs..<br />Om du är osäker på hur du ska göra, vänligen kontakta din administratör innan du fortsätter..<br />Är du verkligen säker på att du vill fortsätta?",
     "Sending email …" : "Skickar epost ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} under version {version} är installerad, för stabilitet och prestanda rekommenderar vi uppdatering till en nyare {name} version.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom är inte läsbar av PHP som är mycket avskräckt av säkerhetsskäl. Ytterligare information finns i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen</a>.",
-    "Copy URL" : "Kopiera URL",
-    "Enable" : "Aktivera",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} delad via länk",
-    "{sharee} (group)" : "{sharee} (grupp)",
-    "{sharee} (remote)" : "{sharee} (externt)",
-    "{sharee} (email)" : "{sharee} (e-post)",
-    "{sharee} (conversation)" : "{sharee} (conversation)",
-    "The specified document has not been found on the server." : "Det angivna dokumentet hittades inte på servern.",
-    "You can click here to return to %s." : "Du kan klicka här för att återvända till %s.",
+    "Shared" : "Delad",
+    "Shared with" : "Delad med",
+    "Shared by" : "Delad av",
+    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
+    "Choose a password for the public link or press the \"Enter\" key" : "Välj ett lösenord för den publika länken eller tryck Enter",
+    "Copied!" : "Kopierad!",
+    "Copy link" : "Kopiera länk",
+    "Not supported!" : "Stöds ej!",
+    "Press ⌘-C to copy." : "Tryck ned ⌘-C för att kopiera.",
+    "Press Ctrl-C to copy." : "Tryck ned Ctrl-C för att kopiera.",
+    "Unable to create a link share" : "Kan inte skapa länkdelning",
+    "Unable to toggle this option" : "Kan inte växla om det här alternativet",
+    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
+    "Link" : "Länk",
+    "Hide download" : "Dölj nedladdning",
+    "Password protection enforced" : "Lösenordsskydd obligatorisk",
+    "Password protect" : "Lösenordsskydda",
+    "Allow editing" : "Tillåt redigering",
+    "Email link to person" : "Skicka länken som e-postmeddelande",
+    "Send" : "Skicka",
+    "Allow upload and editing" : "Tillåt uppladdning och redigering",
+    "Read only" : "Läsbehörigheter",
+    "File drop (upload only)" : "Göm fillista (endast uppladdning)",
+    "Expiration date enforced" : "Förfallodatum obligatorisk",
+    "Set expiration date" : "Välj utgångsdatum",
+    "Expiration" : "Upphör",
+    "Expiration date" : "Förfallodatum",
+    "Note to recipient" : "Notering till mottagare",
+    "Unshare" : "Sluta dela",
+    "Delete share link" : "Radera delad länk",
+    "Add another link" : "Lägg till en annan länk",
+    "Password protection for links is mandatory" : "Lösenordsskydd för länkar är obligatoriskt",
+    "Share to {name}" : "Dela till {name}",
+    "Share link" : "Dela länk",
+    "New share link" : "Ny delad länk",
+    "Created on {time}" : "Skapades {time}",
+    "Password protect by Talk" : "Lösenordsskydda med Talk",
+    "Could not unshare" : "Kunde inte ta bort delning",
+    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
+    "Shared with you and {circle} by {owner}" : "Delad med dig och {circle} av {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Delad med dig och konversation {conversation} av {owner}",
+    "Shared with you in a conversation by {owner}" : "Delad med dig i en konversation av {owner}",
+    "Shared with you by {owner}" : "Delad med dig av {owner}",
+    "Choose a password for the mail share" : "Välj ett lösenord för delning via e-post",
+    "group" : "Grupp",
+    "remote" : "extern",
+    "remote group" : "Fjärrgrupp",
+    "email" : "e-post",
+    "conversation" : "Konversation",
+    "shared by {sharer}" : "delat av {sharer}",
+    "Can reshare" : "Kan dela vidare",
+    "Can edit" : "Kan redigera",
+    "Can create" : "Kan skapa",
+    "Can change" : "Kan ändra",
+    "Can delete" : "Kan radera",
+    "Access control" : "Åtkomstkontroll",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} delad via länk",
+    "Error while sharing" : "Fel vid delning",
+    "Share details could not be loaded for this item." : "Delningsdetaljer kunde inte laddas för detta objekt.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Minst {count} tecken krävs för automatisk ifyllning","Minst {count} tecken krävs för automatisk ifyllning"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Denna lista kan vara trunkerad - vänligen förfina dina söktermer för att se fler resultat",
+    "No users or groups found for {search}" : "Inga användare eller grupper funna för {search}",
+    "No users found for {search}" : "Inga användare funna för {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Ett fel uppstod (\"{message}\"). Försök igen",
+    "An error occurred. Please try again" : "Ett fel uppstod. Vänligen försök igen",
+    "Home" : "Hem",
+    "Work" : "Arbete",
+    "Other" : "Annan",
+    "{sharee} (remote group)" : "{sharee} (remote group)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Dela",
+    "Name or email address..." : "Namn eller e-postadress",
+    "Name or federated cloud ID..." : "Namn eller federerat moln-ID",
+    "Name, federated cloud ID or email address..." : "Namn, federerat moln-ID eller e-postadress...",
+    "Name..." : "Namn...",
+    "Error removing share" : "Fel uppstod när delning försökte tas bort",
     "SQLite will be used as database." : "SQLite kommer att användas som databas",
     "For larger installations we recommend to choose a different database backend." : "För större installationer rekommenderar vi att man väljer en annan databasmotor.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Speciellt när skrivbordsklienten för filsynkronisering används så avråds användande av SQLite.",
     "Wrong password." : "Fel lösenord.",
-    "Please log in before granting %s access to your %s account." : "Logga in innan du ger %s åtkomst till ditt %s konto.",
-    "You are about to grant %s access to your %s account." : "Du håller på att ge %s tillgång till ditt %s-konto.",
-    "Redirecting …" : "Omdirigerar ...",
     "New Password" : "Nytt lösenord",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Utökad säkerhet är aktiverat för ditt konto. Var vänlig verifiera med tvåfaktorsautentisering.",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "Ytterligare information hur du konfigurerar detta finns i %sdokumentationen%s.",
-    "%s will be updated to version %s" : "%s kommer att uppdateras till version %s",
-    "This page will refresh itself when the %s instance is available again." : "Denna sida uppdaterar sig själv när %s-instansen är tillgänglig igen.",
-    "Thank you for your patience." : "Tack för ditt tålamod.",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Vi har skickat ett mejl för lösenordsåterställning till den e-postadress som är känd för detta konto. Om du inte får det inom rimlig tid, kontrollera dina skräppost-mappar.<br>Om det inte är där, fråga din lokala administratör."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Vi har skickat ett mejl för lösenordsåterställning till den e-postadress som är känd för detta konto. Om du inte får det inom rimlig tid, kontrollera dina skräppost-mappar.<br>Om det inte är där, fråga din lokala administratör.",
+    "Search globally" : "Sök globalt",
+    "Your client should now be connected! You can close this window." : "Din klient ska nu vara ansluten! Du kan stänga det här fönstret."
 },
 "nplurals=2; plural=(n != 1);");
