@@ -69,83 +69,6 @@ OC.L10N.register(
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Відсутній індекс \"{indexName}\" у таблиці \"{tableName}\".",
     "The PHP memory limit is below the recommended value of 512MB." : "Обсяг пам'яті PHP нижчий від рекомендованого значення 512 МБ.",
     "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
-    "Shared" : "Опубліковано",
-    "Shared with" : "Спільний доступ з",
-    "Shared by" : "Поділився",
-    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
-    "Choose a password for the public link or press the \"Enter\" key" : "Встановіть пароль на публічне посилання або натисніть на \"Enter\"",
-    "Copied!" : "Скопійовано!",
-    "Copy link" : "Скопіювати посилання",
-    "Not supported!" : "Не підтримується!",
-    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
-    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
-    "Copy" : "Копіювати",
-    "Unable to create a link share" : "Неможливо створити посилання на загальнодоступний ресурс",
-    "Unable to toggle this option" : "Не вдається переключити цей параметр",
-    "Resharing is not allowed" : "Пере-публікація не дозволяється",
-    "Link" : "Посилання",
-    "Hide download" : "Сховати завантаження",
-    "Password protection enforced" : "Вимагати захист паролем",
-    "Password protect" : "Захистити паролем",
-    "Password" : "Пароль",
-    "Allow editing" : "Дозволити редагування",
-    "Email link to person" : "Надіслати посилання електронною поштою",
-    "Send" : "Надіслати",
-    "Allow upload and editing" : "Дозволити завантаження та редагування",
-    "Read only" : "Тільки для читання",
-    "File drop (upload only)" : "Сховище (тільки завантажування)",
-    "Expiration date enforced" : "Вимагати термін дії",
-    "Set expiration date" : "Встановити термін дії",
-    "Expiration" : "Закінчення",
-    "Expiration date" : "Термін дії",
-    "Note to recipient" : "Примітка для одержувача",
-    "Unshare" : "Закрити доступ",
-    "Delete share link" : "Видалити посилання для спільного використання",
-    "Add another link" : "Додати інше посилання",
-    "Password protection for links is mandatory" : "Захист паролем для посилань є обов'язковим",
-    "Share to {name}" : "Поділитися з {name}",
-    "Share link" : "Поділитись посиланням",
-    "New share link" : "Нове посилання для спільного доступу",
-    "Created on {time}" : "Створено о {time}",
-    "Password protect by Talk" : "Захист пароля Talk",
-    "Could not unshare" : "Неможливо припинити ділитися файлом",
-    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
-    "Shared with you and {circle} by {owner}" : "{owner} опублікував для вас, та для круга {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поділився з вами, а також чатом {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} поділився з вами у чаті",
-    "Shared with you by {owner}" : "{owner} опублікував для Вас",
-    "Choose a password for the mail share" : "Встановіть пароль на спільне посилання через електронну пошту",
-    "group" : "група",
-    "remote" : "віддалений",
-    "remote group" : "віддалена група",
-    "email" : "електронна пошта",
-    "conversation" : "розмова",
-    "shared by {sharer}" : "поділився {sharer}",
-    "Can reshare" : "Можна ділитися з іншими",
-    "Can edit" : "Можна редагувати",
-    "Can create" : "Можна створити",
-    "Can change" : "Можна змінювати",
-    "Can delete" : "Можна видаляти",
-    "Access control" : "Контроль доступу",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} ділиться через посилання",
-    "Error while sharing" : "Помилка під час публікації",
-    "Share details could not be loaded for this item." : "Неможливо отримати докладну інформацію щодо цього спільного ресурсу",
-    "Search globally" : "Шукати всюди",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Як мінімум {count} символ потрібен для автозавершення","Як мінімум {count} символи потрібні для автозавершення","Як мінімум {count} символів потрібно для автозавершення","Як мінімум {count} символів потрібно для автозавершення"],
-    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
-    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
-    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
-    "Home" : "Домашній",
-    "Work" : "Робочий",
-    "Other" : "Інший",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Поділитися",
-    "Name or email address..." : "Ім'я або адреса електронної пошти...",
-    "Name or federated cloud ID..." : "Ім'я, або ID федеративної хмари...",
-    "Name, federated cloud ID or email address..." : "Ім'я, ID федеративної хмари або адреса електронної пошти...",
-    "Name..." : "Ім’я",
-    "Error" : "Помилка",
-    "Error removing share" : "Помилка під час вилучення спільного",
     "Non-existing tag #{tag}" : "Ця позначка відсутня #{tag}",
     "restricted" : "обмежений",
     "invisible" : "невидимий",
@@ -177,6 +100,7 @@ OC.L10N.register(
     "An internal error occurred." : "Виникла внутрішня помилка.",
     "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
     "Username or email" : "Ім’я користувача або електронна пошта",
+    "Password" : "Пароль",
     "Log in" : "Увійти",
     "Logging in …" : "Вхід...",
     "Wrong username or password." : "Неправильне ім’я користувача або пароль.",
@@ -206,6 +130,7 @@ OC.L10N.register(
     "Modified" : "Змінено",
     "{newName} already exists" : "{newName} вже існує",
     "Choose" : "Обрати",
+    "Copy" : "Копіювати",
     "Move" : "Перемістити",
     "Error loading file picker template: {error}" : "Помилка при завантаженні шаблону вибору: {error}",
     "OK" : "OK",
@@ -246,6 +171,7 @@ OC.L10N.register(
     "File not found" : "Файл не знайдено",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не знайдено на сервері. Може бути, доступ до нього був видалений, або минув термін дії доступу?",
     "Back to %s" : "Назад до %s",
+    "Error" : "Помилка",
     "Internal Server Error" : "Внутрішня помилка серверу",
     "The server was unable to complete your request." : "Сервер не зміг обробити ваш запит.",
     "If this happens again, please send the technical details below to the server administrator." : "Якщо це станеться знову, надішліть технічні подробиці нижче адміністратору сервера.",
@@ -302,7 +228,6 @@ OC.L10N.register(
     "Account access" : "Доступ до облікового запису",
     "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s.",
     "Account connected" : "Обліковий запис під’єднано",
-    "Your client should now be connected! You can close this window." : "Тепер ваш клієнт під’єднано. Ви можете закрити це вікно.",
     "This share is password-protected" : "Доступ до цього ресурсу захищений паролем",
     "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
     "Two-factor authentication" : "Двофакторна аутентифікація",
@@ -335,11 +260,86 @@ OC.L10N.register(
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваші файли зашифровані. Якщо ви не зробили ключ відновлення, після скидання паролю відновити ваші дані буде неможливо.<br /> Якщо ви не знаєте, що робити, будь ласка, зверніться до адміністратора перед продовженням.<br /> Ви дійсно хочете продовжити?",
     "Sending email …" : "Відправлення пошти ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "Встановлена версія {name} є меншою, ніж {version}, з причин стабільності та ефективності рекомендовано оновити версію {name}.",
+    "Shared" : "Опубліковано",
+    "Shared with" : "Спільний доступ з",
+    "Shared by" : "Поділився",
+    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
+    "Choose a password for the public link or press the \"Enter\" key" : "Встановіть пароль на публічне посилання або натисніть на \"Enter\"",
+    "Copied!" : "Скопійовано!",
+    "Copy link" : "Скопіювати посилання",
+    "Not supported!" : "Не підтримується!",
+    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
+    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
+    "Unable to create a link share" : "Неможливо створити посилання на загальнодоступний ресурс",
+    "Unable to toggle this option" : "Не вдається переключити цей параметр",
+    "Resharing is not allowed" : "Пере-публікація не дозволяється",
+    "Link" : "Посилання",
+    "Hide download" : "Сховати завантаження",
+    "Password protection enforced" : "Вимагати захист паролем",
+    "Password protect" : "Захистити паролем",
+    "Allow editing" : "Дозволити редагування",
+    "Email link to person" : "Надіслати посилання електронною поштою",
+    "Send" : "Надіслати",
+    "Allow upload and editing" : "Дозволити завантаження та редагування",
+    "Read only" : "Тільки для читання",
+    "File drop (upload only)" : "Сховище (тільки завантажування)",
+    "Expiration date enforced" : "Вимагати термін дії",
+    "Set expiration date" : "Встановити термін дії",
+    "Expiration" : "Закінчення",
+    "Expiration date" : "Термін дії",
+    "Note to recipient" : "Примітка для одержувача",
+    "Unshare" : "Закрити доступ",
+    "Delete share link" : "Видалити посилання для спільного використання",
+    "Add another link" : "Додати інше посилання",
+    "Password protection for links is mandatory" : "Захист паролем для посилань є обов'язковим",
+    "Share to {name}" : "Поділитися з {name}",
+    "Share link" : "Поділитись посиланням",
+    "New share link" : "Нове посилання для спільного доступу",
+    "Created on {time}" : "Створено о {time}",
+    "Password protect by Talk" : "Захист пароля Talk",
+    "Could not unshare" : "Неможливо припинити ділитися файлом",
+    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
+    "Shared with you and {circle} by {owner}" : "{owner} опублікував для вас, та для круга {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поділився з вами, а також чатом {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} поділився з вами у чаті",
+    "Shared with you by {owner}" : "{owner} опублікував для Вас",
+    "Choose a password for the mail share" : "Встановіть пароль на спільне посилання через електронну пошту",
+    "group" : "група",
+    "remote" : "віддалений",
+    "remote group" : "віддалена група",
+    "email" : "електронна пошта",
+    "conversation" : "розмова",
+    "shared by {sharer}" : "поділився {sharer}",
+    "Can reshare" : "Можна ділитися з іншими",
+    "Can edit" : "Можна редагувати",
+    "Can create" : "Можна створити",
+    "Can change" : "Можна змінювати",
+    "Can delete" : "Можна видаляти",
+    "Access control" : "Контроль доступу",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} ділиться через посилання",
+    "Error while sharing" : "Помилка під час публікації",
+    "Share details could not be loaded for this item." : "Неможливо отримати докладну інформацію щодо цього спільного ресурсу",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Як мінімум {count} символ потрібен для автозавершення","Як мінімум {count} символи потрібні для автозавершення","Як мінімум {count} символів потрібно для автозавершення","Як мінімум {count} символів потрібно для автозавершення"],
+    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
+    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
+    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
+    "Home" : "Домашній",
+    "Work" : "Робочий",
+    "Other" : "Інший",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Поділитися",
+    "Name or email address..." : "Ім'я або адреса електронної пошти...",
+    "Name or federated cloud ID..." : "Ім'я, або ID федеративної хмари...",
+    "Name, federated cloud ID or email address..." : "Ім'я, ID федеративної хмари або адреса електронної пошти...",
+    "Name..." : "Ім’я",
+    "Error removing share" : "Помилка під час вилучення спільного",
     "SQLite will be used as database." : "В якості бази даних буде використана SQLite.",
     "For larger installations we recommend to choose a different database backend." : "Для великих установок ми радимо вибрати іншу базу даних.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Використання SQLite особливо не рекомендується при синхронізації файлів з використанням клієнта для ПК.",
     "Wrong password." : "Невірний пароль.",
     "New Password" : "Новий пароль",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора."
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
+    "Search globally" : "Шукати всюди",
+    "Your client should now be connected! You can close this window." : "Тепер ваш клієнт під’єднано. Ви можете закрити це вікно."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
