@@ -53,64 +53,6 @@ OC.L10N.register(
     "Good password" : "Mật khẩu tốt",
     "Strong password" : "Mật khẩu mạnh",
     "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
-    "Shared" : "Được chia sẻ",
-    "Shared with" : "Chia sẽ với",
-    "Shared by" : "Đã chia sẽ bởi",
-    "Choose a password for the public link" : "Chọn mật khẩu cho liên kết công khai",
-    "Choose a password for the public link or press the \"Enter\" key" : "Chọn một mật khẩu cho liên kết công cộng hoặc nhấn phím \"Enter\"",
-    "Copied!" : "Được sao chép",
-    "Not supported!" : "Không được hỗ trợ",
-    "Press ⌘-C to copy." : "Nhất  ⌘-C để sao chép",
-    "Press Ctrl-C to copy." : "Nhấn Ctrl-C để sao chép.",
-    "Copy" : "Sao chép",
-    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
-    "Link" : "Liên kết",
-    "Password protect" : "Mật khẩu bảo vệ",
-    "Password" : "Mật khẩu",
-    "Allow editing" : "Cho phép điều chỉnh",
-    "Email link to person" : "Liên kết email tới cá nhân",
-    "Send" : "Gửi",
-    "Allow upload and editing" : "Cho phép tải lên và chỉnh sửa",
-    "Read only" : "Chỉ xem",
-    "File drop (upload only)" : "Kéo thả file (chỉ áp dụng trong trường hợp tải lên)",
-    "Set expiration date" : "Đặt ngày kết thúc",
-    "Expiration" : "Hết hạn",
-    "Expiration date" : "Ngày kết thúc",
-    "Unshare" : "Bỏ chia sẻ",
-    "Share to {name}" : "Chia sẻ với {name}",
-    "Share link" : "Chia sẻ liên kết",
-    "Password protect by Talk" : "Mật khẩu bảo vệ bằng đàm thoại",
-    "Could not unshare" : "Không thể chia sẻ",
-    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
-    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
-    "Choose a password for the mail share" : "Chọn một mật khẩu để chia sẻ qua mail",
-    "group" : "nhóm",
-    "remote" : "Từ xa",
-    "email" : "Thư điện tử",
-    "conversation" : "đàm thoại",
-    "shared by {sharer}" : "được chia sẻ bởi {sharer}",
-    "Can reshare" : "Có thể chia sẻ lại",
-    "Can edit" : "Có thể chỉnh sửa",
-    "Can create" : "Có thể tạo",
-    "Can change" : "Có thể thay đổi",
-    "Can delete" : "Có thể xóa",
-    "Access control" : "Kiểm soát truy cập",
-    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
-    "Share details could not be loaded for this item." : "Các chi tiết chia sẻ không thể được nạp đối với mục này",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Cần ít nhất {count} ký tự cho tự động hoàn thành"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Danh sách này có thể bị cắt ngắn - vui lòng chỉnh cụm từ tìm kiếm của bạn để thấy nhiều hơn kết quả khác.",
-    "No users or groups found for {search}" : "Không có người dùng hoặc nhóm người dùng được tìm với từ khóa {search}",
-    "No users found for {search}" : "Không tìm thấy người dùng cho {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Đã xảy ra lỗi (\"{message}\"). Hãy thử lại",
-    "An error occurred. Please try again" : "Có lỗi vừa xảy ra. Xin vui lòng thử lại",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Chia sẻ",
-    "Name or email address..." : "Tên hoặc địa chỉ email.",
-    "Name or federated cloud ID..." : "Tên hoặc ID đám mây liên kết.",
-    "Name, federated cloud ID or email address..." : "Tên người dùng, ID đám mây liên kết hoặc địa chỉ email.",
-    "Name..." : "Tên người dùng...",
-    "Error" : "Lỗi",
-    "Error removing share" : "Lỗi khi xóa chia sẻ",
     "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
     "restricted" : "hạn chế",
     "invisible" : "không thể nhìn thấy.",
@@ -143,6 +85,7 @@ OC.L10N.register(
     "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
     "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
     "Username or email" : "Tên truy cập hoặc email",
+    "Password" : "Mật khẩu",
     "Log in" : "Đăng nhập",
     "Logging in …" : "Đang đăng nhập",
     "User disabled" : "Vô hiệu hóa sử dụng",
@@ -164,6 +107,7 @@ OC.L10N.register(
     "Yes" : "Có",
     "No files in here" : "Không có file nào ở đây",
     "Choose" : "Chọn",
+    "Copy" : "Sao chép",
     "Move" : "Chuyển",
     "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
     "OK" : "Đồng ý",
@@ -200,6 +144,7 @@ OC.L10N.register(
     "Help" : "Giúp đỡ",
     "Access forbidden" : "Truy cập bị cấm",
     "File not found" : "Không tìm thấy tệp tin",
+    "Error" : "Lỗi",
     "Internal Server Error" : "Lỗi máy chủ.",
     "The server was unable to complete your request." : "Máy chủ không thể hoàn thành được yêu cầu của bạn",
     "If this happens again, please send the technical details below to the server administrator." : "Nếu điều này tiếp tục xảy ra, xin vui lòng gửi thông tin kỹ thuật chi tiết tới người quản trị hệ thống.",
@@ -270,29 +215,69 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại vì chưa có địa chỉ thư điện tử đối với tên đăng nhập này. Xin vui long liên hệ với quản trị hệ thống.",
     "Couldn't send reset email. Please make sure your username is correct." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng kiểm tra tên tài khoản đăng nhập",
-    "Updated \"%s\" to %s" : "Được cập nhật từ  \"%s\" sang %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Có lỗi xảy ra với mã kiểm tra sự toàn vẹn. Thông tin thêm....</a>",
     "Dismiss" : "Bỏ qua",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Liên kết để thiết lập lại mật khẩu của bạn vừa được gửi tới hộp thư điện tử của bạn. Nếu bạn không nhận được liên kết ấy trong vòng một khoảng thời gian xác định, xin vui long kiểm tra thư mục thư rác (spam/junk). <br> Nếu không nhận được thư có liên kết nói trên, xin vui lòng liên hệ quản trị hệ thống của bạn.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Các file của bạn đã được mã hóa. Sẽ không có cách nào lấy lại dữ liệu của bạn sau khi mật khẩu được thiết lập lại. <br/> Nếu bạn không chắc điều gì sẽ xảy ra, xin vui lòng liên hệ người quản trị hệ thốngtrước khi bạn tiếp tục. <br/> Bạn có <b> thực sự muốn </b> tiếp tục?",
     "Sending email …" : "Đang gửi mail...",
-    "Enable" : "Bật",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} chia sẻ qua liên kết",
-    "{sharee} (group)" : "{sharee} (nhóm)",
-    "{sharee} (remote)" : "{sharee} (từ xa)",
-    "{sharee} (email)" : "{sharee} (thư điện tử)",
-    "The specified document has not been found on the server." : "Không tìm thấy tài liệu trên máy chủ.",
-    "You can click here to return to %s." : "Bạn có thể nhấp vào đây để quay lại %s.",
+    "Shared" : "Được chia sẻ",
+    "Shared with" : "Chia sẽ với",
+    "Shared by" : "Đã chia sẽ bởi",
+    "Choose a password for the public link" : "Chọn mật khẩu cho liên kết công khai",
+    "Choose a password for the public link or press the \"Enter\" key" : "Chọn một mật khẩu cho liên kết công cộng hoặc nhấn phím \"Enter\"",
+    "Copied!" : "Được sao chép",
+    "Not supported!" : "Không được hỗ trợ",
+    "Press ⌘-C to copy." : "Nhất  ⌘-C để sao chép",
+    "Press Ctrl-C to copy." : "Nhấn Ctrl-C để sao chép.",
+    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
+    "Link" : "Liên kết",
+    "Password protect" : "Mật khẩu bảo vệ",
+    "Allow editing" : "Cho phép điều chỉnh",
+    "Email link to person" : "Liên kết email tới cá nhân",
+    "Send" : "Gửi",
+    "Allow upload and editing" : "Cho phép tải lên và chỉnh sửa",
+    "Read only" : "Chỉ xem",
+    "File drop (upload only)" : "Kéo thả file (chỉ áp dụng trong trường hợp tải lên)",
+    "Set expiration date" : "Đặt ngày kết thúc",
+    "Expiration" : "Hết hạn",
+    "Expiration date" : "Ngày kết thúc",
+    "Unshare" : "Bỏ chia sẻ",
+    "Share to {name}" : "Chia sẻ với {name}",
+    "Share link" : "Chia sẻ liên kết",
+    "Password protect by Talk" : "Mật khẩu bảo vệ bằng đàm thoại",
+    "Could not unshare" : "Không thể chia sẻ",
+    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
+    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
+    "Choose a password for the mail share" : "Chọn một mật khẩu để chia sẻ qua mail",
+    "group" : "nhóm",
+    "remote" : "Từ xa",
+    "email" : "Thư điện tử",
+    "conversation" : "đàm thoại",
+    "shared by {sharer}" : "được chia sẻ bởi {sharer}",
+    "Can reshare" : "Có thể chia sẻ lại",
+    "Can edit" : "Có thể chỉnh sửa",
+    "Can create" : "Có thể tạo",
+    "Can change" : "Có thể thay đổi",
+    "Can delete" : "Có thể xóa",
+    "Access control" : "Kiểm soát truy cập",
+    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
+    "Share details could not be loaded for this item." : "Các chi tiết chia sẻ không thể được nạp đối với mục này",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Cần ít nhất {count} ký tự cho tự động hoàn thành"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Danh sách này có thể bị cắt ngắn - vui lòng chỉnh cụm từ tìm kiếm của bạn để thấy nhiều hơn kết quả khác.",
+    "No users or groups found for {search}" : "Không có người dùng hoặc nhóm người dùng được tìm với từ khóa {search}",
+    "No users found for {search}" : "Không tìm thấy người dùng cho {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Đã xảy ra lỗi (\"{message}\"). Hãy thử lại",
+    "An error occurred. Please try again" : "Có lỗi vừa xảy ra. Xin vui lòng thử lại",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Chia sẻ",
+    "Name or email address..." : "Tên hoặc địa chỉ email.",
+    "Name or federated cloud ID..." : "Tên hoặc ID đám mây liên kết.",
+    "Name, federated cloud ID or email address..." : "Tên người dùng, ID đám mây liên kết hoặc địa chỉ email.",
+    "Name..." : "Tên người dùng...",
+    "Error removing share" : "Lỗi khi xóa chia sẻ",
     "SQLite will be used as database." : "SQLite sẽ được sử dụng làm cơ sở dữ liệu.",
     "For larger installations we recommend to choose a different database backend." : "Đối với các cài đặt hệ thống lớn, chúng tôi khuyên bạn nên chọn một hệ cơ sở dữ liệu khác.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Đặc biệt khi đang sử dụng phần mềm đồng bộ dữ liệu desktop client  để đồng bộ file thì việc sử dụng CSDL SQLite là không nên.",
     "Wrong password." : "Sai mật khẩu.",
-    "You are about to grant %s access to your %s account." : "Bạn sắp được phép %s  truy nhập  tới tài khoản %s của bạn.",
-    "Redirecting …" : "Chuyển tiếp ...",
-    "New Password" : "Mật khẩu mới",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Tính năng bảo mật nâng cao được kích hoạt cho tài khoản của bạn. Vui lòng xác thực sử dụng yếu tố thứ hai.",
-    "%s will be updated to version %s" : "%s sẽ được cập nhật lên phiên bản %s",
-    "This page will refresh itself when the %s instance is available again." : "Trang này sẽ tự động được làm tươi khi bản cài đặt %s được sẵn sàng.",
-    "Thank you for your patience." : "Cảm ơn sự kiên nhẫn của bạn."
+    "New Password" : "Mật khẩu mới"
 },
 "nplurals=1; plural=0;");
