@@ -107,87 +107,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP 头 \"{header}\" 未包含 \"{expected}\"。这是一种潜在的安全或隐私风险，因此推荐调整此项设置。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP 头 \"{header}\" 未设置成 \"{val1}\"，\"{val2}\"，\"{val3}\"，\"{val4}\" 或 \"{val5}\"。这会泄露更多的信息。请查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C 建议↗</a>。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP的请求头 \"Strict-Transport-Security\" 未设置为至少 \"{seconds}\" 秒。为了提高安全性，建议参照<a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>中的说明启用HSTS。",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成 HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
-    "Shared" : "已共享",
-    "Shared with" : "共享给",
-    "Shared by" : "共享人",
-    "Choose a password for the public link" : "为公开链接设置密码",
-    "Choose a password for the public link or press the \"Enter\" key" : "为公开链接设置密码，或按 \"回车\" 键",
-    "Copied!" : "已复制！",
-    "Copy link" : "复制链接",
-    "Not supported!" : "不支持！",
-    "Press ⌘-C to copy." : "按 ⌘ + C 进行复制。",
-    "Press Ctrl-C to copy." : "按  Ctrl + C 进行复制。",
-    "Copy" : "复制",
-    "Unable to create a link share" : "无法创建共享链接",
-    "Unable to toggle this option" : "无法切换此项",
-    "Resharing is not allowed" : "不允许二次共享",
-    "Link" : "链接",
-    "Hide download" : "隐藏下载",
-    "Password protection enforced" : "强制密码保护",
-    "Password protect" : "密码保护",
-    "Password" : "密码",
-    "Allow editing" : "允许编辑",
-    "Email link to person" : "发送链接到个人",
-    "Send" : "发送",
-    "Allow upload and editing" : "允许上传和编辑",
-    "Read only" : "只读",
-    "File drop (upload only)" : "文件拖拽（仅上传）",
-    "Expiration date enforced" : "强制有效期",
-    "Set expiration date" : "设置过期日期",
-    "Expiration" : "过期",
-    "Expiration date" : "过期日期",
-    "Note to recipient" : "备注",
-    "Unshare" : "取消共享",
-    "Delete share link" : "删除共享链接",
-    "Add another link" : "添加其他链接",
-    "Password protection for links is mandatory" : "强制使用密码保护的链接",
-    "Share to {name}" : "共享给 {name}",
-    "Share link" : "共享链接",
-    "New share link" : "新共享链接",
-    "Created on {time}" : "创建于 {time}",
-    "Password protect by Talk" : "通过 Talk 保护密码",
-    "Could not unshare" : "无法共享",
-    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
-    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 共享给您及对话 {conversation}",
-    "Shared with you in a conversation by {owner}" : "由 {owner} 通过一个对话与您分享",
-    "Shared with you by {owner}" : "{owner} 共享给您",
-    "Choose a password for the mail share" : "为电子邮件共享选择一个密码",
-    "group" : "群组",
-    "remote" : "外部",
-    "remote group" : "远程群组",
-    "email" : "邮件",
-    "conversation" : "对话",
-    "shared by {sharer}" : "由 {sharer} 共享",
-    "Can reshare" : "可以再次共享",
-    "Can edit" : "可以编辑",
-    "Can create" : "可以创建",
-    "Can change" : "可以修改",
-    "Can delete" : "可以删除",
-    "Access control" : "访问控制",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 通过链接共享",
-    "Error while sharing" : "共享时出错",
-    "Share details could not be loaded for this item." : "无法加载这个项目的共享详情。",
-    "Search globally" : "全局搜索",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["{count}字符需要自动完成"],
-    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被截断 - 请缩短您的搜索词以查看更多结果。",
-    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
-    "No users found for {search}" : "没有找到 {search} 用户",
-    "An error occurred (\"{message}\"). Please try again" : "发生错误（\"{message}\"）。请重试",
-    "An error occurred. Please try again" : "发生错误。请重试",
-    "Home" : "家庭",
-    "Work" : "工作",
-    "Other" : "其他",
-    "{sharee} (remote group)" : "{sharee}（远程组）",
-    "{sharee} ({type}, {owner})" : "{share}({type},{owner})",
-    "Share" : "共享",
-    "Name or email address..." : "姓名或电子邮件地址...",
-    "Name or federated cloud ID..." : "姓名或联合云 ID...",
-    "Name, federated cloud ID or email address..." : "姓名，联合云 ID 或电子邮件地址...",
-    "Name..." : "名称...",
-    "Error" : "错误",
-    "Error removing share" : "移除共享时出错",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成要求使用HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
     "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
     "restricted" : "受限",
     "invisible" : "不可见",
@@ -221,6 +141,7 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "请重试或联系您的管理员。",
     "Username or email" : "用户名或邮箱",
     "Username or\temail" : "用户名或\t邮箱",
+    "Password" : "密码",
     "Log in" : "登录",
     "Logging in …" : "正在登录 …",
     "Wrong username or password." : "错误的用户名或密码。",
@@ -255,6 +176,7 @@ OC.L10N.register(
     "Modified" : "已修改",
     "{newName} already exists" : "{newName} 已经存在",
     "Choose" : "选择",
+    "Copy" : "复制",
     "Move" : "移动",
     "Error loading file picker template: {error}" : "加载文件选择模板出错：{error}",
     "OK" : "确认",
@@ -304,6 +226,7 @@ OC.L10N.register(
     "File not found" : "文件未找到",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "服务器上找不到该文档。可能此共享已被删除或过期。",
     "Back to %s" : "返回 %s",
+    "Error" : "错误",
     "Internal Server Error" : "内部服务器错误",
     "The server was unable to complete your request." : "服务器不能完成您的请求。",
     "If this happens again, please send the technical details below to the server administrator." : "如果再次发生，请在下方将技术详情发送给服务器管理员。",
@@ -365,7 +288,6 @@ OC.L10N.register(
     "Account access" : "账户访问",
     "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的 %2$s 账户。",
     "Account connected" : "账号已连接",
-    "Your client should now be connected! You can close this window." : "您的客户端现在应该可以连接了！您可以关闭这个窗口。",
     "This share is password-protected" : "这个共享是被密码保护的",
     "The password is wrong. Try again." : "密码错误。请重试。",
     "Two-factor authentication" : "两步验证",
@@ -378,7 +300,7 @@ OC.L10N.register(
     "Use backup code" : "使用备用口令",
     "Cancel log in" : "取消登录",
     "Setup two-factor authentication" : "配置两步验证",
-    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "您的账户已启用安全增强。请选择提供者进行配置：",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的账户已启用安全增强。请选择提供者进行配置：",
     "Error while validating your second factor" : "验证您的第二项时出错",
     "Access through untrusted domain" : "通过不被信任的域名访问",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的  \"trusted_domains\" 设置。",
@@ -403,36 +325,95 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "该用户没有设置电子邮件地址，无发送重置邮件。请联系管理员。",
     "Couldn't send reset email. Please make sure your username is correct." : "无法发送重置邮件，请检查您的用户名是否正确。",
-    "Updated \"%s\" to %s" : "更新 \"%s\" 为 %s",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">代码完整性检查出现异常，点击查看详细信息...</a>",
     "Dismiss" : "忽略",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "密码重置邮件已经发送到您的电子邮箱中。如果您长时间没能收到邮件，请检查您邮箱的垃圾/广告文件夹。<br>如果未能收到邮件请联系管理员。",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已经加密。当您的密码重置后没有任何方式能恢复您的数据。<br />如果您不确定，请在继续前联系您的管理员。<br/>您是否真的要继续？",
     "Sending email …" : "正在发送邮件…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} 已安装 {version} 版本，出于稳定和性能的考虑，建议更新到 {name} 版本。",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP 无法访问 /dev/urandom，出于安全原因这是强烈不推荐的。更多信息请参见<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。",
-    "Copy URL" : "复制超链接",
-    "Enable" : "启用",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} 通过链接共享",
-    "{sharee} (group)" : "{sharee}（分组）",
-    "{sharee} (remote)" : "{sharee}（外部）",
-    "{sharee} (email)" : "{sharee}（邮件）",
-    "{sharee} (conversation)" : "{sharee}（对话）",
-    "The specified document has not been found on the server." : "在服务器上没找到指定的文件。",
-    "You can click here to return to %s." : "您可以点击这里返回 %s。",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成 HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
+    "Shared" : "已共享",
+    "Shared with" : "共享给",
+    "Shared by" : "共享人",
+    "Choose a password for the public link" : "为公开链接设置密码",
+    "Choose a password for the public link or press the \"Enter\" key" : "为公开链接设置密码，或按 \"回车\" 键",
+    "Copied!" : "已复制！",
+    "Copy link" : "复制链接",
+    "Not supported!" : "不支持！",
+    "Press ⌘-C to copy." : "按 ⌘ + C 进行复制。",
+    "Press Ctrl-C to copy." : "按  Ctrl + C 进行复制。",
+    "Unable to create a link share" : "无法创建共享链接",
+    "Unable to toggle this option" : "无法切换此项",
+    "Resharing is not allowed" : "不允许二次共享",
+    "Link" : "链接",
+    "Hide download" : "隐藏下载",
+    "Password protection enforced" : "强制密码保护",
+    "Password protect" : "密码保护",
+    "Allow editing" : "允许编辑",
+    "Email link to person" : "发送链接到个人",
+    "Send" : "发送",
+    "Allow upload and editing" : "允许上传和编辑",
+    "Read only" : "只读",
+    "File drop (upload only)" : "文件拖拽（仅上传）",
+    "Expiration date enforced" : "强制有效期",
+    "Set expiration date" : "设置过期日期",
+    "Expiration" : "过期",
+    "Expiration date" : "过期日期",
+    "Note to recipient" : "备注",
+    "Unshare" : "取消共享",
+    "Delete share link" : "删除共享链接",
+    "Add another link" : "添加其他链接",
+    "Password protection for links is mandatory" : "强制使用密码保护的链接",
+    "Share to {name}" : "共享给 {name}",
+    "Share link" : "共享链接",
+    "New share link" : "新共享链接",
+    "Created on {time}" : "创建于 {time}",
+    "Password protect by Talk" : "通过 Talk 保护密码",
+    "Could not unshare" : "无法共享",
+    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
+    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 共享给您及对话 {conversation}",
+    "Shared with you in a conversation by {owner}" : "由 {owner} 通过一个对话与您分享",
+    "Shared with you by {owner}" : "{owner} 共享给您",
+    "Choose a password for the mail share" : "为电子邮件共享选择一个密码",
+    "group" : "群组",
+    "remote" : "外部",
+    "remote group" : "远程群组",
+    "email" : "邮件",
+    "conversation" : "对话",
+    "shared by {sharer}" : "由 {sharer} 共享",
+    "Can reshare" : "可以再次共享",
+    "Can edit" : "可以编辑",
+    "Can create" : "可以创建",
+    "Can change" : "可以修改",
+    "Can delete" : "可以删除",
+    "Access control" : "访问控制",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 通过链接共享",
+    "Error while sharing" : "共享时出错",
+    "Share details could not be loaded for this item." : "无法加载这个项目的共享详情。",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["{count}字符需要自动完成"],
+    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被截断 - 请缩短您的搜索词以查看更多结果。",
+    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
+    "No users found for {search}" : "没有找到 {search} 用户",
+    "An error occurred (\"{message}\"). Please try again" : "发生错误（\"{message}\"）。请重试",
+    "An error occurred. Please try again" : "发生错误。请重试",
+    "Home" : "家庭",
+    "Work" : "工作",
+    "Other" : "其他",
+    "{sharee} (remote group)" : "{sharee}（远程组）",
+    "{sharee} ({type}, {owner})" : "{share}({type},{owner})",
+    "Share" : "共享",
+    "Name or email address..." : "姓名或电子邮件地址...",
+    "Name or federated cloud ID..." : "姓名或联合云 ID...",
+    "Name, federated cloud ID or email address..." : "姓名，联合云 ID 或电子邮件地址...",
+    "Name..." : "名称...",
+    "Error removing share" : "移除共享时出错",
     "SQLite will be used as database." : "SQLite 将被作为数据库使用。",
     "For larger installations we recommend to choose a different database backend." : "在更大的环境下，我们建议选择一个不同的数据库后端。",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite。",
     "Wrong password." : "密码错误。",
-    "Please log in before granting %s access to your %s account." : "请在登录之前授权 %s 访问您的 %s 账户。",
-    "You are about to grant %s access to your %s account." : "您将分配 %s 访问权限给您的 %s 账户。",
-    "Redirecting …" : "正在跳转 …",
     "New Password" : "新密码",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "您的帐户已启用增强安全性，请使用第二种验证方式。",
-    "Further information how to configure this can be found in the %sdocumentation%s." : "更多配置信息可以查看 %s文档%s。",
-    "%s will be updated to version %s" : "%s 将会更新至版本 %s",
-    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时此页面将刷新。",
-    "Thank you for your patience." : "感谢您久等了。",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。"
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。",
+    "Search globally" : "全局搜索",
+    "Your client should now be connected! You can close this window." : "您的客户端现在应该可以连接了！您可以关闭这个窗口。"
 },
 "nplurals=1; plural=0;");
