@@ -18,7 +18,6 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
     "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
     "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
-    "Sharing %s failed, because the file does not exist" : "%s yayımlanmasında səhv baş verdi ona görə ki, fayl mövcud deyil.",
     "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
     "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
     "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
@@ -26,7 +25,6 @@ OC.L10N.register(
     "Authentication error" : "Təyinat metodikası",
     "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
-    "Share type %s is not valid for %s" : "Yayımlanma  tipi %s etibarlı deyil %s üçün",
-    "%s shared »%s« with you" : "%s yayımlandı »%s« sizinlə"
+    "Sharing %s failed, because the file does not exist" : "%s yayımlanmasında səhv baş verdi ona görə ki, fayl mövcud deyil."
 },
 "nplurals=2; plural=(n != 1);");
