@@ -31,8 +31,14 @@ OC.L10N.register(
     "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo nižší.",
     "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či dílčím správcem",
     "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
+    "»%s« started remote wipe" : "»%s« vzdálené vymazání spuštěno",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Přístroj či aplikace »%s« spustila proces vzdáleného vymazání. Obdržíte další email poté co bude proces ukončen",
+    "»%s« finished remote wipe" : "»%s« vzdálené vymazání dokončeno",
+    "Device or application »%s« has finished the remote wipe process." : "Přístroj či aplikace »%s« dokončila proces vzdáleného vymazání.",
     "Remote wipe started" : "Vymazání na dálku zahájeno",
+    "A remote wipe was started on device %s" : "Vzdálené vymazání běží na přístroji %s",
     "Remote wipe finished" : "Vymazání na dálku dokončeno",
+    "The remote wipe on %s has finished" : "Vzdálené vymazání přístroje %s dokončeno",
     "Authentication" : "Ověření",
     "Unknown filetype" : "Neznámý typ souboru",
     "Invalid image" : "Chybný obrázek",
@@ -99,9 +105,9 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Úložiště pro sdílení %s musí implementovat rozhraní OCP\\Share_Backend",
     "Sharing backend %s not found" : "Úložiště sdílení %s nenalezeno",
     "Sharing backend for %s not found" : "Úložiště  sdílení pro %s nenalezeno",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám nasdílel(a) „%2$s“ a chce přidat:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám nasdílel(a) „%2$s“ a chce přidat",
-    "»%s« added a note to a file shared with you" : "„%s“ přidal(a) poznámku k souboru, který je s vámi sdílený",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí »%2$s« a dodává:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí »%2$s« a dodává",
+    "»%s« added a note to a file shared with you" : "»%s« dodává poznámku k nasdílenému souboru ",
     "Open »%s«" : "Otevřít „%s“",
     "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
     "You are not allowed to share %s" : "Nemáte povoleno sdílet %s",
@@ -197,11 +203,11 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, ale stále se tváří jako chybějící?",
     "Please ask your server administrator to restart the web server." : "Požádejte svého správce systému o restart webového serveru.",
-    "PostgreSQL >= 9.5 required" : "Je vyžadováno PostgreSQL verze 9.5 a novější",
+    "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL verze 9 a novější",
     "Please upgrade your database version" : "Aktualizujte verzi své databáze",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli.",
     "Your data directory is readable by other users" : "Váš datový adresář mohou číst ostatní uživatelé",
-    "Your data directory must be an absolute path" : "Je třeba, aby váš datový adresář byl zadán jako úplný popis umístění",
+    "Your data directory must be an absolute path" : "Váš datový adresář musí být zadán jako úplná cesta",
     "Check the value of \"datadirectory\" in your configuration" : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení",
     "Your data directory is invalid" : "Váš datový adresář není platný",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“.",
@@ -216,8 +222,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Chyba připojení úložiště. %s",
     "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Je vyžadována knihovna %s ve verzi vyšší než %s - dostupná verze %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Je vyžadována knihovna %s ve verzi nižší než %s - dostupná verze %s.",
     "Create" : "Vytvořit",
     "Change" : "Změnit",
     "Delete" : "Smazat",
@@ -229,39 +233,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Sdílení %s se nezdařilo, podpůrná vrstva nepodporuje typ sdílení %i",
     "Sharing %s failed, because the file does not exist" : "Sdílení %s se nezdařilo, protože soubor neexistuje",
     "Sharing %s failed, because you can not share with yourself" : "Sdílení %s se nezdařilo, protože nemůžete sdílet sami se sebou",
-    "Sharing %s failed, because the user %s does not exist" : "Sdílení položky %s se nezdařilo, protože uživatel %s neexistuje",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Sdílení položky %s se nezdařilo, protože uživatel %s není členem žádné skupiny společné s uživatelem %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Sdílení položky %s se nezdařilo, protože položka už je s uživatelem %s sdílena",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení položky %s se nezdařilo, protože ta je už s uživatelem %s sdílena",
-    "Sharing %s failed, because the group %s does not exist" : "Sdílení položky %s se nezdařilo, protože skupina %s neexistuje",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Sdílení položky %s se nezdařilo, protože uživatel %s není členem skupiny %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Pro vytvoření veřejného odkazu je nutné zadat heslo, jsou povoleny pouze chráněné odkazy",
-    "Sharing %s failed, because sharing with links is not allowed" : "Sdílení položky %s se nezdařilo, protože sdílení pomocí odkazů není povoleno",
-    "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sdílení %s se nezdařilo, %s se nepodařilo nalézt, server pravděpodobně právě není dostupný.",
-    "Share type %s is not valid for %s" : "Sdílení typu %s není korektní pro %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nedaří se nastavit datum skončení platnosti. Sdílení nemůže vypršet později než za %s po zveřejnění",
-    "Cannot set expiration date. Expiration date is in the past" : "Takové datum skončení platnosti nelze nastavit – je třeba, aby bylo v budoucnosti a ne minulosti…",
-    "Sharing failed, because the user %s is the original sharer" : "Sdílení položky se nezdařilo, protože uživatel %s je původním vlastníkem",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Sdílení položky %s se nezdařilo, protože jsou k tomu nutná vyšší oprávnění, než jaká byla %s povolena.",
-    "Sharing %s failed, because resharing is not allowed" : "Sdílení položky %s se nezdařilo, protože znovu-sdílení není povoleno",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sdílení položky %s selhalo, protože úložiště sdílení %s nenalezla zdroj",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Sdílení položky %s selhalo, protože soubor nebyl nalezen ve vyrovnávací paměti",
-    "%s shared »%s« with you" : "%s s vámi sdílí „%s“",
-    "%s shared »%s« with you." : "%s s vámi sdílel(a) „%s“",
-    "%s via %s" : "%s pomocí %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikaci „%s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %s",
-    "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL verze 9 a novější",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "Identifikátor „%s“ je už použitý poskytovatelem federování cloudu „%s“",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Sdílení %1$s se nezdařilo, protože uživatel %2$s neexistuje",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Sdílení položky %1$s se nezdařilo, protože uživatel %2$s není členem žádné skupiny společné s uživatelem %3$s",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Sdílení %1$s se nezdařilo, protože tato položka už je sdílena s %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s uživatelem %2$s sdílena",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Sdílení %1$s se nezdařilo, protože skupina %2$s neexistuje",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Sdílení %1$s se nezdařilo, protože %2$s není členem skupiny %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Pro vytvoření veřejného odkazu je nutné zadat heslo, jsou povoleny pouze chráněné odkazy",
+    "Sharing %s failed, because sharing with links is not allowed" : "Sdílení položky %s se nezdařilo, protože sdílení pomocí odkazů není povoleno",
+    "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Sdílení %1$s se nezdařilo, %2$s se nedaří nalézt, možná je server v tuto chvíli nedostupný.",
     "Share type %1$s is not valid for %2$s" : "Typ sdílení %1$s není platné pro %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nedaří se nastavit datum skončení platnosti. Sdílení nemůže vypršet později než za %s po zveřejnění",
+    "Cannot set expiration date. Expiration date is in the past" : "Takové datum skončení platnosti nelze nastavit – je třeba, aby bylo v budoucnosti a ne minulosti…",
+    "Sharing failed, because the user %s is the original sharer" : "Sdílení položky se nezdařilo, protože uživatel %s je původním vlastníkem",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Sdílení položky %1$s se nezdařilo, protože jsou k tomu nutná vyšší oprávnění, než jaká byla %2$s povolena.",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Sdílení položky %1$s se nezdařilo, protože úložiště sdílení %2$s nenalezla zdroj"
+    "Sharing %s failed, because resharing is not allowed" : "Sdílení položky %s se nezdařilo, protože znovu-sdílení není povoleno",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Sdílení položky %1$s se nezdařilo, protože úložiště sdílení %2$s nenalezla zdroj",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Sdílení položky %s selhalo, protože soubor nebyl nalezen ve vyrovnávací paměti"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
