@@ -31,10 +31,19 @@ OC.L10N.register(
     "Server version %s or lower is required." : "Servilo kun versio %s aŭ malpli bezoniĝas.",
     "Logged in user must be an admin or sub admin" : "La ensalutanta uzanto estu administranto aŭ subadministranto",
     "Logged in user must be an admin" : "La ensalutanta uzanto estu administranto",
+    "Wiping of device %s has started" : "Forviŝado de la aparato %s komencis",
+    "Wiping of device »%s« has started" : "Forviŝado de la aparato „%s“ komencis",
+    "»%s« started remote wipe" : "„%s“ komencis foran forviŝadon",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "La aparato aŭ aplikaĵo „%s“ komencis la taskon de fora forviŝado. Vi ricevos plian retmesaĝon, kiam la tasko finiĝos",
+    "Wiping of device %s has finished" : "La forviŝado de la aparato %s finiĝis",
+    "Wiping of device »%s« has finished" : "La forviŝado de la aparato „%s“ finiĝis",
+    "»%s« finished remote wipe" : "„%s“ finis la foran forviŝadon",
+    "Device or application »%s« has finished the remote wipe process." : "La aparato aŭ aplikaĵo „%s“ finis la taskon de fora forviŝado.",
     "Remote wipe started" : "Defora forviŝado komenciĝis",
     "A remote wipe was started on device %s" : "Defora forviŝado komenciĝis ĉe aparato %s",
     "Remote wipe finished" : "Defora forviŝado finis",
     "The remote wipe on %s has finished" : "La defora forviŝado ĉe %s finis",
+    "Authentication" : "Aŭtentigo",
     "Unknown filetype" : "Nekonata dosiertipo",
     "Invalid image" : "Nevalida bildo",
     "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
@@ -198,6 +207,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tion kaŭzas probable kaŝilo aŭ plirapidigilo kiel „Zend OPcache“ aŭ „eAccelerator“.",
     "PHP modules have been installed, but they are still listed as missing?" : "Ĉu PHP-moduloj estas instalitaj, sed ĉiam montritaj kiel mankantaj?",
     "Please ask your server administrator to restart the web server." : "Bonvolu peti vian serviladministranton, ke ŝi aŭ li restartigu la TTT-servilon.",
+    "PostgreSQL >= 9 required" : "PostgreSQL ⩾ 9 necesas",
     "Please upgrade your database version" : "Bonvolu ĝisdatigi la version de via datumbazo",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bv. ŝanĝi la permesojn al 0770, tiel la dosierujo ne listigeblas de aliaj uzantoj.",
     "Your data directory is readable by other users" : "Via dosierujo de datumoj legeblas de aliaj uzantoj",
@@ -216,52 +226,34 @@ OC.L10N.register(
     "Storage connection error. %s" : "Konekta eraro al konservejo. %s",
     "Storage is temporarily not available" : "Konservejo provizore ne disponeblas",
     "Storage connection timeout. %s" : "Konekto al konservejo eltempiĝis. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Biblioteko %s kun versio pli ol %s bezoniĝas. Nuna versio estas %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Biblioteko %s kun versio malpli ol %s bezoniĝas. Nuna versio estas %s.",
     "Create" : "Krei",
     "Change" : "Ŝanĝi",
     "Delete" : "Forigi",
     "Share" : "Kunhavigi",
     "Unlimited" : "Senlima",
-    "Verifying" : "Kontrolante",
-    "Verifying …" : "Kontrolante...",
+    "Verifying" : "Kontrolado",
+    "Verifying …" : "Kontrolado...",
     "Verify" : "Kontroli",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Kunhavigo de %s malsukcesis, ĉar la interna servo ne permesas kunhavon de tipo %i",
     "Sharing %s failed, because the file does not exist" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne ekzistas",
     "Sharing %s failed, because you can not share with yourself" : "Kunhavigo de %s malsukcesis, ĉar vi ne povas kunhavigi kun vi mem",
-    "Sharing %s failed, because the user %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s ne ekzistas",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s estas ano de neniu grupo, de kiu %s estas ano",
-    "Sharing %s failed, because this item is already shared with %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhavatas kun %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhaviĝis kun %s",
-    "Sharing %s failed, because the group %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la grupo %s ne ekzistas",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Kunhavigo de %s malsukcesis, ĉar %s ne estas ano de la grupo %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Vi bezonas doni pasvorton por krei publikan ligilon, ĉar nur protektitaj ligiloj estas permesataj",
-    "Sharing %s failed, because sharing with links is not allowed" : "Kunhavo de %s malsukcesis, ĉar kunhavo per ligiloj ne permesatas",
-    "Not allowed to create a federated share with the same user" : "Vi ne permesas krei federan kunhavon kun la sama uzanto",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Kunhavigo de %s malsukcesis, ne eblis trovi %s; eble la servilo estas provizore neatingebla.",
-    "Share type %s is not valid for %s" : "Kunhava tipo %s ne validas por %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ne eblis agordi limdaton. Kunhavoj ne povas senvalidiĝi pli ol %s post sia kreado.",
-    "Cannot set expiration date. Expiration date is in the past" : "Ne eblis agordi limdaton: ĝi troviĝas en la estinteco.",
-    "Sharing failed, because the user %s is the original sharer" : "Kunhavigo malsukcesis, ĉar la uzanto %s estas la origina kunhavanto",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Kunhavigo de %s malsukcesis, ĉar la permesoj transpasas tiujn de %s",
-    "Sharing %s failed, because resharing is not allowed" : "Kunhavigo de %s malsukcesis, ĉar rekunhavigo ne permesatas",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Kunhavigo de %s malsukcesis, ĉar la kunhava interna servo por %s ne povis trovi ĝian fonton",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne troveblis en la dosiera kaŝmemoro",
-    "%s shared »%s« with you" : "%s kunhavigis „%s“ kun vi",
-    "%s shared »%s« with you." : "%s kunhavigis „%s“ kun vi.",
-    "%s via %s" : "%s pere de %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La aplikaĵo „%s“ ne instaliĝis, ĉar la jenaj dependecoj ne plenumiĝas: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL ⩾ 9 necesas",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "Identigilo „%s“ jam uziĝas de federnuba provizanto „%s“",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Kunhavigo de %1$s malsukcesis, ĉar la uzanto %2$s ne ekzistas",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Kunhavigo de %1$s malsukcesis, ĉar la uzanto %2$s estas ano de neniu grupo, de kiu %3$s estas ano",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar tiu elemento jam kunhaviĝas kun %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la ero jam kunhaviĝis kun uzanto %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Kunhavigo de %1$s malsukcesis, ĉar la grupo %2$s ne ekzistas",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Kunhavigo de %1$s malsukcesis, ĉar %2$s ne estas ano de la grupo %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Vi bezonas doni pasvorton por krei publikan ligilon, ĉar nur protektitaj ligiloj estas permesataj",
+    "Sharing %s failed, because sharing with links is not allowed" : "Kunhavo de %s malsukcesis, ĉar kunhavo per ligiloj ne permesatas",
+    "Not allowed to create a federated share with the same user" : "Vi ne permesas krei federan kunhavon kun la sama uzanto",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Kunhavigo de %1$s malsukcesis, ne eblis trovi %2$s; eble la servilo estas provizore neatingebla.",
     "Share type %1$s is not valid for %2$s" : "Kunhava tipo %1$s ne validas por %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ne eblis agordi limdaton. Kunhavoj ne povas senvalidiĝi pli ol %s post sia kreado.",
+    "Cannot set expiration date. Expiration date is in the past" : "Ne eblis agordi limdaton: ĝi troviĝas en la estinteco.",
+    "Sharing failed, because the user %s is the original sharer" : "Kunhavigo malsukcesis, ĉar la uzanto %s estas la origina kunhavanto",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la permesoj transpasas tiujn de %2$s",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Kunhavigo de %1$s malsukcesis, ĉar la kunhava interna servo por %2$s ne povis trovi ĝian fonton"
+    "Sharing %s failed, because resharing is not allowed" : "Kunhavigo de %s malsukcesis, ĉar rekunhavigo ne permesatas",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Kunhavigo de %1$s malsukcesis, ĉar la kunhava interna servo por %2$s ne povis trovi ĝian fonton",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne troveblis en la dosiera kaŝmemoro"
 },
 "nplurals=2; plural=(n != 1);");
