@@ -57,6 +57,7 @@ OC.L10N.register(
     "Additional settings" : "Дополнителни параметри",
     "Personal info" : "Лични податоци",
     "Mobile & desktop" : "Мобилен & компјутер",
+    "%s enter the database username and name." : "%s внесете го корисничкото име и името на базата.",
     "%s enter the database username." : "%s внеси го корисничкото име за базата.",
     "%s enter the database name." : "%s внеси го името на базата.",
     "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
@@ -129,9 +130,11 @@ OC.L10N.register(
     "The username is already being used" : "Корисничкото име е веќе во употреба",
     "User disabled" : "Оневозможен корисник",
     "a safe home for all your data" : "безбеден дом за сите ваши податоци",
+    "Can't read file" : "Неможе да се прочита датотеката",
     "Application is not enabled" : "Апликацијата не е овозможена",
     "Authentication error" : "Грешка во автентикација",
     "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
+    "PostgreSQL >= 9 required" : "Потребно е PostgreSQL >= 9 ",
     "Create" : "Креирај",
     "Change" : "Измени",
     "Delete" : "Избриши",
