@@ -66,7 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minuut geleden","%n minuten geleden"],
     "in a few seconds" : "over een paar seconden",
     "seconds ago" : "seconden geleden",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met ID: %s bestaat niet. Schakel die in binnen de app-instellingen of neem contact op met je beheerder.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module met ID: %s bestaat niet. Schakel die in binnen de app-instellingen of neem contact op met je beheerder.",
     "File name is a reserved word" : "Bestandsnaam is een gereserveerd woord",
     "File name contains at least one invalid character" : "De bestandsnaam bevat in ieder geval één verboden teken",
     "File name is too long" : "De bestandsnaam is te lang",
@@ -207,13 +207,13 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
     "Please ask your server administrator to restart the web server." : "Vraag je beheerder de webserver opnieuw te starten.",
-    "PostgreSQL >= 9.5 required" : "PostgreSQL >= 9.5 vereist",
-    "Please upgrade your database version" : "Werk je database versie bij",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 is vereist",
+    "Please upgrade your database version" : "Werk je databaseversie bij",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de permissie in 0770 zodat de directory niet door andere gebruikers bekeken kan worden.",
-    "Your data directory is readable by other users" : "Je data map is leesbaar voor andere gebruikers",
-    "Your data directory must be an absolute path" : "Je data map moet een absolute bestandslocatie hebben",
+    "Your data directory is readable by other users" : "Je datamap is leesbaar voor andere gebruikers",
+    "Your data directory must be an absolute path" : "Je datamap moet een absolute bestandslocatie hebben",
     "Check the value of \"datadirectory\" in your configuration" : "Controleer de waarde van \"datadirectory\" in je configuratie",
-    "Your data directory is invalid" : "Je data folder  is ongeldig",
+    "Your data directory is invalid" : "Je datamap is ongeldig",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Zorg dat er een bestand genaamd \".ocdata\" in de hoofddirectory aanwezig is.",
     "Action \"%s\" not supported or implemented." : "Actie \"%s\" niet ondersteund of geïmplementeerd.",
     "Authentication failed, wrong token or provider ID given" : "Authenticatie mislukt, ongeldig token of provider ID opgegeven",
@@ -226,8 +226,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Opslag verbindingsfout. %s",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Library %s met een versienummer hoger dan %s is vereist - beschikbare versie %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Library %s met een versienummer lager dan %s is vereist - beschikbare versie %s.",
     "Create" : "Aanmaken",
     "Change" : "Wijzigen",
     "Delete" : "Verwijderen",
@@ -239,39 +237,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Delen van %s is mislukt, omdat de share-backend het niet toestaat om type %i te delen",
     "Sharing %s failed, because the file does not exist" : "Delen van %s is mislukt, omdat het bestand niet bestaat",
     "Sharing %s failed, because you can not share with yourself" : "Delen van %s is mislukt, omdat je niet met jezelf kan delen",
-    "Sharing %s failed, because the user %s does not exist" : "Delen van %s is mislukt, omdat gebruiker %s niet bestaat",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Delen van %s is mislukt, omdat gebruiker %s geen lid is van een groep waar %s lid van is",
-    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met gebruiker %s",
-    "Sharing %s failed, because the group %s does not exist" : "Delen van %s is mislukt, omdat de groep %s niet bestaat",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Delen van %s is mislukt, omdat %s geen lid is van groep %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Je moet een wachtwoord opgeven om een openbare koppeling te maken, alleen wachtwoord beveiligde  links zijn toegestaan",
-    "Sharing %s failed, because sharing with links is not allowed" : "Delen van %s is mislukt, omdat het delen doormiddel van een een link niet is toegestaan",
-    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerd gedeelde folder te maken met dezelfde gebruiker.",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server tijdelijk niet bereikbaar.",
-    "Share type %s is not valid for %s" : "Delen van type %s is niet geldig voor %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Een vervaldatum kan niet worden ingesteld. Gedeelde folders kunnen niet vervallen na %s ",
-    "Cannot set expiration date. Expiration date is in the past" : "Kon vervaldatum niet instellen. De vervaldatum ligt in het verleden",
-    "Sharing failed, because the user %s is the original sharer" : "Delen mislukt, omdat gebruiker %s de originele deler is",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Delen van %s is mislukt, omdat de rechten toegekend aan %s overschreden zijn.",
-    "Sharing %s failed, because resharing is not allowed" : "Delen van %s is mislukt, omdat her-delen niet is toegestaan",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delen van %s is mislukt, omdat de gedeelde backend voor %s de bron niet kon vinden",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Delen van %s is mislukt, omdat het bestand niet in de bestand cache kon worden gevonden",
-    "%s shared »%s« with you" : "%s heeft \"%s \" met je gedeeld",
-    "%s shared »%s« with you." : "%s heeft \"%s\" met je gedeeld.",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden nodig zijn: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 is vereist",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" wordt al gebruikt door cloud federatieprovider \"%s\"",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Delen van %1$s is mislukt, omdat gebruiker %2$s niet bestaat",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Delen van %1$s is mislukt, omdat gebruiker %2$s geen lid is van een groep waar %3$s lid van is",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Delen van %1$s is mislukt, omdat het object al wordt gedeeld met %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Delen van %1$s is mislukt, omdat het object al wordt gedeeld met gebruiker %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Delen van %1$s is mislukt, omdat groep %2$s niet bestaat",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Delen van %1$s is mislukt, omdat %2$s geen lid is van groep %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Je moet een wachtwoord opgeven om een openbare koppeling te maken, alleen wachtwoord beveiligde  links zijn toegestaan",
+    "Sharing %s failed, because sharing with links is not allowed" : "Delen van %s is mislukt, omdat het delen doormiddel van een een link niet is toegestaan",
+    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerd gedeelde folder te maken met dezelfde gebruiker.",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Delen van %1$s mislukt, kon %2$s niet vinden, misschien is de server niet bereikbaar.",
     "Share type %1$s is not valid for %2$s" : "Delen van type %1$s is niet geldig voor %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Een vervaldatum kan niet worden ingesteld. Gedeelde folders kunnen niet vervallen na %s ",
+    "Cannot set expiration date. Expiration date is in the past" : "Kon vervaldatum niet instellen. De vervaldatum ligt in het verleden",
+    "Sharing failed, because the user %s is the original sharer" : "Delen mislukt, omdat gebruiker %s de originele deler is",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Delen van %1$s is mislukt, omdat de rechten toegekend aan %2$s overschreden zijn.",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Delen van %1$s is mislukt, omdat de delende backend voor %2$s de bron niet kon vinden"
+    "Sharing %s failed, because resharing is not allowed" : "Delen van %s is mislukt, omdat her-delen niet is toegestaan",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Delen van %1$s is mislukt, omdat de delende backend voor %2$s de bron niet kon vinden",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Delen van %s is mislukt, omdat het bestand niet in de bestand cache kon worden gevonden"
 },
 "nplurals=2; plural=(n != 1);");
