@@ -15,7 +15,7 @@ OC.L10N.register(
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
     "Education Edition" : "Edycja edukacyjna",
-    "Enterprise bundle" : "Pakiet firmowy",
+    "Enterprise bundle" : "Pakiet dla firm",
     "Groupware bundle" : "Pakiet do pracy grupowej",
     "Social sharing bundle" : "Pakiet udostępniania społecznościowego",
     "PHP %s or higher is required." : "Wymagane jest PHP %s lub wyższe.",
@@ -43,7 +43,7 @@ OC.L10N.register(
     "A remote wipe was started on device %s" : "Zdalne czyszczenie zostało uruchomione na urządzeniu %s",
     "Remote wipe finished" : "Zdalne czyszczenie zakończone",
     "The remote wipe on %s has finished" : "Zakończono zdalne czyszczenie na %s",
-    "Authentication" : "Poświadczenie",
+    "Authentication" : "Uwierzytelnienie",
     "Unknown filetype" : "Nieznany typ pliku",
     "Invalid image" : "Błędne zdjęcie",
     "Avatar image is not square" : "Zdjęcie awatara nie jest kwadratowe",
@@ -85,7 +85,7 @@ OC.L10N.register(
     "Overview" : "Przegląd",
     "Basic settings" : "Ustawienia podstawowe",
     "Sharing" : "Udostępnianie",
-    "Security" : "Bepieczeństwo",
+    "Security" : "Bezpieczeństwo",
     "Groupware" : "Praca grupowa",
     "Additional settings" : "Ustawienia dodatkowe",
     "Personal info" : "Informacje osobiste",
@@ -105,12 +105,12 @@ OC.L10N.register(
     "Set an admin username." : "Ustaw nazwę administratora.",
     "Set an admin password." : "Ustaw hasło administratora.",
     "Can't create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
-    "Invalid Federated Cloud ID" : "Nieprawidłowy ID Chmury Federalnej",
+    "Invalid Federated Cloud ID" : "Nieprawidłowy ID Chmury Federacyjnej",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do współdzielenia %s musi implementować interfejs OCP\\Share_Backend",
     "Sharing backend %s not found" : "Zaplecze %s do współdzielenia nie zostało znalezione",
     "Sharing backend for %s not found" : "Zaplecze do współdzielenia dla %s nie zostało znalezione",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s współdzieli »%2$s« z Tobą i chce dodać: ",
-    "%1$s shared »%2$s« with you and wants to add" : " %1$s współdzieli »%2$s« z Tobą i chce dodać",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s udostępnił Ci »%2$s« i chce dodać: ",
+    "%1$s shared »%2$s« with you and wants to add" : " %1$s udostępnił Ci »%2$s« i chce dodać",
     "»%s« added a note to a file shared with you" : "»%s« dodał notatkę do pliku współdzielonego z Tobą",
     "Open »%s«" : "Otwórz »%s«",
     "%1$s via %2$s" : "%1$s przez %2$s",
@@ -120,8 +120,8 @@ OC.L10N.register(
     "Files can’t be shared with create permissions" : "Pliki nie mogą zostać udostępnione z prawem do tworzenia",
     "Expiration date is in the past" : "Data ważności jest przeszła",
     "Can’t set expiration date more than %s days in the future" : "Nie można ustawić daty ważności na dłuższą niż %s dni",
-    "%1$s shared »%2$s« with you" : "%1$s współdzieli »%2$s« z Tobą",
-    "%1$s shared »%2$s« with you." : "%1$s współdzieli »%2$s« z Tobą.",
+    "%1$s shared »%2$s« with you" : "%1$s udostępnił Ci »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s udostępnił Ci »%2$s«.",
     "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
     "The requested share does not exist anymore" : "Żądane współdzielenie już nie istnieje",
     "Could not find category \"%s\"" : "Nie można znaleźć kategorii \"%s\"",
@@ -207,7 +207,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Jest to prawdopodobnie spowodowane przez cache lub akcelerator, taki jak Zend OPcache lub eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
     "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
-    "PostgreSQL >= 9.5 required" : "Wymagany PostgreSQL >= 9.5",
+    "PostgreSQL >= 9 required" : "Wymagany PostgreSQL >= 9",
     "Please upgrade your database version" : "Zaktualizuj wersję bazy danych",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników.",
     "Your data directory is readable by other users" : "Twój katalog danych jest widoczny dla innych użytkowników",
@@ -226,8 +226,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Błąd połączenia z magazynem. %s",
     "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
     "Storage connection timeout. %s" : "Limit czasu połączenia do magazynu. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Biblioteka %s wymagana jest z wersją wyższą niż %s - dostępna wersja %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Biblioteka %s wymagana jest w wersji niższej niż %s - dostępna wersja %s.",
     "Create" : "Utwórz",
     "Change" : "Zmień",
     "Delete" : "Usuń",
@@ -239,39 +237,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Udostępnianie %s nie udało się, ponieważ zaplecze nie pozwala na współdzielenie takiego typu jak %i",
     "Sharing %s failed, because the file does not exist" : "Udostępnianie %s nie powiodło się. ponieważ plik nie istnieje",
     "Sharing %s failed, because you can not share with yourself" : "Udostępnianie %s nie powiodło się, ponieważ nie możesz współdzielić z samym sobą",
-    "Sharing %s failed, because the user %s does not exist" : "Udostępnianie %s nie powiodło się, ponieważ użytkownik %s nie istnieje",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Udostępnianie %s nie powiodło się, ponieważ użytkownik %s nie jest członkiem żadnej grupy, której członkiem jest %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już współdzielony z użytkownikiem %s",
-    "Sharing %s failed, because the group %s does not exist" : "Udostępnianie %s nie powiodło się, ponieważ grupa %s nie istnieje",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Udostępnianie %s nie powiodło się, ponieważ %s nie jest członkiem grupy %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Aby utworzyć link publiczny, musisz podać hasło, ponieważ dozwolone są tylko linki chronione",
-    "Sharing %s failed, because sharing with links is not allowed" : "Udostępnianie %s nie powiodło się, ponieważ współdzielenie za pomocą linków jest niedozwolone",
-    "Not allowed to create a federated share with the same user" : "Nie jest dozwolone tworzenie współdzielenia federacyjnego z tym samym użytkownikiem",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Udostępnianie %s nie powiodło się, nie można znaleźć %s, może serwer jest obecnie nieosiągalny.",
-    "Share type %s is not valid for %s" : "Typ udostępnienia %s jest nieprawidłowy dla %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nie można ustawić daty wygaśnięcia. Współdzielenie nie może wygasać później niż %s od momentu udostępnienia",
-    "Cannot set expiration date. Expiration date is in the past" : "Nie można ustawić daty wygaśnięcia. Data wygaśnięcia jest w przeszłości.",
-    "Sharing failed, because the user %s is the original sharer" : "Udostępnianie nie powiodło się, ponieważ użytkownik %s jest właścicielem współdzielenia",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Udostępnianie %s nie powiodło się, ponieważ uprawnienia przekraczają uprawnieniom przyznanym %s",
-    "Sharing %s failed, because resharing is not allowed" : "Udostępnianie %s nie powiodło się, ponieważ ponowne współdzielenie nie jest dozwolone",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Udostępnianie %s nie powiodło się, ponieważ zaplecze współdzielenia dla %s nie mogło znaleźć jego źródła",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Udostępnianie %s nie powiodło się, ponieważ nie można znaleźć pliku w pamięci podręcznej plików",
-    "%s shared »%s« with you" : "%s współdzieli »%s« z Tobą",
-    "%s shared »%s« with you." : "%s współdzieli »%s« z Tobą.",
-    "%s via %s" : "%s przez %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikacja \"%s\" nie może zostać zainstalowana, ponieważ nie są spełnione następujące zależności: %s",
-    "PostgreSQL >= 9 required" : "Wymagany PostgreSQL >= 9",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" jest już używane przez dostawcę chmury federacyjnej \"%s\"",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Udostępnianie %1$s nie powiodło się, ponieważ użytkownik %2$s nie istnieje",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Udostępnianie %1$s nie powiodło się, ponieważ użytkownik %2$s nie jest członkiem żadnej grupy, której członkiem jest %3$s",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element jest już współdzielony z %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ ten element jest już udostępniony użytkownikowi %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Udostępnianie %1$s nie powiodło się, ponieważ grupa %2$s nie istnieje",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Udostępnianie %1$s nie powiodło się, ponieważ %2$s nie jest członkiem grupy %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Aby utworzyć link publiczny, musisz podać hasło, ponieważ dozwolone są tylko linki chronione",
+    "Sharing %s failed, because sharing with links is not allowed" : "Udostępnianie %s nie powiodło się, ponieważ współdzielenie za pomocą linków jest niedozwolone",
+    "Not allowed to create a federated share with the same user" : "Nie jest dozwolone tworzenie współdzielenia federacyjnego z tym samym użytkownikiem",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Udostępnianie %1$s nie powiodło się, ponieważ nie udało się znaleźć %2$s, być może serwer jest obecnie nieosiągalny.",
     "Share type %1$s is not valid for %2$s" : "Typ udostępnienia %1$s jest nieprawidłowy dla %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nie można ustawić daty wygaśnięcia. Współdzielenie nie może wygasać później niż %s od momentu udostępnienia",
+    "Cannot set expiration date. Expiration date is in the past" : "Nie można ustawić daty wygaśnięcia. Data wygaśnięcia jest w przeszłości.",
+    "Sharing failed, because the user %s is the original sharer" : "Udostępnianie nie powiodło się, ponieważ użytkownik %s jest właścicielem współdzielenia",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Udostępnianie %1$s nie powiodło się, ponieważ uprawnienia przekraczają uprawnieniom przyznanym %2$s",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Udostępnianie %1$s nie powiodło się, ponieważ zaplecze współdzielenia dla %2$s nie mogło znaleźć swojego źródła"
+    "Sharing %s failed, because resharing is not allowed" : "Udostępnianie %s nie powiodło się, ponieważ ponowne współdzielenie nie jest dozwolone",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Udostępnianie %1$s nie powiodło się, ponieważ zaplecze współdzielenia dla %2$s nie mogło znaleźć swojego źródła",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Udostępnianie %s nie powiodło się, ponieważ nie można znaleźć pliku w pamięci podręcznej plików"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
