@@ -207,7 +207,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
-    "PostgreSQL >= 9.5 required" : "PostgreSQL >= 9.5 requerido",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
     "Please upgrade your database version" : "Por favor atualize sua versão do banco de dados",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
     "Your data directory is readable by other users" : "O diretório de dados está legível para outros usuários",
@@ -225,9 +225,7 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
-    "Storage connection timeout. %s" : "Esgotado o tempo de conexão ao armazenamento. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão maior que %s - versão disponível %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão menor que %s - versão disponível %s.",
+    "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
     "Create" : "Criar",
     "Change" : "Mudar",
     "Delete" : "Excluir",
@@ -239,39 +237,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "O compartilhamento %s falhou pois a plataforma de serviço não permite ações de tipo %i",
     "Sharing %s failed, because the file does not exist" : "Compartilhamento %s falhou pois o arquivo não existe",
     "Sharing %s failed, because you can not share with yourself" : "O compartilhamento %s falhou pois você não pode compartilhar com você mesmo",
-    "Sharing %s failed, because the user %s does not exist" : "O compartilhamento %s falhou pois o usuário %s não existe",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "O compartilhamento %s falhou pois o usuário %s não é membro de nenhum grupo que o usuário %s pertença",
-    "Sharing %s failed, because this item is already shared with %s" : "O compartilhamento %s falhou pois este ítem já está compartilhado com %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "O compartilhamento de %s falhou pois esse item já é compartilhada com o usuário %s",
-    "Sharing %s failed, because the group %s does not exist" : "O compartilhamento %s falhou pois o grupo %s não existe",
-    "Sharing %s failed, because %s is not a member of the group %s" : "O compartilhamento %s falhou, pois %s não é membro do grupo %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
-    "Sharing %s failed, because sharing with links is not allowed" : "O compartilhamento %s falhou pois compartilhamento com links não é permitido",
-    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou pois não foi possível encontrar %s. Talvez o servidor esteja inacessível.",
-    "Share type %s is not valid for %s" : "O tipo de compartilhamento %s não é válido para %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não foi possível definir a data de expiração. Os compartilhamentos não podem expirar mais tarde que %s depois de terem sido compartilhados",
-    "Cannot set expiration date. Expiration date is in the past" : "Não foi possível definir a data de expiração pois ela está no passado",
-    "Sharing failed, because the user %s is the original sharer" : "O compartilhamento falhou pois o usuário %s é o compartilhador original",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartilhamento %s falhou pois as permissões excedem as permissões concedidas a %s",
-    "Sharing %s failed, because resharing is not allowed" : "O compartilhamento %s falhou pois recompartilhamentos não são permitidos",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "O compartilhamento %s falhou pois a plataforma de serviço de compartilhamento para %s não conseguiu encontrar a sua fonte",
-    "Sharing %s failed, because the file could not be found in the file cache" : "O compartilhamento %s falhou pois o arquivo não pôde ser encontrado no cache de arquivos",
-    "%s shared »%s« with you" : "%s compartilhou »%s« com você",
-    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "O aplicativo \"%s\" não pode ser instalado pois as seguintes dependências não foram cumpridas: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" já é usada pelo provedor de nuvem federada \"%s\"",
     "Sharing %1$s failed, because the user %2$s does not exist" : "O compartilhamento %1$s falhou, porque o usuário %2$s não existe",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "O compartilhamento %1$s falhou, porque o usuário %2$s não é membro de nenhum grupo que %3$s é",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "O compartilhamento %1$s falhou, porque o item já está compartilhado com %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "O compartilhamento %1$s falhou, porque este item já está compartilhando com o usuário %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "O compartilhamento %1$s falhou, porque o grupo %2$s não existe",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "O compartilhamento %1$s falhou, porque %2$s não é membro do grupo %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
+    "Sharing %s failed, because sharing with links is not allowed" : "O compartilhamento %s falhou pois compartilhamento com links não é permitido",
+    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "O compartilhamento%1$s falhou, não pude encontrar %2$s, talvez o servidor esteja inacessível.",
     "Share type %1$s is not valid for %2$s" : "O tipo de compartilhamento %1$s é inválido para %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não foi possível definir a data de expiração. Os compartilhamentos não podem expirar mais tarde que %s depois de terem sido compartilhados",
+    "Cannot set expiration date. Expiration date is in the past" : "Não foi possível definir a data de expiração pois ela está no passado",
+    "Sharing failed, because the user %s is the original sharer" : "O compartilhamento falhou pois o usuário %s é o compartilhador original",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "O compartilhamento %1$s falhou, porque as permissões excedem aquelas concedidas à %2$s",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "O compartilhamento %1$s falhou, Talvez a infraestrutura de compartilhamento para %2$s não pode encontrar sua fonte"
+    "Sharing %s failed, because resharing is not allowed" : "O compartilhamento %s falhou pois recompartilhamentos não são permitidos",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "O compartilhamento %1$s falhou, Talvez a infraestrutura de compartilhamento para %2$s não pode encontrar sua fonte",
+    "Sharing %s failed, because the file could not be found in the file cache" : "O compartilhamento %s falhou pois o arquivo não pôde ser encontrado no cache de arquivos"
 },
 "nplurals=2; plural=(n > 1);");
