@@ -207,7 +207,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
     "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
-    "PostgreSQL >= 9.5 required" : "Требуется PostgreSQL >= 9.5",
+    "PostgreSQL >= 9 required" : "Требуется PostgreSQL >= 9",
     "Please upgrade your database version" : "Обновите базу данных",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога.",
     "Your data directory is readable by other users" : "Каталог данных доступен для чтения другим пользователям",
@@ -226,8 +226,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
     "Storage is temporarily not available" : "Хранилище временно недоступно",
     "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Требуется библиотека %s версии не меньше %s, установлена версия %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Требуется библиотека %s версии не выше %s, установлена версия %s.",
     "Create" : "Создание",
     "Change" : "Изменение",
     "Delete" : "Удаление",
@@ -239,39 +237,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Не удалось поделиться %s, так как механизм хранения не допускает публикации из элементов типа %i",
     "Sharing %s failed, because the file does not exist" : "Не удалось поделиться %s, файл не существует",
     "Sharing %s failed, because you can not share with yourself" : "Не удалось поделиться %s. Вы не можете поделиться с самим собой.",
-    "Sharing %s failed, because the user %s does not exist" : "Не удалось поделиться %s, пользователь %s не существует.",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не удалось поделиться %s, так как пользователь %s не состоит в какой-либо группе, в которой состоит %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться %s, пользователь %s уже имеет доступ к этому элементу",
-    "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
-    "Sharing %s failed, because the group %s does not exist" : "Не удалось поделиться %s, группа %s не существует",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Не удалось поделиться %s, пользователь %s не является членом группы %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
-    "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
-    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не удалось поделиться %s, не удалось найти %s, возможно, сервер не доступен.",
-    "Share type %s is not valid for %s" : "Тип общего доступа %s недопустим для %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Невозможно установить дату истечения. Общие ресурсы не могут устареть позже %s с момента их публикации.",
-    "Cannot set expiration date. Expiration date is in the past" : "Невозможно установить дату окончания. Дата окончания в прошлом.",
-    "Sharing failed, because the user %s is the original sharer" : "Не удалось поделиться, потому что пользователь %s владелец этого элемента",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Не удалось поделиться %s, права превышают предоставленные права доступа %s",
-    "Sharing %s failed, because resharing is not allowed" : "Не удалось поделиться %s, повторное открытие доступа запрещено",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не удалось поделиться %s, бэкенд общего доступа не нашел путь до %s",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше.",
-    "%s shared »%s« with you" : "%s предоставил(а) Вам доступ к «%s»",
-    "%s shared »%s« with you." : "%s предоставил(а) Вам доступ к «%s».",
-    "%s via %s" : "%s через %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложение «%s» не может быть установлено, так как не удовлетворены следующие зависимости: %s",
-    "PostgreSQL >= 9 required" : "Требуется PostgreSQL >= 9",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "Идентификатор «%s» уже используется поставщиком услуг межсерверного обмена «%s»",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Не удалось предоставить общий доступ к «%1$s», пользователь %2$s не существует.",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Не удалось предоставить доступ к «%1$s» , так как пользователь %2$s не состоит в какой-либо группе, в которой состоит %3$s",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Не удалось предоставить общий доступ к «%1$s» , пользователю %2$s такой доступ уже предоставлен.",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не удалось предоставить доступ к «%1$s», так как этот ресурс уже доступен пользователю %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Не удалось предоставить доступ к «%1$s», группа %2$s не существует",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Не удалось предоставить доступ к «%1$s», пользователь %2$s не является участником группы %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
+    "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
+    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Не удалось предоставить доступ к «%1$s», не удалось найти %2$s, возможно, сервер не доступен.",
     "Share type %1$s is not valid for %2$s" : "Тип общего доступа «%1$s» недопустим для «%2$s»",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Невозможно установить дату истечения. Общие ресурсы не могут устареть позже %s с момента их публикации.",
+    "Cannot set expiration date. Expiration date is in the past" : "Невозможно установить дату окончания. Дата окончания в прошлом.",
+    "Sharing failed, because the user %s is the original sharer" : "Не удалось поделиться, потому что пользователь %s владелец этого элемента",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Не удалось предоставить доступ к «%1$s», прав %2$s недостаточно",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Не удалось предоставить доступ к «%1$s», механизм предоставления общего доступа не смог определить путь к «%2$s»"
+    "Sharing %s failed, because resharing is not allowed" : "Не удалось поделиться %s, повторное открытие доступа запрещено",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Не удалось предоставить доступ к «%1$s», механизм предоставления общего доступа не смог определить путь к «%2$s»",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
