@@ -10,6 +10,9 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s in %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s in %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s in %5$s",
+    "Enterprise bundle" : "Poslovni paket",
+    "Groupware bundle" : "Paket za skupinsko delo",
+    "Social sharing bundle" : "Paket družbene izmenjave",
     "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
     "PHP with a version lower than %s is required." : "Zahtevana je različica PHP manj kot %s.",
     "%sbit or higher PHP required." : "Zahtevana je različica PHP %s ali višja.",
@@ -19,26 +22,39 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Podprta so okolja: %s",
     "Server version %s or higher is required." : "Zahtevana je različica strežnika %s ali višja.",
     "Server version %s or lower is required." : "Zahtevana je različica strežnika %s ali nižja.",
+    "Authentication" : "Overitev",
     "Unknown filetype" : "Neznana vrsta datoteke",
     "Invalid image" : "Neveljavna slika",
+    "Avatar image is not square" : "Slika podobe ni kvadratna",
     "today" : "danes",
+    "tomorrow" : "jutri",
     "yesterday" : "včeraj",
+    "_in %n day_::_in %n days_" : ["čez %n dan","čez %n dneva","čez %n dni","čez %n dni"],
     "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
+    "next month" : "naslednji mesec",
     "last month" : "zadnji mesec",
+    "_in %n month_::_in %n months_" : ["čez %n mesec","čez %n meseca","čez %n mesece","čez %n mesecev"],
     "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
+    "next year" : "naslednje leto",
     "last year" : "lansko leto",
+    "_in %n year_::_in %n years_" : ["čez %n leto","čez %n leti","čez %n leta","čez %n let"],
     "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
+    "_in %n hour_::_in %n hours_" : ["čez %n uro","čez %n uri","čez %n ure","čez %n ur"],
     "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
+    "_in %n minute_::_in %n minutes_" : ["čez %n minuto","čez %n minuti","čez %n minute","čez %n minut"],
     "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
+    "in a few seconds" : "čez nekaj sekund",
     "seconds ago" : "pred nekaj sekundami",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z ID: %s ne obstaja. Omogočite ga med nastavitvami, ali pa stopite v stik s skrbnikom sistema.",
     "File name is a reserved word" : "Ime datoteke je zadržana beseda",
-    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
+    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
     "File name is too long" : "Ime datoteke je predolgo",
     "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
     "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programa \\\"%s\\\" ni mogoče namestiti, ker ni mogoče brati datoteke appinfo.",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programa »%s« ni mogoče namestiti, ker datoteke appinfo ni mogoče brati.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programa »%s« ni mogoče namestiti, ker ni združljiv z nameščeno različico strežnika.",
     "__language_name__" : "Slovenščina",
+    "This is an automatically sent email, please do not reply." : "To sporočilo je samodejno poslano, nanj se nima smisla odzvati.",
     "Help" : "Pomoč",
     "Apps" : "Programi",
     "Settings" : "Nastavitve",
@@ -49,8 +65,10 @@ OC.L10N.register(
     "Basic settings" : "Osnovne nastavitve",
     "Sharing" : "Souporaba",
     "Security" : "Varnost",
+    "Groupware" : "Skupinsko delo",
     "Additional settings" : "Dodatne nastavitve",
     "Personal info" : "Osebni podatki",
+    "Mobile & desktop" : "Mobilni in namizni dostop",
     "%s enter the database username and name." : "%s - vnos uporabniškega imena in imena podatkovne zbirke.",
     "%s enter the database username." : "%s - vnos uporabniškega imena podatkovne zbirke.",
     "%s enter the database name." : "%s - vnos imena podatkovne zbirke.",
@@ -148,6 +166,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
     "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
+    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
     "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
     "Check the value of \"datadirectory\" in your configuration" : "V konfiguraciji preverite nastavitev \"datadirectory\"",
@@ -157,32 +176,19 @@ OC.L10N.register(
     "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, višjo od %s – na voljo je različica %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, manjšo od %s – na voljo je različica %s.",
+    "Create" : "Ustvari",
+    "Change" : "Spremeni",
+    "Delete" : "Izbriši",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %i.",
     "Sharing %s failed, because the file does not exist" : "Souporaba %s je spodletela, ker ta datoteka ne obstaja",
     "Sharing %s failed, because you can not share with yourself" : "Nastavitev %s souporabe je spodletela, ker souporaba s samim seboj ni mogoča.",
-    "Sharing %s failed, because the user %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ne obstaja.",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član nobene skupine, v kateri je tudi uporabnik %s.",
-    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletela, ker je ima uporabnik %s predmet že v souporabi.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
-    "Sharing %s failed, because the group %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker je skupina %s ne obstaja.",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član skupine %s.",
     "You need to provide a password to create a public link, only protected links are allowed" : "Navesti je treba geslo za ustvarjanje javne povezave, saj so dovoljene le zaščitene.",
     "Sharing %s failed, because sharing with links is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker souporaba preko povezave ni dovoljena.",
     "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Omogočanje souporabe %s je spodletelo, ker ni mogoče najti %s. Najverjetneje je strežnik nedosegljiv.",
-    "Share type %s is not valid for %s" : "Vrsta souporabe %s za %s ni veljavna.",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ni mogoče določiti datuma preteka. Ni dovoljeno, da so mape ali datoteke, dodeljene v souporabo, v souporabi po %s.",
     "Cannot set expiration date. Expiration date is in the past" : "Ni mogoče nastaviti datuma preteka. Ta datum je že preteklost.",
     "Sharing failed, because the user %s is the original sharer" : "Nastavitev souporabe je spodletela, ker je uporabnik %s souporabo izvorno nastavil.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje souporabe %s je spodletelo, ker zahteve presegajo dodeljena dovoljenja za %s.",
     "Sharing %s failed, because resharing is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker nadaljnje omogočanje souporabe ni dovoljeno.",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Nastavljanje souporabe %s je spodletelo, ker ozadnji program %s ne upravlja z viri.",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja.",
-    "%s shared »%s« with you" : "%s je omogočil souporabo »%s«",
-    "%s via %s" : "%s prek %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Programa \"%s\" ni mogoče namestiti zaradi nerešenih odvisnosti: %s",
-    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9."
+    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
