@@ -9,7 +9,7 @@ OC.L10N.register(
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
     "Sample configuration detected" : "Exempel-konfiguration detekterad",
-    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har detekterats att exempel-konfigurationen har kopierats. Detta kan förstöra din installation och stöds ej. Vänligen läs dokumentationen innan ändringar på config.php utförs",
+    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Vänligen läs dokumentationen innan du utför ändringar på config.php",
     "%1$s and %2$s" : "%1$s och %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s och %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s och %4$s",
@@ -99,9 +99,9 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
     "You need to enter details of an existing account." : "Du måste ange inloggningsuppgifter av ett aktuellt konto.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
-    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux server istället.",
+    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir i din php.ini eller byt till 64-bitars PHP.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Vänligen ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
     "Set an admin username." : "Ange ett användarnamn för administratören.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
@@ -180,22 +180,22 @@ OC.L10N.register(
     "User disabled" : "Användare inaktiverad",
     "Login canceled by app" : "Inloggningen avbruten av appen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
-    "a safe home for all your data" : "En säker lagringsplats för all din data",
+    "a safe home for all your data" : "ett säkert hem för alla dina data",
     "File is currently busy, please try again later" : "Filen är för tillfället upptagen, vänligen försök igen senare",
     "Can't read file" : "Kan ej läsa filen",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
-    "Token expired. Please reload page." : "Ogiltig token. Ladda om sidan.",
+    "Token expired. Please reload page." : "Token har löpt ut. Vänligen uppdatera sidan.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
     "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
     "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Detta kan vanligtvis fixas genom att ge webbservern skrivåtkomst till mappen för appar eller genom att avaktivera App store i konfigurationsfilen. Se %s",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Detta kan vanligtvis lösas genom att ge webbservern skrivåtkomst till mappen för appar eller genom att inaktivera appbutiken i konfigurationsfilen. Se %s",
     "Cannot create \"data\" directory" : "Kan inte skapa \"datamapp\"",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Detta kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Rättigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
     "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
-    "Please install one of these locales on your system and restart your webserver." : "Vänligen installera en av dessa locale på din server och starta om din webbserver,",
-    "Please ask your server administrator to install the module." : "Vänligen be din administratör att installera modulen.",
+    "Please install one of these locales on your system and restart your webserver." : "Vänligen Installera en av dessa språk på ditt system och starta om webbservern.",
+    "Please ask your server administrator to install the module." : "Vänligen be serveradministratören att installera modulen.",
     "PHP module %s not installed." : "PHP-modulen %s är inte installerad.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
@@ -208,8 +208,8 @@ OC.L10N.register(
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
     "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webbservern.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
-    "Please upgrade your database version" : "Vänligen uppgradera din databas-version",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra rättigheterna till 0770 så att katalogen inte kan listas av andra användare.",
+    "Please upgrade your database version" : "Vänligen uppgradera din databasversion",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
     "Your data directory is readable by other users" : "Din datamapp är läsbar av andra användare",
     "Your data directory must be an absolute path" : "Du måste specificera en korrekt sökväg till datamappen",
     "Check the value of \"datadirectory\" in your configuration" : "Kontrollera värdet av \"datakatalog\" i din konfiguration",
