@@ -207,7 +207,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能由缓存/加速器导致的，例如 Zend OPcache 或 eAccelerator。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
     "Please ask your server administrator to restart the web server." : "请联系服务器管理员重启 Web 服务器。",
-    "PostgreSQL >= 9.5 required" : "要求 PostgreSQL >= 9.5",
+    "PostgreSQL >= 9 required" : "要求 PostgreSQL >= 9",
     "Please upgrade your database version" : "请升级您的数据库版本",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
     "Your data directory is readable by other users" : "您的数据目录可被其他用户读取",
@@ -226,8 +226,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "存储连接错误。%s",
     "Storage is temporarily not available" : "存储暂时不可用",
     "Storage connection timeout. %s" : "存储连接超时。%s",
-    "Library %s with a version higher than %s is required - available version %s." : "%s 需要 %s 或更高的版本 - 可用版本 %s。",
-    "Library %s with a version lower than %s is required - available version %s." : "%s 需要 %s 或更低的版本 - 可用版本 %s。",
     "Create" : "创建",
     "Change" : "修改",
     "Delete" : "删除",
@@ -239,39 +237,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "共享 %s 失败，因为后端不允许共享 %i 类型",
     "Sharing %s failed, because the file does not exist" : "共享 %s 失败，因为文件不存在",
     "Sharing %s failed, because you can not share with yourself" : "共享 %s 失败，因为您不能共享给自己",
-    "Sharing %s failed, because the user %s does not exist" : "共享 %s 失败，因为用户 %s 不存在",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "共享 %s 失败，因为用户 %s 不是 %s 所属的任何组的用户",
-    "Sharing %s failed, because this item is already shared with %s" : "共享 %s 失败，因为该项已经共享给用户 %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "共享 %s 失败，因为该项已经共享给用户 %s",
-    "Sharing %s failed, because the group %s does not exist" : "共享 %s 失败，因为 %s 分组不存在",
-    "Sharing %s failed, because %s is not a member of the group %s" : "共享 %s 失败，因为 %s 不是 %s 分组的成员",
-    "You need to provide a password to create a public link, only protected links are allowed" : "您需要提供密码以创建公开链接，因为只允许创建受保护的链接",
-    "Sharing %s failed, because sharing with links is not allowed" : "共享 %s 失败，因为不允许使用链接共享",
-    "Not allowed to create a federated share with the same user" : "不允许创建对相同用户的联合共享",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "共享 %s 失败，无法找到 %s，该服务当前无法连接。",
-    "Share type %s is not valid for %s" : "%s 不是 %s 的合法共享类型",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "无法设置过期时间。过期时间不能晚于其共享时间 %s",
-    "Cannot set expiration date. Expiration date is in the past" : "无法设置过期时间。过期时间不能为过去",
-    "Sharing failed, because the user %s is the original sharer" : "共享失败，因为用户 %s 是原始的共享者",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "共享 %s 失败，因为权限超过了 %s 的已有权限",
-    "Sharing %s failed, because resharing is not allowed" : "共享 %s 失败，因为不允许二次共享",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "共享 %s 失败，因为无法找到 %s 共享后端的来源",
-    "Sharing %s failed, because the file could not be found in the file cache" : "共享 %s 失败，因为文件缓存中找不到该文件",
-    "%s shared »%s« with you" : "%s 向您共享了 »%s«",
-    "%s shared »%s« with you." : "%s 已与您共享了 »%s«。",
-    "%s via %s" : "%s 通过 %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "应用程序 \"%s\" 无法被安装，因为为满足下列依赖关系：%s",
-    "PostgreSQL >= 9 required" : "要求 PostgreSQL >= 9",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" 已被云联合提供商 \"%s\" 使用",
     "Sharing %1$s failed, because the user %2$s does not exist" : "共享 %1$s 失败，因为 %2$s 用户不存在",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "共享 %1$s失败， 因为用户 %2$s 不是%3$s 所属的任何组的用户",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "共享 %1$s 失败，因为该项已经共享给 %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "共享 %1$s 失败， 因为该项已经共享给用户 %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "共享 %1$s 失败，因为 %2$s 分组不存在",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "共享 %1$s 失败，因为 %2$s 不是 %3$s 分组的成员",
+    "You need to provide a password to create a public link, only protected links are allowed" : "您需要提供密码以创建公开链接，因为只允许创建受保护的链接",
+    "Sharing %s failed, because sharing with links is not allowed" : "共享 %s 失败，因为不允许使用链接共享",
+    "Not allowed to create a federated share with the same user" : "不允许创建对相同用户的联合共享",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "共享 %1$s 失败，无法找到 %2$s，该服务当前无法连接。",
     "Share type %1$s is not valid for %2$s" : "%1$s 不是 %2$s 合法的共享类型",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "无法设置过期时间。过期时间不能晚于其共享时间 %s",
+    "Cannot set expiration date. Expiration date is in the past" : "无法设置过期时间。过期时间不能为过去",
+    "Sharing failed, because the user %s is the original sharer" : "共享失败，因为用户 %s 是原始的共享者",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "共享 %1$s 失败， 因为已经超出了 %2$s 的权限。",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "共享 %1$s失败，因为无法找到 %2$s 共享后端的来源"
+    "Sharing %s failed, because resharing is not allowed" : "共享 %s 失败，因为不允许二次共享",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "共享 %1$s失败，因为无法找到 %2$s 共享后端的来源",
+    "Sharing %s failed, because the file could not be found in the file cache" : "共享 %s 失败，因为文件缓存中找不到该文件"
 },
 "nplurals=1; plural=0;");
