@@ -29,6 +29,7 @@ namespace OC\Authentication\Token;
 use OC\Authentication\Exceptions\ExpiredTokenException;
 use OC\Authentication\Exceptions\InvalidTokenException;
 use OC\Authentication\Exceptions\PasswordlessTokenException;
+use OC\Authentication\Exceptions\WipeTokenException;
 
 interface IProvider {
 
@@ -44,6 +45,7 @@ interface IProvider {
 	 * @param int $type token type
 	 * @param int $remember whether the session token should be used for remember-me
 	 * @return IToken
+	 * @throws \RuntimeException when OpenSSL reports a problem
 	 */
 	public function generateToken(string $token,
 								  string $uid,
@@ -59,6 +61,7 @@ interface IProvider {
 	 * @param string $tokenId
 	 * @throws InvalidTokenException
 	 * @throws ExpiredTokenException
+	 * @throws WipeTokenException
 	 * @return IToken
 	 */
 	public function getToken(string $tokenId): IToken;
@@ -69,6 +72,7 @@ interface IProvider {
 	 * @param int $tokenId
 	 * @throws InvalidTokenException
 	 * @throws ExpiredTokenException
+	 * @throws WipeTokenException
 	 * @return IToken
 	 */
 	public function getTokenById(int $tokenId): IToken;
@@ -79,6 +83,7 @@ interface IProvider {
 	 * @param string $oldSessionId
 	 * @param string $sessionId
 	 * @throws InvalidTokenException
+	 * @throws \RuntimeException when OpenSSL reports a problem
 	 */
 	public function renewSessionToken(string $oldSessionId, string $sessionId);
 
@@ -155,6 +160,7 @@ interface IProvider {
 	 * @param string $oldTokenId
 	 * @param string $newTokenId
 	 * @return IToken
+	 * @throws \RuntimeException when OpenSSL reports a problem
 	 */
 	public function rotate(IToken $token, string $oldTokenId, string $newTokenId): IToken;
 
