@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
@@ -24,7 +25,9 @@
 namespace OC\Http\Client;
 
 use GuzzleHttp\Client as GuzzleClient;
+use GuzzleHttp\RequestOptions;
 use OCP\Http\Client\IClient;
+use OCP\Http\Client\IResponse;
 use OCP\ICertificateManager;
 use OCP\IConfig;
 
@@ -40,68 +43,72 @@ class Client implements IClient {
 	private $config;
 	/** @var ICertificateManager */
 	private $certificateManager;
-	private $configured = false;
 
 	/**
 	 * @param IConfig $config
 	 * @param ICertificateManager $certificateManager
 	 * @param GuzzleClient $client
 	 */
-	public function __construct(IConfig $config,
-								ICertificateManager $certificateManager,
-								GuzzleClient $client) {
+	public function __construct(
+		IConfig $config,
+		ICertificateManager $certificateManager,
+		GuzzleClient $client
+	) {
 		$this->config = $config;
 		$this->client = $client;
 		$this->certificateManager = $certificateManager;
 	}
 
-	/**
-	 * Sets the default options to the client
-	 */
-	private function setDefaultOptions() {
-		if ($this->configured) {
-			return;
-		}
-		$this->configured = true;
-		// Either use user bundle or the system bundle if nothing is specified
-		if ($this->certificateManager->listCertificates() !== []) {
-			$this->client->setDefaultOption('verify', $this->certificateManager->getAbsoluteBundlePath());
-		} else {
-			// If the instance is not yet setup we need to use the static path as
-			// $this->certificateManager->getAbsoluteBundlePath() tries to instantiiate
-			// a view
-			if ($this->config->getSystemValue('installed', false)) {
-				$this->client->setDefaultOption('verify', $this->certificateManager->getAbsoluteBundlePath(null));
-			} else {
-				$this->client->setDefaultOption('verify', \OC::$SERVERROOT . '/resources/config/ca-bundle.crt');
-			}
+	private function buildRequestOptions(array $options): array {
+		$defaults = [
+			RequestOptions::PROXY => $this->getProxyUri(),
+			RequestOptions::VERIFY => $this->getCertBundle(),
+			RequestOptions::TIMEOUT => 30,
+		];
+
+		$options = array_merge($defaults, $options);
+
+		if (!isset($options[RequestOptions::HEADERS]['User-Agent'])) {
+			$options[RequestOptions::HEADERS]['User-Agent'] = 'Nextcloud Server Crawler';
 		}
 
-		$this->client->setDefaultOption('headers/User-Agent', 'Nextcloud Server Crawler');
-		$proxyUri = $this->getProxyUri();
-		if ($proxyUri !== '') {
-			$this->client->setDefaultOption('proxy', $proxyUri);
+		return $options;
+	}
+
+	private function getCertBundle(): string {
+		if ($this->certificateManager->listCertificates() !== []) {
+			return $this->certificateManager->getAbsoluteBundlePath();
 		}
+
+		// If the instance is not yet setup we need to use the static path as
+		// $this->certificateManager->getAbsoluteBundlePath() tries to instantiiate
+		// a view
+		if ($this->config->getSystemValue('installed', false)) {
+			return $this->certificateManager->getAbsoluteBundlePath(null);
+		}
+
+		return \OC::$SERVERROOT . '/resources/config/ca-bundle.crt';
 	}
 
 	/**
 	 * Get the proxy URI
 	 *
-	 * @return string
+	 * @return string|null
 	 */
-	private function getProxyUri() {
-		$proxyHost = $this->config->getSystemValue('proxy', null);
-		$proxyUserPwd = $this->config->getSystemValue('proxyuserpwd', null);
-		$proxyUri = '';
+	private function getProxyUri(): ?string {
+		$proxyHost = $this->config->getSystemValue('proxy', '');
 
-		if ($proxyUserPwd !== null) {
-			$proxyUri .= $proxyUserPwd . '@';
-		}
-		if ($proxyHost !== null) {
-			$proxyUri .= $proxyHost;
+		if ($proxyHost === '' || $proxyHost === null) {
+			return null;
 		}
 
-		return $proxyUri;
+		$proxyUserPwd = $this->config->getSystemValue('proxyuserpwd', '');
+
+		if ($proxyUserPwd === '' || $proxyUserPwd === null) {
+			return $proxyHost;
+		}
+
+		return $proxyUserPwd . '@' . $proxyHost;
 	}
 
 	/**
@@ -130,12 +137,11 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function get($uri, array $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->get($uri, $options);
+	public function get(string $uri, array $options = []): IResponse {
+		$response = $this->client->request('get', $uri, $this->buildRequestOptions($options));
 		$isStream = isset($options['stream']) && $options['stream'];
 		return new Response($response, $isStream);
 	}
@@ -161,12 +167,11 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function head($uri, $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->head($uri, $options);
+	public function head(string $uri, array $options = []): IResponse {
+		$response = $this->client->request('head', $uri, $this->buildRequestOptions($options));
 		return new Response($response);
 	}
 
@@ -196,12 +201,15 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function post($uri, array $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->post($uri, $options);
+	public function post(string $uri, array $options = []): IResponse {
+		if (isset($options['body']) && is_array($options['body'])) {
+			$options['form_params'] = $options['body'];
+			unset($options['body']);
+		}
+		$response = $this->client->request('post', $uri, $this->buildRequestOptions($options));
 		return new Response($response);
 	}
 
@@ -231,12 +239,11 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function put($uri, array $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->put($uri, $options);
+	public function put(string $uri, array $options = []): IResponse {
+		$response = $this->client->request('put', $uri, $this->buildRequestOptions($options));
 		return new Response($response);
 	}
 
@@ -266,16 +273,14 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function delete($uri, array $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->delete($uri, $options);
+	public function delete(string $uri, array $options = []): IResponse {
+		$response = $this->client->request('delete', $uri, $this->buildRequestOptions($options));
 		return new Response($response);
 	}
 
-
 	/**
 	 * Sends a options request
 	 *
@@ -302,12 +307,11 @@ class Client implements IClient {
 	 *              'verify' => true, // bool or string to CA file
 	 *              'debug' => true,
 	 *              'timeout' => 5,
-	 * @return Response
+	 * @return IResponse
 	 * @throws \Exception If the request could not get completed
 	 */
-	public function options($uri, array $options = []) {
-		$this->setDefaultOptions();
-		$response = $this->client->options($uri, $options);
+	public function options(string $uri, array $options = []): IResponse {
+		$response = $this->client->request('options', $uri, $this->buildRequestOptions($options));
 		return new Response($response);
 	}
 }
