@@ -35,6 +35,7 @@ declare(strict_types=1);
 
 namespace OC;
 
+use function array_merge;
 use InterfaSys\LogNormalizer\Normalizer;
 
 use OC\Log\ExceptionSerializer;
@@ -42,7 +43,6 @@ use OCP\Log\IFileBased;
 use OCP\Log\IWriter;
 use OCP\ILogger;
 use OCP\Support\CrashReport\IRegistry;
-use OCP\Util;
 
 /**
  * logging utilities
@@ -214,12 +214,26 @@ class Log implements ILogger {
 		}
 		$message = strtr($message, $replace);
 
-		if ($level >= $minLevel) {
-			$this->writeLog($app, $message, $level);
-		}
+		try {
+			if ($level >= $minLevel) {
+				$this->writeLog($app, $message, $level);
 
-		if (!is_null($this->crashReporters)) {
-			$this->crashReporters->delegateBreadcrumb($message, 'log', $context);
+				if ($this->crashReporters !== null) {
+					$messageContext = array_merge(
+						$context,
+						[
+							'level' => $level
+						]
+					);
+					$this->crashReporters->delegateMessage($message, $messageContext);
+				}
+			} else {
+				if ($this->crashReporters !== null) {
+					$this->crashReporters->delegateBreadcrumb($message, 'log', $context);
+				}
+			}
+		} catch (\Throwable $e) {
+			// make sure we dont hard crash if logging fails
 		}
 	}
 
@@ -307,16 +321,20 @@ class Log implements ILogger {
 
 		array_walk($context, [$this->normalizer, 'format']);
 
-		if ($level >= $minLevel) {
-			if (!$this->logger instanceof IFileBased) {
-				$data = json_encode($data, JSON_PARTIAL_OUTPUT_ON_ERROR);
+		try {
+			if ($level >= $minLevel) {
+				if (!$this->logger instanceof IFileBased) {
+					$data = json_encode($data, JSON_PARTIAL_OUTPUT_ON_ERROR);
+				}
+				$this->writeLog($app, $data, $level);
 			}
-			$this->writeLog($app, $data, $level);
-		}
 
-		$context['level'] = $level;
-		if (!is_null($this->crashReporters)) {
-			$this->crashReporters->delegateReport($exception, $context);
+			$context['level'] = $level;
+			if (!is_null($this->crashReporters)) {
+				$this->crashReporters->delegateReport($exception, $context);
+			}
+		} catch (\Throwable $e) {
+			// make sure we dont hard crash if logging fails
 		}
 	}
 
