@@ -26,7 +26,7 @@ class OpenDocument extends Office {
 	/**
 	 * {@inheritDoc}
 	 */
-	public function getMimeType() {
+	public function getMimeType(): string {
 		return '/application\/vnd.oasis.opendocument.*/';
 	}
 }
