@@ -28,7 +28,7 @@ class PDF extends Bitmap {
 	/**
 	 * {@inheritDoc}
 	 */
-	public function getMimeType() {
+	public function getMimeType(): string {
 		return '/application\/pdf/';
 	}
 }
