@@ -23,8 +23,6 @@
 
 namespace OC\Repair\Owncloud;
 
-use OC\DB\Connection;
-use OC\DB\MDB2SchemaManager;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IConfig;
 use OCP\IDBConnection;
@@ -40,12 +38,14 @@ class SaveAccountsTableData implements IRepairStep {
 
 	const BATCH_SIZE = 75;
 
-	/** @var IDBConnection|Connection */
+	/** @var IDBConnection */
 	protected $db;
 
 	/** @var IConfig */
 	protected $config;
 
+	protected $hasForeignKeyOnPersistentLocks = false;
+
 	/**
 	 * @param IDBConnection $db
 	 * @param IConfig $config
@@ -79,6 +79,9 @@ class SaveAccountsTableData implements IRepairStep {
 		}
 
 		// Remove the table
+		if ($this->hasForeignKeyOnPersistentLocks) {
+			$this->db->dropTable('persistent_locks');
+		}
 		$this->db->dropTable('accounts');
 	}
 
@@ -86,18 +89,30 @@ class SaveAccountsTableData implements IRepairStep {
 	 * @return bool
 	 */
 	protected function shouldRun() {
-		// This is the equivalent of the new migration code that is used in 13+
-		$filterExpression = '/^' . preg_quote($this->config->getSystemValue('dbtableprefix', 'oc_')) . '/';
-		$this->db->getConfiguration()->setFilterSchemaAssetsExpression($filterExpression);
-		$schema = $this->db->getSchemaManager()->createSchema();
+		$schema = $this->db->createSchema();
+		$prefix = $this->config->getSystemValue('dbtableprefix', 'oc_');
 
-		$tableName = $this->config->getSystemValue('dbtableprefix', 'oc_') . 'accounts';
+		$tableName = $prefix . 'accounts';
 		if (!$schema->hasTable($tableName)) {
 			return false;
 		}
 
 		$table = $schema->getTable($tableName);
-		return $table->hasColumn('user_id');
+		if (!$table->hasColumn('user_id')) {
+			return false;
+		}
+
+		if ($schema->hasTable($prefix . 'persistent_locks')) {
+			$locksTable = $schema->getTable($prefix . 'persistent_locks');
+			$foreignKeys = $locksTable->getForeignKeys();
+			foreach ($foreignKeys as $foreignKey) {
+				if ($tableName === $foreignKey->getForeignTableName()) {
+					$this->hasForeignKeyOnPersistentLocks = true;
+				}
+			}
+		}
+
+		return true;
 	}
 
 	/**
