@@ -31,6 +31,7 @@ namespace OC\Setup;
 
 use OC\DB\MySqlTools;
 use OCP\IDBConnection;
+use OCP\ILogger;
 
 class MySQL extends AbstractDatabase {
 	public $dbprettyname = 'MySQL/MariaDB';
@@ -68,21 +69,23 @@ class MySQL extends AbstractDatabase {
 			$query = "CREATE DATABASE IF NOT EXISTS `$name` CHARACTER SET $characterSet COLLATE ${characterSet}_bin;";
 			$connection->executeUpdate($query);
 		} catch (\Exception $ex) {
-			$this->logger->error('Database creation failed: {error}', [
+			$this->logger->logException($ex, [
+				'message' => 'Database creation failed.',
+				'level' => ILogger::ERROR,
 				'app' => 'mysql.setup',
-				'error' => $ex->getMessage()
 			]);
 			return;
 		}
 
 		try {
 			//this query will fail if there aren't the right permissions, ignore the error
-			$query="GRANT ALL PRIVILEGES ON `$name` . * TO '$user'";
+			$query="GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE, EVENT, TRIGGER ON `$name` . * TO '$user'";
 			$connection->executeUpdate($query);
 		} catch (\Exception $ex) {
-			$this->logger->debug('Could not automatically grant privileges, this can be ignored if database user already had privileges: {error}', [
+			$this->logger->logException($ex, [
+				'message' => 'Could not automatically grant privileges, this can be ignored if database user already had privileges.',
+				'level' => ILogger::DEBUG,
 				'app' => 'mysql.setup',
-				'error' => $ex->getMessage()
 			]);
 		}
 	}
@@ -103,10 +106,11 @@ class MySQL extends AbstractDatabase {
 			$connection->executeUpdate($query);
 		}
 		catch (\Exception $ex){
-			$this->logger->error('Database User creation failed: {error}', [
-                                'app' => 'mysql.setup',
-                                'error' => $ex->getMessage()
-                        ]);
+			$this->logger->logException($ex, [
+				'message' => 'Database user creation failed.',
+				'level' => ILogger::ERROR,
+				'app' => 'mysql.setup',
+			]);
 		}
 	}
 
@@ -154,12 +158,13 @@ class MySQL extends AbstractDatabase {
 					} else {
 						break;
 					}
-				};
+				}
 			}
 		} catch (\Exception $ex) {
-			$this->logger->info('Can not create a new MySQL user, will continue with the provided user: {error}', [
+			$this->logger->logException($ex, [
+				'message' => 'Can not create a new MySQL user, will continue with the provided user.',
+				'level' => ILogger::INFO,
 				'app' => 'mysql.setup',
-				'error' => $ex->getMessage()
 			]);
 		}
 
