@@ -154,6 +154,10 @@ class PostgreSQL extends AbstractDatabase {
 			// create the user
 			$query = $connection->prepare("CREATE USER " . addslashes($this->dbUser) . " CREATEDB PASSWORD '" . addslashes($this->dbPassword) . "'");
 			$query->execute();
+			if ($this->databaseExists($connection)) {
+				$query = $connection->prepare('GRANT CONNECT ON DATABASE ' . addslashes($this->dbName) . ' TO '.addslashes($this->dbUser));
+				$query->execute();
+			}
 		} catch (DatabaseException $e) {
 			$this->logger->error('Error while trying to create database user');
 			$this->logger->logException($e);
