@@ -223,19 +223,6 @@ interface ICache {
 	 */
 	public function searchQuery(ISearchQuery $query);
 
-	/**
-	 * Search for files by tag of a given users.
-	 *
-	 * Note that every user can tag files differently.
-	 *
-	 * @param string|int $tag name or tag id
-	 * @param string $userId owner of the tags
-	 * @return ICacheEntry[] file data
-	 * @since 9.0.0
-	 * @deprecated 9.0.0 due to lack of pagination, not all backends might implement this
-	 */
-	public function searchByTag($tag, $userId);
-
 	/**
 	 * find a folder in the cache which has not been fully scanned
 	 *
