@@ -43,6 +43,7 @@ namespace OCP;
  * It provides the following hooks:
  *  - post_shared
  * @since 5.0.0
+ * @deprecated 17.0.0
  */
 class Share extends \OC\Share\Constants {
 
@@ -54,6 +55,7 @@ class Share extends \OC\Share\Constants {
 	 * @param string $owner Owner of the share
 	 * @return array Return list of items with file_target, permissions and expiration
 	 * @since 6.0.0 - parameter $owner was added in 8.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function getItemSharedWithUser($itemType, $itemSource, $user, $owner = null) {
 		return \OC\Share\Share::getItemSharedWithUser($itemType, $itemSource, $user, $owner);
@@ -68,10 +70,11 @@ class Share extends \OC\Share\Constants {
 	 * @param bool $includeCollections
 	 * @return array
 	 * @since 5.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function getItemSharedWithBySource($itemType, $itemSource, $format = self::FORMAT_NONE,
 		$parameters = null, $includeCollections = false) {
-		return \OC\Share\Share::getItemSharedWithBySource($itemType, $itemSource, $format, $parameters, $includeCollections);
+		// not used by any app - only here to not break apps syntax
 	}
 
 	/**
@@ -80,19 +83,10 @@ class Share extends \OC\Share\Constants {
 	 * @param bool $checkPasswordProtection
 	 * @return array|bool false will be returned in case the token is unknown or unauthorized
 	 * @since 5.0.0 - parameter $checkPasswordProtection was added in 7.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function getShareByToken($token, $checkPasswordProtection = true) {
-		return \OC\Share\Share::getShareByToken($token, $checkPasswordProtection);
-	}
-
-	/**
-	 * resolves reshares down to the last real share
-	 * @param array $linkItem
-	 * @return array file owner
-	 * @since 6.0.0
-	 */
-	public static function resolveReShare($linkItem) {
-		return \OC\Share\Share::resolveReShare($linkItem);
+		// not used by any app - only here to not break apps syntax
 	}
 
 
@@ -105,11 +99,12 @@ class Share extends \OC\Share\Constants {
 	 * @param bool $includeCollections
 	 * @return mixed Return depends on format
 	 * @since 5.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function getItemsShared($itemType, $format = self::FORMAT_NONE, $parameters = null,
 		$limit = -1, $includeCollections = false) {
 
-		return \OC\Share\Share::getItemsShared($itemType, $format, $parameters, $limit, $includeCollections);
+		// only used by AppVNCSafe app (https://github.com/vnc-biz/nextcloud-appvncsafe/issues/2) - only here to not break apps syntax
 	}
 
 	/**
@@ -121,6 +116,7 @@ class Share extends \OC\Share\Constants {
 	 * @param bool $includeCollections
 	 * @return mixed Return depends on format
 	 * @since 5.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function getItemShared($itemType, $itemSource, $format = self::FORMAT_NONE,
 	                                     $parameters = null, $includeCollections = false) {
@@ -136,8 +132,9 @@ class Share extends \OC\Share\Constants {
 	 * @param string $recipient with whom was the item shared
 	 * @param bool $status
 	 * @since 6.0.0 - parameter $originIsSource was added in 8.0.0
+	 * @deprecated 17.0.0
 	 */
 	public static function setSendMailStatus($itemType, $itemSource, $shareType, $recipient, $status) {
-		return \OC\Share\Share::setSendMailStatus($itemType, $itemSource, $shareType, $recipient, $status);
+		// not used by any app - only here to not break apps syntax
 	}
 }
