@@ -1,22 +1,27 @@
 <?php
 
+declare(strict_types=1);
+
 /**
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @copyright Copyright (c) 2016 Christoph Wurst <christoph@winzerhof-wurst.at>
  *
- * Two-factor backup codes
+ * @author Christoph Wurst <christoph@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
+ * @license GNU AGPL version 3 or any later version
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -51,7 +56,7 @@ class SecurityProvider implements IProvider {
 			throw new InvalidArgumentException();
 		}
 
-		$l = $this->l10n->get('core', $language);
+		$l = $this->l10n->get('settings', $language);
 
 		switch ($event->getSubject()) {
 			case 'twofactor_success':
@@ -76,6 +81,28 @@ class SecurityProvider implements IProvider {
 					$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/password.svg')));
 				}
 				break;
+			case 'remote_wipe_start':
+				$params = $event->getSubjectParameters();
+				$event->setParsedSubject($l->t('Remote wipe was started on %1$s', [
+					$params['name'],
+				]));
+				if ($this->activityManager->getRequirePNG()) {
+					$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/delete.png')));
+				} else {
+					$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/delete.svg')));
+				}
+				break;
+			case 'remote_wipe_finish':
+				$params = $event->getSubjectParameters();
+				$event->setParsedSubject($l->t('Remote wipe has finished on %1$s', [
+					$params['name'],
+				]));
+				if ($this->activityManager->getRequirePNG()) {
+					$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/delete.png')));
+				} else {
+					$event->setIcon($this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'actions/delete.svg')));
+				}
+				break;
 			default:
 				throw new InvalidArgumentException();
 		}
