@@ -1,6 +1,30 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
+    "Migration started …" : "بدأت عملية الترحيل …",
+    "Saved" : "حفظ",
+    "Not saved" : "لم يتم حفظه",
+    "Sending…" : "جارٍ الإرسال …",
+    "Email sent" : "تم ارسال البريد الالكتروني",
+    "Valid until {date}" : "صالح إلى غاية {date}",
+    "Delete" : "إلغاء",
+    "Local" : "المحلي",
+    "Private" : "خاص بك",
+    "Only visible to local users" : "ظاهر فقط للمستخدِمين المحليين",
+    "Only visible to you" : "ظاهر فقط بالنسبة لك",
+    "Contacts" : "جهات الإتصال",
+    "Public" : "عمومي",
+    "Verify" : "تحقق",
+    "Verifying …" : "عملية التحقق جارية …",
+    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
+    "Very weak password" : "كلمة السر ضعيفة جدا",
+    "Weak password" : "كلمة السر ضعيفة",
+    "Good password" : "كلمة السر جيدة",
+    "Strong password" : "كلمة السر قوية",
+    "Select a profile picture" : "اختر صورة الملف الشخصي ",
+    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
+    "Groups" : "مجموعات",
     "{actor} changed your password" : "{actor} قام بتغيير كلمتك السرية",
     "You changed your password" : "لقد قمت بتعديل كلمة مرورك",
     "Your password was reset by an administrator" : "قام أحد المدراء بإعادة تعيين كلمة مرورك",
@@ -11,9 +35,7 @@ OC.L10N.register(
     "Couldn't remove app." : "لم نتمكّن مِن حذف التطبيق.",
     "Couldn't update app." : "تعذر تحديث التطبيق.",
     "Wrong password" : "كلمة مرور خاطئة",
-    "Saved" : "حفظ",
     "No user supplied" : "لم يتم توفير مستخدم ",
-    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
     "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
     "Federated Cloud Sharing" : "المشاركة السحابية الموحّدة",
@@ -30,40 +52,22 @@ OC.L10N.register(
     "Set your password" : "قم بإدخال كلمتك السرية",
     "Go to %s" : "الإنتقال إلى %s",
     "Install Client" : "تنصيب العميل",
-    "Delete" : "إلغاء",
     "Unlimited" : "غير محدود",
-    "Verifying …" : "عملية التحقق جارية …",
-    "Verify" : "تحقق",
-    "Migration in progress. Please wait until the migration is finished" : "عملية الترحيل جارية. الرجاء الإنتظار حتى تكتمل العملية",
-    "Migration started …" : "بدأت عملية الترحيل …",
-    "Not saved" : "لم يتم حفظه",
-    "Sending…" : "جارٍ الإرسال …",
-    "Email sent" : "تم ارسال البريد الالكتروني",
-    "Local" : "المحلي",
-    "Private" : "خاص بك",
-    "Only visible to local users" : "ظاهر فقط للمستخدِمين المحليين",
-    "Only visible to you" : "ظاهر فقط بالنسبة لك",
-    "Contacts" : "جهات الإتصال",
-    "Public" : "عمومي",
-    "Very weak password" : "كلمة السر ضعيفة جدا",
-    "Weak password" : "كلمة السر ضعيفة",
-    "Good password" : "كلمة السر جيدة",
-    "Strong password" : "كلمة السر قوية",
-    "Select a profile picture" : "اختر صورة الملف الشخصي ",
-    "Week starts on {fdow}" : "بداية الأسبوع يوم {fdow}",
-    "Groups" : "مجموعات",
-    "Arabic (Algeria)" : "العربية (الجزائر)",
-    "Arabic (Morocco)" : "العربية (المغرب)",
-    "Arabic (Tunisia)" : "العربية (تونس)",
-    "Arabic" : "العربية",
-    "Chinese" : "الصينية",
-    "English" : "الإنجليزية",
-    "French (France)" : "الفرنسية (فرنسا)",
-    "French" : "الفرنسية",
-    "Japanese" : "اليابانية",
-    "Kabyle (Algeria)" : "القبائلية (الجزائر)",
-    "Kabyle" : "القبائلية",
     "Save changes" : "حفظ التعديلات",
+    "Official" : "رسمي",
+    "Remove" : "حذف",
+    "Disable" : "إيقاف",
+    "All" : "الكل",
+    "No results" : "دون أية نتيجة",
+    "View in store" : "العرض على المتجر",
+    "Visit website" : "زر الموقع",
+    "Report a bug" : "الإبلاغ عن عِلّة",
+    "User documentation" : "دليل المستخدم",
+    "Admin documentation" : "دليل المدير",
+    "Developer documentation" : "دليل المُطوّر",
+    "Results from other categories" : "نتائج عبر الفئات الأخرى",
+    "Enable all" : "تنشيط الكل",
+    "Enable" : "تفعيل",
     "Device settings" : "إعدادات الجهاز",
     "Allow filesystem access" : "السماح بالنفاذ إلى نظام الملفات",
     "Rename" : "تعديل الإسم",
@@ -88,20 +92,6 @@ OC.L10N.register(
     "Done" : "تم",
     "Copied!" : "تم نسخه !",
     "Copy" : "نسخ",
-    "Official" : "رسمي",
-    "Remove" : "حذف",
-    "Disable" : "إيقاف",
-    "All" : "الكل",
-    "No results" : "دون أية نتيجة",
-    "View in store" : "العرض على المتجر",
-    "Visit website" : "زر الموقع",
-    "Report a bug" : "الإبلاغ عن عِلّة",
-    "User documentation" : "دليل المستخدم",
-    "Admin documentation" : "دليل المدير",
-    "Developer documentation" : "دليل المُطوّر",
-    "Results from other categories" : "نتائج عبر الفئات الأخرى",
-    "Enable all" : "تنشيط الكل",
-    "Enable" : "تفعيل",
     "New password" : "كلمات سر جديدة",
     "Delete user" : "احذف المستخدم",
     "Welcome mail sent!" : "تم إرسال بريد الترحيب!",
@@ -202,6 +192,50 @@ OC.L10N.register(
     "Help translate" : "ساعد في الترجمه",
     "Current password" : "كلمات السر الحالية",
     "Change password" : "عدل كلمة السر",
+    "Arabic (Algeria)" : "العربية (الجزائر)",
+    "Arabic (Bahrain)" : "العربية (البحرين)",
+    "Arabic (Egypt)" : "العربية (مصر)",
+    "Arabic (Iraq)" : "العربية (العراق)",
+    "Arabic (Jordan)" : "العربية (الأردن)",
+    "Arabic (Kuwait)" : "العربية (الكويت)",
+    "Arabic (Lebanon)" : "العربية (لبنان)",
+    "Arabic (Libya)" : "العربية (ليبيا)",
+    "Arabic (Morocco)" : "العربية (المغرب)",
+    "Arabic (Oman)" : "العربية (عمان)",
+    "Arabic (Qatar)" : "العربية (قطر)",
+    "Arabic (Sudan)" : "العربية (السودان)",
+    "Arabic (Syria)" : "العربية (سوريا)",
+    "Arabic (Tunisia)" : "العربية (تونس)",
+    "Arabic (Yemen)" : "العربية (اليمن)",
+    "Arabic" : "العربية",
+    "Basque" : "الباسكية",
+    "Catalan" : "الكتالونية",
+    "Central Morocco Tamazight (Latin)" : "الأمازيغية لوسط المغرب (لاتينية)",
+    "Central Morocco Tamazight (Latin, Morocco)" : "الأمازيغية لوسط المغرب (لاتينية، المغرب)",
+    "Central Morocco Tamazight" : "الأمازيغية لوسط المغرب",
+    "Chinese" : "الصينية",
+    "Dutch" : "الهولندية",
+    "English" : "الإنجليزية",
+    "French (Benin)" : "الفرنسية (البنين)",
+    "French (Chad)" : "الفرنسية (تشاد)",
+    "French (France)" : "الفرنسية (فرنسا)",
+    "French (Mali)" : "الفرنسية (مالي)",
+    "French (Niger)" : "الفرنسية (النيجر)",
+    "French (Senegal)" : "الفرنسية (السنغال)",
+    "French" : "الفرنسية",
+    "German (Germany)" : "الألمانية (ألمانيا)",
+    "German" : "الألمانية",
+    "Hindi (India)" : "الهندية (الهند)",
+    "Hindi" : "الهندية",
+    "Indonesian" : "الأندونيسية",
+    "Italian (Italy)" : "الإيطالية (إيطاليا)",
+    "Japanese" : "اليابانية",
+    "Kabyle (Algeria)" : "القبائلية (الجزائر)",
+    "Kabyle" : "القبائلية",
+    "Persian" : "الفارسية",
+    "Spanish" : "الإسبانية",
+    "Tachelhit" : "تاشلحيت",
+    "Zulu" : "الزولو",
     "Follow us on Google+" : "تابعونا على Google+"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
