@@ -1,6 +1,30 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migración en cursu. Espera fasta que la migración fine, por favor.",
+    "Migration started …" : "Migración aniciada...",
+    "Saved" : "Guardóse",
+    "Not saved" : "Nun se guardó",
+    "Sending…" : "Unviando...",
+    "Email sent" : "Corréu-e unviáu",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Asocedió un fallu. Xubi un certificáu PEM con codificación ASCII, por favor.",
+    "Valid until {date}" : "Válidu fasta {date}",
+    "Delete" : "Desaniciar",
+    "Local" : "Llocal",
+    "Only visible to local users" : "Namái visible pa usuarios llocales",
+    "Only visible to you" : "Namái visible pa ti",
+    "Contacts" : "Contautos",
+    "Visible to local users and to trusted servers" : "Visible pa usuarios llocales y sirvidores d'enfotu",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando...",
+    "Unable to change password" : "Nun pue camudase la contraseña",
+    "Very weak password" : "Contraseña mui feble",
+    "Weak password" : "Contraseña feble",
+    "So-so password" : "Contraseña pasable",
+    "Good password" : "Contraseña bona",
+    "Strong password" : "Contraseña mui bona",
+    "Select a profile picture" : "Esbillar una imaxe de perfil",
+    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} camudó la to contraseña",
     "You changed your password" : "Camudesti la to contraseña",
     "Your password was reset by an administrator" : "La to contraseña reafitóla un alministrador",
@@ -14,9 +38,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
     "Couldn't update app." : "Nun pudo anovase l'aplicación.",
     "Wrong password" : "Contraseña incorreuta",
-    "Saved" : "Guardóse",
     "No user supplied" : "Nun s'apurrieron usuarios",
-    "Unable to change password" : "Nun pue camudase la contraseña",
     "Authentication error" : "Fallu d'autenticación",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Apurri una contraseña de recuperación d'alministrador, d'otramiente perderánse tolos datos d'usuariu.",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña y volvi tentalo.",
@@ -51,30 +73,23 @@ OC.L10N.register(
     "Set your password" : "Afita la to contraseña",
     "Go to %s" : "Dir a %s",
     "Install Client" : "Instalar veceru",
-    "Delete" : "Desaniciar",
     "Unlimited" : "Non llendáu",
-    "Verifying …" : "Verificando...",
-    "Verify" : "Verificar",
-    "Migration in progress. Please wait until the migration is finished" : "Migración en cursu. Espera fasta que la migración fine, por favor.",
-    "Migration started …" : "Migración aniciada...",
-    "Not saved" : "Nun se guardó",
-    "Sending…" : "Unviando...",
-    "Email sent" : "Corréu-e unviáu",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Asocedió un fallu. Xubi un certificáu PEM con codificación ASCII, por favor.",
-    "Valid until {date}" : "Válidu fasta {date}",
-    "Local" : "Llocal",
-    "Only visible to local users" : "Namái visible pa usuarios llocales",
-    "Only visible to you" : "Namái visible pa ti",
-    "Contacts" : "Contautos",
-    "Visible to local users and to trusted servers" : "Visible pa usuarios llocales y sirvidores d'enfotu",
-    "Very weak password" : "Contraseña mui feble",
-    "Weak password" : "Contraseña feble",
-    "So-so password" : "Contraseña pasable",
-    "Good password" : "Contraseña bona",
-    "Strong password" : "Contraseña mui bona",
-    "Select a profile picture" : "Esbillar una imaxe de perfil",
-    "Groups" : "Grupos",
     "Limit to groups" : "Llendar a grupos",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicaciones oficiales desendólquense dientro la comunidá. Ufren funcionalidá central y tán preparaes pal usu en producción.",
+    "Official" : "Oficial",
+    "Remove" : "Desaniciar",
+    "Disable" : "Desactivar",
+    "All" : "Toos",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Nun pue instalase esta aplicación porque nun se cumplen les dependencies de darréu:",
+    "View in store" : "Ver na tienda",
+    "Visit website" : "Visitar sitiu web",
+    "Report a bug" : "Informar un fallu",
+    "User documentation" : "Documentación d'usuariu",
+    "Developer documentation" : "Documentación de desendolcaores",
+    "No apps found for your version" : "Nun s'alcontraron anovamientos pa la to versión",
+    "Enable all" : "Habilitar too",
+    "Enable" : "Activar",
+    "The app will be downloaded from the app store" : "L'aplicación baxaráse dende la tienda d'aplicaciones",
     "Allow filesystem access" : "Permitir accesu al sistema de ficheros",
     "Revoke" : "Revocar",
     "Internet Explorer" : "Internet Explorer",
@@ -96,21 +111,6 @@ OC.L10N.register(
     "Done" : "Fecho",
     "Copied!" : "¡Copióse!",
     "Copy" : "Copiar",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicaciones oficiales desendólquense dientro la comunidá. Ufren funcionalidá central y tán preparaes pal usu en producción.",
-    "Official" : "Oficial",
-    "Remove" : "Desaniciar",
-    "Disable" : "Desactivar",
-    "All" : "Toos",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Nun pue instalase esta aplicación porque nun se cumplen les dependencies de darréu:",
-    "View in store" : "Ver na tienda",
-    "Visit website" : "Visitar sitiu web",
-    "Report a bug" : "Informar un fallu",
-    "User documentation" : "Documentación d'usuariu",
-    "Developer documentation" : "Documentación de desendolcaores",
-    "No apps found for your version" : "Nun s'alcontraron anovamientos pa la to versión",
-    "Enable all" : "Habilitar too",
-    "Enable" : "Activar",
-    "The app will be downloaded from the app store" : "L'aplicación baxaráse dende la tienda d'aplicaciones",
     "New password" : "Contraseña nueva",
     "{size} used" : "{size} usaos",
     "Email" : "Corréu-e",
@@ -157,7 +157,6 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Username" : "Nome d'usuariu SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Store credentials" : "Atroxar credenciales",
     "Test email settings" : "Probar configuración de corréu electrónicu",
     "Send email" : "Unviar mensaxe",
     "Security & setup warnings" : "Alvertancies de seguranza y configuración",
@@ -216,6 +215,7 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Help translate" : "Ayúdanos nes traducciones",
     "Current password" : "Contraseña actual",
-    "Change password" : "Camudar contraseña"
+    "Change password" : "Camudar contraseña",
+    "Store credentials" : "Atroxar credenciales"
 },
 "nplurals=2; plural=(n != 1);");
