@@ -1,6 +1,25 @@
 OC.L10N.register(
     "settings",
     {
+    "Saved" : "Запаметяване",
+    "Email sent" : "Имейлът е изпратен",
+    "Valid until {date}" : "Далидна до {date}",
+    "Delete" : "Изтриване",
+    "Local" : "Локално",
+    "Only visible to local users" : "Видима само за локални потребители",
+    "Only visible to you" : "Видима само за вас",
+    "Contacts" : "Контакти",
+    "Visible to local users and to trusted servers" : "Видима за локални потребители и от доверени сървъри",
+    "Public" : "Публичен",
+    "Unable to change password" : "Неуспешна смяна на паролата.",
+    "Very weak password" : "Много проста парола",
+    "Weak password" : "Проста парола",
+    "So-so password" : "Не особено добра парола",
+    "Good password" : "Добра парола",
+    "Strong password" : "Сложна парола",
+    "Select a profile picture" : "Избор на снимка за профила",
+    "Week starts on {fdow}" : "Първи ден от седмицата е {fdow}",
+    "Groups" : "Групи",
     "{actor} changed your password" : "{actor} промени паролата ви",
     "You changed your password" : "Променихте паролата си",
     "Your password was reset by an administrator" : "Паролата ви е променена от администратора",
@@ -12,9 +31,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Приложението не бе премахнато.",
     "Couldn't update app." : "Приложението не бе актуализирано.",
     "Wrong password" : "Грешна парола",
-    "Saved" : "Запаметяване",
     "No user supplied" : "Липсва потребител",
-    "Unable to change password" : "Неуспешна смяна на паролата.",
     "Authentication error" : "Възникна проблем с удостоверяването",
     "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
     "Invalid SMTP password." : "Невалидна SMTP парола.",
@@ -33,54 +50,9 @@ OC.L10N.register(
     "Welcome aboard %s" : "Добре дошли %s",
     "Your username is: %s" : "Потребителско име: %s",
     "Set your password" : "Задайте парола",
-    "Email sent" : "Имейлът е изпратен",
-    "Valid until {date}" : "Далидна до {date}",
-    "Delete" : "Изтриване",
-    "Local" : "Локално",
-    "Only visible to local users" : "Видима само за локални потребители",
-    "Only visible to you" : "Видима само за вас",
-    "Contacts" : "Контакти",
-    "Visible to local users and to trusted servers" : "Видима за локални потребители и от доверени сървъри",
-    "Public" : "Публичен",
-    "Very weak password" : "Много проста парола",
-    "Weak password" : "Проста парола",
-    "So-so password" : "Не особено добра парола",
-    "Good password" : "Добра парола",
-    "Strong password" : "Сложна парола",
-    "Select a profile picture" : "Избор на снимка за профила",
-    "Week starts on {fdow}" : "Първи ден от седмицата е {fdow}",
-    "Groups" : "Групи",
-    "Afrikaans" : "африкаанс (бурски)",
-    "Armenian" : "арменски",
-    "English" : "английски",
-    "Hungarian" : "унгарски",
-    "Japanese" : "японски",
+    "Unlimited" : "Неограничено",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Ползването на двустепенното удостоверяване може да бъде наложено на всички\tпотребители или определени групи. Ако потребител не е настроил втората стъпка - няма да може да се впише.",
     "Limit to groups" : "Ограничен достъп",
-    "Device settings" : "Настройки за устройството",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome за Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Allow filesystem access" : "Разрешен достъп до файловете",
-    "Revoke" : "Отнемане",
-    "This session" : "Текущата сесия",
-    "Device" : "Устройство",
-    "Last activity" : "Последна активност",
-    "Devices & sessions" : "Устройства и сесии",
-    "Web, desktop and mobile clients currently logged in to your account." : "Уеб, настолни и мобилни клиенти, които в момента са вписани чрез вашия акаунт.",
-    "App name" : "Име на приложението",
-    "Create new app password" : "Създай парола за приложението",
-    "Use the credentials below to configure your app or device." : "Ползвайте данните по-долу за да настроите вашето приложение или устройство.",
-    "Username" : "Потребител",
-    "Password" : "Парола",
-    "Done" : "Готово",
-    "Copied!" : "Копирано!",
-    "Copy" : "Копиране",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Официалните приложения са разработени от общността. ",
     "Official" : "Официално",
     "Update to {version}" : "Актуализирай до {version}",
@@ -100,6 +72,30 @@ OC.L10N.register(
     "Enable untested app" : "Включване (нетествано приложение)",
     "The app will be downloaded from the app store" : "Приложението ще бъде свалено от магазина за приложения.",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Приложението не е маркирано като съвместимо с вашата версия на Nextcloud. Можете да инсталирате приложението, но е вероятно да не работи безпроблемно.",
+    "Device settings" : "Настройки за устройството",
+    "Allow filesystem access" : "Разрешен достъп до файловете",
+    "Revoke" : "Отнемане",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome за Android",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "This session" : "Текущата сесия",
+    "Device" : "Устройство",
+    "Last activity" : "Последна активност",
+    "Devices & sessions" : "Устройства и сесии",
+    "Web, desktop and mobile clients currently logged in to your account." : "Уеб, настолни и мобилни клиенти, които в момента са вписани чрез вашия акаунт.",
+    "App name" : "Име на приложението",
+    "Create new app password" : "Създай парола за приложението",
+    "Use the credentials below to configure your app or device." : "Ползвайте данните по-долу за да настроите вашето приложение или устройство.",
+    "Username" : "Потребител",
+    "Password" : "Парола",
+    "Done" : "Готово",
+    "Copied!" : "Копирано!",
+    "Copy" : "Копиране",
     "New password" : "Нова парола",
     "Add user in group" : "Добавяне към група",
     "Delete user" : "Изтриване",
@@ -114,7 +110,6 @@ OC.L10N.register(
     "Last login" : "Последно вписване",
     "Default language" : "Стандартен език",
     "Add a new user" : "Добавяне на новия потребител",
-    "Unlimited" : "Неограничено",
     "Default quota" : "Стандартна квота",
     "All languages" : "Всички езици",
     "Your apps" : "Вашите приложения",
@@ -158,7 +153,6 @@ OC.L10N.register(
     "Credentials" : "Потребител и парола",
     "SMTP Username" : "SMTP потребител",
     "SMTP Password" : "SMTP парола",
-    "Store credentials" : "Запиши",
     "Test email settings" : "Проверка на имейл настройките",
     "Send email" : "Изпрати имейл",
     "Security & setup warnings" : "Предупреждения за сигурността и настройките",
@@ -176,8 +170,6 @@ OC.L10N.register(
     "Last job ran %s." : "За последно cron задача е стартирала %s.",
     "Last job execution ran %s. Something seems wrong." : "За последно cron задача е стартирала %s. Изглежда, че има проблем.",
     "Execute one task with each page loaded" : "Изпълнява една задача с всяка заредена страница.",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Услугата webcron стартира cron.php всеки 15 минути по HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Ползва услугата cron на сървъра за да стартира cron.php всеки 15 минути.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Необходимо е cron.php да се стартира от системния потребител \"%s\".",
     "Sharing" : "Споделяне",
     "Allow apps to use the Share API" : "Разреши приложенията да използват Share API",
@@ -223,14 +215,17 @@ OC.L10N.register(
     "Current password" : "Текуща парола",
     "Change password" : "Промени паролата",
     "Use a second factor besides your password to increase security for your account." : "Ползвайте двустепенно удостоверяване за да повишите сигурността на профила си.",
-    "iPhone iOS" : "iPhone iOS",
-    "iPad iOS" : "iPad iOS",
-    "iOS Client" : "iOS клиент",
-    "Android Client" : "Android клиент",
     "Not supported!" : "Не се поддържа!",
     "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
     "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
-    "Follow us on Google+" : "Следвайте ни в Google+",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Ползвате <strong>%s</strong> от <strong>%s</strong> (<strong>%s %%</strong>)"
+    "Afrikaans" : "африкаанс (бурски)",
+    "Armenian" : "арменски",
+    "English" : "английски",
+    "Hungarian" : "унгарски",
+    "Japanese" : "японски",
+    "Store credentials" : "Запиши",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Услугата webcron стартира cron.php всеки 15 минути по HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Ползва услугата cron на сървъра за да стартира cron.php всеки 15 минути.",
+    "Follow us on Google+" : "Следвайте ни в Google+"
 },
 "nplurals=2; plural=(n != 1);");
