@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migrace probíhá. Počkejte než bude dokončena",
+    "Migration started …" : "Migrace spuštěna…",
+    "Saved" : "Uloženo",
+    "Not saved" : "Neuloženo",
+    "Sending…" : "Odesílání…",
+    "Email sent" : "Email odeslán",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Došlo k chybě. Nahrajte ASCII-kódovaný PEM certifikát.",
+    "Valid until {date}" : "Platný do {date}",
+    "Delete" : "Smazat",
+    "Local" : "Místní",
+    "Private" : "Soukromý",
+    "Only visible to local users" : "Viditelný pouze pro místní uživatele",
+    "Only visible to you" : "Viditelný pouze pro vás",
+    "Contacts" : "Kontakty",
+    "Visible to local users and to trusted servers" : "Viditelné pro místní uživatele a důvěryhodné servery",
+    "Public" : "Veřejný",
+    "Will be synced to a global and public address book" : "Bude synchronizováno do globálního a veřejného adresáře",
+    "Verify" : "Ověřit",
+    "Verifying …" : "Ověřování…",
+    "Unable to change password" : "Změna hesla se nezdařila",
+    "Very weak password" : "Velmi slabé heslo",
+    "Weak password" : "Slabé heslo",
+    "So-so password" : "Středně silné heslo",
+    "Good password" : "Dobré heslo",
+    "Strong password" : "Odolné heslo",
+    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
+    "Select a profile picture" : "Vyberte profilový obrázek",
+    "Week starts on {fdow}" : "Týden začíná v {fdow}",
+    "Groups" : "Skupiny",
+    "Group list is empty" : "Seznam skupin je prázdný.",
+    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
     "{actor} added you to group {group}" : "{actor} vás přidal(a) do skupiny {group}",
     "You added {user} to group {group}" : "Přidali jste {user} do skupiny {group}",
     "{actor} added {user} to group {group}" : "{actor} přidal(a) {user} do skupiny {group}",
@@ -26,13 +58,13 @@ OC.L10N.register(
     "Security" : "Zabezpečení",
     "You successfully logged in using two-factor authentication (%1$s)" : "Úspěšně jste se přihlásili pomocí dvoufázového ověření (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o přihlášení s použitím dvoufázové autentizace se nezdařil (%1$s)",
+    "Remote wipe was started on %1$s" : "Vzdálené vymazání přístroje spuštěno pro %1$s",
+    "Remote wipe has finished on %1$s" : "Vzdálené vymazání přístroje dokončeno pro %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> nebo <strong>email</strong> bylo změněno",
     "Couldn't remove app." : "Nepodařilo se odebrat aplikaci.",
     "Couldn't update app." : "Nelze aktualizovat aplikaci.",
     "Wrong password" : "Nesprávné heslo",
-    "Saved" : "Uloženo",
     "No user supplied" : "Nebyl uveden uživatel",
-    "Unable to change password" : "Změna hesla se nezdařila",
     "Authentication error" : "Chyba přihlášení",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Zadejte správcovské heslo pro obnovu, jinak budou všechna uživatelská data ztracena.",
     "Wrong admin recovery password. Please check the password and try again." : "Chybné správcovské heslo pro obnovu. Překontrolujte správnost hesla a zkuste to znovu.",
@@ -75,176 +107,10 @@ OC.L10N.register(
     "Logged in user must be a subadmin" : "Je třeba, aby přihlášený uživatel byl dílčím správcem",
     "Create" : "Vytvořit",
     "Change" : "Změnit",
-    "Delete" : "Smazat",
     "Share" : "Sdílet",
     "Unlimited" : "Neomezeně",
     "Verifying" : "Ověřuje se",
-    "Verifying …" : "Ověřování…",
-    "Verify" : "Ověřit",
-    "Migration in progress. Please wait until the migration is finished" : "Migrace probíhá. Počkejte než bude dokončena",
-    "Migration started …" : "Migrace spuštěna…",
-    "Not saved" : "Neuloženo",
-    "Sending…" : "Odesílání…",
-    "Email sent" : "Email odeslán",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Došlo k chybě. Nahrajte ASCII-kódovaný PEM certifikát.",
-    "Valid until {date}" : "Platný do {date}",
-    "Local" : "Místní",
-    "Private" : "Soukromý",
-    "Only visible to local users" : "Viditelný pouze pro místní uživatele",
-    "Only visible to you" : "Viditelný pouze pro vás",
-    "Contacts" : "Kontakty",
-    "Visible to local users and to trusted servers" : "Viditelné pro místní uživatele a důvěryhodné servery",
-    "Public" : "Veřejný",
-    "Will be synced to a global and public address book" : "Bude synchronizováno do globálního a veřejného adresáře",
-    "Very weak password" : "Velmi slabé heslo",
-    "Weak password" : "Slabé heslo",
-    "So-so password" : "Středně silné heslo",
-    "Good password" : "Dobré heslo",
-    "Strong password" : "Odolné heslo",
-    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
-    "Select a profile picture" : "Vyberte profilový obrázek",
-    "Week starts on {fdow}" : "Týden začíná v {fdow}",
-    "Groups" : "Skupiny",
-    "Group list is empty" : "Seznam skupin je prázdný.",
-    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
-    "Afrikaans (South Africa)" : "afrikánština (Jihoafrická republika)",
-    "Afrikaans" : "Afrikánština",
-    "Albanian (Albania)" : "albánština (Albánie)",
-    "Albanian" : "Albánština",
-    "Arabic (Algeria)" : "arabština (Alžír)",
-    "Arabic (Egypt)" : "Arabština (Egypt)",
-    "Arabic (Iraq)" : "Arabština (Irák)",
-    "Arabic (Jordan)" : "Arabština (Jordán)",
-    "Arabic (Kuwait)" : "Arabština (Kuvajt)",
-    "Arabic (Lebanon)" : "Arabština (Libanon)",
-    "Arabic (Libya)" : "Arabština (Libye)",
-    "Arabic (Qatar)" : "arabština (Katar)",
-    "Arabic" : "arabština",
-    "Armenian" : "arménština",
-    "Assamese" : "Ásámština",
-    "Basque" : "baskičtina",
-    "Belarusian" : "Běloruština",
-    "Bulgarian (Bulgaria)" : "bulharština (Bulharsko)",
-    "Bulgarian" : "bulharština",
-    "Catalan (Spain)" : "katalánština (Španělsko)",
-    "Catalan" : "Katalánština",
-    "Chinese" : "Čínština",
-    "Croatian (Croatia)" : "Chorvatština (Chorvatsko)",
-    "Croatian" : "chorvatština",
-    "Czech (Czech Republic)" : "Čeština (Česko)",
-    "Czech" : "Čeština",
-    "Danish" : "Dánština",
-    "Embu" : "Embu",
-    "English (Australia)" : "angličtina (Austrálie)",
-    "English (Canada)" : "angličtina (Kanada)",
-    "English (India)" : "angličtina (Indie)",
-    "English (Ireland)" : "angličtina (Irsko)",
-    "English (Jamaica)" : "angličtina (Jamajka)",
-    "English (Malta)" : "angličtina (Malta)",
-    "English (Mauritius)" : "Angličtina (Maurícius)",
-    "English (New Zealand)" : "angličtina (Nový Zéland)",
-    "English (Philippines)" : "angličtina (Filipíny)",
-    "English (South Africa)" : "Angličtina (Jihoafrická republika)",
-    "English (United Kingdom)" : "Angličtina (Spojené království)",
-    "English (United States)" : "angličtina (Spojené Státy)",
-    "English" : "Angličtina",
-    "Esperanto" : "Esperanto",
-    "Estonian (Estonia)" : "estonština (Estonsko)",
-    "Estonian" : "Estonština",
-    "Finnish (Finland)" : "Finština (Finsko)",
-    "Finnish" : "Finština",
-    "French (Belgium)" : "francouzština (Belgie)",
-    "French (Burkina Faso)" : "Francouzština (Burkina Faso)",
-    "French (Canada)" : "Francouzština (Kanada)",
-    "French (France)" : "francouzština (Francie)",
-    "French (Mali)" : "francouzština (Mali)",
-    "French (Rwanda)" : "francouzština (Rwanda)",
-    "French (Senegal)" : "francouzština (Senegal)",
-    "French (Switzerland)" : "francouzština (Švýcarsko)",
-    "French" : "Francouzština",
-    "Galician" : "galicijština",
-    "Georgian" : "gruzínština",
-    "German (Austria)" : "němčina (Rakousko)",
-    "German (Belgium)" : "němčina (Belgie)",
-    "German (Germany)" : "němčina (Německo)",
-    "German (Luxembourg)" : "němčina (Lucembursko)",
-    "German (Switzerland)" : "němčina (Švýcarsko)",
-    "German" : "Němčina",
-    "Greek (Cyprus)" : "řečtina (Kypr)",
-    "Greek (Greece)" : "řečtina (Řecko)",
-    "Greek" : "Řečtina",
-    "Hausa" : "hauština",
-    "Hawaiian" : "havajština",
-    "Hebrew (Israel)" : "hebrejština (Izrael)",
-    "Hebrew" : "Hebrejština",
-    "Hungarian (Hungary)" : "Maďarština (Maďarsko)",
-    "Hungarian" : "Maďarština",
-    "Icelandic" : "Islandština",
-    "Irish (Ireland)" : "irština (Irsko)",
-    "Irish" : "Irština",
-    "Italian (Italy)" : "italština (Itálie)",
-    "Italian" : "Italština",
-    "Japanese (Japan)" : "japonština (Japonsko)",
-    "Japanese" : "Japonština",
-    "Kalaallisut" : "grónština",
-    "Kannada" : "kannadština",
-    "Kinyarwanda" : "rwandština",
-    "Korean (South Korea)" : "Korejština (Severní Korea)",
-    "Korean" : "korejština",
-    "Latvian (Latvia)" : "lotyština (Lotyšsko)",
-    "Latvian" : "Lotyština",
-    "Lithuanian (Lithuania)" : "litevština (Litva)",
-    "Lithuanian" : "Litevština",
-    "Macedonian (Macedonia)" : "makedonština (Makedonie)",
-    "Macedonian" : "makedonština",
-    "Malayalam" : "malajálamština",
-    "Nepali" : "nepálština",
-    "Norwegian Bokmål" : "Norština (Bokmål)",
-    "Persian (Iran)" : "perština (Írán)",
-    "Persian" : "perština",
-    "Polish (Poland)" : "polština (Polsko)",
-    "Polish" : "Polština",
-    "Portuguese (Brazil)" : "portugalština (Brazílie)",
-    "Portuguese (Portugal)" : "portugalština (Portugalsko)",
-    "Portuguese" : "Portugalština",
-    "Romanian (Moldova)" : "rumunština (Moldávie)",
-    "Romanian" : "Rumunština",
-    "Russian (Russia)" : "ruština (Rusko)",
-    "Russian (Ukraine)" : "ruština (Ukrajina)",
-    "Russian" : "Ruština",
-    "Serbian" : "Srbština",
-    "Slovak (Slovakia)" : "slovenština (Slovensko)",
-    "Slovak" : "Slovenština",
-    "Slovenian (Slovenia)" : "slovinština (Slovensko)",
-    "Slovenian" : "Slovinština",
-    "Somali (Djibouti)" : "somálština (Džibutsko)",
-    "Spanish (Argentina)" : "španělština (Argentina)",
-    "Spanish (Colombia)" : "španělština (Kolumbie)",
-    "Spanish (Ecuador)" : "španělština (Ekvádor)",
-    "Spanish (Latin America)" : "španělština (latinská Amerika)",
-    "Spanish (Mexico)" : "španělština (Mexiko)",
-    "Spanish (Panama)" : "španělština (Panama)",
-    "Spanish (Peru)" : "španělština (Peru)",
-    "Spanish (United States)" : "španělština (Spojené Státy)",
-    "Spanish" : "Španělština",
-    "Swahili" : "Svahilština",
-    "Swedish (Finland)" : "švédština (Finsko)",
-    "Swedish (Sweden)" : "švédština (Švédsko)",
-    "Swedish" : "Švédština",
-    "Swiss German (Switzerland)" : "švýcarská němčina (Švýcarsko)",
-    "Swiss German" : "Švýcarská němčina",
-    "Thai" : "Thajština",
-    "Tibetan (India)" : "tibetština (Indie)",
-    "Tibetan" : "tibetština",
-    "Turkish (Turkey)" : "turečtina (Turecko)",
-    "Turkish" : "Turečtina",
-    "Ukrainian (Ukraine)" : "ukrajinština (Ukrajina)",
-    "Ukrainian" : "Ukrajinština",
-    "Uzbek" : "Uzbečtina",
-    "Vietnamese" : "Vietnamština",
-    "Welsh" : "Velština",
-    "Zulu" : "zuluština",
+    "Nextcloud settings" : "Nextcloud nastavení",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvoufázové ověřování je možné vynutit pro všechny\tuživatele a konkrétní skupiny. Pokud nemají nastaveného poskytovatele dvoufázového ověřování, nebudou se moci přihlásit do systému.",
     "Enforce two-factor authentication" : "Vynutit dvoufázové ověřování",
     "Limit to groups" : "Omezit na skupiny",
@@ -255,47 +121,6 @@ OC.L10N.register(
     "Excluded groups" : "Vynechané skupiny",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Když jsou skupiny vybrány/vynechány, je pro zjišťování zda je uživateli vynuceno dvoufázové (2FA) ověřování použita následující logika: Pokud nejsou vybrány žádné skupiny, je 2FA zapnuto pro všechny kromě členů vynechaných skupin. Pokud jsou nějaké skupiny vybrány, je 2FA zapnuto pro všechny jejich členy. Pokud je uživatel členem jak vybrané, tak vynechané skupiny, pak má ta vybraná přednost a 2FA je vynuceno.",
     "Save changes" : "Uložit změny",
-    "Marked for remote wipe" : "Označeno k vymazání na dálku",
-    "Device settings" : "Nastavení zařízení",
-    "Allow filesystem access" : "Umožnit přístup k souborovému systému",
-    "Rename" : "Přejmenovat",
-    "Revoke" : "Odvolat",
-    "Wipe device" : "Vymazat zařízení",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome pro Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Aplikace Nextcloud pro iOS",
-    "Nextcloud Android app" : "Aplikace Nextcloud pro Android",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk pro iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk pro Android",
-    "Sync client - {os}" : "Synchronizační klient – {os}",
-    "This session" : "Toto sezení",
-    "Device" : "Přístroj",
-    "Last activity" : "Poslední aktivita",
-    "Devices & sessions" : "Zařízení a sezení",
-    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví a mobilní klienti aktuálně přihlášení k vašemu účtu.",
-    "Do you really want to wipe your data from this device?" : "Opravdu chcete vymazat svá data z tohoto zařízení?",
-    "Confirm wipe" : "Potvrdit vymazání",
-    "Error while creating device token" : "Chyba při vytváření tokenů přístroje",
-    "Error while updating device token scope" : "Chyba při aktualizaci rozsahu tokenu zařízení",
-    "Error while updating device token name" : "Chyba při aktualizaci názvu tokenu zařízení",
-    "Error while deleting the token" : "Chyba při mazání tokenu",
-    "App name" : "Název aplikace",
-    "Create new app password" : "Vytvořit nové heslo aplikace",
-    "Use the credentials below to configure your app or device." : "Pro nastavení aplikace nebo zařízení použijte níže uvedené údaje.",
-    "For security reasons this password will only be shown once." : "Toto heslo bude z bezpečnostních důvodů zobrazeno pouze jedenkrát.",
-    "Username" : "Uživatelské jméno",
-    "Password" : "Heslo",
-    "Done" : "Dokončeno",
-    "Show QR code for mobile apps" : "Zobrazit QR kód pro mobilní aplikace",
-    "Copied!" : "Zkopírováno!",
-    "Copy" : "Zkopírovat",
-    "Could not copy app password. Please copy it manually." : "Nedaří se zkopírovat heslo pro aplikaci. Zkopírujte ho ručně.",
     "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného Nextcloud.",
     "Supported" : "Podporováno",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Oficiální aplikace jsou vyvíjeny komunitou. Poskytují klíčové funkce a jsou připravené na produkční nasazení.",
@@ -326,6 +151,49 @@ OC.L10N.register(
     "Enable untested app" : "Zapnout nevyzkoušenou aplikaci",
     "The app will be downloaded from the app store" : "Aplikace bude stažena z obchodu aplikací",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tato aplikace není označena jako kompatibilní s vámi používanou verzí Nexcloud. Pokud budete pokračovat, pořád budete moci aplikaci nainstalovat. Uvědomte si ale, že aplikace nemusí fungovat, jak je očekáváno.",
+    "Marked for remote wipe" : "Označeno k vymazání na dálku",
+    "Device settings" : "Nastavení zařízení",
+    "Allow filesystem access" : "Umožnit přístup k souborovému systému",
+    "Rename" : "Přejmenovat",
+    "Revoke" : "Odvolat",
+    "Wipe device" : "Vymazat zařízení",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Odstranění tohoto tokenu může zabránit vymazání přístroje, pokud nebyl proces vymazání do teď zahájen.",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome pro Android",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Aplikace Nextcloud pro iOS",
+    "Nextcloud Android app" : "Aplikace Nextcloud pro Android",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk pro iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk pro Android",
+    "Sync client - {os}" : "Synchronizační klient – {os}",
+    "This session" : "Toto sezení",
+    "Device" : "Přístroj",
+    "Last activity" : "Poslední aktivita",
+    "Devices & sessions" : "Zařízení a sezení",
+    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví a mobilní klienti aktuálně přihlášení k vašemu účtu.",
+    "Do you really want to wipe your data from this device?" : "Opravdu chcete vymazat svá data z tohoto zařízení?",
+    "Confirm wipe" : "Potvrdit vymazání",
+    "Error while creating device token" : "Chyba při vytváření tokenů přístroje",
+    "Error while updating device token scope" : "Chyba při aktualizaci rozsahu tokenu zařízení",
+    "Error while updating device token name" : "Chyba při aktualizaci názvu tokenu zařízení",
+    "Error while deleting the token" : "Chyba při mazání tokenu",
+    "Error while wiping the device with the token" : "Chyba při vymazávání zařízení s tokenem",
+    "App name" : "Název aplikace",
+    "Create new app password" : "Vytvořit nové heslo aplikace",
+    "Use the credentials below to configure your app or device." : "Pro nastavení aplikace nebo zařízení použijte níže uvedené údaje.",
+    "For security reasons this password will only be shown once." : "Toto heslo bude z bezpečnostních důvodů zobrazeno pouze jedenkrát.",
+    "Username" : "Uživatelské jméno",
+    "Password" : "Heslo",
+    "Done" : "Dokončeno",
+    "Show QR code for mobile apps" : "Zobrazit QR kód pro mobilní aplikace",
+    "Copied!" : "Zkopírováno!",
+    "Copy" : "Zkopírovat",
+    "Could not copy app password. Please copy it manually." : "Nedaří se zkopírovat heslo pro aplikaci. Zkopírujte ho ručně.",
     "You do not have permissions to see the details of this user" : "Nemáte oprávnění k zobrazení podrobností o tomto uživateli",
     "The backend does not support changing the display name" : "Podpůrná vrstva nepodporuje změnu zobrazovaného názvu",
     "New password" : "Nové heslo",
@@ -354,9 +222,9 @@ OC.L10N.register(
     "Add a new user" : "Přidat nového uživatele",
     "No users in here" : "Nejsou zde žádní uživatelé",
     "Default quota" : "Výchozí kvóta",
-    "Password change is disabled because the master key is disabled" : "Změna hesla je vypnutá protože je vypnutý hlavní klíč",
     "Common languages" : "Běžné jazyky",
     "All languages" : "Všechny jazyky",
+    "Password change is disabled because the master key is disabled" : "Změna hesla je vypnutá protože je vypnutý hlavní klíč",
     "Your apps" : "Vaše aplikace",
     "Active apps" : "Aktivní aplikace",
     "Disabled apps" : "Vypnuté aplikace",
@@ -370,13 +238,13 @@ OC.L10N.register(
     "Show last login" : "Zobrazit poslední přihlášení",
     "Show user backend" : "Zobrazit vedení uživatelů",
     "Show storage path" : "Zobrazit cestu k úložišti",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Chystáte se smazat skupinu {group}. Uživatelé NEbudou smazáni.",
-    "Please confirm the group removal " : "Potvrďte odstranění skupiny",
     "Remove group" : "Odebrat skupinu",
     "Admins" : "Správci",
     "Disabled users" : "Zakázaní uživatelé",
     "Everyone" : "Všichni",
     "Add group" : "Přidat skupinu",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Chystáte se smazat skupinu {group}. Uživatelé NEbudou smazáni.",
+    "Please confirm the group removal " : "Potvrďte odstranění skupiny",
     "An error occured during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla povolena ale je třeba ji aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
     "App update" : "Aktualizace aplikace",
@@ -411,6 +279,7 @@ OC.L10N.register(
     "Credentials" : "Přihlašovací údaje",
     "SMTP Username" : "SMTP uživatelské jméno ",
     "SMTP Password" : "SMTP heslo",
+    "Save" : "Uložit",
     "Test email settings" : "Test nastavení e-mailu",
     "Send email" : "Odeslat email",
     "Security & setup warnings" : "Upozornění zabezpečení a nastavení",
@@ -513,6 +382,186 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘-C.",
     "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl-C.",
     "Error while loading browser sessions and device tokens" : "Chyba při načítání sezení prohlížeče a tokenů přístroje",
+    "Afrikaans (South Africa)" : "afrikánština (Jihoafrická republika)",
+    "Afrikaans" : "Afrikánština",
+    "Albanian (Albania)" : "albánština (Albánie)",
+    "Albanian" : "Albánština",
+    "Amharic (Ethiopia)" : "amharština (Etiopie)",
+    "Arabic (Algeria)" : "arabština (Alžír)",
+    "Arabic (Egypt)" : "Arabština (Egypt)",
+    "Arabic (Iraq)" : "Arabština (Irák)",
+    "Arabic (Jordan)" : "Arabština (Jordán)",
+    "Arabic (Kuwait)" : "Arabština (Kuvajt)",
+    "Arabic (Lebanon)" : "Arabština (Libanon)",
+    "Arabic (Libya)" : "Arabština (Libye)",
+    "Arabic (Qatar)" : "arabština (Katar)",
+    "Arabic (Yemen)" : "arabština (Jemen)",
+    "Arabic" : "arabština",
+    "Armenian" : "arménština",
+    "Assamese" : "Ásámština",
+    "Asu (Tanzania)" : "asu (Tanzanie)",
+    "Basque" : "baskičtina",
+    "Belarusian" : "Běloruština",
+    "Bosnian" : "bosenština",
+    "Bulgarian (Bulgaria)" : "bulharština (Bulharsko)",
+    "Bulgarian" : "bulharština",
+    "Catalan (Spain)" : "katalánština (Španělsko)",
+    "Catalan" : "Katalánština",
+    "Chinese (Traditional Han)" : "Čínština (tradiční)",
+    "Chinese" : "Čínština",
+    "Croatian (Croatia)" : "Chorvatština (Chorvatsko)",
+    "Croatian" : "chorvatština",
+    "Czech (Czech Republic)" : "Čeština (Česko)",
+    "Czech" : "Čeština",
+    "Danish (Denmark)" : "dánština (Dánsko)",
+    "Danish" : "Dánština",
+    "Dutch (Netherlands)" : "nizozemština (Nizozemsko)",
+    "Embu" : "Embu",
+    "English (Australia)" : "angličtina (Austrálie)",
+    "English (Belgium)" : "angličtina (Belgie)",
+    "English (Canada)" : "angličtina (Kanada)",
+    "English (Guam)" : "angličtina (Guam)",
+    "English (India)" : "angličtina (Indie)",
+    "English (Ireland)" : "angličtina (Irsko)",
+    "English (Jamaica)" : "angličtina (Jamajka)",
+    "English (Malta)" : "angličtina (Malta)",
+    "English (Mauritius)" : "Angličtina (Maurícius)",
+    "English (Namibia)" : "angličtina (Namibie)",
+    "English (New Zealand)" : "angličtina (Nový Zéland)",
+    "English (Philippines)" : "angličtina (Filipíny)",
+    "English (South Africa)" : "Angličtina (Jihoafrická republika)",
+    "English (United Kingdom)" : "Angličtina (Spojené království)",
+    "English (United States)" : "angličtina (Spojené Státy)",
+    "English" : "Angličtina",
+    "Esperanto" : "Esperanto",
+    "Estonian (Estonia)" : "estonština (Estonsko)",
+    "Estonian" : "Estonština",
+    "Faroese" : "faerština",
+    "Finnish (Finland)" : "Finština (Finsko)",
+    "Finnish" : "Finština",
+    "French (Belgium)" : "francouzština (Belgie)",
+    "French (Burkina Faso)" : "Francouzština (Burkina Faso)",
+    "French (Canada)" : "Francouzština (Kanada)",
+    "French (Congo - Kinshasa)" : "francouzština (Kongo-Kinshasa)",
+    "French (France)" : "francouzština (Francie)",
+    "French (Mali)" : "francouzština (Mali)",
+    "French (Rwanda)" : "francouzština (Rwanda)",
+    "French (Senegal)" : "francouzština (Senegal)",
+    "French (Switzerland)" : "francouzština (Švýcarsko)",
+    "French (Togo)" : "francouzština (Togo)",
+    "French" : "Francouzština",
+    "Galician" : "galicijština",
+    "Georgian" : "gruzínština",
+    "German (Austria)" : "němčina (Rakousko)",
+    "German (Belgium)" : "němčina (Belgie)",
+    "German (Germany)" : "němčina (Německo)",
+    "German (Luxembourg)" : "němčina (Lucembursko)",
+    "German (Switzerland)" : "němčina (Švýcarsko)",
+    "German" : "Němčina",
+    "Greek (Cyprus)" : "řečtina (Kypr)",
+    "Greek (Greece)" : "řečtina (Řecko)",
+    "Greek" : "Řečtina",
+    "Hausa" : "hauština",
+    "Hawaiian" : "havajština",
+    "Hebrew (Israel)" : "hebrejština (Izrael)",
+    "Hebrew" : "Hebrejština",
+    "Hungarian (Hungary)" : "Maďarština (Maďarsko)",
+    "Hungarian" : "Maďarština",
+    "Icelandic" : "Islandština",
+    "Indonesian (Indonesia)" : "indonéština (Indonésie)",
+    "Irish (Ireland)" : "irština (Irsko)",
+    "Irish" : "Irština",
+    "Italian (Italy)" : "italština (Itálie)",
+    "Italian" : "Italština",
+    "Japanese (Japan)" : "japonština (Japonsko)",
+    "Japanese" : "Japonština",
+    "Kabuverdianu (Cape Verde)" : "kapverdština (Kapverdy)",
+    "Kabyle (Algeria)" : "kabylština (Alžírsko)",
+    "Kalaallisut" : "grónština",
+    "Kannada" : "kannadština",
+    "Kinyarwanda" : "rwandština",
+    "Korean (South Korea)" : "Korejština (Severní Korea)",
+    "Korean" : "korejština",
+    "Latvian (Latvia)" : "lotyština (Lotyšsko)",
+    "Latvian" : "Lotyština",
+    "Lithuanian (Lithuania)" : "litevština (Litva)",
+    "Lithuanian" : "Litevština",
+    "Luo (Kenya)" : "luo (Keňa)",
+    "Luo" : "luo",
+    "Macedonian (Macedonia)" : "makedonština (Makedonie)",
+    "Macedonian" : "makedonština",
+    "Malagasy (Madagascar)" : "malgaština (Madagaskar)",
+    "Malagasy" : "malgaština",
+    "Malayalam" : "malajálamština",
+    "Manx (United Kingdom)" : "Manština (Velká Británie)",
+    "Nepali" : "nepálština",
+    "Norwegian Bokmål" : "Norština (Bokmål)",
+    "Oromo (Ethiopia)" : "oromština (Etiopie)",
+    "Oromo" : "oromština",
+    "Persian (Afghanistan)" : "perština (Afghánistán)",
+    "Persian (Iran)" : "perština (Írán)",
+    "Persian" : "perština",
+    "Polish (Poland)" : "polština (Polsko)",
+    "Polish" : "Polština",
+    "Portuguese (Brazil)" : "portugalština (Brazílie)",
+    "Portuguese (Portugal)" : "portugalština (Portugalsko)",
+    "Portuguese" : "Portugalština",
+    "Romanian (Moldova)" : "rumunština (Moldávie)",
+    "Romanian (Romania)" : "rumunština (Rumunsko)",
+    "Romanian" : "Rumunština",
+    "Russian (Russia)" : "ruština (Rusko)",
+    "Russian (Ukraine)" : "ruština (Ukrajina)",
+    "Russian" : "Ruština",
+    "Samburu" : "samburu",
+    "Serbian (Cyrillic, Bosnia and Herzegovina)" : "srbština (azbuka, Bosna a Hercegovina)",
+    "Serbian" : "Srbština",
+    "Sichuan Yi (China)" : "Ijo (Čína)",
+    "Slovak (Slovakia)" : "slovenština (Slovensko)",
+    "Slovak" : "Slovenština",
+    "Slovenian (Slovenia)" : "slovinština (Slovensko)",
+    "Slovenian" : "Slovinština",
+    "Somali (Djibouti)" : "somálština (Džibutsko)",
+    "Somali (Ethiopia)" : "somálština (Etiopie)",
+    "Somali (Kenya)" : "somálština (Keňa)",
+    "Somali (Somalia)" : "somálština (Somálsko)",
+    "Spanish (Argentina)" : "španělština (Argentina)",
+    "Spanish (Bolivia)" : "španělština (Bolívie)",
+    "Spanish (Colombia)" : "španělština (Kolumbie)",
+    "Spanish (Ecuador)" : "španělština (Ekvádor)",
+    "Spanish (Equatorial Guinea)" : "španělština (Rovníková Guinea)",
+    "Spanish (Honduras)" : "španělština (Honduras)",
+    "Spanish (Latin America)" : "španělština (latinská Amerika)",
+    "Spanish (Mexico)" : "španělština (Mexiko)",
+    "Spanish (Panama)" : "španělština (Panama)",
+    "Spanish (Peru)" : "španělština (Peru)",
+    "Spanish (United States)" : "španělština (Spojené Státy)",
+    "Spanish" : "Španělština",
+    "Swahili (Kenya)" : "svahilština (Keňa)",
+    "Swahili (Tanzania)" : "svahilština (Tanzanie)",
+    "Swahili" : "Svahilština",
+    "Swedish (Finland)" : "švédština (Finsko)",
+    "Swedish (Sweden)" : "švédština (Švédsko)",
+    "Swedish" : "Švédština",
+    "Swiss German (Switzerland)" : "švýcarská němčina (Švýcarsko)",
+    "Swiss German" : "Švýcarská němčina",
+    "Tachelhit (Latin, Morocco)" : "tašelhit (latinka, Maroko)",
+    "Telugu (India)" : "telužština (Indie)",
+    "Thai" : "Thajština",
+    "Tibetan (India)" : "tibetština (Indie)",
+    "Tibetan" : "tibetština",
+    "Tonga (Tonga)" : "tongánština (Tonga)",
+    "Turkish (Turkey)" : "turečtina (Turecko)",
+    "Turkish" : "Turečtina",
+    "Ukrainian (Ukraine)" : "ukrajinština (Ukrajina)",
+    "Ukrainian" : "Ukrajinština",
+    "Uzbek (Cyrillic)" : "uzbečtina (azbuka)",
+    "Uzbek (Latin)" : "uzbečtina (latinka)",
+    "Uzbek" : "Uzbečtina",
+    "Vietnamese (Vietnam)" : "vietnamština (Vietnam)",
+    "Vietnamese" : "Vietnamština",
+    "Welsh" : "Velština",
+    "Yoruba" : "jorubština",
+    "Zulu" : "zuluština",
     "Store credentials" : "Ukládat přihlašovací údaje",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php je registrován u služby webcron, aby volal cron.php jednou za 15 minut přes HTTP.",
     "Use system cron service to call the cron.php file every 15 minutes." : "Použít systémovou službu cron pro volání cron.php každých 15 minut.",
