@@ -1,6 +1,44 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Immigration er i gang. Vent venligst indtil overflytningen er afsluttet",
+    "Migration started …" : "Migrering er påbegyndt...",
+    "Saved" : "Gemt",
+    "Not saved" : "Ikke gemt",
+    "Sending…" : "Sender...",
+    "Email sent" : "E-mail afsendt",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Der opstod en fejl. Upload venligst et ASCII-indkodet PEM-certifikat.",
+    "Valid until {date}" : "Gyldig indtil {date}",
+    "Delete" : "Slet",
+    "Local" : "Lokal",
+    "Private" : "Privat",
+    "Only visible to local users" : "Kun synlig for lokale brugere",
+    "Only visible to you" : "Kun synlig for dig",
+    "Contacts" : "Kontakter",
+    "Public" : "Offentlig",
+    "Verify" : "Bekræft",
+    "Verifying …" : "Bekræfter.....",
+    "Unable to change password" : "Kunne ikke ændre kodeord",
+    "Very weak password" : "Meget svagt kodeord",
+    "Weak password" : "Svagt kodeord",
+    "So-so password" : "Jævnt kodeord",
+    "Good password" : "Godt kodeord",
+    "Strong password" : "Stærkt kodeord",
+    "Select a profile picture" : "Vælg et profilbillede",
+    "Week starts on {fdow}" : "Ugen starter {fdow}",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Tom gruppeliste",
+    "{actor} added you to group {group}" : "{actor} tilføjede dig til gruppe {group}",
+    "You added {user} to group {group}" : "Tilføjede {user} til gruppen {group}",
+    "{actor} added {user} to group {group}" : "{actor} tilføjede {user} til gruppe {group}",
+    "An administrator added you to group {group}" : "En administrator tilføjede dig til gruppen {group}",
+    "An administrator added {user} to group {group}" : "En administrator tilføjede {user} til gruppen {group}",
+    "{actor} removed you from group {group}" : "{actor} fjernede dig fra gruppen {group}",
+    "You removed {user} from group {group}" : "Fjernede {user}  fra gruppen {group}",
+    "{actor} removed {user} from group {group}" : "{actor} fjernede {user}fra gruppen {group}",
+    "An administrator removed you from group {group}" : "En administrator fjernede dig fra gruppen {group}",
+    "An administrator removed {user} from group {group}" : "En administrator fjernede {user} fra gruppen {group}",
+    "Your <strong>group memberships</strong> were modified" : "Dine <strong>gruppemedlemsskaber</strong> blev ændret",
     "{actor} changed your password" : "{actor} ændrede din adgangskode",
     "You changed your password" : "Du ændrede din kode",
     "Your password was reset by an administrator" : "Din adgangskode er blevet resat af en administrator",
@@ -14,9 +52,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Kunne ikke fjerne app'en.",
     "Couldn't update app." : "Kunne ikke opdatere app'en.",
     "Wrong password" : "Forkert kodeord",
-    "Saved" : "Gemt",
     "No user supplied" : "Intet brugernavn givet",
-    "Unable to change password" : "Kunne ikke ændre kodeord",
     "Authentication error" : "Adgangsfejl",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Angiv venligst en administrator gendannelseskode, ellers vil alt brugerdata gå tabt",
     "Wrong admin recovery password. Please check the password and try again." : "Forkert admin gendannelseskode. Se venligst koden efter og prøv igen.",
@@ -56,35 +92,33 @@ OC.L10N.register(
     "Set your password" : "Sæt dit password",
     "Go to %s" : "Gå til %s",
     "Install Client" : "Installer client",
-    "Delete" : "Slet",
+    "Create" : "Opret",
     "Unlimited" : "Ubegrænset",
-    "Verifying …" : "Bekræfter.....",
-    "Verify" : "Bekræft",
-    "Migration in progress. Please wait until the migration is finished" : "Immigration er i gang. Vent venligst indtil overflytningen er afsluttet",
-    "Migration started …" : "Migrering er påbegyndt...",
-    "Not saved" : "Ikke gemt",
-    "Sending…" : "Sender...",
-    "Email sent" : "E-mail afsendt",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Der opstod en fejl. Upload venligst et ASCII-indkodet PEM-certifikat.",
-    "Valid until {date}" : "Gyldig indtil {date}",
-    "Local" : "Lokal",
-    "Private" : "Privat",
-    "Only visible to local users" : "Kun synlig for lokale brugere",
-    "Only visible to you" : "Kun synlig for dig",
-    "Contacts" : "Kontakter",
-    "Public" : "Offentlig",
-    "Very weak password" : "Meget svagt kodeord",
-    "Weak password" : "Svagt kodeord",
-    "So-so password" : "Jævnt kodeord",
-    "Good password" : "Godt kodeord",
-    "Strong password" : "Stærkt kodeord",
-    "Select a profile picture" : "Vælg et profilbillede",
-    "Week starts on {fdow}" : "Ugen starter {fdow}",
-    "Groups" : "Grupper",
-    "Group list is empty" : "Tom gruppeliste",
     "Limit to groups" : "Begræns til grupper",
     "Excluded groups" : "Ekskluderede grupper",
     "Save changes" : "Gem ændringer",
+    "Official" : "Officiel",
+    "by" : "af",
+    "Update to {version}" : "Opdateret til {version}",
+    "Remove" : "Fjern",
+    "Disable" : "Deaktiver",
+    "All" : "Alle",
+    "No results" : "Ingen resultater",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en mindste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en højeste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
+    "View in store" : "Se i butik",
+    "Visit website" : "Besøg hjemmeside",
+    "Report a bug" : "Rapporter en fejl",
+    "User documentation" : "Brugerdokumentation",
+    "Admin documentation" : "Admin-dokumentation",
+    "Developer documentation" : "Dokumentation for udviklere",
+    "Update to {update}" : "Opdater til {update}",
+    "No apps found for your version" : "Ingen apps fundet til din verion",
+    "Enable all" : "Aktiver alle",
+    "Download and enable" : "Download og aktiver",
+    "Enable" : "Aktiver",
+    "The app will be downloaded from the app store" : "Appen vil blive downloaded fra app storen.",
     "Device settings" : "Enhedsindstillinger",
     "Allow filesystem access" : "Tillad filsystem adgang",
     "Revoke" : "Tilbagekald",
@@ -115,28 +149,6 @@ OC.L10N.register(
     "Done" : "Færdig",
     "Copied!" : "Kopieret",
     "Copy" : "Kopier",
-    "Official" : "Officiel",
-    "by" : "af",
-    "Update to {version}" : "Opdateret til {version}",
-    "Remove" : "Fjern",
-    "Disable" : "Deaktiver",
-    "All" : "Alle",
-    "No results" : "Ingen resultater",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en mindste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en højeste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
-    "View in store" : "Se i butik",
-    "Visit website" : "Besøg hjemmeside",
-    "Report a bug" : "Rapporter en fejl",
-    "User documentation" : "Brugerdokumentation",
-    "Admin documentation" : "Admin-dokumentation",
-    "Developer documentation" : "Dokumentation for udviklere",
-    "Update to {update}" : "Opdater til {update}",
-    "No apps found for your version" : "Ingen apps fundet til din verion",
-    "Enable all" : "Aktiver alle",
-    "Download and enable" : "Download og aktiver",
-    "Enable" : "Aktiver",
-    "The app will be downloaded from the app store" : "Appen vil blive downloaded fra app storen.",
     "New password" : "Nyt kodeord",
     "Add user in group" : "Tilføj bruger i gruppe",
     "Set user as admin for" : "Gør bruger til administrator for",
@@ -173,13 +185,13 @@ OC.L10N.register(
     "Show Languages" : "Vis sprog",
     "Show last login" : "Vis seneste login",
     "Show user backend" : "Vis bruger-backend",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Du er ved at fjerne gruppen {group}. Brugerne bliver IKKE slettet.",
-    "Please confirm the group removal " : "Bekræft at gruppen skal fjernes",
     "Remove group" : "Fjern gruppe",
     "Admins" : "Administratore",
     "Disabled users" : "Deaktiverede brugere",
     "Everyone" : "Alle",
     "Add group" : "Tilføj gruppe",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Du er ved at fjerne gruppen {group}. Brugerne bliver IKKE slettet.",
+    "Please confirm the group removal " : "Bekræft at gruppen skal fjernes",
     "App update" : "App opdatering",
     "Error: This app can not be enabled because it makes the server unstable" : "Fejl: Denne app kan ikke aktiveres fordi den gør serveren ustabil",
     "SSL Root Certificates" : "SSL rodcertifikater",
@@ -210,7 +222,6 @@ OC.L10N.register(
     "Credentials" : "Brugeroplysninger",
     "SMTP Username" : "SMTP Brugernavn",
     "SMTP Password" : "SMTP Kodeord",
-    "Store credentials" : "Gem brugeroplysninger",
     "Test email settings" : "Test e-mail-indstillinger",
     "Send email" : "Send e-mail",
     "Security & setup warnings" : "Advarsler om sikkerhed og opsætning",
@@ -281,6 +292,7 @@ OC.L10N.register(
     "Twitter handle @…" : "Twitter handle @…",
     "Help translate" : "Hjælp med oversættelsen",
     "Current password" : "Nuværende adgangskode",
-    "Change password" : "Skift kodeord"
+    "Change password" : "Skift kodeord",
+    "Store credentials" : "Gem brugeroplysninger"
 },
 "nplurals=2; plural=(n != 1);");
