@@ -1,6 +1,36 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
+    "Migration started …" : "Η μετάβαση ξεκίνησε ...",
+    "Saved" : "Αποθηκεύτηκαν",
+    "Not saved" : "Δεν αποθηκεύτηκε",
+    "Sending…" : "Γινεται αποστολή...",
+    "Email sent" : "Το Email απεστάλη ",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
+    "Valid until {date}" : "Έγκυρο έως {date}",
+    "Delete" : "Διαγραφή",
+    "Local" : "Τοπικά",
+    "Private" : "Ιδιωτικά",
+    "Only visible to local users" : "Εμφανές μόνο σε τοπικούς χρήστες",
+    "Only visible to you" : "Εμφανές μόνο σε εσάς",
+    "Contacts" : "Επαφές",
+    "Visible to local users and to trusted servers" : "Προσθήκη στη λίστα των έμπιστων διακομιστών",
+    "Public" : "Δημόσιο",
+    "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
+    "Verify" : "Επαλήθευση",
+    "Verifying …" : "Γίνεται επαλήθευση ...",
+    "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
+    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
+    "Weak password" : "Αδύναμο συνθηματικό",
+    "So-so password" : "Μέτριο συνθηματικό",
+    "Good password" : "Καλό συνθηματικό",
+    "Strong password" : "Δυνατό συνθηματικό",
+    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
+    "Week starts on {fdow}" : "Η εβδομάδα ξεκινά την {fdow}",
+    "Groups" : "Ομάδες",
+    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
+    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
     "{actor} added you to group {group}" : "{actor} σας πρόσθεσε στην ομάδα {group}",
     "You added {user} to group {group}" : "Προσθέσατε τον χρήστη {user} στην ομάδα {group}",
     "{actor} added {user} to group {group}" : "{actor} πρόσθεσε τον χρήστη {user} στην ομάδα {group}",
@@ -24,9 +54,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
     "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
     "Wrong password" : "Εσφαλμένο συνθηματικό",
-    "Saved" : "Αποθηκεύτηκαν",
     "No user supplied" : "Δεν εισήχθη χρήστης",
-    "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
     "Authentication error" : "Σφάλμα πιστοποίησης",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Παρακαλώ παρέχετε έναν κωδικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν.",
     "Wrong admin recovery password. Please check the password and try again." : "Λάθος κωδικός ανάκτησης διαχειριστή. Παρακαλώ ελέγξτε τον κωδικό και δοκιμάστε ξανά.",
@@ -65,69 +93,14 @@ OC.L10N.register(
     "Set your password" : "Καθορισμός συνθηματικού",
     "Go to %s" : "Πηγαίνετε στο %s",
     "Install Client" : "Εγκατάσταση πελάτη",
-    "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
-    "Migration started …" : "Η μετάβαση ξεκίνησε ...",
-    "Not saved" : "Δεν αποθηκεύτηκε",
-    "Sending…" : "Γινεται αποστολή...",
-    "Email sent" : "Το Email απεστάλη ",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
-    "Valid until {date}" : "Έγκυρο έως {date}",
-    "Delete" : "Διαγραφή",
-    "Local" : "Τοπικά",
-    "Private" : "Ιδιωτικά",
-    "Only visible to local users" : "Εμφανές μόνο σε τοπικούς χρήστες",
-    "Only visible to you" : "Εμφανές μόνο σε εσάς",
-    "Contacts" : "Επαφές",
-    "Visible to local users and to trusted servers" : "Προσθήκη στη λίστα των έμπιστων διακομιστών",
-    "Public" : "Δημόσιο",
-    "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
-    "Verify" : "Επαλήθευση",
-    "Verifying …" : "Γίνεται επαλήθευση ...",
-    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
-    "Weak password" : "Αδύναμο συνθηματικό",
-    "So-so password" : "Μέτριο συνθηματικό",
-    "Good password" : "Καλό συνθηματικό",
-    "Strong password" : "Δυνατό συνθηματικό",
-    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
-    "Week starts on {fdow}" : "Η εβδομάδα ξεκινά την {fdow}",
-    "Groups" : "Ομάδες",
-    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
-    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
-    "English (United Kingdom)" : "Αγγλικά (Ηνωμένο Βασίλειο)",
-    "English (United States)" : "Αγγλικά (Η.Π.Α.)",
-    "German (Austria)" : "Γερμανικά (Αυστρία)",
-    "German (Belgium)" : "Γερμανικά (Βέλγιο)",
-    "German (Germany)" : "Γερμανικά (Γερμανία)",
-    "German (Liechtenstein)" : "Γερμανικά (Λιχτενστάιν)",
-    "German (Luxembourg)" : "Γερμανικά (Λουξεμβούργο)",
-    "German (Switzerland)" : "Γερμανικά (Ελβετία)",
-    "German" : "Γερμανικά",
+    "Create" : "Δημιουργία",
+    "Change" : "Αλλαγή",
+    "Share" : "Διαμοιρασμός",
+    "Unlimited" : "Απεριόριστο",
+    "Verifying" : "Γίνεται επαλήθευση",
+    "Nextcloud settings" : "Ρυθμίσεις Nextcloud ",
     "Limit to groups" : "Όριο στις ομάδες",
     "Save changes" : "Αποθήκευση αλλαγών",
-    "Device settings" : "Ρυθμίσεις συσκευής",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome για Android",
-    "Revoke" : "Ανάκληση",
-    "Sync client - {os}" : "Συγχρονισμός πελατών - {os}",
-    "This session" : "Αυτή η συνεδρία",
-    "Device" : "Συσκευή",
-    "Last activity" : "Τελευταία δραστηριότητα",
-    "Web, desktop and mobile clients currently logged in to your account." : " ",
-    "Error while creating device token" : "Σφάλμα κατά τη δημιουργία διακριτικού συσκευής",
-    "Error while deleting the token" : "Σφάλμα κατά την διαγραφή του διακριτικού",
-    "App name" : "Όνομα εφαρμογής",
-    "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
-    "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
-    "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
-    "Username" : "Όνομα χρήστη",
-    "Password" : "Συνθηματικό",
-    "Done" : "Ολοκληρώθηκε",
-    "Copied!" : "Αντιγράφτηκε!",
-    "Copy" : "Αντιγραφή",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται μέσα από την κοινότητα. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για παραγωγική χρήση. ",
     "Official" : "Επίσημο",
     "by" : "από",
@@ -147,6 +120,31 @@ OC.L10N.register(
     "Enable all" : "Ενεργοποίηση όλων",
     "Enable" : "Ενεργοποίηση",
     "The app will be downloaded from the app store" : "Αυτή η εφαρμογή θα ",
+    "Device settings" : "Ρυθμίσεις συσκευής",
+    "Rename" : "Μετονομασία",
+    "Revoke" : "Ανάκληση",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome για Android",
+    "Sync client - {os}" : "Συγχρονισμός πελατών - {os}",
+    "This session" : "Αυτή η συνεδρία",
+    "Device" : "Συσκευή",
+    "Last activity" : "Τελευταία δραστηριότητα",
+    "Web, desktop and mobile clients currently logged in to your account." : " ",
+    "Error while creating device token" : "Σφάλμα κατά τη δημιουργία διακριτικού συσκευής",
+    "Error while deleting the token" : "Σφάλμα κατά την διαγραφή του διακριτικού",
+    "App name" : "Όνομα εφαρμογής",
+    "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
+    "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
+    "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
+    "Username" : "Όνομα χρήστη",
+    "Password" : "Συνθηματικό",
+    "Done" : "Ολοκληρώθηκε",
+    "Copied!" : "Αντιγράφτηκε!",
+    "Copy" : "Αντιγραφή",
     "New password" : "Νέο συνθηματικό",
     "Add user in group" : "Προσθήκη χρήστη στην ομάδα",
     "Set user as admin for" : "Ορισμός χρήστη ως διαχειριστή για",
@@ -165,7 +163,6 @@ OC.L10N.register(
     "User backend" : "Σύστημα υποστήριξης χρήστη",
     "Last login" : "Τελευταία είσοδος",
     "Add a new user" : "Προσθήκη νέου χρήστη",
-    "Unlimited" : "Απεριόριστο",
     "Default quota" : "Προεπιλέγμενη χωρητικότητα",
     "Your apps" : "Οι εφαρμογές σας",
     "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
@@ -207,7 +204,6 @@ OC.L10N.register(
     "Credentials" : "Πιστοποιητικά",
     "SMTP Username" : "Όνομα χρήστη SMTP",
     "SMTP Password" : "Συνθηματικό SMTP",
-    "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
     "Test email settings" : "Δοκιμή ρυθμίσεων email",
     "Send email" : "Αποστολή email",
     "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
@@ -229,9 +225,8 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
     "Start migration" : "Έναρξη μετάβασης",
     "Background jobs" : "Εργασίες παρασκηνίου",
+    "Pick background job setting" : "Επιλέξτε τη ρύθμιση εργασίας φόντου",
     "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Το cron.php πρέπει να εκτελεστεί από τον χρήστη του συστήματος \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Για να τρέξετε αυτό χρειάζεστε την επέκταση PHP POSIX. Δείτε {linkstart} PHP τεκμηρίωση {linked} για περισσότερες λεπτομέρειες.",
     "Sharing" : "Διαμοιρασμός",
@@ -251,6 +246,7 @@ OC.L10N.register(
     "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
     "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
     "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης του ονόματος χρήστη στο πεδίο διαμοιρασμού. Αν η ρύθμιση αυτή είναι απενεργοποιημένη θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη ή το email του. ",
+    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Εμφάνιση κειμένου αποποίησης ευθυνών στη σελίδα δημοσίευσης συνδέσμων. (Εμφανίζεται μόνο όταν η λίστα αρχείων είναι κρυφή.)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Αυτό το κείμενο θα ",
     "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
     "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
@@ -280,6 +276,43 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Help translate" : "Βοηθήστε στη μετάφραση",
     "Current password" : "Τρέχων συνθηματικό",
-    "Change password" : "Αλλαγή συνθηματικού"
+    "Change password" : "Αλλαγή συνθηματικού",
+    "Use a second factor besides your password to increase security for your account." : "Χρησιμοποιείστε έναν δεύτερο παράγοντα εκτός του κωδικού πρόσβασης για να αυξήσετε την ασφάλεια του λογαριαμού σας.",
+    "Afrikaans (Namibia)" : "Αφρικανικά (Ναμίμπια)",
+    "Afrikaans (South Africa)" : "Αφρικανικά (Νότια Αφρική)",
+    "Afrikaans" : "Αφρικανικά",
+    "Akan (Ghana)" : "Ακάν (Γκάνα)",
+    "Akan" : "Ακάν",
+    "Albanian (Albania)" : "Αλβανικά (Αλβανία)",
+    "Albanian" : "Αλβανικά",
+    "Amharic (Ethiopia)" : "Αμχαρικά (Αιθιοπία)",
+    "Amharic" : "Αμχαρικά",
+    "Arabic (Algeria)" : "Αραβικά (Αλγερία)",
+    "Arabic (Bahrain)" : "Αραβικά (Μπαχρέιν)",
+    "Arabic (Egypt)" : "Αραβικά (Αίγυπτος)",
+    "Arabic (Iraq)" : "Αραβικά (Ιράκ)",
+    "Arabic (Jordan)" : "Αραβικά (Ιορδανία)",
+    "Arabic (Kuwait)" : "Αραβικά (Κουβέιτ)",
+    "Arabic (Lebanon)" : "Αραβικά (Λίβανο)",
+    "Arabic (Libya)" : "Αραβικά (Λιβύη)",
+    "Arabic (Morocco)" : "Αραβικά (Μαρόκο)",
+    "Arabic (Oman)" : "Αραβικά (Ομάν)",
+    "Arabic (Qatar)" : "Αραβικά (Κατάρ)",
+    "Arabic (Saudi Arabia)" : "Αραβικά (Σαουδική Αραβία)",
+    "Arabic (Sudan)" : "Αραβικά (Σουδάν)",
+    "Arabic (Syria)" : "Αραβικά (Συρία)",
+    "Arabic (Tunisia)" : "Αραβικά (Τυνησία)",
+    "English (United Kingdom)" : "Αγγλικά (Ηνωμένο Βασίλειο)",
+    "English (United States)" : "Αγγλικά (Η.Π.Α.)",
+    "German (Austria)" : "Γερμανικά (Αυστρία)",
+    "German (Belgium)" : "Γερμανικά (Βέλγιο)",
+    "German (Germany)" : "Γερμανικά (Γερμανία)",
+    "German (Liechtenstein)" : "Γερμανικά (Λιχτενστάιν)",
+    "German (Luxembourg)" : "Γερμανικά (Λουξεμβούργο)",
+    "German (Switzerland)" : "Γερμανικά (Ελβετία)",
+    "German" : "Γερμανικά",
+    "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά."
 },
 "nplurals=2; plural=(n != 1);");
