@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
+    "Migration started …" : "Migration started …",
+    "Saved" : "Saved",
+    "Not saved" : "Not saved",
+    "Sending…" : "Sending…",
+    "Email sent" : "Email sent",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
+    "Valid until {date}" : "Valid until {date}",
+    "Delete" : "Delete",
+    "Local" : "Local",
+    "Private" : "Private",
+    "Only visible to local users" : "Only visible to local users",
+    "Only visible to you" : "Only visible to you",
+    "Contacts" : "Contacts",
+    "Visible to local users and to trusted servers" : "Visible to local users and to trusted servers",
+    "Public" : "Public",
+    "Will be synced to a global and public address book" : "Will be synced to a global and public address book",
+    "Verify" : "Verify",
+    "Verifying …" : "Verifying …",
+    "Unable to change password" : "Unable to change password",
+    "Very weak password" : "Very weak password",
+    "Weak password" : "Weak password",
+    "So-so password" : "So-so password",
+    "Good password" : "Good password",
+    "Strong password" : "Strong password",
+    "Select a profile picture" : "Select a profile picture",
+    "Groups" : "Groups",
     "{actor} changed your password" : "{actor} changed your password",
     "You changed your password" : "You changed your password",
     "Your password was reset by an administrator" : "Your password was reset by an administrator",
@@ -14,9 +41,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Couldn't remove app.",
     "Couldn't update app." : "Couldn't update app.",
     "Wrong password" : "Incorrect password",
-    "Saved" : "Saved",
     "No user supplied" : "No user supplied",
-    "Unable to change password" : "Unable to change password",
     "Authentication error" : "Authentication error",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Please provide an admin recovery password; otherwise, all user data will be lost.",
     "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
@@ -55,33 +80,26 @@ OC.L10N.register(
     "Set your password" : "Set your password",
     "Go to %s" : "Go to %s",
     "Install Client" : "Install Client",
-    "Delete" : "Delete",
     "Unlimited" : "Unlimited",
-    "Verifying …" : "Verifying …",
-    "Verify" : "Verify",
-    "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
-    "Migration started …" : "Migration started …",
-    "Not saved" : "Not saved",
-    "Sending…" : "Sending…",
-    "Email sent" : "Email sent",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
-    "Valid until {date}" : "Valid until {date}",
-    "Local" : "Local",
-    "Private" : "Private",
-    "Only visible to local users" : "Only visible to local users",
-    "Only visible to you" : "Only visible to you",
-    "Contacts" : "Contacts",
-    "Visible to local users and to trusted servers" : "Visible to local users and to trusted servers",
-    "Public" : "Public",
-    "Will be synced to a global and public address book" : "Will be synced to a global and public address book",
-    "Very weak password" : "Very weak password",
-    "Weak password" : "Weak password",
-    "So-so password" : "So-so password",
-    "Good password" : "Good password",
-    "Strong password" : "Strong password",
-    "Select a profile picture" : "Select a profile picture",
-    "Groups" : "Groups",
     "Limit to groups" : "Limit to groups",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Official apps are developed by the community. They offer additional functionality and are ready for production use.",
+    "Official" : "Official",
+    "Remove" : "Remove",
+    "Disable" : "Disable",
+    "All" : "All",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will cause an error in the future.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will cause an error in the future.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
+    "View in store" : "View in store",
+    "Visit website" : "Visit website",
+    "Report a bug" : "Report a bug",
+    "User documentation" : "User documentation",
+    "Admin documentation" : "Admin documentation",
+    "Developer documentation" : "Developer documentation",
+    "No apps found for your version" : "No apps found for your version",
+    "Enable all" : "Enable all",
+    "Enable" : "Enable",
+    "The app will be downloaded from the app store" : "The app will be downloaded from the app store",
     "Allow filesystem access" : "Allow filesystem access",
     "Revoke" : "Revoke",
     "Internet Explorer" : "Internet Explorer",
@@ -109,24 +127,6 @@ OC.L10N.register(
     "Done" : "Done",
     "Copied!" : "Copied!",
     "Copy" : "Copy",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Official apps are developed by the community. They offer additional functionality and are ready for production use.",
-    "Official" : "Official",
-    "Remove" : "Remove",
-    "Disable" : "Disable",
-    "All" : "All",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will cause an error in the future.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will cause an error in the future.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
-    "View in store" : "View in store",
-    "Visit website" : "Visit website",
-    "Report a bug" : "Report a bug",
-    "User documentation" : "User documentation",
-    "Admin documentation" : "Admin documentation",
-    "Developer documentation" : "Developer documentation",
-    "No apps found for your version" : "No apps found for your version",
-    "Enable all" : "Enable all",
-    "Enable" : "Enable",
-    "The app will be downloaded from the app store" : "The app will be downloaded from the app store",
     "New password" : "New password",
     "{size} used" : "{size} used",
     "Email" : "Email",
@@ -178,7 +178,6 @@ OC.L10N.register(
     "Credentials" : "Credentials",
     "SMTP Username" : "SMTP Username",
     "SMTP Password" : "SMTP Password",
-    "Store credentials" : "Store credentials",
     "Test email settings" : "Test email settings",
     "Send email" : "Send email",
     "Security & setup warnings" : "Security & setup warnings",
@@ -208,8 +207,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Background job didn’t run yet!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information.",
     "Execute one task with each page loaded" : "Execute one task with each page loaded",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Use system cron service to call the cron.php file every 15 minutes.",
     "The cron.php needs to be executed by the system user \"%s\"." : "The cron.php needs to be executed by the system user \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details.",
     "Sharing" : "Sharing",
@@ -265,6 +262,9 @@ OC.L10N.register(
     "Twitter handle @…" : "Twitter handle @…",
     "Help translate" : "Help translate",
     "Current password" : "Current password",
-    "Change password" : "Change password"
+    "Change password" : "Change password",
+    "Store credentials" : "Store credentials",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Use system cron service to call the cron.php file every 15 minutes."
 },
 "nplurals=2; plural=(n != 1);");
