@@ -1,6 +1,34 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor aguarda hasta que termine la migración",
+    "Migration started …" : "La migración ha comenzado ...",
+    "Saved" : "Guardado",
+    "Not saved" : "No guardado",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Se presentó un error. Por favor carga un certificado PEM con codificación ASCII",
+    "Valid until {date}" : "Válido hasta {date}",
+    "Delete" : "Borrar",
+    "Local" : "Local",
+    "Private" : "Privado",
+    "Only visible to local users" : "Visible sólo para usuarios locales",
+    "Only visible to you" : "Sólo visible para ti",
+    "Contacts" : "Contactos",
+    "Visible to local users and to trusted servers" : "Visible para usuarios locales y para servidores de confianza",
+    "Public" : "Público",
+    "Will be synced to a global and public address book" : "Será sincronizado a una libreta de direcciones global y pública",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando ...",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Ocurrió un error al cambiar tu región",
+    "Select a profile picture" : "Selecciona una imagen de perfil",
+    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -14,9 +42,7 @@ OC.L10N.register(
     "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
     "Couldn't update app." : "No fue posible actualizar la aplicación.",
     "Wrong password" : "Contraseña incorrecta",
-    "Saved" : "Guardado",
     "No user supplied" : "No se proporcionó usuario alguno",
-    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Authentication error" : "Error de autenticación",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
@@ -55,14 +81,30 @@ OC.L10N.register(
     "Set your password" : "Establece tu contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
-    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor aguarda hasta que termine la migración",
-    "Migration started …" : "La migración ha comenzado ...",
-    "Not saved" : "No guardado",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
-    "Disconnect" : "Desconectar",
-    "Revoke" : "Revocar",
+    "Unlimited" : "Ilimitado",
+    "Enforce two-factor authentication" : "Forzar autenticación de dos factores",
+    "Limit to groups" : "Limitar a grupos",
+    "Save changes" : "Guardar cambios",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad centralizada y se encuentran listas para ser usadas en producción. ",
+    "Official" : "Oficial",
+    "Remove" : "Eliminar",
+    "Disable" : "Deshabilitar",
+    "All" : "Todos",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
+    "View in store" : "Ver en la tienda",
+    "Visit website" : "Visita el sitio web",
+    "Report a bug" : "Reporta un detalle",
+    "User documentation" : "Documentación del usuario",
+    "Admin documentation" : "Documentación del administrador",
+    "Developer documentation" : "Documentación del desarrollador",
+    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Enable all" : "Habilitar todo",
+    "Enable" : "Habilitar",
+    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
+    "Revoke" : "Revocar",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -71,57 +113,23 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome para Android",
     "Sync client - {os}" : "Sync client - {os}",
     "This session" : "Esta sesión",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar. ",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Error while loading browser sessions and device tokens" : "Se presentó un error al cargar las sesiones de tu navegador y las fichas de los dispositivos.",
+    "Device" : "Dispositivo",
+    "Last activity" : "Última actividad",
+    "Devices & sessions" : "Dispositivos y sesiones",
+    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
     "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "Error while deleting the token" : "Se presentó un error al borrar la ficha",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Se presentó un error. Por favor carga un certificado PEM con codificación ASCII",
-    "Valid until {date}" : "Válido hasta {date}",
-    "Delete" : "Borrar",
-    "Local" : "Local",
-    "Private" : "Privado",
-    "Only visible to local users" : "Visible sólo para usuarios locales",
-    "Only visible to you" : "Sólo visible para ti",
-    "Contacts" : "Contactos",
-    "Visible to local users and to trusted servers" : "Visible para usuarios locales y para servidores de confianza",
-    "Public" : "Público",
-    "Will be synced to a global and public address book" : "Será sincronizado a una libreta de direcciones global y pública",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificando ...",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Select a profile picture" : "Selecciona una imagen de perfil",
-    "Groups" : "Grupos",
-    "Limit to groups" : "Limitar a grupos",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad centralizada y se encuentran listas para ser usadas en producción. ",
-    "Official" : "Oficial",
-    "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
-    "All" : "Todos",
-    "View in store" : "Ver en la tienda",
-    "Visit website" : "Visita el sitio web",
-    "Report a bug" : "Reporta un detalle",
-    "User documentation" : "Documentación del usuario",
-    "Admin documentation" : "Documentación del administrador",
-    "Developer documentation" : "Documentación del desarrollador",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
-    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
-    "Enable all" : "Habilitar todo",
-    "Enable" : "Habilitar",
-    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
-    "New password" : "Nueva contraseña",
-    "{size} used" : "{size} usado",
+    "App name" : "Nombre de la aplicación",
+    "Create new app password" : "Crear una nueva contraseña de aplicación",
+    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
+    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
     "Username" : "Usuario",
     "Password" : "Contraseña",
+    "Done" : "Terminado",
+    "Copied!" : "¡Copiado!",
+    "Copy" : "Copiar",
+    "New password" : "Nueva contraseña",
+    "{size} used" : "{size} usado",
     "Email" : "Correo electrónico",
     "Group admin for" : "Administrador del grupo para",
     "Quota" : "Cuota",
@@ -129,7 +137,6 @@ OC.L10N.register(
     "Storage location" : "Úbicación del almacenamiento",
     "User backend" : "Backend del usuario",
     "Last login" : "Último inicio de sesión",
-    "Unlimited" : "Ilimitado",
     "Default quota" : "Cuota predeterminada",
     "Your apps" : "Tus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
@@ -169,12 +176,14 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Username" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Store credentials" : "Almacenar credenciales",
     "Test email settings" : "Probar las configuraciones de correo electrónico",
     "Send email" : "Enviar correo electrónico",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "All checks passed." : "Pasaron todas las verificaciones. ",
+    "There are some warnings regarding your setup." : "Hay advertencias respecto de la configuración.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revise la seguridad de su Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">el escáner de seguridad ↗</a>.",
     "Version" : "Versión",
+    "Two-Factor Authentication" : "Autenticación de dos factores",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
@@ -196,8 +205,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un desempeño ideal, es importante configurar los trabajos de fondo correctamente. Para instancias más grandes 'Cron' es la configuración recomendada. Por favor consulta la documentación para más información. ",
     "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registrado en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP. ",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos. ",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
     "Sharing" : "Compartiendo",
@@ -222,7 +229,6 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Administration" : "Administración",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
-    "Follow us on Google+" : "Síguenos en Google+",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
@@ -235,6 +241,9 @@ OC.L10N.register(
     "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "Cancel" : "Cancelar",
     "Choose as profile picture" : "Seleccionar como foto del perfil",
+    "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
+    "You are using <strong>%s</strong>" : "Estas usando <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Estas usando <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
     "Full name" : "Nombre completo",
     "No display name set" : "No se ha establecido el nombre a desplegar",
     "Your email address" : "Tu dirección de correo electrónico",
@@ -246,134 +255,15 @@ OC.L10N.register(
     "Your postal address" : "Tu dirección postal",
     "Website" : "Sitio web",
     "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
-    "Link https://…" : "Liga https:// ...",
+    "Link https://…" : "Enlace https:// ...",
     "Twitter" : "Twitter",
     "Twitter handle @…" : "Cuenta de twitter @...",
     "Help translate" : "Ayuda a traducir",
+    "Locale" : "Región",
     "Current password" : "Contraseña actual",
     "Change password" : "Cambiar contraseña",
-    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
-    "Device" : "Dispositivo",
-    "Last activity" : "Última actividad",
-    "App name" : "Nombre de la aplicación",
-    "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Done" : "Terminado",
-    "Enabled apps" : "Aplicaciones habilitadas",
-    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está usando una versión anticuada (%s) de %s. Por favor actualiza tu sistema operativo o funciones tales como %s no funcionarán de forma confiable.",
-    "A problem occurred, please check your log files (Error: %s)" : "Se presentó un problema, por favor verifica tus archivos de bitácoras (Error: %s)",
-    "Migration Completed" : "Migración completada",
-    "Group already exists." : "El grupo ya existe.",
-    "Unable to add group." : "No fue posible agregar el grupo.",
-    "Unable to delete group." : "No fue posible borrar el grupo.",
-    "No valid group selected" : "No se ha seleccionado un grupo válido",
-    "A user with that name already exists." : "Un usuario con ese nombre ya existe. ",
-    "To send a password link to the user an email address is required." : "Para enviar la liga a una contraseña al usuario, se requiere de una dirección de correo electrónico.",
-    "Unable to create user." : "No fue posible crear el usuario. ",
-    "Unable to delete user." : "No fue posible eliminar el usuario.",
-    "Error while enabling user." : "Se presentó un error al habilitar el usuario. ",
-    "Error while disabling user." : "Se presentó un error al deshabilitar el usuario.",
-    "Your full name has been changed." : "Tu nombre completo ha sido cambiado.",
-    "Forbidden" : "Prohibido",
-    "Invalid user" : "Usuario inválido",
-    "Unable to change mail address" : "No fue posible cambiar la dirección de correo",
-    "Email saved" : "Correo electrónico guardado",
-    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
-    "Are you really sure you want add {domain} as trusted domain?" : "¿Realmente estás seguro que quieres agregar a {domain} como un dominio de confianza?",
-    "Add trusted domain" : "Agregar un dominio de confianza",
-    "Update to %s" : "Actualizar a %s",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicaciones aprobadas son desarrolladas por desarrolladores de confianza y han pasado una verificación de seguridad. Se les brinda mantenimiento activamente en un repositorio de código abierto y los mantenedores las consideran estables para un uso casual a normal. ",
-    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicación no cuenta con una verificación contra temas de seguridad y es nueva o se sabe que es instable. Instalala bajo tu propio riesgo. ",
-    "Disabling app …" : "Deshabilitando la aplicación ...",
-    "Error while disabling app" : "Se presentó un error mientras se deshabilitaba la aplicación",
-    "Enabling app …" : "Habilitando aplicación ...",
-    "Error while enabling app" : "Se presentó un error al habilitar la aplicación",
-    "Error: Could not disable broken app" : "Error: No fue posible deshabilitar la aplicación rota",
-    "Error while disabling broken app" : "Se presentó un error al deshabilitar la aplicación rota",
-    "Updated" : "Actualizado",
-    "Removing …" : "Eliminando ...",
-    "Approved" : "Aprobado",
-    "Experimental" : "Experimental",
-    "No apps found for {query}" : "No se encontraron aplicaciones para {query}",
-    "iPhone iOS" : "iPhone iOS",
-    "iPad iOS" : "iPad iOS",
-    "iOS Client" : "Cliente iOS",
-    "Android Client" : "Cliente Android",
-    "Unable to delete {objName}" : "No fue posible borrar {objName}",
-    "Error creating group: {message}" : "Se presentó un error al crear el grupo: {message}",
-    "A valid group name must be provided" : "Debes proporcionar un nombre de grupo válido",
-    "deleted {groupName}" : "borrado {groupName}",
-    "undo" : "deshacer",
-    "never" : "nunca",
-    "deleted {userName}" : "borrado {userName}",
-    "No user found for <strong>{pattern}</strong>" : "No se encontraron usuarios para <strong>{pattern}</strong>",
-    "Unable to add user to group {group}" : "No fue posible agregar el usuario al grupo {group}",
-    "Unable to remove user from group {group}" : "No fue posible eliminar el usuario del grupo {group}",
-    "Invalid quota value \"{val}\"" : "Valor de cuota inválido \"{val}\"",
-    "no group" : "sin grupos",
-    "Password successfully changed" : "La contraseña se cambió exitosamente",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "El cambiar la contraseña puede generar pérdida de datos, porque la recuperación de datos no está disponible para este usuario",
-    "Could not change the users email" : "No fue posible cambiar el correo electrónico del usuario. ",
-    "Error while changing status of {user}" : "Se presentó un error al cambiar el estatus del usuario {user}",
-    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
-    "Error creating user: {message}" : "Se presentó un error al crear el usuario: {message}",
-    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
-    "A valid email must be provided" : "Se debe proporcionar un correo electrónico válido",
-    "by %s" : "por %s",
-    "%s-licensed" : "%s-licensed",
-    "Documentation:" : "Documentación:",
-    "Show description …" : "Mostrar descripción ...",
-    "Hide description …" : "Ocultar descripción ...",
-    "This app has an update available." : "Esta aplicación tiene una actualización disponible.",
-    "Enable only for specific groups" : "Habilitar sólo para grupos específicos",
-    "Online documentation" : "Documentación en línea",
-    "Getting help" : "Obtener ayuda",
-    "Commercial support" : "Soporte comercial",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Tricks section and the documentation for more information." : "Es importante que todo esté configurado correctamente por la seguridad y desempeño de tu instancia. Para ayudarte con esto, estamos haciendo unas validaciones automáticas. Por favor ve la sección de Consejos y Trucos así como la documentación para más información.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
-    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor verifica la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación de instalación ↗</a> para notas de configuración de PHP y la configuración de tu servidor de PHP, especialmete al usar php-fpm.",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuración de Sólo Lectura ha sido habilitada. Esto previene establecer algunas configuraciones mediante la interface web. Adicionalmente, el archivo necesita que se le establezca tener permisos de escritura manualmente en cada actualización. ",
-    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques internos de documentación. Esto hará que varias aplicaciones principales sean inaccesibles. ",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto es posiblemente causado por un caché/acelerador tal como Zend OPcache o eAccelerator.  ",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
-    "%1$s below version %2$s is installed, for stability and performance reasons it is recommended to update to a newer %1$s version." : "%1$s con versión inferior a %2$s está instalado, por razones de estabilidad y desempeño te recomendamos actualizar a una versión de %1$s más reciente. ",
-    "The PHP module 'fileinfo' is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "El modulo PHP 'fileinfo' no ha sido encontrado. Recomendamos ámpliamente que se habilite este módulo para obtener los mejores resultados en la detección de tipos MIME",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a> for more information." : "El bloqueo de archivos transaccional está deshabilitado. Esto puede generar problemas con condiciones extremas. Habilita 'filelocking.enabled' en el archivo config.php para evitar estos problemas. Consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación  ↗</a> para más información. ",
-    "System locale can not be set to a one which supports UTF-8." : "No es posible establecer la regionalización del sistema a una que soporte UTF-8.",
-    "This means that there might be problems with certain characters in filenames." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de archivos. ",
-    "It is strongly proposed to install the required packages on your system to support one of the following locales: %s." : "Se recomienda ámpliamente instalar los paquetes requeridos en tu sistema para soportar alguna de las siguientes regionalizaciones: %s.",
-    "If your installation is not installed at the root of the domain and uses system Cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si tu instalación no se hizo en la raíz del dominio y usa el sistema Cron, puede haber temas con la generación de la URL. Para prevenir estos problemas, por favor establece la opción  \"overwrite.cli.url\" en tu archivo config.php a la ruta del webroot de tu instalación (Se sugiere: \"%s\")",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No fue posible ejecutar el trabajo de cron via CLI. Se presentaron los siguientes errores técnicos:",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Por favor verifica las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">guias de instalación ↗</a>, y valida si hay algún error o advertencia en la <a href=\"%s\">bitácora</a>.",
-    "Tips & tricks" : "Consejos & trucos",
-    "There are a lot of features and config switches available to optimally customize and use this instance. Here are some pointers for more information." : "Existen muchas funcionalidades y configuraciones disponibles para personalizar y usar de manera óptima esta instancia. Aquí hay algunos consejos para más información. ",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation ↗</a>." : "Para migrar a otra base de datos usa la herramienta de línea de comandos;  'occ db:convert-type', o bien consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación ↗ </a>.",
-    "How to do backups" : "Cómo hacer respaldos",
-    "Performance tuning" : "Optimización de rendimiento",
-    "Improving the config.php" : "Mejorando la config.php",
-    "Theming" : "Tematizar",
-    "Check the security of your Nextcloud over our security scan" : "Verifica la seguridad de tu Nextcloud con nuestro escaneo de seguridad",
-    "Hardening and security guidance" : "Consejos de reforzamiento y seguridad",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Estás usando <strong>%s</strong> de <strong>%s</strong>",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Estás usando <strong>%s</strong> de <strong>%s</strong> (<strong> %s %%</strong>)",
-    "Settings" : "Configuraciones ",
-    "Show storage location" : "Mostrar la ubicación del almacenamiento",
-    "Show email address" : "Mostrar dirección de correo electrónico",
-    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "When the password of a new user is left empty, an activation email with a link to set the password is sent." : "Cuando la contraseña de un usuario nuevo se deja en blanco, se envía un correo electrónico de activación con una liga para establecerla.  ",
-    "E-Mail" : "Correo electrónico",
-    "Create" : "Crear",
-    "Admin Recovery Password" : "Recuperación de la contraseña del administrador",
-    "Enter the recovery password in order to recover the users files during password change" : "Ingresa la contraseña de recuperación con la finalidad de recuperar los archivos de los usuarios al cambiar la contraseña.",
-    "Disabled" : "Deshabilitado",
-    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indica la cuota de almacenamiento (ejem: \"512 MB\" ó \"12 GB\")",
-    "Other" : "Otro",
-    "change full name" : "cambiar el nombre completo",
-    "set new password" : "establecer nueva contraseña",
-    "change email address" : "cambiar la dirección de correo electrónico",
-    "Default" : "Predeterminado"
+    "Store credentials" : "Almacenar credenciales",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registrado en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP. ",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos. "
 },
 "nplurals=2; plural=(n != 1);");
