@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
+    "Migration started …" : "La migración ha comenzado ...",
+    "Saved" : "Guardado",
+    "Not saved" : "No guardado",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Se presentó un error. Por favor carga un certificado PEM con codificación ASCII",
+    "Valid until {date}" : "Válido hasta {date}",
+    "Delete" : "Borrar",
+    "Local" : "Local",
+    "Private" : "Privado",
+    "Only visible to local users" : "Visible sólo para usuarios locales",
+    "Only visible to you" : "Sólo visible para ti",
+    "Contacts" : "Contactos",
+    "Visible to local users and to trusted servers" : "Visible para usuarios locales y para servidores de confianza",
+    "Public" : "Público",
+    "Will be synced to a global and public address book" : "Será sincronizado a una libreta de direcciones global y pública",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando ...",
+    "Unable to change password" : "No fue posible cambiar la contraseña",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
+    "Select a profile picture" : "Selecciona una imagen de perfil",
+    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -14,9 +41,7 @@ OC.L10N.register(
     "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
     "Couldn't update app." : "No fue posible actualizar la aplicación.",
     "Wrong password" : "Contraseña incorrecta",
-    "Saved" : "Guardado",
     "No user supplied" : "No se proporcionó usuario alguno",
-    "Unable to change password" : "No fue posible cambiar la contraseña",
     "Authentication error" : "Error de autenticación",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
@@ -55,33 +80,26 @@ OC.L10N.register(
     "Set your password" : "Establece tu contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
-    "Delete" : "Borrar",
     "Unlimited" : "Ilimitado",
-    "Verifying …" : "Verificando ...",
-    "Verify" : "Verificar",
-    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
-    "Migration started …" : "La migración ha comenzado ...",
-    "Not saved" : "No guardado",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Se presentó un error. Por favor carga un certificado PEM con codificación ASCII",
-    "Valid until {date}" : "Válido hasta {date}",
-    "Local" : "Local",
-    "Private" : "Privado",
-    "Only visible to local users" : "Visible sólo para usuarios locales",
-    "Only visible to you" : "Sólo visible para ti",
-    "Contacts" : "Contactos",
-    "Visible to local users and to trusted servers" : "Visible para usuarios locales y para servidores de confianza",
-    "Public" : "Público",
-    "Will be synced to a global and public address book" : "Será sincronizado a una libreta de direcciones global y pública",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
-    "Select a profile picture" : "Selecciona una imagen de perfil",
-    "Groups" : "Grupos",
     "Limit to groups" : "Limitar a grupos",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad centralizada y se encuentran listas para ser usadas en producción. ",
+    "Official" : "Oficial",
+    "Remove" : "Eliminar",
+    "Disable" : "Deshabilitar",
+    "All" : "Todos",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
+    "View in store" : "Ver en la tienda",
+    "Visit website" : "Visita el sitio web",
+    "Report a bug" : "Reporta un detalle",
+    "User documentation" : "Documentación del usuario",
+    "Admin documentation" : "Documentación del administrador",
+    "Developer documentation" : "Documentación del desarrollador",
+    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Enable all" : "Habilitar todo",
+    "Enable" : "Habilitar",
+    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Revoke" : "Revocar",
     "Internet Explorer" : "Internet Explorer",
@@ -106,24 +124,6 @@ OC.L10N.register(
     "Done" : "Terminado",
     "Copied!" : "¡Copiado!",
     "Copy" : "Copiar",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad centralizada y se encuentran listas para ser usadas en producción. ",
-    "Official" : "Oficial",
-    "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
-    "All" : "Todos",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
-    "View in store" : "Ver en la tienda",
-    "Visit website" : "Visita el sitio web",
-    "Report a bug" : "Reporta un detalle",
-    "User documentation" : "Documentación del usuario",
-    "Admin documentation" : "Documentación del administrador",
-    "Developer documentation" : "Documentación del desarrollador",
-    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
-    "Enable all" : "Habilitar todo",
-    "Enable" : "Habilitar",
-    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
     "New password" : "Nueva contraseña",
     "{size} used" : "{size} usado",
     "Email" : "Correo electrónico",
@@ -172,7 +172,6 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Username" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Store credentials" : "Almacenar credenciales",
     "Test email settings" : "Probar las configuraciones de correo electrónico",
     "Send email" : "Enviar correo electrónico",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
@@ -199,8 +198,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un desempeño ideal, es importante configurar los trabajos de fondo correctamente. Para instancias más grandes 'Cron' es la configuración recomendada. Por favor consulta la documentación para más información. ",
     "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registrado en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP. ",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos. ",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
     "Sharing" : "Compartiendo",
@@ -253,6 +250,9 @@ OC.L10N.register(
     "Twitter handle @…" : "Cuenta de twitter @...",
     "Help translate" : "Ayuda a traducir",
     "Current password" : "Contraseña actual",
-    "Change password" : "Cambiar contraseña"
+    "Change password" : "Cambiar contraseña",
+    "Store credentials" : "Almacenar credenciales",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registrado en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP. ",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos. "
 },
 "nplurals=2; plural=(n != 1);");
