@@ -1,6 +1,34 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Kolimine on käimas. Palun oota, kuni see on lõpetatud",
+    "Migration started …" : "Kolimist on alustatud ...",
+    "Saved" : "Salvestatud",
+    "Not saved" : "Ei ole salvestatud",
+    "Sending…" : "Saadan...",
+    "Email sent" : "E-kiri on saadetud",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tekkis viga. Palun lae üles ASCII kodeeringud PEM sertifikaat.",
+    "Valid until {date}" : "Kehtib kuni {date}",
+    "Delete" : "Kustuta",
+    "Local" : "Kohalik",
+    "Private" : "Privaatne",
+    "Only visible to local users" : "Ainult nähtav kohalikele kasutajatele",
+    "Only visible to you" : "Ainult sinule nähtav",
+    "Contacts" : "Kontaktid",
+    "Visible to local users and to trusted servers" : "Nähtav kohelikele kasutajatele ja usaldatud serveritele",
+    "Public" : "Avalik",
+    "Will be synced to a global and public address book" : "Sünkroniseeritakse globaalsesse ja avalikku aadressiraamatusse",
+    "Verify" : "Kontrolli",
+    "Verifying …" : "Kontrollin ...",
+    "Unable to change password" : "Ei suuda parooli muuta",
+    "Very weak password" : "Väga nõrk parool",
+    "Weak password" : "Nõrk parool",
+    "So-so password" : "Enam-vähem sobiv parool",
+    "Good password" : "Hea parool",
+    "Strong password" : "Väga hea parool",
+    "Select a profile picture" : "Vali profiili pilt",
+    "Week starts on {fdow}" : "Nädala esimene päev: {fdow}",
+    "Groups" : "Grupid",
     "{actor} changed your password" : "{actor} muutis sinu parooli",
     "You changed your password" : "Sa muutsid oma parooli",
     "Your password was reset by an administrator" : "Administraator lähtestas sinu parooli",
@@ -14,9 +42,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Ei suutnud rakendit eemaldada.",
     "Couldn't update app." : "Rakenduse uuendamine ebaõnnestus.",
     "Wrong password" : "Vale parool",
-    "Saved" : "Salvestatud",
     "No user supplied" : "Kasutajat ei sisestatud",
-    "Unable to change password" : "Ei suuda parooli muuta",
     "Authentication error" : "Autentimise viga",
     "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "Paigaldan ja uuendan rakendusi läbi rakenduste poe või liitpilve jagamise",
@@ -51,41 +77,29 @@ OC.L10N.register(
     "Set your password" : "Määra oma parool",
     "Go to %s" : "Mine %s",
     "Install Client" : "Paigalda kliendiprogramm",
-    "Migration in progress. Please wait until the migration is finished" : "Kolimine on käimas. Palun oota, kuni see on lõpetatud",
-    "Migration started …" : "Kolimist on alustatud ...",
-    "Not saved" : "Ei ole salvestatud",
-    "Sending…" : "Saadan...",
-    "Email sent" : "E-kiri on saadetud",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tekkis viga. Palun lae üles ASCII kodeeringud PEM sertifikaat.",
-    "Valid until {date}" : "Kehtib kuni {date}",
-    "Delete" : "Kustuta",
-    "Local" : "Kohalik",
-    "Private" : "Privaatne",
-    "Only visible to local users" : "Ainult nähtav kohalikele kasutajatele",
-    "Only visible to you" : "Ainult sinule nähtav",
-    "Contacts" : "Kontaktid",
-    "Visible to local users and to trusted servers" : "Nähtav kohelikele kasutajatele ja usaldatud serveritele",
-    "Public" : "Avalik",
-    "Will be synced to a global and public address book" : "Sünkroniseeritakse globaalsesse ja avalikku aadressiraamatusse",
-    "Verify" : "Kontrolli",
-    "Verifying …" : "Kontrollin ...",
-    "Very weak password" : "Väga nõrk parool",
-    "Weak password" : "Nõrk parool",
-    "So-so password" : "Enam-vähem sobiv parool",
-    "Good password" : "Hea parool",
-    "Strong password" : "Väga hea parool",
-    "Select a profile picture" : "Vali profiili pilt",
-    "Week starts on {fdow}" : "Nädala esimene päev: {fdow}",
-    "Groups" : "Grupid",
+    "Unlimited" : "Piiramatult",
     "Limit to groups" : "Luba gruppidele",
+    "Official" : "Ametlik",
+    "Remove" : "Eemalda",
+    "Disable" : "Lülita välja",
+    "All" : "Kõik",
+    "No results" : "Vasteid ei leitud",
+    "Visit website" : "Külasta veebisaiti",
+    "Report a bug" : "Teata veast",
+    "User documentation" : "Kasutaja dokumentatsioon",
+    "Admin documentation" : "Administraatori dokumentatsioon",
+    "Developer documentation" : "Arendaja dokumentatsioon",
+    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
+    "Enable all" : "Luba kõik",
+    "Enable" : "Lülita sisse",
+    "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
+    "Revoke" : "Tühista",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
     "Google Chrome" : "Google Chrome",
     "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome for Android",
-    "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
-    "Revoke" : "Tühista",
     "Sync client - {os}" : "Kliendiprogramm - {os}",
     "This session" : "See sessioon",
     "Device" : "Seade",
@@ -101,19 +115,6 @@ OC.L10N.register(
     "Done" : "Valmis",
     "Copied!" : "Kopeeritud!",
     "Copy" : "Kopeeri",
-    "Official" : "Ametlik",
-    "Remove" : "Eemalda",
-    "Disable" : "Lülita välja",
-    "All" : "Kõik",
-    "No results" : "Vasteid ei leitud",
-    "Visit website" : "Külasta veebisaiti",
-    "Report a bug" : "Teata veast",
-    "User documentation" : "Kasutaja dokumentatsioon",
-    "Admin documentation" : "Administraatori dokumentatsioon",
-    "Developer documentation" : "Arendaja dokumentatsioon",
-    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
-    "Enable all" : "Luba kõik",
-    "Enable" : "Lülita sisse",
     "You do not have permissions to see the details of this user" : "Sul puuduvad õigused selle kasutaja üksikasjade vaatamiseks",
     "New password" : "Uus parool",
     "Delete user" : "Kustuta kasutaja",
@@ -131,7 +132,6 @@ OC.L10N.register(
     "User backend" : "Kasutaja taustarakendus",
     "Last login" : "Viimane sisselogimine",
     "Default language" : "Vaikekeel",
-    "Unlimited" : "Piiramatult",
     "Default quota" : "Vaikimisi mahupiir",
     "Common languages" : "Levinud keeled",
     "All languages" : "Kõik keeled",
@@ -143,13 +143,13 @@ OC.L10N.register(
     "New user" : "Uus kasutaja",
     "Default quota:" : "Vaikekvoot:",
     "Show last login" : "Näita viimast sisselogimist",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Sa oled eemaldamas gruppi {group}. Selles grupis olevaid kasutajaid EI kustutata.",
-    "Please confirm the group removal " : "Palun kinnita grupi eemaldamine",
     "Remove group" : "Eemalda grupp",
     "Admins" : "Haldurid",
     "Disabled users" : "Keelatud kasutajad",
     "Everyone" : "Igaüks",
     "Add group" : "Lisa grupp",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Sa oled eemaldamas gruppi {group}. Selles grupis olevaid kasutajaid EI kustutata.",
+    "Please confirm the group removal " : "Palun kinnita grupi eemaldamine",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Rakendus on lubatud, aga see vajab uuendamist. Sind suunatakse 5 sekundi pärast uuendamise lehele.",
     "SSL Root Certificates" : "SSL juursertifikaadid",
     "Common Name" : "Üldnimetus",
@@ -180,7 +180,6 @@ OC.L10N.register(
     "Credentials" : "Kasutajatunnused",
     "SMTP Username" : "SMTP kasutajatunnus",
     "SMTP Password" : "SMTP parool",
-    "Store credentials" : "Säilita kasutajaandmed",
     "Test email settings" : "Testi e-posti seadeid",
     "Send email" : "Saada kiri",
     "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
@@ -194,8 +193,6 @@ OC.L10N.register(
     "Select default encryption module:" : "Määra vaikimisi krüpteerimise moodul:",
     "Start migration" : "Alusta kolimist",
     "Execute one task with each page loaded" : "Käivita toiming igal lehe laadimisel",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti järel.",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php tuleb käivitada süsteemikasutaja \"%s\" poolt.",
     "Sharing" : "Jagamine",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administraatorina saate jagamise valikuid täpselt seadistada. Lisateavet leiad dokumentatsioonist.",
@@ -241,6 +238,9 @@ OC.L10N.register(
     "Help translate" : "Aita tõlkida",
     "Locale" : "Kasutuskoht",
     "Current password" : "Praegune parool",
-    "Change password" : "Muuda parooli"
+    "Change password" : "Muuda parooli",
+    "Store credentials" : "Säilita kasutajaandmed",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti järel."
 },
 "nplurals=2; plural=(n != 1);");
