@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
+    "Migration started …" : "Migraatio käynnistyi…",
+    "Saved" : "Tallennettu",
+    "Not saved" : "Ei tallennettu",
+    "Sending…" : "Lähetetään…",
+    "Email sent" : "Sähköposti lähetetty",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
+    "Valid until {date}" : "Kelvollinen {date} asti",
+    "Delete" : "Poista",
+    "Local" : "Paikallinen",
+    "Private" : "Yksityinen",
+    "Only visible to local users" : "Näkyvillä vain paikallisille käyttäjille",
+    "Only visible to you" : "Näkyvillä vain sinulle",
+    "Contacts" : "Yhteystiedot",
+    "Visible to local users and to trusted servers" : "Näkyvillä vain paikallisille käyttäjille ja luotetuille palvelimille",
+    "Public" : "Julkinen",
+    "Will be synced to a global and public address book" : "Synkronoidaan maailmanlaajuiseen ja julkiseen osoitekirjaan",
+    "Verify" : "Vahvista",
+    "Verifying …" : "Vahvistetaan…",
+    "Unable to change password" : "Salasanan vaihto ei onnistunut",
+    "Very weak password" : "Erittäin heikko salasana",
+    "Weak password" : "Heikko salasana",
+    "So-so password" : "Kohtalainen salasana",
+    "Good password" : "Hyvä salasana",
+    "Strong password" : "Vahva salasana",
+    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "Select a profile picture" : "Valitse profiilikuva",
+    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
+    "Groups" : "Ryhmät",
+    "Group list is empty" : "Ryhmälista on tyhjä",
+    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
     "{actor} added you to group {group}" : "{actor} lisäsi sinut ryhmään {group}",
     "You added {user} to group {group}" : "Lisäsit käyttäjän {user} ryhmään {group}",
     "{actor} added {user} to group {group}" : "{actor} lisäsi käyttäjän {user} ryhmään {group}",
@@ -29,9 +61,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
     "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
     "Wrong password" : "Väärä salasana",
-    "Saved" : "Tallennettu",
     "No user supplied" : "Käyttäjää ei määritetty",
-    "Unable to change password" : "Salasanan vaihto ei onnistunut",
     "Authentication error" : "Tunnistautumisvirhe",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
@@ -71,38 +101,11 @@ OC.L10N.register(
     "Install Client" : "Asenna sovellus",
     "Create" : "Luo",
     "Change" : "Muuta",
-    "Delete" : "Poista",
     "Share" : "Jaa",
     "Unlimited" : "Rajoittamaton",
-    "Verifying …" : "Vahvistetaan…",
-    "Verify" : "Vahvista",
-    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
-    "Migration started …" : "Migraatio käynnistyi…",
-    "Not saved" : "Ei tallennettu",
-    "Sending…" : "Lähetetään…",
-    "Email sent" : "Sähköposti lähetetty",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
-    "Valid until {date}" : "Kelvollinen {date} asti",
-    "Local" : "Paikallinen",
-    "Private" : "Yksityinen",
-    "Only visible to local users" : "Näkyvillä vain paikallisille käyttäjille",
-    "Only visible to you" : "Näkyvillä vain sinulle",
-    "Contacts" : "Yhteystiedot",
-    "Visible to local users and to trusted servers" : "Näkyvillä vain paikallisille käyttäjille ja luotetuille palvelimille",
-    "Public" : "Julkinen",
-    "Will be synced to a global and public address book" : "Synkronoidaan maailmanlaajuiseen ja julkiseen osoitekirjaan",
-    "Very weak password" : "Erittäin heikko salasana",
-    "Weak password" : "Heikko salasana",
-    "So-so password" : "Kohtalainen salasana",
-    "Good password" : "Hyvä salasana",
-    "Strong password" : "Vahva salasana",
-    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
-    "Select a profile picture" : "Valitse profiilikuva",
-    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
-    "Groups" : "Ryhmät",
-    "Group list is empty" : "Ryhmälista on tyhjä",
-    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
+    "Verifying" : "Vahvistetaan",
+    "Nextcloud settings" : "Nextcloud-asetukset",
+    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille\tkäyttäjille ja tietyille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
     "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
     "Limit to groups" : "Rajoita ryhmiin",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Kaksivaiheisen tunnistautumisen pakottaminen on mahdollista kohdentaa vain tietyille ryhmille.",
@@ -110,42 +113,6 @@ OC.L10N.register(
     "Enforced groups" : "Pakotetut ryhmät",
     "Two-factor authentication is not enforced for\tmembers of the following groups." : "Kaksivaiheinen tunnistautuminen ei ole pakotettu\tseuraavien ryhmien jäsenille.",
     "Save changes" : "Tallenna muutokset",
-    "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
-    "Device settings" : "Laiteasetukset",
-    "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
-    "Rename" : "Nimeä uudelleen",
-    "Revoke" : "Peru oikeus",
-    "Wipe device" : "Tyhjennä laite",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome Android-laitteelle",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
-    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
-    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
-    "Sync client - {os}" : "Synkronointisovellus - {os}",
-    "This session" : "Tämä istunto",
-    "Device" : "Laite",
-    "Last activity" : "Viimeksi käytetty",
-    "Devices & sessions" : "Laitteet ja istunnot",
-    "Web, desktop and mobile clients currently logged in to your account." : "Verkko-, työpöytä- ja mobiililaitteet, jotka ovat parhaillaan kirjautuneet tilillesi.",
-    "Do you really want to wipe your data from this device?" : "Haluatko varmasit tyhjentää tiedot tältä laitteelta?",
-    "Confirm wipe" : "Vahvista tyhjentäminen",
-    "App name" : "Sovelluksen nimi",
-    "Create new app password" : "Luo uusi sovellussalasana",
-    "Use the credentials below to configure your app or device." : "Käytä oheista tunnusta ja salasanaa konfiguroidessasi sovelluksen tai laitteen.",
-    "For security reasons this password will only be shown once." : "Turvallisuussyistä tämä salasana näytetään vain kerran.",
-    "Username" : "Käyttäjätunnus",
-    "Password" : "Salasana",
-    "Done" : "Valmis",
-    "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
-    "Copied!" : "Kopioitu!",
-    "Copy" : "Kopioi",
     "This app is supported via your current Nextcloud subscription." : "Tämä sovellus on tuettu nykyisen Nextcloud-tilauksesi kautta.",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Viralliset sovellukset ovat yhteisössä kehitettyjä. Ne tarjoavat keskeistä toiminnallisuutta ja ovat valmiita tuotantokäyttöön.",
     "Official" : "Virallinen",
@@ -172,6 +139,46 @@ OC.L10N.register(
     "Download and enable" : "Lataa ja ota käyttöön",
     "Enable" : "Käytä",
     "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
+    "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
+    "Device settings" : "Laiteasetukset",
+    "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
+    "Rename" : "Nimeä uudelleen",
+    "Revoke" : "Peru oikeus",
+    "Wipe device" : "Tyhjennä laite",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome Android-laitteelle",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
+    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
+    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
+    "Sync client - {os}" : "Synkronointisovellus - {os}",
+    "This session" : "Tämä istunto",
+    "Device" : "Laite",
+    "Last activity" : "Viimeksi käytetty",
+    "Devices & sessions" : "Laitteet ja istunnot",
+    "Web, desktop and mobile clients currently logged in to your account." : "Verkko-, työpöytä- ja mobiililaitteet, jotka ovat parhaillaan kirjautuneet tilillesi.",
+    "Do you really want to wipe your data from this device?" : "Haluatko varmasit tyhjentää tiedot tältä laitteelta?",
+    "Confirm wipe" : "Vahvista tyhjentäminen",
+    "Error while creating device token" : "Virhe laitepolettia luotaessa",
+    "Error while updating device token name" : "Virhe laitepoletin nimeä päivittäessä",
+    "Error while deleting the token" : "Virhe polettia poistaessa",
+    "Error while wiping the device with the token" : "Virhe tyhjennettäessä laitetta polettia käyttäen",
+    "App name" : "Sovelluksen nimi",
+    "Create new app password" : "Luo uusi sovellussalasana",
+    "Use the credentials below to configure your app or device." : "Käytä oheista tunnusta ja salasanaa konfiguroidessasi sovelluksen tai laitteen.",
+    "For security reasons this password will only be shown once." : "Turvallisuussyistä tämä salasana näytetään vain kerran.",
+    "Username" : "Käyttäjätunnus",
+    "Password" : "Salasana",
+    "Done" : "Valmis",
+    "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
+    "Copied!" : "Kopioitu!",
+    "Copy" : "Kopioi",
     "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "New password" : "Uusi salasana",
     "Add user in group" : "Lisää käyttäjä ryhmään",
@@ -180,7 +187,7 @@ OC.L10N.register(
     "Never" : "Ei koskaan",
     "Delete user" : "Poista käyttäjä",
     "Wipe all devices" : "Tyhjennä kaikki laitteet",
-    "Disable user" : "Poista käytöstä käyttäjä",
+    "Disable user" : "Poista käyttäjä käytöstä",
     "Enable user" : "Ota käyttäjä käyttöön",
     "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
     "{size} used" : "{size} käytetty",
@@ -212,13 +219,13 @@ OC.L10N.register(
     "Show last login" : "Näytä viimeisin sisäänkirjautuminen",
     "Show user backend" : "Näytä käyttäjätaustaosa",
     "Show storage path" : "Näytä tallennustilan polku",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
-    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
     "Remove group" : "Poista ryhmä",
     "Admins" : "Ylläpitäjät",
     "Disabled users" : "Käytöstä poistetut käyttäjät",
     "Everyone" : "Kaikki",
     "Add group" : "Lisää ryhmä",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
+    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
     "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
     "App update" : "Sovelluspäivitys",
@@ -252,7 +259,7 @@ OC.L10N.register(
     "Credentials" : "Tilitiedot",
     "SMTP Username" : "SMTP-käyttäjätunnus",
     "SMTP Password" : "SMTP-salasana",
-    "Store credentials" : "Säilytä tilitiedot",
+    "Save" : "Tallenna",
     "Test email settings" : "Testaa sähköpostiasetukset",
     "Send email" : "Lähetä sähköpostiviesti",
     "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
@@ -283,7 +290,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Taustatyötä ei suoritettu vielä!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Optimaalisen suorituskyvyn vuoksi on tärkeää määrittää taustatyöt oikein. Suuria asennuksia varten 'Cron' on suositeltava asetus. Lisätietoja on saatavilla dokumentaatiossa.",
     "Execute one task with each page loaded" : "Suorita yksi tehtävä jokaista ladattua sivua kohden",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Käytä järjestelmän cron-palvelua kutsuaksesi cron.php-tiedostoa 15 minuutin välein.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
     "Sharing" : "Jakaminen",
@@ -310,7 +316,7 @@ OC.L10N.register(
     "Administration" : "Ylläpito",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
     "Like our Facebook page" : "Tykkää Facebook-sivustamme",
-    "Follow us on Twitter" : "Seuraa Twitteriä",
+    "Follow us on Twitter" : "Seuraa meitä Twitterissä",
     "Follow us on Mastodon" : "Seuraa meitä Mastodonissa",
     "Check out our blog" : "Lue blogia",
     "Subscribe to our newsletter" : "Tilaa uutiskirje",
@@ -346,13 +352,12 @@ OC.L10N.register(
     "Change password" : "Vaihda salasana",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "Disconnect" : "Katkaise yhteys",
-    "iPhone iOS" : "iPhone iOS",
-    "iPad iOS" : "iPad iOS",
-    "iOS Client" : "iOS-asiakas",
-    "Android Client" : "Android-asiakas",
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Default quota :" : "Oletuskiintiö:"
+    "Error while loading browser sessions and device tokens" : "Virhe ladatessa selainistuntoja ja laitepoletteja",
+    "Store credentials" : "Säilytä tilitiedot",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Käytä järjestelmän cron-palvelua kutsuaksesi cron.php-tiedostoa 15 minuutin välein.",
+    "Follow us on Google+" : "Seuraa meitä Google+:ssa"
 },
 "nplurals=2; plural=(n != 1);");
