@@ -1,6 +1,36 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
+    "Migration started …" : "המרה החלה...",
+    "Saved" : "נשמר",
+    "Not saved" : "לא נשמר",
+    "Sending…" : "בשליחה…",
+    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "אירעה שגיאה. יש להעלות תעודת ASCII-encoded PEM.",
+    "Valid until {date}" : "בתוקף עד ל- {date}",
+    "Delete" : "מחיקה",
+    "Local" : "מקומ",
+    "Private" : "פרטי",
+    "Only visible to local users" : "גלוי למשתמשים מקומיים בלבד",
+    "Only visible to you" : "גלוי רק לך",
+    "Contacts" : "אנשי קשר",
+    "Visible to local users and to trusted servers" : "גלוי למשתמשים מקומיים ולשרתים מהימנים",
+    "Public" : "ציבורי",
+    "Will be synced to a global and public address book" : "יסונכרן לספר כתובות גלובלי וציבורי",
+    "Verify" : "אימות",
+    "Verifying …" : "מתבצע אימות…",
+    "Unable to change password" : "לא ניתן לשנות את הססמה",
+    "Very weak password" : "סיסמא מאוד חלשה",
+    "Weak password" : "סיסמא חלשה",
+    "So-so password" : "סיסמא ככה-ככה",
+    "Good password" : "סיסמא טובה",
+    "Strong password" : "סיסמא חזקה",
+    "Select a profile picture" : "יש לבחור תמונת פרופיל",
+    "Week starts on {fdow}" : "השבוע מתחיל ב{fdow}",
+    "Groups" : "קבוצות",
+    "Group list is empty" : "רשימת הקבוצות ריקה",
+    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
     "{actor} added you to group {group}" : "נוספת לקבוצה {group} על ידי {actor}",
     "You added {user} to group {group}" : "הוספת את {user} לקבוצה {group}",
     "{actor} added {user} to group {group}" : "ההוספה של {user} לקבוצה {group} נעשתה על ידי {actor}",
@@ -18,9 +48,7 @@ OC.L10N.register(
     "Couldn't remove app." : "לא ניתן להסיר את היישום.",
     "Couldn't update app." : "לא ניתן לעדכן את היישום.",
     "Wrong password" : "ססמה שגויה",
-    "Saved" : "נשמר",
     "No user supplied" : "לא סופק שם משתמש",
-    "Unable to change password" : "לא ניתן לשנות את הססמה",
     "Authentication error" : "שגיאת אימות",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
     "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
@@ -59,133 +87,41 @@ OC.L10N.register(
     "Set your password" : "הגדרת הססמה שלך",
     "Go to %s" : "מעבר אל %s",
     "Install Client" : "התקנת לקו",
-    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
-    "Migration started …" : "המרה החלה...",
-    "Not saved" : "לא נשמר",
-    "Sending…" : "בשליחה…",
-    "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "אירעה שגיאה. יש להעלות תעודת ASCII-encoded PEM.",
-    "Valid until {date}" : "בתוקף עד ל- {date}",
-    "Delete" : "מחיקה",
-    "Local" : "מקומ",
-    "Private" : "פרטי",
-    "Only visible to local users" : "גלוי למשתמשים מקומיים בלבד",
-    "Only visible to you" : "גלוי רק לך",
-    "Contacts" : "אנשי קשר",
-    "Visible to local users and to trusted servers" : "גלוי למשתמשים מקומיים ולשרתים מהימנים",
-    "Public" : "ציבורי",
-    "Will be synced to a global and public address book" : "יסונכרן לספר כתובות גלובלי וציבורי",
-    "Verify" : "אימות",
-    "Verifying …" : "מתבצע אימות…",
-    "Very weak password" : "סיסמא מאוד חלשה",
-    "Weak password" : "סיסמא חלשה",
-    "So-so password" : "סיסמא ככה-ככה",
-    "Good password" : "סיסמא טובה",
-    "Strong password" : "סיסמא חזקה",
-    "Select a profile picture" : "יש לבחור תמונת פרופיל",
-    "Week starts on {fdow}" : "השבוע מתחיל ב{fdow}",
-    "Groups" : "קבוצות",
-    "Group list is empty" : "רשימת הקבוצות ריקה",
-    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
-    "Afrikaans (Namibia)" : "אפריקאנס (נמיביה)",
-    "Afrikaans (South Africa)" : "אפריקאנס (דרום אפריקה)",
-    "Afrikaans" : "אפריקאנס",
-    "Albanian (Albania)" : "אלבנית (אלבניה)",
-    "Albanian" : "אלבנית",
-    "Amharic (Ethiopia)" : "אמהרית (אתיופיה)",
-    "Amharic" : "אמהרית",
-    "Arabic (Algeria)" : "ערבית (אלג׳יריה)",
-    "Arabic (Bahrain)" : "ערבית (בחריין)",
-    "Arabic (Egypt)" : "ערבית (מצרים)",
-    "Arabic (Iraq)" : "ערבית (עיראק)",
-    "Arabic (Jordan)" : "ערבית (ירדן)",
-    "Arabic (Kuwait)" : "ערבית (כוויית)",
-    "Arabic (Lebanon)" : "ערבית (לבנון)",
-    "Arabic (Libya)" : "ערבית (לוב)",
-    "Arabic (Morocco)" : "ערבית (מרוקו)",
-    "Arabic (Oman)" : "ערבית (עומאן)",
-    "Arabic (Qatar)" : "ערבית (קטאר)",
-    "Arabic (Saudi Arabia)" : "ערבית (ערב הסעודית)",
-    "Arabic (Sudan)" : "ערבית (סודאן)",
-    "Arabic (Syria)" : "ערבית (סוריה)",
-    "Arabic (Tunisia)" : "ערבית (תוניסיה)",
-    "Arabic (United Arab Emirates)" : "ערבית (איחוד האמירויות הערביות)",
-    "Arabic (Yemen)" : "ערבית (תימן)",
-    "Arabic" : "ערבית",
-    "Armenian (Armenia)" : "ארמנית (ארמניה)",
-    "Armenian" : "ארמנית",
-    "Azerbaijani (Cyrillic)" : "אזרית (בכתב קירילי)",
-    "Azerbaijani (Cyrillic, Azerbaijan)" : "אזרית (בכתב קירילי, אזרבייג׳ן)",
-    "Azerbaijani (Latin)" : "אזרית (בכתב לטיני)",
-    "Azerbaijani (Latin, Azerbaijan)" : "אזרית (בכתב לטיני, אזרבייג׳ן)",
-    "Azerbaijani" : "אזרית",
-    "Basque (Spain)" : "בסקית (ספרד)",
-    "Basque" : "בסקית",
-    "Belarusian (Belarus)" : "בלרוסית (בלרוס)",
-    "Belarusian" : "בלרוסית",
-    "Chiga (Uganda)" : "צ׳יגה (אוגנדה)",
-    "Chiga" : "צ׳יגה",
-    "Croatian (Croatia)" : "קרואטית (קרואטיה)",
-    "Croatian" : "קרואטית",
-    "Czech (Czech Republic)" : "צ׳כית (הרפובליקה הצ׳כית)",
-    "Czech" : "צ׳כית",
-    "Danish (Denmark)" : "דנית (דנמרק)",
-    "Danish" : "דנית",
-    "Dutch (Belgium)" : "הולנדית (בלגיה)",
-    "Dutch (Netherlands)" : "הולנדית (הולנד)",
-    "Dutch" : "הולנדית",
-    "English" : "אנגלית",
-    "Esperanto" : "אספרנטו",
-    "Estonian (Estonia)" : "אסטונית (אסטוניה)",
-    "Estonian" : "אסטונית",
-    "Filipino (Philippines)" : "פיליפינו (הפיליפינים)",
-    "Filipino" : "פיליפינו",
-    "Finnish (Finland)" : "פינית (פינלנד)",
-    "Finnish" : "פינית",
-    "French (Belgium)" : "צרפתית (בלגיה)",
-    "French (Benin)" : "צרפתית (בנין)",
-    "French (Burkina Faso)" : "צרפתית (בורקינה פאסו)",
-    "French (Burundi)" : "צרפת (בורונדי)",
-    "French (Cameroon)" : "צרפתית (קמרון)",
-    "French (Canada)" : "צרפתית (קנדה)",
-    "French (Central African Republic)" : "צרפתית (הרפובליקה המרכז אפריקאית)",
-    "French (Chad)" : "צרפתית (צ׳אד)",
-    "French (Comoros)" : "צרפתית (קומורוס)",
-    "French (France)" : "צרפתית (צרפת)",
-    "French (Monaco)" : "צרפתית (מונקו)",
-    "French (Senegal)" : "צרפתית (סנגל)",
-    "French (Switzerland)" : "צרפתית (שווייץ)",
-    "French (Togo)" : "צרפתית (טוגו)",
-    "French" : "צרפתית",
-    "Fulah (Senegal)" : "פולה (סנגל)",
-    "Fulah" : "פולה",
-    "Galician (Spain)" : "גליסית (ספרד)",
-    "Galician" : "גליסית",
-    "Ganda (Uganda)" : "גנדה (אוגנדה)",
-    "Ganda" : "גנדה",
-    "Georgian (Georgia)" : "גאורגית (גאורגיה)",
-    "Georgian" : "גאורגית",
-    "German (Austria)" : "גרמנית (אוסטריה)",
-    "German (Belgium)" : "גרמנית (בלגיה)",
-    "German (Germany)" : "גרמנית (גרמניה)",
-    "German (Liechtenstein)" : "גרמנית (ליכטנשטיין)",
-    "German (Luxembourg)" : "גרמנית (לוקסמבורג)",
-    "German (Switzerland)" : "גרמנית (שווייץ)",
-    "German" : "גרמנית",
-    "Greek (Cyprus)" : "יוונית (קפריסין)",
-    "Greek (Greece)" : "יוונית (יוון)",
-    "Greek" : "יוונית",
-    "Hebrew (Israel)" : "עברית (ישראל)",
-    "Hebrew" : "עברית",
+    "Unlimited" : "ללא הגבלה",
     "Limit to groups" : "הגבלה לקבוצות",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "היישומונים הרשמיים מפותחים על ידי ובתוך הקהילה. הם מציעים תכונות ליבה מסוימות והן מוכנות לשימוש יומיומי.",
+    "Official" : "רישמי",
+    "Remove" : "הסרה",
+    "Disable" : "ניטרול",
+    "All" : "הכל",
+    "No results" : "אין תוצאות",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
+    "View in store" : "הצגה באחסון",
+    "Visit website" : "ביקור באתר האינטרנט",
+    "Report a bug" : "דיווח על באג",
+    "User documentation" : "תיעוד משתמש",
+    "Admin documentation" : "תיעוד מנהל",
+    "Developer documentation" : "תיעוד מפתח",
+    "Update to {update}" : "עדכון ל־{version}",
+    "Results from other categories" : "תוצאות מקטגוריות אחרות",
+    "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
+    "Disable all" : "להשבית הכול",
+    "Enable all" : "הפעלת הכול",
+    "Download and enable" : "להוריד ולהפעיל",
+    "Enable" : "הפעלה",
+    "Enable untested app" : "לאפשר יישומון שלא נבדק",
+    "The app will be downloaded from the app store" : "היישום ירד מחנות היישומים",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
+    "Allow filesystem access" : "לאפשר גישה למערכת הקבצים",
+    "Revoke" : "שלילה",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
     "Google Chrome" : "Google Chrome",
     "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome עבור Android",
-    "Allow filesystem access" : "לאפשר גישה למערכת הקבצים",
-    "Revoke" : "שלילה",
     "Sync client - {os}" : "לקוח סנכרון - {os}",
     "This session" : "הפעלה זו",
     "Device" : "התקן",
@@ -203,26 +139,19 @@ OC.L10N.register(
     "Done" : "הסתיים",
     "Copied!" : "הועתק!",
     "Copy" : "העתקה",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "היישומונים הרשמיים מפותחים על ידי ובתוך הקהילה. הם מציעים תכונות ליבה מסוימות והן מוכנות לשימוש יומיומי.",
-    "Official" : "רישמי",
-    "Remove" : "הסרה",
-    "Disable" : "ניטרול",
-    "All" : "הכל",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מזערית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ליישומון זה לא מוקצית גרסת Nextcloud מרבית. מצב כזה עשוי להוביל לשגיאה בעתיד.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
-    "View in store" : "הצגה באחסון",
-    "Visit website" : "ביקור באתר האינטרנט",
-    "Report a bug" : "דיווח על באג",
-    "User documentation" : "תיעוד משתמש",
-    "Admin documentation" : "תיעוד מנהל",
-    "Developer documentation" : "תיעוד מפתח",
-    "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
-    "Enable all" : "הפעלת הכול",
-    "Enable" : "הפעלה",
-    "The app will be downloaded from the app store" : "היישום ירד מחנות היישומים",
+    "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
+    "The backend does not support changing the display name" : "המנגנון שלך לא תומך בשינוי שם התצוגה",
     "New password" : "סיסמא חדשה",
+    "Select user quota" : "בחירת מכסת משתמש",
+    "No language set" : "לא הוגדרה שפה",
+    "Never" : "מעולם לא",
+    "Delete user" : "מחיקת משתמש",
+    "Disable user" : "השבתת משתמש",
+    "Enable user" : "הפעלת משתמש",
+    "Resend welcome email" : "שליחת הודעת קבלת פנים בדוא״ל מחדש",
     "{size} used" : "{size} בשימוש",
+    "Welcome mail sent!" : "נשלחה הודעת קבלת פנים בדוא״ל!",
+    "Display name" : "שם תצוגה",
     "Email" : "דואר אלקטרוני",
     "Group admin for" : "מנהל הקבוצה",
     "Quota" : "מכסה",
@@ -230,17 +159,32 @@ OC.L10N.register(
     "Storage location" : "מיקום אחסון",
     "User backend" : "מנגנון משתמש",
     "Last login" : "כניסה אחרונה",
-    "Unlimited" : "ללא הגבלה",
+    "Default language" : "שפת בררת מחדל",
+    "Add a new user" : "הוספת משתמש חדש",
+    "No users in here" : "אין כאן משתמשים",
     "Default quota" : "מכסת בררת מחדל",
+    "Common languages" : "שפות נפוצות",
+    "All languages" : "כל השפות",
     "Your apps" : "היישומונים שלך",
+    "Active apps" : "יישומונים פעילים",
     "Disabled apps" : "יישומונים מושבתים",
     "Updates" : "עדכונים",
     "App bundles" : "מאגדי יישומונים",
+    "{license}-licensed" : "ברישיון {license}",
+    "New user" : "משתמש חדש",
+    "Default quota:" : "מכסת בררת מחדל:",
+    "Select default quota" : "בחירת מכסת בררת מחדל",
+    "Show Languages" : "הצגת שפות",
     "Show last login" : "הצגת כניסה אחרונה",
     "Show user backend" : "הצגת צד אחורי למשתמש",
+    "Show storage path" : "הצגת נתיב אחסון",
+    "Remove group" : "הסרת קבוצה",
     "Admins" : "מנהלים",
+    "Disabled users" : "משתמשים מושבתים",
     "Everyone" : "כולם",
     "Add group" : "הוספת קבוצה",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
+    "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
     "An error occured during the request. Unable to proceed." : "אירעה שגיאה במהלך הבקשה. לא ניתן להמשיך.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
     "App update" : "עדכון יישומן",
@@ -252,6 +196,7 @@ OC.L10N.register(
     "Valid until %s" : "בתוקף עד %s",
     "Import root certificate" : "יבוא אישור אבטחה לנתיב יסוד",
     "Administrator documentation" : "תיעוד מנהל",
+    "Documentation" : "תיעוד",
     "Forum" : "פורום",
     "None" : "כלום",
     "Login" : "התחברות",
@@ -273,7 +218,6 @@ OC.L10N.register(
     "Credentials" : "פרטי גישה",
     "SMTP Username" : "שם משתמש SMTP ",
     "SMTP Password" : "סיסמת SMTP",
-    "Store credentials" : "שמירת אישורים",
     "Test email settings" : "בדיקת הגדרות דואר אלקטרוני",
     "Send email" : "שליחת דואר אלקטרוני",
     "Security & setup warnings" : "הזהרות אבטחה והתקנה",
@@ -284,6 +228,7 @@ OC.L10N.register(
     "Checking for system and security issues." : "נבדקות תקלות מערכת ואבטחה.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "בדיקת האבטחה של ה־Nextcloud שלך באמצעות <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">סריקת האבטחה שלנו ↖️</a>.",
     "Version" : "גרסה",
+    "Two-Factor Authentication" : "אימות דו־שלבי",
     "Server-side encryption" : "הצפנת צד שרת",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "הצפנה בצד השרת מאפשרת להצפין קבצים שנשלחים לשרת. לתכונה זו יש מגבלות כגון ירידה בביצועים, מומלץ להפעיל רק אם יש צורך.",
     "Enable server-side encryption" : "הפעלת הצפנה בצד שרת",
@@ -305,8 +250,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "משימת הרקע לא רצה עדיין!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "לביצועים מיטביים חשוב להגדיר משימות רקע כראוי. למערכות גדולות יותר מוטב להשתמש ב־‚Cron’. נא לעיין בתיעוד לקבל מידע נוסף.",
     "Execute one task with each page loaded" : "יש להפעיל משימה אחת עם כל עמוד שנטען",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php רשום בשירות webcron לקרוא ל- cron.php בכל 15 דקות באמצעות HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "ניתן להשתמש בשירות cron של המערכת כדי לקרוא לקובץ cron.php בכל 15 דקות.",
     "The cron.php needs to be executed by the system user \"%s\"." : "יש להפעיל את cron.php בתור משתמש המערכת „%s”.",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "כדי להריץ זאת יש צורך בהרחבת POSIX ל־PHP. נא לעיין ב{linkstart}תיעוד של PHP{linkend} לפרטים נוספים.",
     "Sharing" : "שיתוף",
@@ -364,6 +307,159 @@ OC.L10N.register(
     "Help translate" : "עזרה בתרגום",
     "Locale" : "הגדרות אזוריות",
     "Current password" : "סיסמא נוכחית",
-    "Change password" : "שינוי סיסמא"
+    "Change password" : "שינוי סיסמא",
+    "Disconnect" : "ניתוק",
+    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
+    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
+    "Afrikaans (Namibia)" : "אפריקאנס (נמיביה)",
+    "Afrikaans (South Africa)" : "אפריקאנס (דרום אפריקה)",
+    "Afrikaans" : "אפריקאנס",
+    "Albanian (Albania)" : "אלבנית (אלבניה)",
+    "Albanian" : "אלבנית",
+    "Amharic (Ethiopia)" : "אמהרית (אתיופיה)",
+    "Amharic" : "אמהרית",
+    "Arabic (Algeria)" : "ערבית (אלג׳יריה)",
+    "Arabic (Bahrain)" : "ערבית (בחריין)",
+    "Arabic (Egypt)" : "ערבית (מצרים)",
+    "Arabic (Iraq)" : "ערבית (עיראק)",
+    "Arabic (Jordan)" : "ערבית (ירדן)",
+    "Arabic (Kuwait)" : "ערבית (כוויית)",
+    "Arabic (Lebanon)" : "ערבית (לבנון)",
+    "Arabic (Libya)" : "ערבית (לוב)",
+    "Arabic (Morocco)" : "ערבית (מרוקו)",
+    "Arabic (Oman)" : "ערבית (עומאן)",
+    "Arabic (Qatar)" : "ערבית (קטאר)",
+    "Arabic (Saudi Arabia)" : "ערבית (ערב הסעודית)",
+    "Arabic (Sudan)" : "ערבית (סודאן)",
+    "Arabic (Syria)" : "ערבית (סוריה)",
+    "Arabic (Tunisia)" : "ערבית (תוניסיה)",
+    "Arabic (United Arab Emirates)" : "ערבית (איחוד האמירויות הערביות)",
+    "Arabic (Yemen)" : "ערבית (תימן)",
+    "Arabic" : "ערבית",
+    "Armenian (Armenia)" : "ארמנית (ארמניה)",
+    "Armenian" : "ארמנית",
+    "Assamese (India)" : "אסאמית (הודו)",
+    "Assamese" : "אסאמית",
+    "Azerbaijani (Cyrillic)" : "אזרית (בכתב קירילי)",
+    "Azerbaijani (Cyrillic, Azerbaijan)" : "אזרית (בכתב קירילי, אזרבייג׳ן)",
+    "Azerbaijani (Latin)" : "אזרית (בכתב לטיני)",
+    "Azerbaijani (Latin, Azerbaijan)" : "אזרית (בכתב לטיני, אזרבייג׳ן)",
+    "Azerbaijani" : "אזרית",
+    "Basque (Spain)" : "בסקית (ספרד)",
+    "Basque" : "בסקית",
+    "Belarusian (Belarus)" : "בלרוסית (בלרוס)",
+    "Belarusian" : "בלרוסית",
+    "Bengali (Bangladesh)" : "בנגלית (בנגלדש)",
+    "Bengali (India)" : "בנגלית (הודו)",
+    "Bengali" : "בנגלית",
+    "Bosnian (Bosnia and Herzegovina)" : "בוסנית (בוסניה והרצגובינה)",
+    "Bosnian" : "בוסנית",
+    "Bulgarian (Bulgaria)" : "בולגרית (בולגריה)",
+    "Bulgarian" : "בולגרית",
+    "Burmese (Myanmar [Burma])" : "בורמזית (מיאנמר [בורמה])",
+    "Burmese" : "בורמזית",
+    "Catalan (Spain)" : "קטלאנית (ספרד)",
+    "Catalan" : "קטלאנית",
+    "Chiga (Uganda)" : "צ׳יגה (אוגנדה)",
+    "Chiga" : "צ׳יגה",
+    "Chinese" : "סינית",
+    "Croatian (Croatia)" : "קרואטית (קרואטיה)",
+    "Croatian" : "קרואטית",
+    "Czech (Czech Republic)" : "צ׳כית (הרפובליקה הצ׳כית)",
+    "Czech" : "צ׳כית",
+    "Danish (Denmark)" : "דנית (דנמרק)",
+    "Danish" : "דנית",
+    "Dutch (Belgium)" : "הולנדית (בלגיה)",
+    "Dutch (Netherlands)" : "הולנדית (הולנד)",
+    "Dutch" : "הולנדית",
+    "English (American Samoa)" : "אנגלית (סמואה האמריקנית)",
+    "English (Australia)" : "אנגלית (אוסטרליה)",
+    "English (Belgium)" : "אנגלית (בלגיה)",
+    "English (Belize)" : "אנגלית (בליז)",
+    "English (Botswana)" : "אנגלית (בוטסואנה)",
+    "English (Canada)" : "אנגלית (קנדה)",
+    "English (Guam)" : "אנגלית (גואם)",
+    "English (India)" : "אנגלית (הודו)",
+    "English (Ireland)" : "אנגלית (אירלנד)",
+    "English (Jamaica)" : "אנגלית (ג׳מייקה)",
+    "English (Malta)" : "אנגלית (מלטה)",
+    "English (Marshall Islands)" : "אנגלית (איי מרשל)",
+    "English (Mauritius)" : "אנגלית (מאוריציוס)",
+    "English (Namibia)" : "אנגלית (נמיביה)",
+    "English (New Zealand)" : "אנגלית (ניו זילנד)",
+    "English (Northern Mariana Islands)" : "אנגלית (איי מריאנה הצפוניים)",
+    "English (Pakistan)" : "אנגלית (פקיסטן)",
+    "English (Philippines)" : "אנגלית (פיליפינים)",
+    "English (Singapore)" : "אנגלית (סינגפור)",
+    "English (South Africa)" : "אנגלית (דרום אפריקה)",
+    "English (Trinidad and Tobago)" : "אנגליה (טרינידד וטובגו)",
+    "English (United States)" : "אנגלית (ארצות הברית)",
+    "English" : "אנגלית",
+    "Esperanto" : "אספרנטו",
+    "Estonian (Estonia)" : "אסטונית (אסטוניה)",
+    "Estonian" : "אסטונית",
+    "Filipino (Philippines)" : "פיליפינו (הפיליפינים)",
+    "Filipino" : "פיליפינו",
+    "Finnish (Finland)" : "פינית (פינלנד)",
+    "Finnish" : "פינית",
+    "French (Belgium)" : "צרפתית (בלגיה)",
+    "French (Benin)" : "צרפתית (בנין)",
+    "French (Burkina Faso)" : "צרפתית (בורקינה פאסו)",
+    "French (Burundi)" : "צרפת (בורונדי)",
+    "French (Cameroon)" : "צרפתית (קמרון)",
+    "French (Canada)" : "צרפתית (קנדה)",
+    "French (Central African Republic)" : "צרפתית (הרפובליקה המרכז אפריקאית)",
+    "French (Chad)" : "צרפתית (צ׳אד)",
+    "French (Comoros)" : "צרפתית (קומורוס)",
+    "French (France)" : "צרפתית (צרפת)",
+    "French (Monaco)" : "צרפתית (מונקו)",
+    "French (Senegal)" : "צרפתית (סנגל)",
+    "French (Switzerland)" : "צרפתית (שווייץ)",
+    "French (Togo)" : "צרפתית (טוגו)",
+    "French" : "צרפתית",
+    "Fulah (Senegal)" : "פולה (סנגל)",
+    "Fulah" : "פולה",
+    "Galician (Spain)" : "גליסית (ספרד)",
+    "Galician" : "גליסית",
+    "Ganda (Uganda)" : "גנדה (אוגנדה)",
+    "Ganda" : "גנדה",
+    "Georgian (Georgia)" : "גאורגית (גאורגיה)",
+    "Georgian" : "גאורגית",
+    "German (Austria)" : "גרמנית (אוסטריה)",
+    "German (Belgium)" : "גרמנית (בלגיה)",
+    "German (Germany)" : "גרמנית (גרמניה)",
+    "German (Liechtenstein)" : "גרמנית (ליכטנשטיין)",
+    "German (Luxembourg)" : "גרמנית (לוקסמבורג)",
+    "German (Switzerland)" : "גרמנית (שווייץ)",
+    "German" : "גרמנית",
+    "Greek (Cyprus)" : "יוונית (קפריסין)",
+    "Greek (Greece)" : "יוונית (יוון)",
+    "Greek" : "יוונית",
+    "Hebrew (Israel)" : "עברית (ישראל)",
+    "Hebrew" : "עברית",
+    "Hungarian (Hungary)" : "הונגרית (הונגריה)",
+    "Hungarian" : "הונגרית",
+    "Icelandic (Iceland)" : "איסלנדית (איסלנד)",
+    "Icelandic" : "איסלנד",
+    "Indonesian (Indonesia)" : "אינדונזית (אינדונזיה)",
+    "Indonesian" : "אינדונזית",
+    "Irish (Ireland)" : "אירית (אירלנד)",
+    "Irish" : "אירית",
+    "Italian (Italy)" : "איטלקית (איטליה)",
+    "Italian (Switzerland)" : "איטלקית (שווייץ)",
+    "Italian" : "איטלקית",
+    "Japanese (Japan)" : "יפנית (יפן)",
+    "Japanese" : "יפנית",
+    "Kalaallisut (Greenland)" : "כלשית (גרינלנד)",
+    "Kalaallisut" : "כלשית",
+    "Kalenjin (Kenya)" : "קלנג׳ין (קניה)",
+    "Kalenjin" : "קלנג׳ין",
+    "Kazakh (Cyrillic)" : "קזחית (קירילית)",
+    "Kazakh (Cyrillic, Kazakhstan)" : "קזחית (קירילית, קזחסטן)",
+    "Kazakh" : "קזחית",
+    "Store credentials" : "שמירת אישורים",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php רשום בשירות webcron לקרוא ל- cron.php בכל 15 דקות באמצעות HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "ניתן להשתמש בשירות cron של המערכת כדי לקרוא לקובץ cron.php בכל 15 דקות.",
+    "Follow us on Google+" : "לעקוב אחרינו ב־Google+‎"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
