@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérlek várj, míg a migráció befejeződik.",
+    "Migration started …" : "Migráció elindítva ...",
+    "Saved" : "Elmentve",
+    "Not saved" : "Nincs mentve",
+    "Sending…" : "Küldés...",
+    "Email sent" : "Az e-mail elküldve!",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hiba történt! Kérem töltsön fel egy, ASCII karakterekkel kódolt PEM tanusítványt!",
+    "Valid until {date}" : "Érvényes: {date}",
+    "Delete" : "Törlés",
+    "Local" : "Helyi",
+    "Private" : "Privát",
+    "Only visible to local users" : "Csak a helyi felhasználók láthatják",
+    "Only visible to you" : "Csak te láthatod",
+    "Contacts" : "Névjegyek",
+    "Visible to local users and to trusted servers" : "Helyi felhasználók és megbízható szerverek láthatják",
+    "Public" : "Nyilvános",
+    "Will be synced to a global and public address book" : "Globális és nyilvános névjegyek számára lesz szinkronizálva",
+    "Verify" : "Ellenőrzés",
+    "Verifying …" : "Ellenőrzés...",
+    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
+    "Very weak password" : "Nagyon gyenge jelszó",
+    "Weak password" : "Gyenge jelszó",
+    "So-so password" : "Nem túl jó jelszó",
+    "Good password" : "Jó jelszó",
+    "Strong password" : "Erős jelszó",
+    "An error occurred while changing your language. Please reload the page and try again." : "Hiba lépett fel nyelvváltás közben. Kérlek töltsd újra az oldalt és próbáld ismét.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Hiba a hely váltása közben. Kérlek töltsd újra az oldalt és próbáld meg ismét.",
+    "Select a profile picture" : "Válasszon profilképet!",
+    "Week starts on {fdow}" : "Hét kezdete {fdow}",
+    "Groups" : "Csoportok",
+    "Group list is empty" : "Csoport lista üres",
+    "Unable to retrieve the group list" : "Csoportlista betöltése sikertelen",
     "{actor} added you to group {group}" : "{actor} hozzá lett adva a {group} csoporthoz",
     "You added {user} to group {group}" : "Hozzáadta {user} felhasználót a(z) {group} csoporthoz",
     "{actor} added {user} to group {group}" : "{actor} hozzáadta {user} felhasználót a(z) {group} csoporthoz",
@@ -30,9 +62,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Az alkalmazást nem sikerült eltávolítani.",
     "Couldn't update app." : "Az alkalmazás frissítése nem sikerült.",
     "Wrong password" : "Hibás jelszó",
-    "Saved" : "Elmentve",
     "No user supplied" : "Nincs megadva felhasználó",
-    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
     "Authentication error" : "Azonosítási hiba",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Kérjük, adjon meg egy rendszergazdai visszaállító jelszót; különben, az összes felhasználó adata eltűnik.",
     "Wrong admin recovery password. Please check the password and try again." : "Hibás rendszergazda helyreállítási jelszó. Ellenőrizze a jelszót és próbálja újra!",
@@ -75,39 +105,9 @@ OC.L10N.register(
     "Logged in user must be a subadmin" : "Nem rendszergazda felhasználóként kell bejelentkezzen",
     "Create" : "Létrehozás",
     "Change" : "Módosít",
-    "Delete" : "Törlés",
     "Share" : "Megosztás",
     "Unlimited" : "Korlátlan",
     "Verifying" : "Ellenőrzés",
-    "Verifying …" : "Ellenőrzés...",
-    "Verify" : "Ellenőrzés",
-    "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérlek várj, míg a migráció befejeződik.",
-    "Migration started …" : "Migráció elindítva ...",
-    "Not saved" : "Nincs mentve",
-    "Sending…" : "Küldés...",
-    "Email sent" : "Az e-mail elküldve!",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hiba történt! Kérem töltsön fel egy, ASCII karakterekkel kódolt PEM tanusítványt!",
-    "Valid until {date}" : "Érvényes: {date}",
-    "Local" : "Helyi",
-    "Private" : "Privát",
-    "Only visible to local users" : "Csak a helyi felhasználók láthatják",
-    "Only visible to you" : "Csak te láthatod",
-    "Contacts" : "Névjegyek",
-    "Visible to local users and to trusted servers" : "Helyi felhasználók és megbízható szerverek láthatják",
-    "Public" : "Nyilvános",
-    "Will be synced to a global and public address book" : "Globális és nyilvános névjegyek számára lesz szinkronizálva",
-    "Very weak password" : "Nagyon gyenge jelszó",
-    "Weak password" : "Gyenge jelszó",
-    "So-so password" : "Nem túl jó jelszó",
-    "Good password" : "Jó jelszó",
-    "Strong password" : "Erős jelszó",
-    "An error occurred while changing your language. Please reload the page and try again." : "Hiba lépett fel nyelvváltás közben. Kérlek töltsd újra az oldalt és próbáld ismét.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Hiba a hely váltása közben. Kérlek töltsd újra az oldalt és próbáld meg ismét.",
-    "Select a profile picture" : "Válasszon profilképet!",
-    "Week starts on {fdow}" : "Hét kezdete {fdow}",
-    "Groups" : "Csoportok",
-    "Group list is empty" : "Csoport lista üres",
-    "Unable to retrieve the group list" : "Csoportlista betöltése sikertelen",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A kétfaktoros hitelesítés minden felhasználóra vagy bizonyos csoportokra követelhető meg. Ha a kétfaktoros hitelesítés nincs nekik beállítva, nem fognak tudni belépni a rendszerbe.",
     "Enforce two-factor authentication" : "Kétfaktoros hitelesítés megkövetelése",
     "Limit to groups" : "Csoportokra korlátozás",
@@ -117,6 +117,33 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for\tmembers of the following groups." : "A kétfaktoros hitelesítés meg van nincs megkövetelve a következő csoport tagjaira.",
     "Excluded groups" : "Kizárt csoportok",
     "Save changes" : "Változások mentése",
+    "Supported" : "Támogatott",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "A hivatalos alkalmazásokat a közösség fejleszti. Ezek adják a központi funkcionalitásokat és éles rendszerekben használhatóak.",
+    "Official" : "Hivatalos",
+    "by" : "által",
+    "Update to {version}" : "Frissítés erre: {version}",
+    "Remove" : "Eltávolítás",
+    "Disable" : "Letiltás",
+    "All" : "Mind",
+    "Limit app usage to groups" : "Alkalmazás asználatának korlátozása a következő csoportokra",
+    "No results" : "Nincsenek eredmények",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs minimum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs maximum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az alkalmazást nem lehet telepíteni, mert a következő függőségek hiányoznak:",
+    "View in store" : "Megtekintés a tárban",
+    "Visit website" : "Weboldal meglátogatása",
+    "Report a bug" : "Hiba bejelentése",
+    "User documentation" : "Felhasználói dokumentáció",
+    "Admin documentation" : "Rendszergazdai dokumentáció",
+    "Developer documentation" : "Fejlesztői dokumentáció",
+    "Update to {update}" : "Frissítés erre: {update}",
+    "Results from other categories" : "Eredmények más kategóriákból",
+    "No apps found for your version" : "Nem található alkalmazás a verziód számára",
+    "Disable all" : "Összes tiltása",
+    "Enable all" : "Mind engedélyezése",
+    "Download and enable" : "Letöltés és engedélyezés",
+    "Enable" : "Engedélyezés",
+    "The app will be downloaded from the app store" : "Az alkalmazás letöltésre kerül az alkalmazástárból",
     "Device settings" : "Eszköz beállítások",
     "Allow filesystem access" : "Fájlrendszer hozzáférés engedélyezése",
     "Rename" : "Átnevez",
@@ -150,33 +177,6 @@ OC.L10N.register(
     "Done" : "Kész",
     "Copied!" : "Másolva!",
     "Copy" : "Másol",
-    "Supported" : "Támogatott",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "A hivatalos alkalmazásokat a közösség fejleszti. Ezek adják a központi funkcionalitásokat és éles rendszerekben használhatóak.",
-    "Official" : "Hivatalos",
-    "by" : "által",
-    "Update to {version}" : "Frissítés erre: {version}",
-    "Remove" : "Eltávolítás",
-    "Disable" : "Letiltás",
-    "All" : "Mind",
-    "Limit app usage to groups" : "Alkalmazás asználatának korlátozása a következő csoportokra",
-    "No results" : "Nincsenek eredmények",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs minimum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs maximum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az alkalmazást nem lehet telepíteni, mert a következő függőségek hiányoznak:",
-    "View in store" : "Megtekintés a tárban",
-    "Visit website" : "Weboldal meglátogatása",
-    "Report a bug" : "Hiba bejelentése",
-    "User documentation" : "Felhasználói dokumentáció",
-    "Admin documentation" : "Rendszergazdai dokumentáció",
-    "Developer documentation" : "Fejlesztői dokumentáció",
-    "Update to {update}" : "Frissítés erre: {update}",
-    "Results from other categories" : "Eredmények más kategóriákból",
-    "No apps found for your version" : "Nem található alkalmazás a verziód számára",
-    "Disable all" : "Összes tiltása",
-    "Enable all" : "Mind engedélyezése",
-    "Download and enable" : "Letöltés és engedélyezés",
-    "Enable" : "Engedélyezés",
-    "The app will be downloaded from the app store" : "Az alkalmazás letöltésre kerül az alkalmazástárból",
     "You do not have permissions to see the details of this user" : "Nincs jogosultságod megnézni ennek a felhasználónak a részleteit.",
     "The backend does not support changing the display name" : "A feldolgozó nem támogatja a megjelenítő nevének megváltoztatását",
     "New password" : "Az új jelszó",
@@ -203,9 +203,9 @@ OC.L10N.register(
     "Add a new user" : "Új felhasználó felvétele",
     "No users in here" : "Nincs ilyen felhasználó",
     "Default quota" : "Alapértelmezett kvóta",
-    "Password change is disabled because the master key is disabled" : "A jelszó változtatása tiltva van mert a mester kulcs tiltva van",
     "Common languages" : "Alapvető nyelvek",
     "All languages" : "Minden nyelv",
+    "Password change is disabled because the master key is disabled" : "A jelszó változtatása tiltva van mert a mester kulcs tiltva van",
     "Your apps" : "Alkalmazásaid",
     "Active apps" : "Aktív alkalmazások",
     "Disabled apps" : "Letiltott alkalmazások",
@@ -219,13 +219,13 @@ OC.L10N.register(
     "Show last login" : "Utolsó bejelentkezés megjelenítése",
     "Show user backend" : "Felhasználói háttér mutatása",
     "Show storage path" : "Tároló útvonal mutatása",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "A {group} csoportot fodja törölni. A felhasználó NEM fog törlődni.",
-    "Please confirm the group removal " : "Kérem erősítse meg a csoport törlését",
     "Remove group" : "Csoport törlése",
     "Admins" : "Rendszergazdák",
     "Disabled users" : "Letiltott felhasználók",
     "Everyone" : "Mindenki",
     "Add group" : "csoport hozzáadása",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "A {group} csoportot fodja törölni. A felhasználó NEM fog törlődni.",
+    "Please confirm the group removal " : "Kérem erősítse meg a csoport törlését",
     "An error occured during the request. Unable to proceed." : "Hiba lépett fel a kérés közben. Nem lehet végrehajtani.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ez az alkalmazás engedélyezve van, de frissíteni kell. A frissítő oldalra irányítjuk 5 másodpercen belül.",
     "App update" : "Alkalmazás frissítése",
@@ -260,7 +260,6 @@ OC.L10N.register(
     "Credentials" : "Azonosítók",
     "SMTP Username" : "SMTP felhasználónév",
     "SMTP Password" : "SMTP jelszó",
-    "Store credentials" : "Azonosítók eltárolása",
     "Test email settings" : "Az e-mail beállítások ellenőrzése",
     "Send email" : "E-mail küldése",
     "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
@@ -294,8 +293,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Háttérfeladat még nem futott le!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Az optimális teljesítményhez fontos, hogy a háttérfeladatok megfelelően legyenek beállítva. Nagyobb telepítésekhez a 'Cron' javasolt. Kérlek nézd meg a dokumentációt a részletekért.",
     "Execute one task with each page loaded" : "Egy-egy feladat végrehajtása minden alkalommal, amikor egy weboldalt letöltenek",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "a cron.php a webcron szolgáltatásban van regisztrálva 15 percenkénti meghívásra HTTP-n keresztül.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "A rendszer cron szolgáltatásának használata a cron.php meghívására 15 percenként.",
     "The cron.php needs to be executed by the system user \"%s\"." : "A cron.php-t ennek a rendszer felhasználónak kell végrehajtania: \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Ennek futtatásához PHP POSIX kiterjesztés szükséges. Nézd meg a {linkstart}PHP dokumentációt{linkend} a részletekért.",
     "Sharing" : "Megosztás",
@@ -356,16 +353,13 @@ OC.L10N.register(
     "Current password" : "Jelenlegi jelszó",
     "Change password" : "Jelszó megváltoztatása",
     "Disconnect" : "Szétkapcsolás",
-    "iPhone iOS" : "iPhone iOS",
-    "iPad iOS" : "iPad iOS",
-    "iOS Client" : "iOS kliens",
-    "Android Client" : "Android kliens",
     "Not supported!" : "Nem támogatott.",
     "Press ⌘-C to copy." : "A másoláshoz nyomj ⌘-C-t.",
     "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
     "Error while loading browser sessions and device tokens" : "Hiba a böngésző munkamenet és az eszköz tokenek betöltése közben.",
-    "Default quota :" : "Alapértelmezett kvóta :",
-    "Follow us on Google+" : "Kövess Google+ -on",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Jelenleg használt: <strong>%s</strong>, ebből: <strong>%s</strong> (<strong>%s %%</strong>)"
+    "Store credentials" : "Azonosítók eltárolása",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "a cron.php a webcron szolgáltatásban van regisztrálva 15 percenkénti meghívásra HTTP-n keresztül.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "A rendszer cron szolgáltatásának használata a cron.php meghívására 15 percenként.",
+    "Follow us on Google+" : "Kövess Google+ -on"
 },
 "nplurals=2; plural=(n != 1);");
