@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai",
+    "Migration started …" : "Migrasi dimulai …",
+    "Saved" : "Disimpan",
+    "Not saved" : "Belum disimpan",
+    "Sending…" : "Mengirim…",
+    "Email sent" : "Surel terkirim",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
+    "Valid until {date}" : "Berlaku sampai {date}",
+    "Delete" : "Hapus",
+    "Local" : "Lokal",
+    "Private" : "Pribadi",
+    "Only visible to local users" : "Hanya terlihat untuk pengguna lokal saja",
+    "Only visible to you" : "Hanya terlihat untuk Anda saja",
+    "Contacts" : "Kontak",
+    "Visible to local users and to trusted servers" : "Terlihat untuk semua pengguna lokal dan server yang dipercaya",
+    "Public" : "Publik",
+    "Will be synced to a global and public address book" : "Akan disinkronisasikan ke buku alamat global dan publik",
+    "Verify" : "Verifikasi",
+    "Verifying …" : "Sedang memferivikasi …",
+    "Unable to change password" : "Tidak dapat mengubah kata sandi",
+    "Very weak password" : "Kata sandi sangat lemah",
+    "Weak password" : "Kata sandi lemah",
+    "So-so password" : "Kata sandi lumayan",
+    "Good password" : "Kata sandi baik",
+    "Strong password" : "Kata sandi kuat",
+    "An error occurred while changing your language. Please reload the page and try again." : "Galat terjadi ketika mengubah bahasa Anda. Mohon muat ulang halaman dan coba lagi.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Galat terjadi saat mengubah tempat Anda. Mohon muat ulang halaman dan coba lagi.",
+    "Select a profile picture" : "Pilih foto profil",
+    "Week starts on {fdow}" : "Minggu dimulai di hari {fdow}",
+    "Groups" : "Grup",
+    "Group list is empty" : "Daftar grup kosong",
+    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "{actor} added you to group {group}" : "{actor} menambahkan Anda ke grup {group}",
     "You added {user} to group {group}" : "Anda menambahkan {user} ke grup {group}",
     "{actor} added {user} to group {group}" : "{actor} menambahkan {user} kedalam grup {group}",
@@ -32,9 +64,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
     "Couldn't update app." : "Tidak dapat memperbarui aplikasi.",
     "Wrong password" : "Kata sandi salah",
-    "Saved" : "Disimpan",
     "No user supplied" : "Tidak ada pengguna yang diberikan",
-    "Unable to change password" : "Tidak dapat mengubah kata sandi",
     "Authentication error" : "Terjadi kesalahan saat otentikasi",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Berikan kata sandi pemulihan admin; Jika tidak, semua data pengguna akan hilang.",
     "Wrong admin recovery password. Please check the password and try again." : "Kata sandi pemulihan admin salah. Periksa kata sandi dan ulangi kembali.",
@@ -75,109 +105,40 @@ OC.L10N.register(
     "Go to %s" : "Pergi ke %s",
     "Install Client" : "Pasang Klien",
     "Logged in user must be a subadmin" : "Masuk ke dalam pengguna harus sebagai seorang subadmin",
-    "Delete" : "Hapus",
     "Unlimited" : "Tak terbatas",
-    "Verifying …" : "Sedang memferivikasi …",
-    "Verify" : "Verifikasi",
-    "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai",
-    "Migration started …" : "Migrasi dimulai …",
-    "Not saved" : "Belum disimpan",
-    "Sending…" : "Mengirim…",
-    "Email sent" : "Surel terkirim",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
-    "Valid until {date}" : "Berlaku sampai {date}",
-    "Local" : "Lokal",
-    "Private" : "Pribadi",
-    "Only visible to local users" : "Hanya terlihat untuk pengguna lokal saja",
-    "Only visible to you" : "Hanya terlihat untuk Anda saja",
-    "Contacts" : "Kontak",
-    "Visible to local users and to trusted servers" : "Terlihat untuk semua pengguna lokal dan server yang dipercaya",
-    "Public" : "Publik",
-    "Will be synced to a global and public address book" : "Akan disinkronisasikan ke buku alamat global dan publik",
-    "Very weak password" : "Kata sandi sangat lemah",
-    "Weak password" : "Kata sandi lemah",
-    "So-so password" : "Kata sandi lumayan",
-    "Good password" : "Kata sandi baik",
-    "Strong password" : "Kata sandi kuat",
-    "An error occurred while changing your language. Please reload the page and try again." : "Galat terjadi ketika mengubah bahasa Anda. Mohon muat ulang halaman dan coba lagi.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Galat terjadi saat mengubah tempat Anda. Mohon muat ulang halaman dan coba lagi.",
-    "Select a profile picture" : "Pilih foto profil",
-    "Week starts on {fdow}" : "Minggu dimulai di hari {fdow}",
-    "Groups" : "Grup",
-    "Group list is empty" : "Daftar grup kosong",
-    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
-    "Afrikaans (Namibia)" : "Afrika (Namibia)",
-    "Afrikaans (South Africa)" : "Afrika (Afrika Selatan)",
-    "Afrikaans" : "Afrika",
-    "Akan (Ghana)" : "Akan (Ghana)",
-    "Albanian (Albania)" : "Albania",
-    "Arabic (Morocco)" : "Arabic (Moroko)",
-    "Basque (Spain)" : "Basque (Spanyol)",
-    "Bosnian (Bosnia and Herzegovina)" : "Bosnian (Bosnia dan Herzegovina)",
-    "Catalan (Spain)" : "Catalan (Spanyol)",
-    "Cherokee (United States)" : "Cherokee (Amerika)",
-    "Cornish (United Kingdom)" : "Cornish (Britania Raya)",
-    "Czech (Czech Republic)" : "Czech (Republik Czech)",
-    "Dutch (Belgium)" : "Belanda (Belgium)",
-    "Dutch (Netherlands)" : "Belanda (Netherlands)",
-    "Dutch" : "Belanda",
-    "English (American Samoa)" : "Inggris (Samoa Amerika)",
-    "English (Australia)" : "Inggris (Australia)",
-    "English (Belgium)" : "Inggris (Belgium)",
-    "English (Belize)" : "Inggris (Belize)",
-    "English (Botswana)" : "Inggris (Bostwana)",
-    "English (Canada)" : "Inggris (Kanada)",
-    "English (Guam)" : "Inggris (Guam)",
-    "English (Hong Kong SAR China)" : "Inggris (Hong Kong SAR China)",
-    "English (India)" : "Inggris (India)",
-    "English (Ireland)" : "Inggris (Irlandia)",
-    "English (Jamaica)" : "Inggris (Jamaika)",
-    "English (Malta)" : "Inggris (Malta)",
-    "English (Marshall Islands)" : "Inggris (Kepulauan Marshall)",
-    "English (Mauritius)" : "Inggris (Mauritius)",
-    "English (Namibia)" : "Inggris (Namibia)",
-    "English (New Zealand)" : "Inggris (Selandia Baru)",
-    "English (Northern Mariana Islands)" : "Inggris (Kepulauan Mariana Selatan)",
-    "English (Pakistan)" : "Inggris (Pakistan)",
-    "English (Philippines)" : "Inggris (Filipina)",
-    "English (Singapore)" : "Inggris (Singapura)",
-    "English (South Africa)" : "Inggris (Afrika Selatan)",
-    "English (Trinidad and Tobago)" : "Inggris (Trinidad dan Tobago)",
-    "English (U.S. Minor Outlying Islands)" : "Inggris (Kepualuan Terluar Kecil Amerika Serikat)",
-    "English (U.S. Virgin Islands)" : "Inggris (Kepulauan Virgin Amerika Serikat)",
-    "English (United Kingdom)" : "Inggris (Britania Raya)",
-    "English (United States)" : "Inggris (Amerika Serikat)",
-    "English (Zimbabwe)" : "Inggris (Zimbabwe)",
-    "English" : "Inggris",
-    "Icelandic" : "Islandia",
-    "Indonesian (Indonesia)" : "Bahasa Indonesia (Indonesia)",
-    "Indonesian" : "Bahasa Indonesia",
-    "Japanese" : "Jepang",
-    "Malay (Brunei)" : "Melayu (Brunei)",
-    "Malay (Malaysia)" : "Melayu (Malaysia)",
-    "Malay" : "Melayu",
-    "Manx (United Kingdom)" : "Manx (Britania Raya)",
-    "Portuguese" : "Portugis",
-    "Romanian" : "Romania",
-    "Russian (Russia)" : "Rusia (Rusia)",
-    "Russian (Ukraine)" : "Rusia (Ukraina)",
-    "Russian" : "Rusia",
-    "Spanish (United States)" : "Spanyol (Amerika Serikat)",
-    "Spanish (Uruguay)" : "Spanyol (Uruguay)",
-    "Spanish (Venezuela)" : "Spanyol (Venezuela)",
-    "Spanish" : "Spanyol",
-    "Swedish (Finland)" : "Swedia (Finlandia)",
-    "Swedish (Sweden)" : "Swedia (Swedia)",
-    "Swedish" : "Swedia",
-    "Turkish (Turkey)" : "Turki (Turki)",
-    "Turkish" : "Turki",
-    "Ukrainian (Ukraine)" : "Ukraina (Ukraina)",
-    "Ukrainian" : "Ukraina",
-    "Welsh (United Kingdom)" : "Welsh (Britania Raya)",
-    "Zulu (South Africa)" : "Zulu (Afrika Selatan)",
     "Limit to groups" : "Batasi ke grup",
     "Excluded groups" : "Grup yang dikecualikan",
     "Save changes" : "Simpan perubahan",
+    "This app is supported via your current Nextcloud subscription." : "Aplikasi ini didukung dengan langganan Nextcloud Anda saat ini.",
+    "Supported" : "Didukung",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi resmi dikembangkan oleh dan didalam komunitas. Mereka menawarkan fungsi sentral dan siap untuk penggunaan produksi.",
+    "Official" : "Resmi",
+    "by" : "oleh",
+    "Update to {version}" : "Perbarui ke {version}",
+    "Remove" : "Hapus",
+    "Disable" : "Nonaktifkan",
+    "All" : "Semua",
+    "Limit app usage to groups" : "Batas pemakaian aplikasi untuk grup",
+    "No results" : "Tidak ada hasil",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
+    "View in store" : "Lihat di toko",
+    "Visit website" : "Kunjungi laman web",
+    "Report a bug" : "Laporkan kerusakan",
+    "User documentation" : "Dokumentasi pengguna",
+    "Admin documentation" : "Dokumentasi admin",
+    "Developer documentation" : "Dokumentasi pengembang",
+    "Update to {update}" : "Perbarui ke {update}",
+    "Results from other categories" : "Hasil dari kategori lainnya",
+    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
+    "Disable all" : "Matikan semua",
+    "Enable all" : "Hidupkan semua",
+    "Download and enable" : "Unduh dan hidupkan",
+    "Enable" : "Aktifkan",
+    "Enable untested app" : "Hidupkan aplikasi yang belum dites",
+    "The app will be downloaded from the app store" : "Aplikasi akan diunduh melalui toko aplikasi",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
     "Marked for remote wipe" : "Tandai untuk penghapusan remote",
     "Device settings" : "Pengaturan perangkat",
     "Allow filesystem access" : "Ijinkan akses berkas sistem",
@@ -219,36 +180,6 @@ OC.L10N.register(
     "Copied!" : "Tersalin!",
     "Copy" : "Salin",
     "Could not copy app password. Please copy it manually." : "Tidak dapat menyalin kata sandi aplikasi. Mohon salin secara manual.",
-    "This app is supported via your current Nextcloud subscription." : "Aplikasi ini didukung dengan langganan Nextcloud Anda saat ini.",
-    "Supported" : "Didukung",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikasi resmi dikembangkan oleh dan didalam komunitas. Mereka menawarkan fungsi sentral dan siap untuk penggunaan produksi.",
-    "Official" : "Resmi",
-    "by" : "oleh",
-    "Update to {version}" : "Perbarui ke {version}",
-    "Remove" : "Hapus",
-    "Disable" : "Nonaktifkan",
-    "All" : "Semua",
-    "Limit app usage to groups" : "Batas pemakaian aplikasi untuk grup",
-    "No results" : "Tidak ada hasil",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi minimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aplikasi ini tidak mempunyai versi maksimum Nextcloud yang ditetapkan. Di masa depan nanti ini akan menjadi kesalahan.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
-    "View in store" : "Lihat di toko",
-    "Visit website" : "Kunjungi laman web",
-    "Report a bug" : "Laporkan kerusakan",
-    "User documentation" : "Dokumentasi pengguna",
-    "Admin documentation" : "Dokumentasi admin",
-    "Developer documentation" : "Dokumentasi pengembang",
-    "Update to {update}" : "Perbarui ke {update}",
-    "Results from other categories" : "Hasil dari kategori lainnya",
-    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini",
-    "Disable all" : "Matikan semua",
-    "Enable all" : "Hidupkan semua",
-    "Download and enable" : "Unduh dan hidupkan",
-    "Enable" : "Aktifkan",
-    "Enable untested app" : "Hidupkan aplikasi yang belum dites",
-    "The app will be downloaded from the app store" : "Aplikasi akan diunduh melalui toko aplikasi",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aplikasi ini tidak ditandai sebagai versi Nextcloud Anda yang kompatibel. Jika Anda tetap ingin melanjutkannya, Anda tetap dapat memasang aplikasi. Catatan bahwa aplikasinya mungkin tidak akan berjalan seperti yang diharapkan.",
     "You do not have permissions to see the details of this user" : "Anda tidak memiliki ijin untuk melihat detil pengguna ini",
     "The backend does not support changing the display name" : "Backend tidak mendukung pergantian tampilan nama",
     "New password" : "Kata sandi baru",
@@ -275,9 +206,9 @@ OC.L10N.register(
     "Add a new user" : "Tambah pengguna baru",
     "No users in here" : "Tidak ada pengguna disini",
     "Default quota" : "Kuota standar",
-    "Password change is disabled because the master key is disabled" : "Pengaturan kata sandi dinonaktifkan karena kunci master dinonaktifkan",
     "Common languages" : "Bahasa umum",
     "All languages" : "Semua bahasa",
+    "Password change is disabled because the master key is disabled" : "Pengaturan kata sandi dinonaktifkan karena kunci master dinonaktifkan",
     "Your apps" : "Aplikasi anda",
     "Active apps" : "Aplikasi aktif",
     "Disabled apps" : "Matikan Aplikasi",
@@ -291,13 +222,13 @@ OC.L10N.register(
     "Show last login" : "Tampilkan yang terakhir masuk",
     "Show user backend" : "Tampilkan pengguna backend",
     "Show storage path" : "Tampilkan jalur penyimpanan",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Anda akan menghapus grup  {group}. Pengguna di dalamnya TIDAK akan dihapus.",
-    "Please confirm the group removal " : "Mohon konfirmasi penghapusan grup",
     "Remove group" : "Hapus grup",
     "Admins" : "Admin",
     "Disabled users" : "Nonaktifkan pengguna",
     "Everyone" : "Semua orang",
     "Add group" : "Tambah grup",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Anda akan menghapus grup  {group}. Pengguna di dalamnya TIDAK akan dihapus.",
+    "Please confirm the group removal " : "Mohon konfirmasi penghapusan grup",
     "An error occured during the request. Unable to proceed." : "Galat terjadi saat proses permintaan. Tidak dapat memproses.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi diaktifkan namun butuh diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
     "App update" : "Pembaruan aplikasi",
@@ -332,7 +263,6 @@ OC.L10N.register(
     "Credentials" : "Kredensial",
     "SMTP Username" : "Nama pengguna SMTP",
     "SMTP Password" : "Kata sandi SMTP",
-    "Store credentials" : "Simpan kredensial",
     "Test email settings" : "Pengaturan surel percobaan",
     "Send email" : "Kirim surel",
     "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
@@ -424,8 +354,75 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
     "Press Ctrl-C to copy." : "Tekan CTRL-C untuk menyalin.",
     "Error while loading browser sessions and device tokens" : "Galat saat memuat sesi peramban dan token perangkat",
-    "Default quota :" : "Kuota bawaan : ",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Mohon cek kembali <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Petunjuk pemasangan ↗</a>, dan cek semua galat atau peringatan di <a href=\"%s\">log</a>.",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Anda menggunakan <strong>%s</strong> dari <strong>%s</strong> (<strong>%s %%</strong>)"
+    "Afrikaans (Namibia)" : "Afrika (Namibia)",
+    "Afrikaans (South Africa)" : "Afrika (Afrika Selatan)",
+    "Afrikaans" : "Afrika",
+    "Akan (Ghana)" : "Akan (Ghana)",
+    "Albanian (Albania)" : "Albania",
+    "Arabic (Morocco)" : "Arabic (Moroko)",
+    "Basque (Spain)" : "Basque (Spanyol)",
+    "Bosnian (Bosnia and Herzegovina)" : "Bosnian (Bosnia dan Herzegovina)",
+    "Catalan (Spain)" : "Catalan (Spanyol)",
+    "Cherokee (United States)" : "Cherokee (Amerika)",
+    "Cornish (United Kingdom)" : "Cornish (Britania Raya)",
+    "Czech (Czech Republic)" : "Czech (Republik Czech)",
+    "Dutch (Belgium)" : "Belanda (Belgium)",
+    "Dutch (Netherlands)" : "Belanda (Netherlands)",
+    "Dutch" : "Belanda",
+    "English (American Samoa)" : "Inggris (Samoa Amerika)",
+    "English (Australia)" : "Inggris (Australia)",
+    "English (Belgium)" : "Inggris (Belgium)",
+    "English (Belize)" : "Inggris (Belize)",
+    "English (Botswana)" : "Inggris (Bostwana)",
+    "English (Canada)" : "Inggris (Kanada)",
+    "English (Guam)" : "Inggris (Guam)",
+    "English (Hong Kong SAR China)" : "Inggris (Hong Kong SAR China)",
+    "English (India)" : "Inggris (India)",
+    "English (Ireland)" : "Inggris (Irlandia)",
+    "English (Jamaica)" : "Inggris (Jamaika)",
+    "English (Malta)" : "Inggris (Malta)",
+    "English (Marshall Islands)" : "Inggris (Kepulauan Marshall)",
+    "English (Mauritius)" : "Inggris (Mauritius)",
+    "English (Namibia)" : "Inggris (Namibia)",
+    "English (New Zealand)" : "Inggris (Selandia Baru)",
+    "English (Northern Mariana Islands)" : "Inggris (Kepulauan Mariana Selatan)",
+    "English (Pakistan)" : "Inggris (Pakistan)",
+    "English (Philippines)" : "Inggris (Filipina)",
+    "English (Singapore)" : "Inggris (Singapura)",
+    "English (South Africa)" : "Inggris (Afrika Selatan)",
+    "English (Trinidad and Tobago)" : "Inggris (Trinidad dan Tobago)",
+    "English (U.S. Minor Outlying Islands)" : "Inggris (Kepualuan Terluar Kecil Amerika Serikat)",
+    "English (U.S. Virgin Islands)" : "Inggris (Kepulauan Virgin Amerika Serikat)",
+    "English (United Kingdom)" : "Inggris (Britania Raya)",
+    "English (United States)" : "Inggris (Amerika Serikat)",
+    "English (Zimbabwe)" : "Inggris (Zimbabwe)",
+    "English" : "Inggris",
+    "Icelandic" : "Islandia",
+    "Indonesian (Indonesia)" : "Bahasa Indonesia (Indonesia)",
+    "Indonesian" : "Bahasa Indonesia",
+    "Japanese" : "Jepang",
+    "Malay (Brunei)" : "Melayu (Brunei)",
+    "Malay (Malaysia)" : "Melayu (Malaysia)",
+    "Malay" : "Melayu",
+    "Manx (United Kingdom)" : "Manx (Britania Raya)",
+    "Portuguese" : "Portugis",
+    "Romanian" : "Romania",
+    "Russian (Russia)" : "Rusia (Rusia)",
+    "Russian (Ukraine)" : "Rusia (Ukraina)",
+    "Russian" : "Rusia",
+    "Spanish (United States)" : "Spanyol (Amerika Serikat)",
+    "Spanish (Uruguay)" : "Spanyol (Uruguay)",
+    "Spanish (Venezuela)" : "Spanyol (Venezuela)",
+    "Spanish" : "Spanyol",
+    "Swedish (Finland)" : "Swedia (Finlandia)",
+    "Swedish (Sweden)" : "Swedia (Swedia)",
+    "Swedish" : "Swedia",
+    "Turkish (Turkey)" : "Turki (Turki)",
+    "Turkish" : "Turki",
+    "Ukrainian (Ukraine)" : "Ukraina (Ukraina)",
+    "Ukrainian" : "Ukraina",
+    "Welsh (United Kingdom)" : "Welsh (Britania Raya)",
+    "Zulu (South Africa)" : "Zulu (Afrika Selatan)",
+    "Store credentials" : "Simpan kredensial"
 },
 "nplurals=1; plural=0;");
