@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
+    "Migration started …" : "მიგრაცია დაიწყო …",
+    "Saved" : "დამახსოვრდა",
+    "Not saved" : "არაა შენახული",
+    "Sending…" : "იგზავნება…",
+    "Email sent" : "ელ-წერილი გაიგზავნა",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "წარმოიქმნა შეცდომა. გთხოვთ ატვირთოთ ASCII-თ კოდირებული PEM სერტიფიკატი.",
+    "Valid until {date}" : "ვარგისია {date}-მდე",
+    "Delete" : "წაშლა",
+    "Local" : "ლოკალური",
+    "Private" : "პირადი",
+    "Only visible to local users" : "გამოჩნდება მხოლოდ ლოკალურ მომხმარებლებთან",
+    "Only visible to you" : "გამოჩნდება მხოლოდ თქვენთან",
+    "Contacts" : "კონტაქტები",
+    "Visible to local users and to trusted servers" : "გამოჩნდება ლოკალურ მომხმარებლებთან და სანდო სერვერებთან",
+    "Public" : "ღია",
+    "Will be synced to a global and public address book" : "სინქრონიზაცია მოხდება გლობალურ და ღია მისამართების წიგნში",
+    "Verify" : "დამოწმება",
+    "Verifying …" : "მოწმდება …",
+    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
+    "Very weak password" : "ძალიან სუსტი პაროლი",
+    "Weak password" : "სუსტი პაროლი",
+    "So-so password" : "ნორმალური პაროლი",
+    "Good password" : "კარგი პაროლი",
+    "Strong password" : "ძლიერი პაროლ",
+    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
+    "Groups" : "ჯგუფები",
     "{actor} changed your password" : "{actor} მომხმარებელმა შეცვალა თქვენი პაროლი",
     "You changed your password" : "თქვენ შეცვალეთ თქვენი პაროლი",
     "Your password was reset by an administrator" : "თქვენი პაროლი ადმინისტრატორმა აღადგინა",
@@ -14,9 +41,7 @@ OC.L10N.register(
     "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
     "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
     "Wrong password" : "არასწორი პაროლი",
-    "Saved" : "დამახსოვრდა",
     "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
-    "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
     "Authentication error" : "აუტენტიფიკაციის შეცდომა",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
@@ -55,33 +80,26 @@ OC.L10N.register(
     "Set your password" : "დააყენეთ თქვენი პაროლი",
     "Go to %s" : "გადადით %s-ზე",
     "Install Client" : "დააყენეთ კლიენტი",
-    "Delete" : "წაშლა",
     "Unlimited" : "ულიმიტო",
-    "Verifying …" : "მოწმდება …",
-    "Verify" : "დამოწმება",
-    "Migration in progress. Please wait until the migration is finished" : "მიმდინარეობს მიგრაცია. გთხოვთ დაელოდოთ მიგრაციის დასრულებას",
-    "Migration started …" : "მიგრაცია დაიწყო …",
-    "Not saved" : "არაა შენახული",
-    "Sending…" : "იგზავნება…",
-    "Email sent" : "ელ-წერილი გაიგზავნა",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "წარმოიქმნა შეცდომა. გთხოვთ ატვირთოთ ASCII-თ კოდირებული PEM სერტიფიკატი.",
-    "Valid until {date}" : "ვარგისია {date}-მდე",
-    "Local" : "ლოკალური",
-    "Private" : "პირადი",
-    "Only visible to local users" : "გამოჩნდება მხოლოდ ლოკალურ მომხმარებლებთან",
-    "Only visible to you" : "გამოჩნდება მხოლოდ თქვენთან",
-    "Contacts" : "კონტაქტები",
-    "Visible to local users and to trusted servers" : "გამოჩნდება ლოკალურ მომხმარებლებთან და სანდო სერვერებთან",
-    "Public" : "ღია",
-    "Will be synced to a global and public address book" : "სინქრონიზაცია მოხდება გლობალურ და ღია მისამართების წიგნში",
-    "Very weak password" : "ძალიან სუსტი პაროლი",
-    "Weak password" : "სუსტი პაროლი",
-    "So-so password" : "ნორმალური პაროლი",
-    "Good password" : "კარგი პაროლი",
-    "Strong password" : "ძლიერი პაროლ",
-    "Select a profile picture" : "აირჩიეთ პროფილის სურათი",
-    "Groups" : "ჯგუფები",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "ოფიციალური აპლიკაციები განვითარებულია და მოქცეულია ჩვენს საზოგადოებაში. ისინი გთავაზობენ ცენტრალურ ფუნქციონირებას და საწარმოო გამოყენებისათვის მზადყოფნაში არიან.",
+    "Official" : "ოფიციალური",
+    "Remove" : "წაშლა",
+    "Disable" : "გამორთვა",
+    "All" : "ყველა",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
+    "View in store" : "იხილეთ store-ში",
+    "Visit website" : "საიტზე სტუმრობა",
+    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
+    "User documentation" : "მომხმარებლის დოკუმენტაცია",
+    "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
+    "Developer documentation" : "დეველოპერის დოკუმენტაცია",
+    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
+    "Enable all" : "ყველას ამოქმედება",
+    "Enable" : "ჩართვა",
+    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
     "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
     "Revoke" : "წვდომის გაუქმება",
     "Internet Explorer" : "Internet Explorer-ი",
@@ -106,24 +124,6 @@ OC.L10N.register(
     "Done" : "დასრულებულია",
     "Copied!" : "კოპირებულია",
     "Copy" : "კოპირება",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "ოფიციალური აპლიკაციები განვითარებულია და მოქცეულია ჩვენს საზოგადოებაში. ისინი გთავაზობენ ცენტრალურ ფუნქციონირებას და საწარმოო გამოყენებისათვის მზადყოფნაში არიან.",
-    "Official" : "ოფიციალური",
-    "Remove" : "წაშლა",
-    "Disable" : "გამორთვა",
-    "All" : "ყველა",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მინიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "ეს აპლიკაცია არ საზღვრავს Nextcloud-ის მაქსიმალურ ვერსიას. სამომავლოდ ეს ჩაითვლება შეცდომად.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "ეს აპლიკაცია ვერ დაყენდა რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული:",
-    "View in store" : "იხილეთ store-ში",
-    "Visit website" : "საიტზე სტუმრობა",
-    "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
-    "User documentation" : "მომხმარებლის დოკუმენტაცია",
-    "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
-    "Developer documentation" : "დეველოპერის დოკუმენტაცია",
-    "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
-    "Enable all" : "ყველას ამოქმედება",
-    "Enable" : "ჩართვა",
-    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
     "New password" : "ახალი პაროლი",
     "{size} used" : "მოხმარებულია {size}",
     "Email" : "ელ-ფოსტა",
@@ -174,7 +174,6 @@ OC.L10N.register(
     "Credentials" : "უფლებამოსილებანი",
     "SMTP Username" : "SMTP მოხმარებლის სახელი",
     "SMTP Password" : "SMTP მომხმარებლის პაროლი",
-    "Store credentials" : "უფლებამოსილებანის შენახვა",
     "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
     "Send email" : "ელ-წერილის გაგზავნა",
     "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
@@ -201,8 +200,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "ოპტიმალური მოღვაწეობისთვის მნიშვნელოვანია ფონური საქმეების სწორი კონფიგურაცია. დიდი ინსტანციებისთვის 'კრონი' რეკომენდირებული არჩევანია. გთხოვთ მეტი ინფორმაციისთვის იხილოთ დოკუმენტაცია.",
     "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php რეგისტრირებულია ვებკრონის სერვისით რომ 15 წუთში ერთხელ HTTP-თი გაიშვას.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "გამოიყენეთ სისტემის კრონი cron.php ფაილის გასაშვებად ყოველ 15 წუთში.",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
     "Sharing" : "გაზიარება",
@@ -256,6 +253,9 @@ OC.L10N.register(
     "Twitter handle @…" : "Twitter @…",
     "Help translate" : "თარგმნის დახმარება",
     "Current password" : "მიმდინარე პაროლი",
-    "Change password" : "პაროლის შეცვლა"
+    "Change password" : "პაროლის შეცვლა",
+    "Store credentials" : "უფლებამოსილებანის შენახვა",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php რეგისტრირებულია ვებკრონის სერვისით რომ 15 წუთში ერთხელ HTTP-თი გაიშვას.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "გამოიყენეთ სისტემის კრონი cron.php ფაილის გასაშვებად ყოველ 15 წუთში."
 },
 "nplurals=2; plural=(n!=1);");
