@@ -1,6 +1,37 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
+    "Migration started …" : "이전 시작됨...",
+    "Saved" : "저장됨",
+    "Not saved" : "저장하지 않음",
+    "Sending…" : "보내는 중…",
+    "Email sent" : "이메일 보냄",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
+    "Valid until {date}" : "{date}까지 유효함",
+    "Delete" : "삭제",
+    "Local" : "로컬",
+    "Private" : "개인",
+    "Only visible to local users" : "로컬 사용자만 보임",
+    "Only visible to you" : "나만 보임",
+    "Contacts" : "연락처",
+    "Visible to local users and to trusted servers" : "로컬 사용자와 신뢰된 서버에게 보이기",
+    "Public" : "공개",
+    "Will be synced to a global and public address book" : "공개 및 전역 주소록으로 동기화됨",
+    "Verify" : "확인",
+    "Verifying …" : "확인 중 …",
+    "Unable to change password" : "암호를 변경할 수 없음",
+    "Very weak password" : "매우 약한 암호",
+    "Weak password" : "약한 암호",
+    "So-so password" : "그저 그런 암호",
+    "Good password" : "좋은 암호",
+    "Strong password" : "강력한 암호",
+    "An error occurred while changing your language. Please reload the page and try again." : "언어를 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "지역을 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
+    "Select a profile picture" : "프로필 사진 선택",
+    "Groups" : "그룹",
+    "Group list is empty" : "그룹 목록이 비었음",
+    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
     "{actor} added you to group {group}" : "{actor} 가 당신을 {group} 그룹에 추가했습니다.",
     "You added {user} to group {group}" : "당신은 {user}를 {group} 그룹에 추가했습니다.",
     "{actor} added {user} to group {group}" : "{actor} 가 {user}를 {group} 그룹에 추가했습니다.",
@@ -28,9 +59,7 @@ OC.L10N.register(
     "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
     "Couldn't update app." : "앱을 업데이트할 수 없습니다.",
     "Wrong password" : "잘못된 암호",
-    "Saved" : "저장됨",
     "No user supplied" : "사용자가 지정되지 않음",
-    "Unable to change password" : "암호를 변경할 수 없음",
     "Authentication error" : "인증 오류",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
     "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
@@ -71,38 +100,9 @@ OC.L10N.register(
     "Install Client" : "클라이언트 설치",
     "Create" : "생성",
     "Change" : "변경",
-    "Delete" : "삭제",
     "Share" : "공유",
     "Unlimited" : "무제한",
     "Verifying" : "검사",
-    "Verifying …" : "확인 중 …",
-    "Verify" : "확인",
-    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
-    "Migration started …" : "이전 시작됨...",
-    "Not saved" : "저장하지 않음",
-    "Sending…" : "보내는 중…",
-    "Email sent" : "이메일 보냄",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
-    "Valid until {date}" : "{date}까지 유효함",
-    "Local" : "로컬",
-    "Private" : "개인",
-    "Only visible to local users" : "로컬 사용자만 보임",
-    "Only visible to you" : "나만 보임",
-    "Contacts" : "연락처",
-    "Visible to local users and to trusted servers" : "로컬 사용자와 신뢰된 서버에게 보이기",
-    "Public" : "공개",
-    "Will be synced to a global and public address book" : "공개 및 전역 주소록으로 동기화됨",
-    "Very weak password" : "매우 약한 암호",
-    "Weak password" : "약한 암호",
-    "So-so password" : "그저 그런 암호",
-    "Good password" : "좋은 암호",
-    "Strong password" : "강력한 암호",
-    "An error occurred while changing your language. Please reload the page and try again." : "언어를 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "지역을 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
-    "Select a profile picture" : "프로필 사진 선택",
-    "Groups" : "그룹",
-    "Group list is empty" : "그룹 목록이 비었음",
-    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 유저 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
     "Enforce two-factor authentication" : "2단계 인증 강제하기",
     "Limit to groups" : "그룹으로 제한",
@@ -113,6 +113,24 @@ OC.L10N.register(
     "Excluded groups" : "제외된 그룹",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹이 선택되거나 제외되었을 때, 다음과 같은 상황을 고려할 수 있습니다. 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 유저에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 유저가 선택된 그룹과 제외된 그룹에 동시에 속해있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
     "Save changes" : "변경 사항 저장",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "커뮤니티가 개발한 공식 앱입니다. 이 앱은 Nextcloud의 핵심 기능이며 프로덕션 환경에서 사용할 수 있습니다.",
+    "Official" : "공식",
+    "Remove" : "삭제",
+    "Disable" : "사용 안함",
+    "All" : "모두",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
+    "View in store" : "스토어에서 보기",
+    "Visit website" : "웹 사이트 방문",
+    "Report a bug" : "버그 신고",
+    "User documentation" : "사용자 문서",
+    "Admin documentation" : "관리 문서",
+    "Developer documentation" : "개발자 문서",
+    "No apps found for your version" : "설치된 버전에 대한 앱 없음",
+    "Enable all" : "모두 활성화",
+    "Enable" : "사용함",
+    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
     "Device settings" : "디바이스 설정",
     "Allow filesystem access" : "파일시스템 접근 허용",
     "Rename" : "이름 바꾸기",
@@ -140,24 +158,6 @@ OC.L10N.register(
     "Done" : "완료",
     "Copied!" : "복사 성공!",
     "Copy" : "복사",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "커뮤니티가 개발한 공식 앱입니다. 이 앱은 Nextcloud의 핵심 기능이며 프로덕션 환경에서 사용할 수 있습니다.",
-    "Official" : "공식",
-    "Remove" : "삭제",
-    "Disable" : "사용 안함",
-    "All" : "모두",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
-    "View in store" : "스토어에서 보기",
-    "Visit website" : "웹 사이트 방문",
-    "Report a bug" : "버그 신고",
-    "User documentation" : "사용자 문서",
-    "Admin documentation" : "관리 문서",
-    "Developer documentation" : "개발자 문서",
-    "No apps found for your version" : "설치된 버전에 대한 앱 없음",
-    "Enable all" : "모두 활성화",
-    "Enable" : "사용함",
-    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
     "New password" : "새 암호",
     "Never" : "하지 않음",
     "Delete user" : "유저 지우기",
@@ -191,13 +191,13 @@ OC.L10N.register(
     "Show last login" : "마지막 로그인 보이기",
     "Show user backend" : "사용자 백엔드 보이기",
     "Show storage path" : "스토리지 경로 보이기",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
-    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
     "Remove group" : "그룹 지우기",
     "Admins" : "관리자",
     "Disabled users" : "비활성화된 유저",
     "Everyone" : "모두",
     "Add group" : "그룹 추가",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
+    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
     "An error occured during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "App update" : "앱 업데이트",
@@ -232,7 +232,6 @@ OC.L10N.register(
     "Credentials" : "인증 정보",
     "SMTP Username" : "SMTP 사용자 이름",
     "SMTP Password" : "SMTP 암호",
-    "Store credentials" : "인증 정보 저장",
     "Test email settings" : "이메일 설정 시험",
     "Send email" : "이메일 보내기",
     "Security & setup warnings" : "보안 및 설치 경고",
@@ -265,8 +264,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "배경 작업이 아직 실행되지 않았습니다!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "최적 성능을 위해서 백그라운드 작업을 올바르게 설정하는 것을 추천합니다. 큰 인스턴스에서는 'Cron'을 사용하는 것을 추천합니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "Execute one task with each page loaded" : "개별 페이지를 불러올 때마다 실행",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "15분마다 HTTP를 통해 cron.php를 실행하는 webcron 서비스에 cron.php가 등록되었습니다.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "시스템 cron 서비스를 통해 15분마다 cron.php 파일을 실행합니다.",
     "The cron.php needs to be executed by the system user \"%s\"." : "시스템 사용자 \"%s\"(으)로 cron.php를 실행해야 합니다.",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
     "Sharing" : "공유",
@@ -326,11 +323,11 @@ OC.L10N.register(
     "Current password" : "현재 암호",
     "Change password" : "암호 변경",
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
-    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL이 오래된 %s 버전을 사용하고 있습니다(%s). 운영 체제나 기능을 업데이트하지 않으면 %s 등을 안정적으로 사용할 수 없습니다.",
     "Disconnect" : "연결 해제",
-    "iOS Client" : "iOS 클라이언트",
-    "Android Client" : "Android 클라이언트",
     "Not supported!" : "지원되지 않습니다!",
-    "Press Ctrl-C to copy." : "복사하기 위해 Ctrl-C를 누르세요."
+    "Press Ctrl-C to copy." : "복사하기 위해 Ctrl-C를 누르세요.",
+    "Store credentials" : "인증 정보 저장",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "15분마다 HTTP를 통해 cron.php를 실행하는 webcron 서비스에 cron.php가 등록되었습니다.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "시스템 cron 서비스를 통해 15분마다 cron.php 파일을 실행합니다."
 },
 "nplurals=1; plural=0;");
