@@ -1,6 +1,49 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til den er ferdig.",
+    "Migration started …" : "Migrering startet…",
+    "Saved" : "Lagret",
+    "Not saved" : "Ikke lagret",
+    "Sending…" : "Sender…",
+    "Email sent" : "E-post sendt",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Last opp et ASCII-kodet PEM-sertifikat.",
+    "Valid until {date}" : "Gyldig til {date}",
+    "Delete" : "Slett",
+    "Local" : "Lokal",
+    "Private" : "Privat",
+    "Only visible to local users" : "Kun synlig for lokale brukere",
+    "Only visible to you" : "Kun synlig for deg",
+    "Contacts" : "Kontakter",
+    "Visible to local users and to trusted servers" : "Synlig for lokale brukere og klarerte servere",
+    "Public" : "Offentlig",
+    "Will be synced to a global and public address book" : "Vil blir synkronisert til global og offentlig addressbok",
+    "Verify" : "Bekreft",
+    "Verifying …" : "Bekrefter…",
+    "Unable to change password" : "Kunne ikke endre passord",
+    "Very weak password" : "Veldig svakt passord",
+    "Weak password" : "Svakt passord",
+    "So-so password" : "Bob-bob-passord",
+    "Good password" : "Bra passord",
+    "Strong password" : "Sterkt passord",
+    "An error occurred while changing your language. Please reload the page and try again." : "En feil oppstod under endring av språk. Last inn siden på nytt og prøv igjen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "En feil oppstod under endring av nasjonal innstilling. Last inn siden på nytt og prøv igjen.",
+    "Select a profile picture" : "Velg et profilbilde",
+    "Week starts on {fdow}" : "Uken starter på {fdow}",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Gruppeliste er tom",
+    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
+    "{actor} added you to group {group}" : "{actor} la deg til i gruppen {group}",
+    "You added {user} to group {group}" : "Du la til {user} i gruppen {group}",
+    "{actor} added {user} to group {group}" : "{actor} la {user} til i gruppen {group}",
+    "An administrator added you to group {group}" : "En administrator la deg til i gruppen {group}",
+    "An administrator added {user} to group {group}" : "En administrator la {user} til i gruppen {group}",
+    "{actor} removed you from group {group}" : "{actor} fjernet deg fra gruppen {group}",
+    "You removed {user} from group {group}" : "Du fjernet {user} fra gruppen {group}",
+    "{actor} removed {user} from group {group}" : "{actor} fjernet {user} fra gruppen {group}",
+    "An administrator removed you from group {group}" : "En administrator fjernet deg fra gruppen {group}",
+    "An administrator removed {user} from group {group}" : "En administrator fjernet {user} fra gruppen {group}",
+    "Your <strong>group memberships</strong> were modified" : "Dine<strong>gruppemedlemskap</strong> ble endret",
     "{actor} changed your password" : "{actor} endret ditt passord",
     "You changed your password" : "Du endret ditt passord",
     "Your password was reset by an administrator" : "Ditt passord ble tilbakestilt av en administrator",
@@ -19,9 +62,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Klarte ikke å fjerne app.",
     "Couldn't update app." : "Kunne ikke oppdatere appen.",
     "Wrong password" : "Feil passord",
-    "Saved" : "Lagret",
     "No user supplied" : "Ingen bruker angitt",
-    "Unable to change password" : "Kunne ikke endre passord",
     "Authentication error" : "Autentiseringsfeil",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Angi et administrativt gjenopprettingspassord; ellers vil alle brukerdata gå tapt.",
     "Wrong admin recovery password. Please check the password and try again." : "Feil administrativt gjenopprettingspassord. Sjekk passordet og prøv igjen.",
@@ -62,37 +103,12 @@ OC.L10N.register(
     "Go to %s" : "Gå til %s",
     "Install Client" : "Installer klient",
     "Logged in user must be a subadmin" : "Innlogget bruker må være subadministrator",
-    "Delete" : "Slett",
+    "Create" : "Ny",
+    "Change" : "Endre",
+    "Share" : "Del",
     "Unlimited" : "Ubegrenset",
-    "Verifying …" : "Bekrefter…",
-    "Verify" : "Bekreft",
-    "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til den er ferdig.",
-    "Migration started …" : "Migrering startet…",
-    "Not saved" : "Ikke lagret",
-    "Sending…" : "Sender…",
-    "Email sent" : "E-post sendt",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Last opp et ASCII-kodet PEM-sertifikat.",
-    "Valid until {date}" : "Gyldig til {date}",
-    "Local" : "Lokal",
-    "Private" : "Privat",
-    "Only visible to local users" : "Kun synlig for lokale brukere",
-    "Only visible to you" : "Kun synlig for deg",
-    "Contacts" : "Kontakter",
-    "Visible to local users and to trusted servers" : "Synlig for lokale brukere og klarerte servere",
-    "Public" : "Offentlig",
-    "Will be synced to a global and public address book" : "Vil blir synkronisert til global og offentlig addressbok",
-    "Very weak password" : "Veldig svakt passord",
-    "Weak password" : "Svakt passord",
-    "So-so password" : "Bob-bob-passord",
-    "Good password" : "Bra passord",
-    "Strong password" : "Sterkt passord",
-    "An error occurred while changing your language. Please reload the page and try again." : "En feil oppstod under endring av språk. Last inn siden på nytt og prøv igjen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "En feil oppstod under endring av nasjonal innstilling. Last inn siden på nytt og prøv igjen.",
-    "Select a profile picture" : "Velg et profilbilde",
-    "Week starts on {fdow}" : "Uken starter på {fdow}",
-    "Groups" : "Grupper",
-    "Group list is empty" : "Gruppeliste er tom",
-    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
+    "Verifying" : "Verifiserer",
+    "Nextcloud settings" : "Nextcloud innstillinger",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tofaktor-autentisering kan håndheves for alle brukere og bestemte grupper. Hvis de ikke har en tofaktor-leverandør konfigurert, har de ikke mulighet til å logge på systemet.",
     "Enforce two-factor authentication" : "Krev tofaktor-autentisering",
     "Limit to groups" : "Begrens til grupper",
@@ -103,40 +119,7 @@ OC.L10N.register(
     "Excluded groups" : "Utelukkede grupper",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Når grupper velges/velges bort, bruker de følgende logikk for å avgjøre om en bruker har 2FA håndhevet: Hvis ingen grupper er valgt, er 2FA aktivert for alle unntatt medlemmer av de utelukkede gruppene. Hvis grupper er valgt, er 2FA aktivert for alle medlemmer av disse. Hvis en bruker er både i en valgt og utelukket gruppe, har den valgte forrang og 2FA håndheves.",
     "Save changes" : "Lagre endringer",
-    "Device settings" : "Enhetsinnstillinger",
-    "Allow filesystem access" : "Tillatt filsystemtilgang",
-    "Rename" : "Gi nytt navn",
-    "Revoke" : "Avslå",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome for Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloud iOS-app",
-    "Nextcloud Android app" : "Nextcloud Android-app",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
-    "Sync client - {os}" : "Synkroniseringsklient - {os}",
-    "This session" : "Denne økten",
-    "Device" : "Enhet",
-    "Last activity" : "Seneste aktivitet",
-    "Devices & sessions" : "Enheter og økter",
-    "Web, desktop and mobile clients currently logged in to your account." : "Følgende nett, skrivebord og mobile klienter er for øyeblikket logget på din konto.",
-    "Error while creating device token" : "Feil under opprettelse av enhetsnøkkel",
-    "Error while deleting the token" : "Feil under sletting av nøkkel",
-    "App name" : "Appnavn",
-    "Create new app password" : "Lag nytt apppassord",
-    "Use the credentials below to configure your app or device." : "Bruk påloggingsinformasjonen under for å sette opp appen på din mobile enhet.",
-    "For security reasons this password will only be shown once." : "For sikkerhetens skyld vil dette passordet kun vises en gang.",
-    "Username" : "Brukernavn",
-    "Password" : "Passord",
-    "Done" : "Ferdig",
-    "Show QR code for mobile apps" : "Vis QR-kode for mobilapper",
-    "Copied!" : "Kopiert!",
-    "Copy" : "Kopier",
+    "Supported" : "Støttet",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Offisielle apper utvikles av og innenfor miljøet, de byr på sentral funksjonalitet og er klare for bruk i produksjon.",
     "Official" : "Offisiell",
     "by" : "av",
@@ -162,7 +145,45 @@ OC.L10N.register(
     "Enable all" : "Aktiver alle",
     "Download and enable" : "Last ned og aktiver",
     "Enable" : "Aktiver",
+    "Enable untested app" : "Aktiver utestet app",
     "The app will be downloaded from the app store" : "Denne appen vil bli lastet ned fra app-butikken",
+    "Device settings" : "Enhetsinnstillinger",
+    "Allow filesystem access" : "Tillatt filsystemtilgang",
+    "Rename" : "Gi nytt navn",
+    "Revoke" : "Avslå",
+    "Wipe device" : "Slett enhet",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome for Android",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Nextcloud iOS-app",
+    "Nextcloud Android app" : "Nextcloud Android-app",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
+    "Sync client - {os}" : "Synkroniseringsklient - {os}",
+    "This session" : "Denne økten",
+    "Device" : "Enhet",
+    "Last activity" : "Seneste aktivitet",
+    "Devices & sessions" : "Enheter og økter",
+    "Web, desktop and mobile clients currently logged in to your account." : "Følgende nett, skrivebord og mobile klienter er for øyeblikket logget på din konto.",
+    "Confirm wipe" : "Bekreft sletting",
+    "Error while creating device token" : "Feil under opprettelse av enhetsnøkkel",
+    "Error while deleting the token" : "Feil under sletting av nøkkel",
+    "App name" : "Appnavn",
+    "Create new app password" : "Lag nytt apppassord",
+    "Use the credentials below to configure your app or device." : "Bruk påloggingsinformasjonen under for å sette opp appen på din mobile enhet.",
+    "For security reasons this password will only be shown once." : "For sikkerhetens skyld vil dette passordet kun vises en gang.",
+    "Username" : "Brukernavn",
+    "Password" : "Passord",
+    "Done" : "Ferdig",
+    "Show QR code for mobile apps" : "Vis QR-kode for mobilapper",
+    "Copied!" : "Kopiert!",
+    "Copy" : "Kopier",
+    "Could not copy app password. Please copy it manually." : "Kunne ikke kopiere passord. Venligst kopier manuelt.",
     "You do not have permissions to see the details of this user" : "Du har ikke tilgang til å se detaljer om denne brukeren",
     "The backend does not support changing the display name" : "Serveren støtter ikke endring av visningsnavn",
     "New password" : "Nytt passord",
@@ -172,6 +193,7 @@ OC.L10N.register(
     "No language set" : "Språk ikke satt",
     "Never" : "Aldri",
     "Delete user" : "Slett bruker",
+    "Wipe all devices" : "Slett alle enheter",
     "Disable user" : "Deaktiver bruker",
     "Enable user" : "Aktiver bruker",
     "Resend welcome email" : "Send velkomst-epost igjen",
@@ -185,13 +207,14 @@ OC.L10N.register(
     "Storage location" : "Lagringsplassering",
     "User backend" : "Bruker-server",
     "Last login" : "Siste innlogging",
+    "Will be autogenerated" : "Blir generert automatisk",
     "Default language" : "Standard språk",
     "Add a new user" : "Legg til en ny bruker",
     "No users in here" : "Ingen brukere her",
     "Default quota" : "Standard kvote",
-    "Password change is disabled because the master key is disabled" : "Passordendring er deaktivert fordi hoved-nøkkelen er deaktivert",
     "Common languages" : "Vanlige språk",
     "All languages" : "Alle språk",
+    "Password change is disabled because the master key is disabled" : "Passordendring er deaktivert fordi hoved-nøkkelen er deaktivert",
     "Your apps" : "Dine apper",
     "Active apps" : "Aktive apper",
     "Disabled apps" : "Deaktiverte apper",
@@ -205,13 +228,13 @@ OC.L10N.register(
     "Show last login" : "Vis siste innlogging",
     "Show user backend" : "Vis bruker-bakende",
     "Show storage path" : "Vis lagrings-sti",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Du skal til å fjerne gruppen {group}. Brukerne vil IKKE bli slettet.",
-    "Please confirm the group removal " : "Vennligst bekreft fjerning av gruppe",
     "Remove group" : "Fjern gruppe",
     "Admins" : "Administratorer",
     "Disabled users" : "Deaktiverte brukere",
     "Everyone" : "Alle",
     "Add group" : "Legg til gruppe",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Du skal til å fjerne gruppen {group}. Brukerne vil IKKE bli slettet.",
+    "Please confirm the group removal " : "Vennligst bekreft fjerning av gruppe",
     "An error occured during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli videresendt til oppdateringssiden om 5 sekunder.",
     "App update" : "App-oppdatering",
@@ -246,7 +269,7 @@ OC.L10N.register(
     "Credentials" : "Påloggingsdetaljer",
     "SMTP Username" : "SMTP-brukernavn",
     "SMTP Password" : "SMTP-passord",
-    "Store credentials" : "Lagre påloggingsdetaljer",
+    "Save" : "Lagre",
     "Test email settings" : "Test innstillinger for e-post",
     "Send email" : "Send e-post",
     "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
@@ -281,8 +304,6 @@ OC.L10N.register(
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "For optimal ytelse er det viktig å sette opp bakgrunnsjobber rett. For kjøring på større installasjoner er 'Cron' anbefalt innstilling. Se dokumentasjonen for mer informasjon.",
     "Pick background job setting" : "Velg innstilling for bakgrunnsjobb",
     "Execute one task with each page loaded" : "Utfør en oppgave med hver side som blir lastet",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php er registrert i en webcron-tjeneste for å kalle cron.php hvert kvarter over HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Bruk systemets cron-tjeneste til å kalle cron.php hvert kvarter.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Filen cron.php må kjøres systemet som følgende bruker \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "For å kjøre denne trenger du PHP POSIX utvidelse. Se {linkstart}PHP-dokumentasjonen{linkend} for flere detaljer.",
     "Sharing" : "Deling",
@@ -343,6 +364,16 @@ OC.L10N.register(
     "Locale" : "Nasjonal innstilling",
     "Current password" : "Nåværende passord",
     "Change password" : "Endre passord",
-    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din."
+    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
+    "Disconnect" : "Koble fra",
+    "Not supported!" : "Ikke støttet!",
+    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
+    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
+    "Albanian" : "Albansk",
+    "Arabic" : "Arabisk",
+    "Store credentials" : "Lagre påloggingsdetaljer",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php er registrert i en webcron-tjeneste for å kalle cron.php hvert kvarter over HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Bruk systemets cron-tjeneste til å kalle cron.php hvert kvarter.",
+    "Follow us on Google+" : "Følg oss på Google"
 },
 "nplurals=2; plural=(n != 1);");
