@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
+    "Migration started …" : "Migração iniciada...",
+    "Saved" : "Guardado",
+    "Not saved" : "Não guardado",
+    "Sending…" : "A enviar...",
+    "Email sent" : "Mensagem de correio eletrónico enviada",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
+    "Valid until {date}" : "Válida até {date}",
+    "Delete" : "Apagar",
+    "Local" : "Local",
+    "Private" : "Privado",
+    "Only visible to local users" : "Apenas visível para utilizadores locais",
+    "Only visible to you" : "Apenas visível por si",
+    "Contacts" : "Contactos",
+    "Visible to local users and to trusted servers" : "Visível por utilizadores locais e servidores confiáveis",
+    "Public" : "Público",
+    "Will be synced to a global and public address book" : "Será sincronizado com um livro de endereços público e global",
+    "Verify" : "Verificar",
+    "Verifying …" : "A verificar...",
+    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
+    "Very weak password" : "Palavra-passe muito fraca",
+    "Weak password" : "Palavra-passe fraca",
+    "So-so password" : "Palavra-passe aceitável",
+    "Good password" : "Palavra-passe boa",
+    "Strong password" : "Palavra-passe forte",
+    "Select a profile picture" : "Selecione uma fotografia de perfil",
+    "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} alterou a sua senha",
     "You changed your password" : "Você alterou a sua senha",
     "Your password was reset by an administrator" : "A sua senha foi alterada por um administrador",
@@ -14,9 +41,7 @@ OC.L10N.register(
     "Couldn't remove app." : "Não foi possível remover a aplicação.",
     "Couldn't update app." : "Não foi possível atualizar a app.",
     "Wrong password" : "Palavra-passe errada",
-    "Saved" : "Guardado",
     "No user supplied" : "Nenhum utilizador especificado",
-    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
     "Authentication error" : "Erro na autenticação",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor introduza uma senha administrativa de recuperação ou todos os dados de utilizador serão perdidos.",
     "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação do administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
@@ -55,33 +80,27 @@ OC.L10N.register(
     "Set your password" : "Escolher senha",
     "Go to %s" : "Ir para %s",
     "Install Client" : "Instalar cliente",
-    "Delete" : "Apagar",
     "Unlimited" : "Ilimitado",
-    "Verifying …" : "A verificar...",
-    "Verify" : "Verificar",
-    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
-    "Migration started …" : "Migração iniciada...",
-    "Not saved" : "Não guardado",
-    "Sending…" : "A enviar...",
-    "Email sent" : "Mensagem de correio eletrónico enviada",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
-    "Valid until {date}" : "Válida até {date}",
-    "Local" : "Local",
-    "Private" : "Privado",
-    "Only visible to local users" : "Apenas visível para utilizadores locais",
-    "Only visible to you" : "Apenas visível por si",
-    "Contacts" : "Contactos",
-    "Visible to local users and to trusted servers" : "Visível por utilizadores locais e servidores confiáveis",
-    "Public" : "Público",
-    "Will be synced to a global and public address book" : "Será sincronizado com um livro de endereços público e global",
-    "Very weak password" : "Palavra-passe muito fraca",
-    "Weak password" : "Palavra-passe fraca",
-    "So-so password" : "Palavra-passe aceitável",
-    "Good password" : "Palavra-passe boa",
-    "Strong password" : "Palavra-passe forte",
-    "Select a profile picture" : "Selecione uma fotografia de perfil",
-    "Groups" : "Grupos",
     "Limit to groups" : "Limitado a grupos",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "As apps oficiais são desenvolvidas de e para a comunidade. Oferecem um repositório central de funcionalidades e estão preparadas para uso em produção.",
+    "Official" : "Oficial",
+    "Remove" : "Remover",
+    "Disable" : "Desativar",
+    "All" : "Todos",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
+    "View in store" : "Ver na loja",
+    "Visit website" : "Visitar o website",
+    "Report a bug" : "Reportar um erro",
+    "User documentation" : "Documentação de Utilizador",
+    "Admin documentation" : "Documentação do Administrador",
+    "Developer documentation" : "Documentação de Programador",
+    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
+    "Enable all" : "Ativar todas",
+    "Download and enable" : "Transferir e ativar",
+    "Enable" : "Ativar",
+    "The app will be downloaded from the app store" : "A aplicação será transferida da loja de aplicações",
     "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
     "Revoke" : "Revogar",
     "Internet Explorer" : "Internet Explorer",
@@ -106,25 +125,6 @@ OC.L10N.register(
     "Done" : "Concluído",
     "Copied!" : "Copiado!",
     "Copy" : "Copiar",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "As apps oficiais são desenvolvidas de e para a comunidade. Oferecem um repositório central de funcionalidades e estão preparadas para uso em produção.",
-    "Official" : "Oficial",
-    "Remove" : "Remover",
-    "Disable" : "Desativar",
-    "All" : "Todos",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
-    "View in store" : "Ver na loja",
-    "Visit website" : "Visitar o website",
-    "Report a bug" : "Reportar um erro",
-    "User documentation" : "Documentação de Utilizador",
-    "Admin documentation" : "Documentação do Administrador",
-    "Developer documentation" : "Documentação de Programador",
-    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
-    "Enable all" : "Ativar todas",
-    "Download and enable" : "Transferir e ativar",
-    "Enable" : "Ativar",
-    "The app will be downloaded from the app store" : "A aplicação será transferida da loja de aplicações",
     "New password" : "Nova palavra-passe",
     "{size} used" : "{size} utilizado",
     "Email" : "Email",
@@ -175,7 +175,6 @@ OC.L10N.register(
     "Credentials" : "Credenciais",
     "SMTP Username" : "Nome de utilizador SMTP",
     "SMTP Password" : "Palavra-passe SMTP",
-    "Store credentials" : "Armazenar credenciais",
     "Test email settings" : "Testar definições de e-mail",
     "Send email" : "Enviar email",
     "Security & setup warnings" : "Avisos de configuração e segurança",
@@ -202,8 +201,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Tarefa de segundo plano ainda não foi executada!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para desempenho óptimo é importante que configura as tarefas de segundo plano correctamente. Para maiores instâncias a definição recomendada é 'Cron'. Por favor veja a documentação para mais informações.",
     "Execute one task with each page loaded" : "Executar uma tarefa com cada página carregada",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registada num serviço webcron para chamar cron.php a cada 15 minutos através de HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Use o serviço de tarefas automáticas para chamar o ficheiro cron.php a cada 15 minutos.",
     "The cron.php needs to be executed by the system user \"%s\"." : "O cron.php precisa de ser executado pelo utilizador do sistema \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para esta execução precisa da extensão PHP POSIX. Veja {iniciodaligação}documentação PHP{fimdaligação} para mais mais detalhes.",
     "Sharing" : "Partilha",
@@ -255,6 +252,9 @@ OC.L10N.register(
     "Twitter handle @…" : "Identificador do Twitter  @...",
     "Help translate" : "Ajude a traduzir",
     "Current password" : "Palavra-passe atual",
-    "Change password" : "Alterar palavra-passe"
+    "Change password" : "Alterar palavra-passe",
+    "Store credentials" : "Armazenar credenciais",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registada num serviço webcron para chamar cron.php a cada 15 minutos através de HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Use o serviço de tarefas automáticas para chamar o ficheiro cron.php a cada 15 minutos."
 },
 "nplurals=2; plural=(n != 1);");
