@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
+    "Migration started …" : "Migrarea a început...",
+    "Saved" : "Salvat",
+    "Not saved" : "Nu a fost salvat",
+    "Sending…" : "Se trimite...",
+    "Email sent" : "Mesajul a fost expediat",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A apărut o eroare. Te rugăm să uploadezi un certificat PEM în format ASCII.",
+    "Valid until {date}" : "Valabil până la {date}",
+    "Delete" : "Șterge",
+    "Local" : "Local",
+    "Private" : "Privat",
+    "Only visible to local users" : "Vizibil userilor locali",
+    "Only visible to you" : "Vizibil doar pentru tine",
+    "Contacts" : "Contacte",
+    "Visible to local users and to trusted servers" : "Vizibil userilor locali si serverelor de încredere",
+    "Public" : "Public",
+    "Will be synced to a global and public address book" : "Va fi sincronizat cu o agendă de adrese publice și globale",
+    "Verify" : "Verifică",
+    "Verifying …" : "Se verifică ...",
+    "Unable to change password" : "Imposibil de schimbat parola",
+    "Very weak password" : "Parolă foarte slabă",
+    "Weak password" : "Parolă slabă",
+    "So-so password" : "Parolă medie",
+    "Good password" : "Parolă bună",
+    "Strong password" : "Parolă puternică",
+    "An error occurred while changing your language. Please reload the page and try again." : "A apărut o eroare la schimbarea limbii. Reîncărcați pagina și încercați din nou.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "A apărut o eroare la schimbarea locației. Reîncărcați pagina și încercați din nou.",
+    "Select a profile picture" : "Selectează o imagine de profil",
+    "Week starts on {fdow}" : "Săptămâna începe {fdow}",
+    "Groups" : "Grupuri",
+    "Group list is empty" : "Lista de grupuri este goală",
+    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
     "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
     "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
     "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
@@ -26,19 +58,17 @@ OC.L10N.register(
     "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
     "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
     "Wrong password" : "Parolă greșită",
-    "Saved" : "Salvat",
     "No user supplied" : "Nu a fost furnizat niciun utilizator",
-    "Unable to change password" : "Imposibil de schimbat parola",
     "Authentication error" : "Eroare la autentificare",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
     "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
-    "Federated Cloud Sharing" : "Partajare federalizata cloud",
+    "Federated Cloud Sharing" : "Partajare federalizată cloud",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
     "Invalid SMTP password." : "Parolă SMTP invalidă.",
     "Email setting test" : "Test setări email",
     "Well done, %s!" : "Felicitări, %s!",
     "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
-    "Email could not be sent. Check your mail server log" : "Mailul nu a putut fi trimis. Verifică logul serverului de mail.",
+    "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
     "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
     "Invalid mail address" : "Adresa mail invalidă",
@@ -64,37 +94,139 @@ OC.L10N.register(
     "Your username is: %s" : "Utilizatorul tău este: %s",
     "Set your password" : "Setează parola",
     "Install Client" : "Instalează client",
-    "Delete" : "Șterge",
     "Unlimited" : "Nelimitată",
-    "Verifying …" : "Se verifică ...",
-    "Verify" : "Verifică",
-    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
-    "Migration started …" : "Migrarea a început...",
-    "Not saved" : "Nu a fost salvat",
-    "Sending…" : "Se trimite...",
-    "Email sent" : "Mesajul a fost expediat",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A apărut o eroare. Te rugăm să uploadezi un certificat PEM în format ASCII.",
-    "Valid until {date}" : "Valabil până la {date}",
-    "Local" : "Local",
-    "Private" : "Privat",
-    "Only visible to local users" : "Vizibil userilor locali",
-    "Only visible to you" : "Vizibil doar pentru tine",
-    "Contacts" : "Contacte",
-    "Visible to local users and to trusted servers" : "Vizibil userilor locali si serverelor de încredere",
-    "Public" : "Public",
-    "Will be synced to a global and public address book" : "Va fi sincronizat cu o agendă de adrese publice și globale",
-    "Very weak password" : "Parolă foarte slabă",
-    "Weak password" : "Parolă slabă",
-    "So-so password" : "Parolă medie",
-    "Good password" : "Parolă bună",
-    "Strong password" : "Parolă puternică",
-    "An error occurred while changing your language. Please reload the page and try again." : "A apărut o eroare la schimbarea limbii. Reîncărcați pagina și încercați din nou.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "A apărut o eroare la schimbarea locației. Reîncărcați pagina și încercați din nou.",
-    "Select a profile picture" : "Selectează o imagine de profil",
-    "Week starts on {fdow}" : "Săptămâna începe {fdow}",
-    "Groups" : "Grupuri",
-    "Group list is empty" : "Lista de grupuri este goală",
-    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
+    "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
+    "Limit to groups" : "Limitează pentru grupuri",
+    "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
+    "Save changes" : "Salvează modificările",
+    "Official" : "Oficial",
+    "Disable" : "Dezactivați",
+    "All" : "Toate ",
+    "Visit website" : "Viziteaza pagina web",
+    "Report a bug" : "Raportează un defect",
+    "User documentation" : "Documentație utilizator",
+    "Admin documentation" : "Documentație pentru administrare",
+    "Developer documentation" : "Documentație pentru dezvoltatori",
+    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "Enable" : "Activare",
+    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
+    "Device settings" : "Setările dispozitivului",
+    "Allow filesystem access" : "Permite accesul la fișierele de sistem",
+    "Rename" : "Redenumește",
+    "Revoke" : "Revocă",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome for Android",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Aplicația Nextcloud pentru iOS",
+    "Nextcloud Android app" : "Aplicația Nextcloud pentru Android",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk pentru iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk pentru Android",
+    "This session" : "Această sesiune",
+    "Device" : "Dispozitiv",
+    "Last activity" : "Ultima activitate",
+    "Devices & sessions" : "Dispozitive și sesiuni",
+    "Error while deleting the token" : "Eroare de ștergere token",
+    "App name" : "Numele aplicației",
+    "Create new app password" : "Crează o nouă parolă pentru aplicație",
+    "Username" : "Nume utilizator",
+    "Password" : "Parolă",
+    "Done" : "Realizat",
+    "Copied!" : "S-a copiat!",
+    "Copy" : "Copiază",
+    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
+    "New password" : "Noua parolă",
+    "{size} used" : "{size} folosită",
+    "Email" : "Email",
+    "Quota" : "Cotă",
+    "Language" : "Limba",
+    "Default language" : "Limba implicită",
+    "Your apps" : "Aplicațiile tale",
+    "Disabled apps" : "Aplicații inactive",
+    "Updates" : "Actualizări",
+    "Show user backend" : "Arată administrare utilizator",
+    "Admins" : "Administratori",
+    "Everyone" : "Toți",
+    "Add group" : "Adaugă grup",
+    "SSL Root Certificates" : "Certificate SSL rădăcină",
+    "Common Name" : "Nume comun",
+    "Valid until" : "Valabil până la",
+    "Issued By" : "Emis de",
+    "Valid until %s" : "Valabil până la %s",
+    "Import root certificate" : "Importă certificat rădăcină",
+    "Administrator documentation" : "Documentație pentru administrare",
+    "Forum" : "Forum",
+    "None" : "Niciuna",
+    "Login" : "Autentificare",
+    "Plain" : "Plain",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "Server de email",
+    "Open documentation" : "Deschide documentația",
+    "Send mode" : "Modul de expediere",
+    "Encryption" : "Încriptare",
+    "From address" : "De la adresa",
+    "mail" : "poștă",
+    "Authentication method" : "Modul de autentificare",
+    "Authentication required" : "Autentificare necesară",
+    "Server address" : "Adresa server-ului",
+    "Port" : "Portul",
+    "Credentials" : "Detalii de autentificare",
+    "SMTP Username" : "Nume utilizator SMTP",
+    "SMTP Password" : "Parolă SMTP",
+    "Test email settings" : "Verifică setările de e-mail",
+    "Send email" : "Expediază mesajul",
+    "Security & setup warnings" : "Alerte de securitate & configurare",
+    "All checks passed." : "Toate verificările s-au terminat fără erori.",
+    "Version" : "Versiunea",
+    "Server-side encryption" : "Criptare la nivel de server",
+    "Enable server-side encryption" : "Activează criptarea pe server",
+    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
+    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
+    "Enable encryption" : "Activează criptarea",
+    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
+    "Start migration" : "Pornește migrarea",
+    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
+    "Sharing" : "Partajare",
+    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
+    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
+    "Allow public uploads" : "Permite încărcări publice",
+    "Enforce password protection" : "Impune protecția prin parolă",
+    "Set default expiration date" : "Setează data implicită de expirare",
+    "Expire after " : "Expiră după",
+    "days" : "zile",
+    "Enforce expiration date" : "Impune data de expirare",
+    "Allow resharing" : "Permite repartajarea",
+    "Allow sharing with groups" : "Permite partajarea cu grupuri",
+    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
+    "Administration" : "Administrare",
+    "Profile picture" : "Imagine de profil",
+    "Upload new" : "Încarcă una nouă",
+    "Select from Files" : "Selectează din fișiere",
+    "Remove image" : "Înlătură imagine",
+    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
+    "Cancel" : "Anulare",
+    "Choose as profile picture" : "Alege ca imagine de profil",
+    "Details" : "Detalii",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizezi <strong>%1$s</strong> din <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Full name" : "Nume complet",
+    "Your email address" : "Adresa ta de email",
+    "No email address set" : "Fără adresă de email setată",
+    "Phone number" : "Număr telefon",
+    "Your phone number" : "Numărul tău de telefon",
+    "Address" : "Adresă",
+    "Your postal address" : "Adresă poștală",
+    "Website" : "Site web",
+    "Link https://…" : "Link https://…",
+    "Twitter" : "Twitter",
+    "Help translate" : "Ajută la traducere",
+    "Current password" : "Parola curentă",
+    "Change password" : "Schimbă parola",
     "Afrikaans (Namibia)" : "Afrikaans (Namibia)",
     "Afrikaans (South Africa)" : "Afrikaans (South Africa)",
     "Afrikaans" : "Afrikaans",
@@ -177,139 +309,6 @@ OC.L10N.register(
     "Croatian" : "Croatian",
     "Czech (Czech Republic)" : "Chehă (Republica Chehă)",
     "Czech" : "Chehă",
-    "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
-    "Limit to groups" : "Limitează pentru grupuri",
-    "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
-    "Save changes" : "Salvează modificările",
-    "Device settings" : "Setările dispozitivului",
-    "Allow filesystem access" : "Permite accesul la fișierele de sistem",
-    "Rename" : "Redenumește",
-    "Revoke" : "Revocă",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome for Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Aplicația Nextcloud pentru iOS",
-    "Nextcloud Android app" : "Aplicația Nextcloud pentru Android",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk pentru iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk pentru Android",
-    "This session" : "Această sesiune",
-    "Device" : "Dispozitiv",
-    "Last activity" : "Ultima activitate",
-    "Devices & sessions" : "Dispozitive și sesiuni",
-    "Error while deleting the token" : "Eroare de ștergere token",
-    "App name" : "Numele aplicației",
-    "Create new app password" : "Crează o nouă parolă pentru aplicație",
-    "Username" : "Nume utilizator",
-    "Password" : "Parolă",
-    "Done" : "Realizat",
-    "Copied!" : "S-a copiat!",
-    "Copy" : "Copiază",
-    "Official" : "Oficial",
-    "Disable" : "Dezactivați",
-    "All" : "Toate ",
-    "Visit website" : "Viziteaza pagina web",
-    "Report a bug" : "Raportează un defect",
-    "User documentation" : "Documentație utilizator",
-    "Admin documentation" : "Documentație pentru administrare",
-    "Developer documentation" : "Documentație pentru dezvoltatori",
-    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
-    "Enable" : "Activare",
-    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
-    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
-    "New password" : "Noua parolă",
-    "{size} used" : "{size} folosită",
-    "Email" : "Email",
-    "Quota" : "Cotă",
-    "Language" : "Limba",
-    "Default language" : "Limba implicită",
-    "Your apps" : "Aplicațiile tale",
-    "Disabled apps" : "Aplicații inactive",
-    "Updates" : "Actualizări",
-    "Show user backend" : "Arată administrare utilizator",
-    "Admins" : "Administratori",
-    "Everyone" : "Toți",
-    "Add group" : "Adaugă grup",
-    "SSL Root Certificates" : "Certificate SSL rădăcină",
-    "Common Name" : "Nume comun",
-    "Valid until" : "Valabil până la",
-    "Issued By" : "Emis de",
-    "Valid until %s" : "Valabil până la %s",
-    "Import root certificate" : "Importă certificat rădăcină",
-    "Administrator documentation" : "Documentație pentru administrare",
-    "Forum" : "Forum",
-    "None" : "Niciuna",
-    "Login" : "Autentificare",
-    "Plain" : "Plain",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Email server" : "Server de email",
-    "Open documentation" : "Deschide documentația",
-    "Send mode" : "Modul de expediere",
-    "Encryption" : "Încriptare",
-    "From address" : "De la adresa",
-    "mail" : "poștă",
-    "Authentication method" : "Modul de autentificare",
-    "Authentication required" : "Autentificare necesară",
-    "Server address" : "Adresa server-ului",
-    "Port" : "Portul",
-    "Credentials" : "Detalii de autentificare",
-    "SMTP Username" : "Nume utilizator SMTP",
-    "SMTP Password" : "Parolă SMTP",
-    "Store credentials" : "Stochează datele de autentificare",
-    "Test email settings" : "Verifică setările de e-mail",
-    "Send email" : "Expediază mesajul",
-    "Security & setup warnings" : "Alerte de securitate & configurare",
-    "All checks passed." : "Toate verificările s-au terminat fără erori.",
-    "Version" : "Versiunea",
-    "Server-side encryption" : "Criptare la nivel de server",
-    "Enable server-side encryption" : "Activează criptarea pe server",
-    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
-    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
-    "Enable encryption" : "Activează criptarea",
-    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
-    "Start migration" : "Pornește migrarea",
-    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
-    "Sharing" : "Partajare",
-    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
-    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
-    "Allow public uploads" : "Permite încărcări publice",
-    "Enforce password protection" : "Impune protecția prin parolă",
-    "Set default expiration date" : "Setează data implicită de expirare",
-    "Expire after " : "Expiră după",
-    "days" : "zile",
-    "Enforce expiration date" : "Impune data de expirare",
-    "Allow resharing" : "Permite repartajarea",
-    "Allow sharing with groups" : "Permite partajarea cu grupuri",
-    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
-    "Administration" : "Administrare",
-    "Profile picture" : "Imagine de profil",
-    "Upload new" : "Încarcă una nouă",
-    "Select from Files" : "Selectează din fișiere",
-    "Remove image" : "Înlătură imagine",
-    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
-    "Cancel" : "Anulare",
-    "Choose as profile picture" : "Alege ca imagine de profil",
-    "Details" : "Detalii",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizezi <strong>%1$s</strong> din <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "Nume complet",
-    "Your email address" : "Adresa ta de email",
-    "No email address set" : "Fără adresă de email setată",
-    "Phone number" : "Număr telefon",
-    "Your phone number" : "Numărul tău de telefon",
-    "Address" : "Adresă",
-    "Your postal address" : "Adresă poștală",
-    "Website" : "Site web",
-    "Link https://…" : "Link https://…",
-    "Twitter" : "Twitter",
-    "Help translate" : "Ajută la traducere",
-    "Current password" : "Parola curentă",
-    "Change password" : "Schimbă parola",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "Utilizezi <strong>%s</strong> din <strong>%s</strong> (<strong>%s %%</strong>)"
+    "Store credentials" : "Stochează datele de autentificare"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
