@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
+    "Migration started …" : "Selitev je začeta ...",
+    "Saved" : "Shranjeno",
+    "Sending…" : "Poteka pošiljanje ...",
+    "Email sent" : "Elektronsko sporočilo je poslano",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
+    "Valid until {date}" : "Veljavno do {date}",
+    "Delete" : "Izbriši",
+    "Local" : "Krajevno",
+    "Private" : "Zasebno",
+    "Only visible to local users" : "Vidno le krajevnim uporabnikom",
+    "Contacts" : "Stiki",
+    "Visible to local users and to trusted servers" : "Vidno le krajevnim uporabnikom in odobrenim strežnikom",
+    "Public" : "Javno",
+    "Verify" : "Overi",
+    "Verifying …" : "Poteka overjanje ...",
+    "Unable to change password" : "Ni mogoče spremeniti gesla",
+    "Very weak password" : "Zelo šibko geslo",
+    "Weak password" : "Slabo geslo",
+    "So-so password" : "Šibko geslo",
+    "Good password" : "Dobro geslo",
+    "Strong password" : "Odlično geslo",
+    "Select a profile picture" : "Izbor slike profila",
+    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
+    "Groups" : "Skupine",
+    "Group list is empty" : "Seznam skupin je prazen",
+    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
     "You added {user} to group {group}" : "Uporabnika {user} ste dodali v skupino {group}",
     "An administrator added you to group {group}" : "Administrator vas je dodal v skupino {group}",
     "An administrator added {user} to group {group}" : "Administrator je dodal uporabnika {user} v skupino {group}",
@@ -13,10 +40,8 @@ OC.L10N.register(
     "Couldn't remove app." : "Programa ni mogoče odstraniti.",
     "Couldn't update app." : "Programa ni mogoče posodobiti.",
     "Wrong password" : "Napačno geslo",
-    "Saved" : "Shranjeno",
     "No user supplied" : "Ni navedenega uporabnika",
-    "Unable to change password" : "Ni mogoče spremeniti gesla",
-    "Authentication error" : "Napaka med overjanjem",
+    "Authentication error" : "Napaka overjanja",
     "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
     "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
@@ -31,75 +56,37 @@ OC.L10N.register(
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Za overitev računa Twitter, objavite sporočilo (prepričajte se, da ni nobenega preloma vrstice):",
     "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
     "Set your password" : "Določitev gesla",
+    "Install Client" : "Namesti odjemalca",
     "Create" : "Ustvari",
     "Change" : "Spremeni",
-    "Delete" : "Izbriši",
     "Unlimited" : "Neomejeno",
-    "Verifying …" : "Poteka overjanje ...",
-    "Verify" : "Overi",
-    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
-    "Migration started …" : "Selitev je začeta ...",
-    "Sending…" : "Poteka pošiljanje ...",
-    "Email sent" : "Elektronsko sporočilo je poslano",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
-    "Valid until {date}" : "Veljavno do {date}",
-    "Local" : "Krajevno",
-    "Private" : "Zasebno",
-    "Only visible to local users" : "Vidno le krajevnim uporabnikom",
-    "Contacts" : "Stiki",
-    "Visible to local users and to trusted servers" : "Vidno le krajevnim uporabnikom in odobrenim strežnikom",
-    "Public" : "Javno",
-    "Very weak password" : "Zelo šibko geslo",
-    "Weak password" : "Slabo geslo",
-    "So-so password" : "Šibko geslo",
-    "Good password" : "Dobro geslo",
-    "Strong password" : "Odlično geslo",
-    "Select a profile picture" : "Izbor slike profila",
-    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
-    "Groups" : "Skupine",
-    "Group list is empty" : "Seznam skupin je prazen",
-    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
-    "Afrikaans (Namibia)" : "Afrikanščina (Namibia)",
-    "Afrikaans (South Africa)" : "Afrikanščina (Južna Afrika)",
-    "Afrikaans" : "Afrikanščina",
-    "Akan (Ghana)" : "Akanščina (Gana)",
-    "Akan" : "Akanščina",
-    "Albanian (Albania)" : "Albanščina (Albanija)",
-    "Albanian" : "Albanščina",
-    "Amharic (Ethiopia)" : "Amharščina (Etiopija)",
-    "Amharic" : "Amharščina",
-    "Arabic (Algeria)" : "Arabščina (Alžirija)",
-    "Arabic (Bahrain)" : "Arabščina (Bahrain)",
-    "Arabic (Egypt)" : "Arabščina (Egipt)",
-    "Arabic (Iraq)" : "Arabščina (Irak)",
-    "Arabic (Jordan)" : "Arabščina (Jordanija)",
-    "Arabic (Kuwait)" : "Arabščina (Kuvajt)",
-    "Arabic (Lebanon)" : "Arabščina (Libanon)",
-    "Arabic (Libya)" : "Arabščina (Libija)",
-    "Arabic (Morocco)" : "Arabščina (Maroko)",
-    "Arabic (Oman)" : "Arabščina (Oman)",
-    "Arabic (Qatar)" : "Arabščina (Katar)",
-    "Arabic (Saudi Arabia)" : "Arabščina (Savdova arabija)",
-    "Arabic (Sudan)" : "Arabščina (Sudan)",
-    "Arabic (Syria)" : "Arabščina (Sirija)",
-    "Arabic (Tunisia)" : "Arabščina (Tunizija)",
-    "Arabic (United Arab Emirates)" : "Arabščina (Združeni Emirati)",
-    "Arabic (Yemen)" : "Arabščina (Jemen)",
-    "Arabic" : "Arabščina",
-    "Armenian (Armenia)" : "Armenščina (Armenija)",
-    "Armenian" : "Armenščina",
-    "Assamese (India)" : "Asamščina (Indija)",
-    "Assamese" : "Asamščina",
-    "Asu (Tanzania)" : "Asujščina (Tanzanija)",
-    "Asu" : "Asujščina",
-    "English" : "Angleščina",
-    "Esperanto" : "Esperanto",
-    "Estonian" : "Estonščina",
-    "Faroese" : "Farščina",
-    "Finnish" : "Finščina",
-    "French" : "Francoščina",
+    "Nextcloud settings" : "Nastavitve Nextcloud",
     "Limit to groups" : "Omeji na skupine",
     "Save changes" : "Shrani spremembe",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
+    "Official" : "Uradno",
+    "Update to {version}" : "Posodobi na različico {version}",
+    "Remove" : "Odstrani",
+    "Disable" : "Onemogoči",
+    "All" : "Vsi",
+    "No results" : "Ni zadetkov",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
+    "View in store" : "Pokaži v trgovini",
+    "Visit website" : "Odpri spletno stran",
+    "Report a bug" : "Pošlji poročilo o hrošču",
+    "User documentation" : "Uporabniška dokumentacija",
+    "Admin documentation" : "Skrbniška dokumentacija",
+    "Developer documentation" : "Dokumentacija za razvijalce",
+    "Update to {update}" : "Posodobi na {update}",
+    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
+    "No apps found for your version" : "Za navedeni iskalni niz ni programov",
+    "Disable all" : "Onemogoči vse",
+    "Enable all" : "Omogoči vse",
+    "Download and enable" : "Prejmi in omogoči",
+    "Enable" : "Omogoči",
+    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
     "Device settings" : "Nastavitve naprave",
     "Allow filesystem access" : "Dovoli dostop do datotečnega sistema",
     "Rename" : "Preimenuj",
@@ -126,46 +113,26 @@ OC.L10N.register(
     "Done" : "Končano",
     "Copied!" : "Kopirano!",
     "Copy" : "Kopiraj",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
-    "Official" : "Uradno",
-    "Update to {version}" : "Posodobi na različico {version}",
-    "Remove" : "Odstrani",
-    "Disable" : "Onemogoči",
-    "All" : "Vsi",
-    "No results" : "Ni zadetkov",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
-    "View in store" : "Pokaži v trgovini",
-    "Visit website" : "Odpri spletno stran",
-    "Report a bug" : "Pošlji poročilo o hrošču",
-    "User documentation" : "Uporabniška dokumentacija",
-    "Admin documentation" : "Skrbniška dokumentacija",
-    "Developer documentation" : "Dokumentacija za razvijalce",
-    "Update to {update}" : "Posodobi na {update}",
-    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
-    "No apps found for your version" : "Za nameščeno različico oziroma iskalni niz ni nobenega programa",
-    "Disable all" : "Onemogoči vse",
-    "Enable all" : "Omogoči vse",
-    "Download and enable" : "Prejmi in omogoči",
-    "Enable" : "Omogoči",
-    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
     "New password" : "Novo geslo",
     "Add user in group" : "Dodaj uporabnika v skupino",
+    "Select user quota" : "Izbor količinske omejitve uporabnika",
     "No language set" : "Jezik ni nastavljen",
     "Never" : "Nikoli",
     "Delete user" : "Izbriši uporabnika",
     "Disable user" : "Onemogoči uporabnika",
     "Enable user" : "Omogoči uporabnika",
+    "Display name" : "Prikazno ime",
     "Email" : "Elektronski naslov",
     "Group admin for" : "Skrbnik skupine za",
     "Quota" : "Količinska omejitev",
     "Language" : "Jezik",
     "Storage location" : "Mesto shrambe",
     "Last login" : "Zadnja prijava",
+    "Default language" : "Privzeti jezik",
     "Add a new user" : "Dodaj uporabnika",
     "No users in here" : "Ni še vključenih uporabnikov",
-    "Default quota" : "Privzeta količinska omejitev",
+    "Default quota" : "Privzeta omejitev",
+    "Common languages" : "Splošni jeziki",
     "All languages" : "Vsi jeziki",
     "Your apps" : "Vsi programi",
     "Active apps" : "Zagnani programi",
@@ -219,6 +186,7 @@ OC.L10N.register(
     "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih je nekaj napak namestitve.",
     "There are some warnings regarding your setup." : "Med preverjanjem je bilo javljenih nekaj opozoril.",
     "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>.",
     "Version" : "Različica",
     "Two-Factor Authentication" : "Dvo-stopenjska overitev",
     "Server-side encryption" : "Šifriranje na strežniku",
@@ -291,6 +259,83 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
     "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
     "Error while loading browser sessions and device tokens" : " Napaka med nalaganjem sej brskalnika in žetonov naprave",
+    "Afrikaans (Namibia)" : "Afrikanščina (Namibia)",
+    "Afrikaans (South Africa)" : "Afrikanščina (Južna Afrika)",
+    "Afrikaans" : "Afrikanščina",
+    "Akan (Ghana)" : "Akanščina (Gana)",
+    "Akan" : "Akanščina",
+    "Albanian (Albania)" : "Albanščina (Albanija)",
+    "Albanian" : "Albanščina",
+    "Amharic (Ethiopia)" : "Amharščina (Etiopija)",
+    "Amharic" : "Amharščina",
+    "Arabic (Algeria)" : "Arabščina (Alžirija)",
+    "Arabic (Bahrain)" : "Arabščina (Bahrain)",
+    "Arabic (Egypt)" : "Arabščina (Egipt)",
+    "Arabic (Iraq)" : "Arabščina (Irak)",
+    "Arabic (Jordan)" : "Arabščina (Jordanija)",
+    "Arabic (Kuwait)" : "Arabščina (Kuvajt)",
+    "Arabic (Lebanon)" : "Arabščina (Libanon)",
+    "Arabic (Libya)" : "Arabščina (Libija)",
+    "Arabic (Morocco)" : "Arabščina (Maroko)",
+    "Arabic (Oman)" : "Arabščina (Oman)",
+    "Arabic (Qatar)" : "Arabščina (Katar)",
+    "Arabic (Saudi Arabia)" : "Arabščina (Savdova arabija)",
+    "Arabic (Sudan)" : "Arabščina (Sudan)",
+    "Arabic (Syria)" : "Arabščina (Sirija)",
+    "Arabic (Tunisia)" : "Arabščina (Tunizija)",
+    "Arabic (United Arab Emirates)" : "Arabščina (Združeni Emirati)",
+    "Arabic (Yemen)" : "Arabščina (Jemen)",
+    "Arabic" : "Arabščina",
+    "Armenian (Armenia)" : "Armenščina (Armenija)",
+    "Armenian" : "Armenščina",
+    "Assamese (India)" : "Asamščina (Indija)",
+    "Assamese" : "Asamščina",
+    "Asu (Tanzania)" : "Asujščina (Tanzanija)",
+    "Asu" : "Asujščina",
+    "English" : "Angleščina",
+    "Esperanto" : "Esperanto",
+    "Estonian" : "Estonščina",
+    "Faroese" : "Farščina",
+    "Finnish" : "Finščina",
+    "French" : "Francoščina",
+    "Serbian (Cyrillic)" : "Srbščina (cirilica)",
+    "Serbian (Cyrillic, Bosnia and Herzegovina)" : "Srbščina (cirilica, Bosna in Hercegovina)",
+    "Serbian (Cyrillic, Montenegro)" : "Srbščina (cirilica, Črna gora)",
+    "Serbian (Cyrillic, Serbia)" : "Srbščina (cirilica, Srbija)",
+    "Serbian (Latin)" : "Srbščina (latinica)",
+    "Serbian (Latin, Bosnia and Herzegovina)" : "Srbščina (latinica, Bosna in Hercegovina)",
+    "Serbian (Latin, Montenegro)" : "Srbščina (latinica, Črna gora)",
+    "Serbian (Latin, Serbia)" : "Srbščina (latinica, Srbija)",
+    "Slovenian (Slovenia)" : "Slovenščina (Slovenija)",
+    "Slovenian" : "Slovenščina",
+    "Somali (Djibouti)" : "Somalščina (Džibuti)",
+    "Somali (Ethiopia)" : "Somalščina (Etiopija)",
+    "Somali (Kenya)" : "Somalščina (Kenija)",
+    "Somali (Somalia)" : "Somalščina (Somalija)",
+    "Somali" : "Somalščina",
+    "Spanish (Argentina)" : "Španščina (Argentina)",
+    "Spanish (Bolivia)" : "Španščina (Bilovija)",
+    "Spanish (Chile)" : "Španščina (Čile)",
+    "Spanish (Colombia)" : "Španščina (Kolumbija)",
+    "Spanish (Costa Rica)" : "Španščina (Kostarika)",
+    "Spanish (Dominican Republic)" : "Španščina (Dominikanska republika)",
+    "Spanish (Ecuador)" : "Španščina (Ekvador)",
+    "Spanish (El Salvador)" : "Španščina (El Salvador)",
+    "Spanish (Equatorial Guinea)" : "Španščina (Ekvatorialna Gvineja)",
+    "Spanish (Guatemala)" : "Španščina (Gvatemala)",
+    "Spanish (Honduras)" : "Španščina (Honduras)",
+    "Spanish (Latin America)" : "Španščina (Latinska Amerika)",
+    "Spanish (Mexico)" : "Španščina (Mehika)",
+    "Spanish (Nicaragua)" : "Španščina (Nikaragva)",
+    "Spanish (Panama)" : "Španščina (Panama)",
+    "Spanish (Paraguay)" : "Španščina (Paragvaj)",
+    "Spanish (Peru)" : "Španščina (Peru)",
+    "Spanish (Puerto Rico)" : "Španščina (Portoriko)",
+    "Spanish (Spain)" : "Španščina (Španija)",
+    "Spanish (United States)" : "Španščina (Združene države Amerike)",
+    "Spanish (Uruguay)" : "Španščina (Urugvaj)",
+    "Spanish (Venezuela)" : "Španščina (Venezuela)",
+    "Spanish" : "Španščina",
     "Store credentials" : "Shrani poverila",
     "Follow us on Google+" : "Sledite nam na Google+"
 },
