@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
+    "Migration started …" : "Migrimi filloi …",
+    "Saved" : "U ruajt",
+    "Not saved" : "Nuk u ruajt",
+    "Sending…" : "dërgim",
+    "Email sent" : "Email-i u dërgua",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ndodhi një gabim. Ju lutemi, ngarkoni një dëshmi PEM të koduar me ASCII.",
+    "Valid until {date}" : "E vlefshme deri më {date}",
+    "Delete" : "Fshij",
+    "Local" : "Lokale",
+    "Private" : "Private",
+    "Only visible to local users" : "E dukshme vetëm për përdoruesit lokal",
+    "Only visible to you" : "E dukshme vetëm për ju",
+    "Contacts" : "Kontaktet",
+    "Visible to local users and to trusted servers" : "E dukshme për përdoruesit lokal dhe serverat e besuar",
+    "Public" : "Publiku",
+    "Will be synced to a global and public address book" : "Do të sinkronizohet te një libër adresash publik dhe global",
+    "Verify" : "Verifiko",
+    "Verifying …" : "Duke verifikuar ...",
+    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
+    "Very weak password" : "Fjalëkalim shumë i dobët",
+    "Weak password" : "Fjalëkalim i dobët",
+    "So-so password" : "Fjalëkalim çka",
+    "Good password" : "Fjalëkalim i mirë",
+    "Strong password" : "Fjalëkalim i fortë",
+    "Select a profile picture" : "Përzgjidhni një foto profili",
+    "Groups" : "Grupe",
     "{actor} changed your password" : "{actor} ndryshoi fjalëkalimin tuaj ",
     "You changed your password" : "Ju ndëruat fjalëkalimin",
     "Your password was reset by an administrator" : "Fjalëkalimi juaj është rivendosur nga administratori",
@@ -14,9 +41,7 @@ OC.L10N.register(
     "Couldn't remove app." : "S’hoqi dot aplikacionin.",
     "Couldn't update app." : "S’përditësoi dot aplikacionin.",
     "Wrong password" : "Fjalëkalim i gabuar",
-    "Saved" : "U ruajt",
     "No user supplied" : "S’u dha përdorues",
-    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
     "Authentication error" : "Gabim mirëfilltësimi",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
     "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
@@ -54,33 +79,26 @@ OC.L10N.register(
     "Set your password" : "Vendos fjalëkalimin tënd",
     "Go to %s" : "Shko tek %s",
     "Install Client" : "Instalo Klient",
-    "Delete" : "Fshij",
     "Unlimited" : "E pakufizuar",
-    "Verifying …" : "Duke verifikuar ...",
-    "Verify" : "Verifiko",
-    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
-    "Migration started …" : "Migrimi filloi …",
-    "Not saved" : "Nuk u ruajt",
-    "Sending…" : "dërgim",
-    "Email sent" : "Email-i u dërgua",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ndodhi një gabim. Ju lutemi, ngarkoni një dëshmi PEM të koduar me ASCII.",
-    "Valid until {date}" : "E vlefshme deri më {date}",
-    "Local" : "Lokale",
-    "Private" : "Private",
-    "Only visible to local users" : "E dukshme vetëm për përdoruesit lokal",
-    "Only visible to you" : "E dukshme vetëm për ju",
-    "Contacts" : "Kontaktet",
-    "Visible to local users and to trusted servers" : "E dukshme për përdoruesit lokal dhe serverat e besuar",
-    "Public" : "Publiku",
-    "Will be synced to a global and public address book" : "Do të sinkronizohet te një libër adresash publik dhe global",
-    "Very weak password" : "Fjalëkalim shumë i dobët",
-    "Weak password" : "Fjalëkalim i dobët",
-    "So-so password" : "Fjalëkalim çka",
-    "Good password" : "Fjalëkalim i mirë",
-    "Strong password" : "Fjalëkalim i fortë",
-    "Select a profile picture" : "Përzgjidhni një foto profili",
-    "Groups" : "Grupe",
     "Limit to groups" : "Kufizo grupet",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikacionet zyrtare zhvillohen nga komuniteti dhe brenta tij. Ato ofrojnë funksionalitet qëndror dhe janë gati për përdorim.",
+    "Official" : "Zyrtare",
+    "Remove" : "Hiqe",
+    "Disable" : "Çaktivizoje",
+    "All" : "Krejt",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
+    "View in store" : "Shiko në dyqan",
+    "Visit website" : "Vizitoni sajtin",
+    "Report a bug" : "Njoftoni një të metë",
+    "User documentation" : "Dokumentim për përdoruesit",
+    "Admin documentation" : "Dokumentim për përgjegjësit",
+    "Developer documentation" : "Dokumentim për zhvillues",
+    "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
+    "Enable all" : "Aktivizoi të gjitha",
+    "Enable" : "Aktivizoje",
+    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
     "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
     "Revoke" : "Anulo",
     "Internet Explorer" : "Internet Explorer",
@@ -105,24 +123,6 @@ OC.L10N.register(
     "Done" : "U bë",
     "Copied!" : "U kopjua!",
     "Copy" : "Kopjo",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikacionet zyrtare zhvillohen nga komuniteti dhe brenta tij. Ato ofrojnë funksionalitet qëndror dhe janë gati për përdorim.",
-    "Official" : "Zyrtare",
-    "Remove" : "Hiqe",
-    "Disable" : "Çaktivizoje",
-    "All" : "Krejt",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
-    "View in store" : "Shiko në dyqan",
-    "Visit website" : "Vizitoni sajtin",
-    "Report a bug" : "Njoftoni një të metë",
-    "User documentation" : "Dokumentim për përdoruesit",
-    "Admin documentation" : "Dokumentim për përgjegjësit",
-    "Developer documentation" : "Dokumentim për zhvillues",
-    "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
-    "Enable all" : "Aktivizoi të gjitha",
-    "Enable" : "Aktivizoje",
-    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
     "New password" : "Fjalëkalimi i ri",
     "{size} used" : "{madhësia} e përdorur",
     "Email" : "Email",
@@ -170,7 +170,6 @@ OC.L10N.register(
     "Credentials" : "Kredenciale",
     "SMTP Username" : "Emër përdoruesi SMTP",
     "SMTP Password" : "Fjalëkalim SMTP",
-    "Store credentials" : "Depozitoji kredencialet",
     "Test email settings" : "Testoni rregullimet e email-it",
     "Send email" : "Dërgo email",
     "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
@@ -197,8 +196,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Puna ne background nuk ka filluar akoma!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Për performancë optimale është e rëndësishme të konfigurosh punë të sfondit në mënyrë korrekte. Për raste më të mëdha 'Cron' është konfigurimi i rekomanduar. Ju lutem shih dokumentacionin për më shumë informacion.",
     "Execute one task with each page loaded" : "Kryeni vetëm një veprim me secilën prej faqeve të ngarkuara",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php është regjistruar në një server webcron për të thirrur cron.php çdo 15 minuta mbi HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Përdor shërbimin cron të sistemit për të thirrur skedarin cron.php çdo 15 minuta.",
     "The cron.php needs to be executed by the system user \"%s\"." : "con.php duhet të ekzekutohet bga përdoruesi i sistemit \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
     "Sharing" : "Ndarje me të tjerët",
@@ -251,6 +248,9 @@ OC.L10N.register(
     "Twitter handle @…" : "Përdoruesi i Twitter @ ...",
     "Help translate" : "Ndihmoni në përkthim",
     "Current password" : "Fjalëkalimi i tanishëm",
-    "Change password" : "Ndrysho fjalëkalimin"
+    "Change password" : "Ndrysho fjalëkalimin",
+    "Store credentials" : "Depozitoji kredencialet",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php është regjistruar në një server webcron për të thirrur cron.php çdo 15 minuta mbi HTTP.",
+    "Use system cron service to call the cron.php file every 15 minutes." : "Përdor shërbimin cron të sistemit për të thirrur skedarin cron.php çdo 15 minuta."
 },
 "nplurals=2; plural=(n != 1);");
