@@ -1,6 +1,49 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
+    "Migration started …" : "Міграцію розпочато ...",
+    "Saved" : "Збережено",
+    "Not saved" : "Не збережено",
+    "Sending…" : "Відправка...",
+    "Email sent" : "Лист надіслано",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
+    "Valid until {date}" : "Дійсно до {date}",
+    "Delete" : "Видалити",
+    "Local" : "Локально",
+    "Private" : "Закритий",
+    "Only visible to local users" : "Видимий тільки для локальних користувачів",
+    "Only visible to you" : "Видимий тільки вам",
+    "Contacts" : "Контакти",
+    "Visible to local users and to trusted servers" : "Видимий тільки локальним користувачам і довіреним серверам",
+    "Public" : "Відкритий",
+    "Will be synced to a global and public address book" : "Буде синхронізовано з глобальною та відкритою адресною книгою",
+    "Verify" : "Перевірити",
+    "Verifying …" : "Перевірка ...",
+    "Unable to change password" : "Неможливо змінити пароль",
+    "Very weak password" : "Дуже слабкий пароль",
+    "Weak password" : "Слабкий пароль",
+    "So-so password" : "Такий собі пароль",
+    "Good password" : "Добрий пароль",
+    "Strong password" : "Надійний пароль",
+    "An error occurred while changing your language. Please reload the page and try again." : "Виникла помилка при зміні мови. Перезавантажте сторінку та повторіть спробу.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Виникла помилка при зміні локалі. Перезавантажте сторінку та повторіть спробу.",
+    "Select a profile picture" : "Обрати зображення облікового запису",
+    "Week starts on {fdow}" : "Тиждень починається в {fdow}",
+    "Groups" : "Групи",
+    "Group list is empty" : "Список груп порожній",
+    "Unable to retrieve the group list" : "Неможливо отримати список груп",
+    "{actor} added you to group {group}" : "{actor} додав вас до групи {group}",
+    "You added {user} to group {group}" : "Ви додали {user} до групи {group}",
+    "{actor} added {user} to group {group}" : "{actor} додав {user} до групи {group}",
+    "An administrator added you to group {group}" : "Адміністратор додав вас до групи {group}",
+    "An administrator added {user} to group {group}" : "Адміністратор додав {user} до групи {group}",
+    "{actor} removed you from group {group}" : "{actor} вилучив вас із групи {group}",
+    "You removed {user} from group {group}" : "Ви вилучили {user} з групи {group}",
+    "{actor} removed {user} from group {group}" : "{actor} вилучив {user} з групи {group}",
+    "An administrator removed you from group {group}" : "Адміністратор вилучив вас з групи {group}",
+    "An administrator removed {user} from group {group}" : "Адміністратор вилучив {user} з групи {group}",
+    "Your <strong>group memberships</strong> were modified" : "Парамеири вашої <strong>участі в групі</strong> оновлено",
     "{actor} changed your password" : "{actor} змінив ваш пароль",
     "You changed your password" : "Ви змінили свій пароль",
     "Your password was reset by an administrator" : "Ваш пароль був скинутий адміністратором",
@@ -11,12 +54,10 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Ви успішно увійшли, використовуючи двофакторну аутентифікацію (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Помилка спроби входу в систему, використовуючи двофакторну аутентифікацію (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваш <strong>пароль</strong> чи <strong>електронна пошта</strong> були змінені",
-    "Couldn't remove app." : "Неможливо видалити додаток.",
-    "Couldn't update app." : "Не вдалося оновити додаток. ",
-    "Wrong password" : "Невірний пароль",
-    "Saved" : "Збережено",
+    "Couldn't remove app." : "Неможливо вилучити застосунок.",
+    "Couldn't update app." : "Не вдалося оновити застосунок.",
+    "Wrong password" : "Неправильний пароль",
     "No user supplied" : "Користувача не вказано",
-    "Unable to change password" : "Неможливо змінити пароль",
     "Authentication error" : "Помилка автентифікації",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Будь ласка, введіть пароль відновлення адміністратора; інакше всі дані користувача будуть втрачені.",
     "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
@@ -53,70 +94,11 @@ OC.L10N.register(
     "Set your password" : "Встановіть свій пароль",
     "Go to %s" : "Перейти до %s",
     "Install Client" : "Встановити Клієнт",
-    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
-    "Migration started …" : "Міграцію розпочато ...",
-    "Not saved" : "Не збережено",
-    "Sending…" : "Відправка...",
-    "Email sent" : "Лист надіслано",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
-    "Valid until {date}" : "Дійсно до {date}",
-    "Delete" : "Видалити",
-    "Local" : "Локально",
-    "Private" : "Закритий",
-    "Only visible to local users" : "Видимий тільки для локальних користувачів",
-    "Only visible to you" : "Видимий тільки вам",
-    "Contacts" : "Контакти",
-    "Visible to local users and to trusted servers" : "Видимий тільки локальним користувачам і довіреним серверам",
-    "Public" : "Відкритий",
-    "Will be synced to a global and public address book" : "Буде синхронізовано з глобальною та відкритою адресною книгою",
-    "Verify" : "Перевірити",
-    "Verifying …" : "Перевірка ...",
-    "Very weak password" : "Дуже слабкий пароль",
-    "Weak password" : "Слабкий пароль",
-    "So-so password" : "Такий собі пароль",
-    "Good password" : "Добрий пароль",
-    "Strong password" : "Надійний пароль",
-    "An error occurred while changing your language. Please reload the page and try again." : "Виникла помилка при зміні мови. Перезавантажте сторінку та повторіть спробу.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Виникла помилка при зміні локалі. Перезавантажте сторінку та повторіть спробу.",
-    "Select a profile picture" : "Обрати зображення облікового запису",
-    "Week starts on {fdow}" : "Тиждень починається в {fdow}",
-    "Groups" : "Групи",
-    "Group list is empty" : "Список груп порожній",
-    "Unable to retrieve the group list" : "Неможливо отримати список груп",
+    "Unlimited" : "Необмежено",
     "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторна автентифікація може застосовуватися для всіх \t користувачів і конкретних груп. Якщо вони не мають налаштованого двофакторного провайдера для входу, вони не зможуть увійти в систему.",
     "Enforce two-factor authentication" : "Примусова двофакторна аутентифікація",
     "Limit to groups" : "Обмежити групами",
     "Save changes" : "Зберегти зміни",
-    "Device settings" : "Налаштування пристрою",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome для Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Додаток Nextcloud для iOS",
-    "Nextcloud Android app" : "Додаток Nextcloud для Android",
-    "Nextcloud Talk for iOS" : "Додаток Talk для iOS",
-    "Nextcloud Talk for Android" : "Додаток Talk для Android",
-    "Allow filesystem access" : "Дозволити доступ до файлової системи",
-    "Revoke" : "Відкликати",
-    "Sync client - {os}" : "Клієнт синхронізації - {os}",
-    "This session" : "Цей сеанс",
-    "Device" : "Пристрій",
-    "Last activity" : "Остання активність",
-    "Devices & sessions" : "Пристрої та сеанси",
-    "Web, desktop and mobile clients currently logged in to your account." : "Веб, настільні та мобільні клієнти в даний час авторизовані у вашому обліковому записі",
-    "Error while creating device token" : "Помилка під час створення токена пристрою",
-    "Error while deleting the token" : "Помилка при видаленні токену",
-    "App name" : "Ім'я додатку",
-    "Create new app password" : "Створіть новий пароль додатка",
-    "Username" : "Ім'я користувача",
-    "Password" : "Пароль",
-    "Done" : "Готово",
-    "Copied!" : "Скопійовано!",
-    "Copy" : "Копіювати",
     "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Офіційні додатки розробляються спільнотою та в межах спільноти. Вони пропонують основну функціональність і готові до використання в продакшні.",
     "Official" : "Офіційні",
     "Update to {version}" : "Оновити до {version}",
@@ -138,6 +120,36 @@ OC.L10N.register(
     "Download and enable" : "Завантажити та увімкнути",
     "Enable" : "Увімкнути",
     "The app will be downloaded from the app store" : "Додаток буде завантажено з магазину додатків",
+    "Device settings" : "Налаштування пристрою",
+    "Allow filesystem access" : "Дозволити доступ до файлової системи",
+    "Revoke" : "Відкликати",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome для Android",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Додаток Nextcloud для iOS",
+    "Nextcloud Android app" : "Додаток Nextcloud для Android",
+    "Nextcloud Talk for iOS" : "Додаток Talk для iOS",
+    "Nextcloud Talk for Android" : "Додаток Talk для Android",
+    "Sync client - {os}" : "Клієнт синхронізації - {os}",
+    "This session" : "Цей сеанс",
+    "Device" : "Пристрій",
+    "Last activity" : "Остання активність",
+    "Devices & sessions" : "Пристрої та сеанси",
+    "Web, desktop and mobile clients currently logged in to your account." : "Веб, настільні та мобільні клієнти в даний час авторизовані у вашому обліковому записі",
+    "Error while creating device token" : "Помилка під час створення токена пристрою",
+    "Error while deleting the token" : "Помилка при видаленні токену",
+    "App name" : "Ім'я додатку",
+    "Create new app password" : "Створіть новий пароль додатка",
+    "Username" : "Ім'я користувача",
+    "Password" : "Пароль",
+    "Done" : "Готово",
+    "Copied!" : "Скопійовано!",
+    "Copy" : "Копіювати",
     "You do not have permissions to see the details of this user" : "Ви не маєте прав для перегляду деталей про цього користувача",
     "The backend does not support changing the display name" : "Бекенд не підтримує зміну відображуваного імені",
     "New password" : "Новий пароль",
@@ -162,11 +174,10 @@ OC.L10N.register(
     "Default language" : "Мова за замовчуванням",
     "Add a new user" : "Додати нового користувача",
     "No users in here" : "Немає користувачів",
-    "Unlimited" : "Необмежено",
     "Default quota" : "Квота за замовчуванням",
-    "Password change is disabled because the master key is disabled" : "Зміну пароля вимкнено, оскільки майстер-ключ відключений",
     "Common languages" : "Основні мови",
     "All languages" : "Всі мови",
+    "Password change is disabled because the master key is disabled" : "Зміну пароля вимкнено, оскільки майстер-ключ відключений",
     "Your apps" : "Ваші додатки",
     "Active apps" : "Активні додатки",
     "Disabled apps" : "Відключені додатки",
@@ -180,13 +191,13 @@ OC.L10N.register(
     "Show last login" : "Показати останній вхід",
     "Show user backend" : "Показати користувача",
     "Show storage path" : "Показати шлях до сховища",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Ви збираєтеся видалити групу {group}. Користувачі групи НЕ будуть видалені.",
-    "Please confirm the group removal " : "Будь ласка, підтвердьте видалення групи",
     "Remove group" : "Видалити групу",
     "Admins" : "Адміністратори",
     "Disabled users" : "Вимкнені користувачі",
     "Everyone" : "Всі",
     "Add group" : "Додати групу",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Ви збираєтеся видалити групу {group}. Користувачі групи НЕ будуть видалені.",
+    "Please confirm the group removal " : "Будь ласка, підтвердьте видалення групи",
     "An error occured during the request. Unable to proceed." : "Під час запиту сталася помилка. Не вдається продовжити.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Додаток активовано, але його потрібно оновити. Ви будете перенаправлені на сторінку оновлення через 5 секунд.",
     "App update" : "Оновлення додатку",
@@ -220,7 +231,6 @@ OC.L10N.register(
     "Credentials" : "Облікові дані",
     "SMTP Username" : "Ім'я користувача SMTP",
     "SMTP Password" : "Пароль SMTP",
-    "Store credentials" : "Зберігати облікові дані",
     "Test email settings" : "Тестувати налаштування ел. пошти",
     "Send email" : "Надіслати листа",
     "Security & setup warnings" : "Попередження безпеки та налаштування",
@@ -296,6 +306,7 @@ OC.L10N.register(
     "Help translate" : "Допомогти з перекладом",
     "Locale" : "Регіональні станадрти",
     "Current password" : "Поточний пароль",
-    "Change password" : "Змінити пароль"
+    "Change password" : "Змінити пароль",
+    "Store credentials" : "Зберігати облікові дані"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
