@@ -1,6 +1,38 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
+    "Migration started …" : "迁移开始...",
+    "Saved" : "已保存",
+    "Not saved" : "未保存",
+    "Sending…" : "正在发送…",
+    "Email sent" : "邮件已发送",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "发生错误。请上传 ASCII 编码的 PEM 证书。",
+    "Valid until {date}" : "有效期至 {date}",
+    "Delete" : "删除",
+    "Local" : "本地",
+    "Private" : "私有",
+    "Only visible to local users" : "仅对本地用户可见",
+    "Only visible to you" : "仅您自己可见",
+    "Contacts" : "联系人",
+    "Visible to local users and to trusted servers" : "仅对本地用户和信任的服务器可见",
+    "Public" : "公开",
+    "Will be synced to a global and public address book" : "将同步到全局和公开地址簿中",
+    "Verify" : "验证",
+    "Verifying …" : "正在验证...",
+    "Unable to change password" : "无法修改密码",
+    "Very weak password" : "非常弱的密码",
+    "Weak password" : "弱密码",
+    "So-so password" : "一般强度的密码",
+    "Good password" : "较强的密码",
+    "Strong password" : "强密码",
+    "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
+    "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
+    "Select a profile picture" : "选择个人头像",
+    "Week starts on {fdow}" : "周开始于 {fdow}",
+    "Groups" : "分组",
+    "Group list is empty" : "群组列表为空",
+    "Unable to retrieve the group list" : "无法获取分组列表",
     "{actor} added you to group {group}" : "{actor} 将您加入分组 {group}",
     "You added {user} to group {group}" : "您将 {user} 加入分组 {group}",
     "{actor} added {user} to group {group}" : "{actor} 将 {user} 加入分组 {group}",
@@ -32,9 +64,7 @@ OC.L10N.register(
     "Couldn't remove app." : "无法删除应用。",
     "Couldn't update app." : "无法更新应用。",
     "Wrong password" : "密码错误",
-    "Saved" : "已保存",
     "No user supplied" : "没有满足的用户",
-    "Unable to change password" : "无法修改密码",
     "Authentication error" : "认证错误",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码，否则所有用户的数据都将丢失。",
     "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
@@ -77,39 +107,281 @@ OC.L10N.register(
     "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
     "Create" : "创建",
     "Change" : "修改",
-    "Delete" : "删除",
     "Share" : "共享",
     "Unlimited" : "无限",
     "Verifying" : "正在验证",
-    "Verifying …" : "正在验证...",
-    "Verify" : "验证",
-    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
-    "Migration started …" : "迁移开始...",
-    "Not saved" : "未保存",
-    "Sending…" : "正在发送…",
-    "Email sent" : "邮件已发送",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "发生错误。请上传 ASCII 编码的 PEM 证书。",
-    "Valid until {date}" : "有效期至 {date}",
-    "Local" : "本地",
-    "Private" : "私有",
-    "Only visible to local users" : "仅对本地用户可见",
-    "Only visible to you" : "仅您自己可见",
-    "Contacts" : "联系人",
-    "Visible to local users and to trusted servers" : "仅对本地用户和信任的服务器可见",
-    "Public" : "公开",
-    "Will be synced to a global and public address book" : "将同步到全局和公开地址簿中",
-    "Very weak password" : "非常弱的密码",
-    "Weak password" : "弱密码",
-    "So-so password" : "一般强度的密码",
-    "Good password" : "较强的密码",
-    "Strong password" : "强密码",
-    "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
-    "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
-    "Select a profile picture" : "选择个人头像",
-    "Week starts on {fdow}" : "周开始于 {fdow}",
-    "Groups" : "分组",
-    "Group list is empty" : "群组列表为空",
-    "Unable to retrieve the group list" : "无法获取分组列表",
+    "Nextcloud settings" : "Nextcloud设置",
+    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定组启用。如果没有设置两步验证方式提供者，他们则不能登录到系统。",
+    "Enforce two-factor authentication" : "强制启用两步验证",
+    "Limit to groups" : "限制于组",
+    "Enforcement of two-factor authentication can be set for certain groups only." : "可以仅为某些组设置两步验证的强制执行。",
+    "Two-factor authentication is enforced for all\tmembers of the following groups." : "两步验证对以下分组的所有成员强制启用。",
+    "Enforced groups" : "强制群组",
+    "Two-factor authentication is not enforced for\tmembers of the following groups." : "两步验证不对以下分组的成员强制启用。",
+    "Excluded groups" : "排除群组",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
+    "Save changes" : "保存修改",
+    "This app is supported via your current Nextcloud subscription." : "根据您的Nextcloud订阅，此应用受到支持。",
+    "Supported" : "受支持",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方应用由社区和内部开发。其可以提供核心功能并保证生产用途。",
+    "Official" : "官方",
+    "by" : "由",
+    "Update to {version}" : "更新至 {version}",
+    "Remove" : "移除",
+    "Disable" : "禁用",
+    "All" : "全部",
+    "Limit app usage to groups" : "限制可使用应用的分组",
+    "No results" : "没有结果",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
+    "View in store" : "在商店中查看",
+    "Visit website" : "访问网站",
+    "Report a bug" : "报告问题",
+    "User documentation" : "用户文档",
+    "Admin documentation" : "管理员文档",
+    "Developer documentation" : "开发者文档",
+    "Update to {update}" : "更新至 {update}",
+    "Results from other categories" : "来自其他类别的结果",
+    "No apps found for your version" : "未找到适合当前版本的应用",
+    "Disable all" : "禁用全部",
+    "Enable all" : "启用所有",
+    "Download and enable" : "下载并启用",
+    "Enable" : "启用",
+    "Enable untested app" : "启用未经测试的应用",
+    "The app will be downloaded from the app store" : "该应用将从应用商店下载",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的Nextcloud版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
+    "Marked for remote wipe" : "标记为远程擦除",
+    "Device settings" : "设备设置",
+    "Allow filesystem access" : "允许访问文件系统",
+    "Rename" : "重命名",
+    "Revoke" : "撤销",
+    "Wipe device" : "擦除设备",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果擦除操作还未开始，撤销此令牌可能会妨碍对您设备的擦除操作",
+    "Internet Explorer" : "IE 浏览器",
+    "Edge" : "Edge 浏览器",
+    "Firefox" : "火狐浏览器",
+    "Google Chrome" : "谷歌浏览器",
+    "Safari" : "Safari 浏览器",
+    "Google Chrome for Android" : "安卓版谷歌浏览器",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Nextcloud iOS app" : "Nextcloud iOS 应用",
+    "Nextcloud Android app" : "Nextcloud Android 应用",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
+    "Sync client - {os}" : "同步客户端 - {os}",
+    "This session" : "当前会话",
+    "Device" : "设备",
+    "Last activity" : "最后活跃",
+    "Devices & sessions" : "设备和活动链接",
+    "Web, desktop and mobile clients currently logged in to your account." : "您账号当前登录的 Web 页面，桌面和移动客户端。",
+    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
+    "Confirm wipe" : "确认擦除",
+    "Error while creating device token" : "创建设备令牌时出错",
+    "Error while updating device token scope" : "更新设备令牌范围时出错",
+    "Error while updating device token name" : "更新设备令牌名称时出错",
+    "Error while deleting the token" : "删除令牌时出错",
+    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
+    "App name" : "应用名",
+    "Create new app password" : "创建新应用密码",
+    "Use the credentials below to configure your app or device." : "使用下述凭据配置您的应用或设备。",
+    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
+    "Username" : "用户名",
+    "Password" : "密码",
+    "Done" : "完成",
+    "Show QR code for mobile apps" : "为移动应用展示QR二维码",
+    "Copied!" : "已复制！",
+    "Copy" : "复制",
+    "Could not copy app password. Please copy it manually." : "无法复制应用密码。请手动复制。",
+    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
+    "The backend does not support changing the display name" : "此后端不支持修改显示名称",
+    "New password" : "新密码",
+    "Add user in group" : "向群组中添加用户",
+    "Set user as admin for" : "设置用户为管理员",
+    "Select user quota" : "选择用户容量限额",
+    "No language set" : "没有设置语言",
+    "Never" : "从不",
+    "Delete user" : "删除用户",
+    "Wipe all devices" : "擦除所有设备",
+    "Disable user" : "禁用用户",
+    "Enable user" : "启用用户",
+    "Resend welcome email" : "重新发送欢迎邮件",
+    "{size} used" : "{size} 已使用",
+    "Welcome mail sent!" : "欢迎邮件已经发送！",
+    "Display name" : "显示名称",
+    "Email" : "电子邮件",
+    "Group admin for" : "分组管理员",
+    "Quota" : "配额",
+    "Language" : "语言",
+    "Storage location" : "存储位置",
+    "User backend" : "用户来源",
+    "Last login" : "最后登录",
+    "Will be autogenerated" : "将自动生成",
+    "Default language" : "默认语言",
+    "Add a new user" : "添加新用户",
+    "No users in here" : "这里没有用户",
+    "Default quota" : "默认配额",
+    "Common languages" : "常用语言",
+    "All languages" : "所有语言",
+    "Password change is disabled because the master key is disabled" : "密码修改被禁用，因为主密码被禁用",
+    "Your apps" : "您的应用",
+    "Active apps" : "已启用的应用",
+    "Disabled apps" : "已禁用的应用",
+    "Updates" : "更新",
+    "App bundles" : "应用软件包",
+    "{license}-licensed" : "{license}-许可协议",
+    "New user" : "新建用户",
+    "Default quota:" : "默认配额：",
+    "Select default quota" : "选择默认存储限额",
+    "Show Languages" : "显示语言",
+    "Show last login" : "显示最后登录",
+    "Show user backend" : "显示用户来源",
+    "Show storage path" : "显示存储路径",
+    "Remove group" : "删除分组",
+    "Admins" : "管理员",
+    "Disabled users" : "已禁用的用户",
+    "Everyone" : "所有人",
+    "Add group" : "添加分组",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "您正在删除 {group} 组。组中的用户将不会被删除。",
+    "Please confirm the group removal " : "请确认分组删除",
+    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
+    "App update" : "更新应用",
+    "Error: This app can not be enabled because it makes the server unstable" : "错误：无法启用应用因为它会导致服务器不稳定",
+    "SSL Root Certificates" : "SSL 根证书",
+    "Common Name" : "通用名称",
+    "Valid until" : "有效期至",
+    "Issued By" : "授权由",
+    "Valid until %s" : "有效期至 %s",
+    "Import root certificate" : "导入根证书",
+    "Administrator documentation" : "管理员文档",
+    "Documentation" : "文档",
+    "Forum" : "论坛",
+    "None" : "无",
+    "Login" : "登录",
+    "Plain" : "明文",
+    "NT LAN Manager" : "NT LAN 管理器",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "电子邮件服务器",
+    "Open documentation" : "打开文档",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "设置此服务器以能够发送电子邮件（例如密码重置和通知）非常重要。",
+    "Send mode" : "发送模式",
+    "Encryption" : "加密",
+    "Sendmail mode" : "邮件发送模式",
+    "From address" : "来自地址",
+    "mail" : "邮件",
+    "Authentication method" : "认证方法",
+    "Authentication required" : "需要认证",
+    "Server address" : "服务器地址",
+    "Port" : "端口",
+    "Credentials" : "凭证",
+    "SMTP Username" : "SMTP 用户名",
+    "SMTP Password" : "SMTP 密码",
+    "Save" : "保存",
+    "Test email settings" : "测试电子邮件设置",
+    "Send email" : "发送邮件",
+    "Security & setup warnings" : "安全及设置警告",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "您的每项配置对于实例的安全性和性能都至关重要。 为了帮助您，我们正在做一些自动检查。 有关详细信息，请参阅文档链接。",
+    "All checks passed." : "所有检查已通过。",
+    "There are some errors regarding your setup." : "关于您的设置有一些错误。",
+    "There are some warnings regarding your setup." : "关于您的设置有一些警告。",
+    "Checking for system and security issues." : "正在检查系统和安全问题。",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "请仔细检查<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安装指南↗</a>，并检查<a href=\"%2$s\">日志</a>中是否有错误或警告。",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "通过<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我们的安全检查 ↗</a>检查您 Nextcloud 的安全",
+    "Version" : "版本",
+    "Two-Factor Authentication" : "两步验证",
+    "Server-side encryption" : "服务器端加密",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "服务器端加密可以加密上传到此服务器的文件。这带来了诸如性能损失的限制，因此仅在需要时启用此功能。",
+    "Enable server-side encryption" : "启用服务器端加密",
+    "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有前提都满足时（例如：设定恢复密钥）才能解除加密。",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "单独的加密不能保证系统的安全性。请参考加密应用工作原理和支持的用例的文档获取更多信息。",
+    "Be aware that encryption always increases the file size." : "请注意，加密会增加文件大小。",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定期备份数据有助于保证数据完整，并且确保备份您的加密数据和加密密钥。",
+    "This is the final warning: Do you really want to enable encryption?" : "这是最后一次警告：您确定要启用加密？",
+    "Enable encryption" : "启用加密",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "没有加载加密模块，请在 APP 应用菜单中启用加密模块。",
+    "Select default encryption module:" : "选择默认的加密模块：",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您需要从旧版本（ownCloud<=8.0）迁移您的加密密钥。",
+    "Start migration" : "开始迁移",
+    "Background jobs" : "后台任务",
+    "Last job ran %s." : "上次定时任务执行于：%s。",
+    "Last job execution ran %s. Something seems wrong." : "上次定时任务执行于：%s。但存在一些问题。",
+    "Background job didn’t run yet!" : "后台任务当前没有运行！",
+    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "为了优化性能，正确配置后台任务非常重要。对于较大的实例，推荐配置为 'Cron'。详情请参考相关文档。",
+    "Pick background job setting" : "选择后台任务设置",
+    "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php注册到 webcron 服务上，每5分钟通过HTTP执行一次cron.php。",
+    "Use system cron service to call the cron.php file every 5 minutes." : "使用系统定时任务服务每5分钟执行一次cron.php文件。",
+    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "为了运行该功能，您需要 PHP posix 扩展。请参考 {linkstart}PHP 文档{linkend} 获取更多信息。",
+    "Sharing" : "共享",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "作为管理员，您可以调整共享行为。 有关详细信息，请参阅文档。",
+    "Allow apps to use the Share API" : "允许应用使用共享 API",
+    "Allow users to share via link" : "允许用户通过链接共享文件",
+    "Allow public uploads" : "允许公开上传",
+    "Always ask for a password" : "一直要求输入密码",
+    "Enforce password protection" : "强制密码保护",
+    "Set default expiration date" : "设置默认过期日期",
+    "Expire after " : "过期于",
+    "days" : "天",
+    "Enforce expiration date" : "强制过期日期",
+    "Allow resharing" : "允许二次共享",
+    "Allow sharing with groups" : "允许群组共享",
+    "Restrict users to only share with users in their groups" : "限制仅与组内用户共享",
+    "Exclude groups from sharing" : "在共享中排除组",
+    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
+    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "在共享对话框中允许用户名自动完成。 如果被禁用，则需要输入完整的用户名或电子邮件地址。",
+    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "在公开链接上传页中显示免责声明。（仅当文件列表隐藏时显示。）",
+    "This text will be shown on the public link upload page when the file list is hidden." : "这些内容将在公开链接上传页中当文件列表隐藏时显示。",
+    "Default share permissions" : "默认共享权限",
+    "Personal" : "个人",
+    "Administration" : "管理",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud community{linkclose} 开发，{githubopen}源代码{linkclose} 基于 {licenseopen}AGPL{linkclose} 许可协议。",
+    "Like our Facebook page" : "点赞我们 facebook 页面！",
+    "Follow us on Twitter" : "在 Twitter 上关注我们！",
+    "Follow us on Mastodon" : "在Mastodon上关注我们",
+    "Check out our blog" : "浏览我们的博客！",
+    "Subscribe to our newsletter" : "订阅我们的最新消息！",
+    "Profile picture" : "个人头像",
+    "Upload new" : "上传",
+    "Select from Files" : "选择文件",
+    "Remove image" : "删除图片",
+    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
+    "Picture provided by original account" : "初始账号提供的图片",
+    "Cancel" : "取消",
+    "Choose as profile picture" : "选择个人头像",
+    "Details" : "详情",
+    "You are a member of the following groups:" : "您是以下群组的成员：",
+    "You are using <strong>%s</strong>" : "您正在使用<strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您正在使用 <strong>%1$s</strong> ，来自 <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Full name" : "全名",
+    "No display name set" : "不显示名称设置",
+    "Your email address" : "您的电子邮件",
+    "No email address set" : "尚未设置 Email 地址",
+    "For password reset and notifications" : "用于密码重置和通知",
+    "Phone number" : "电话号码",
+    "Your phone number" : "您的电话号码",
+    "Address" : "地址",
+    "Your postal address" : "您的邮寄地址",
+    "Website" : "网站",
+    "It can take up to 24 hours before the account is displayed as verified." : "在帐户显示为验证之前最多可能需要24小时。",
+    "Link https://…" : "链接 https://…",
+    "Twitter" : "推特",
+    "Twitter handle @…" : "推特用户名@…",
+    "Help translate" : "帮助翻译",
+    "Locale" : "本地",
+    "Current password" : "当前密码",
+    "Change password" : "修改密码",
+    "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
+    "Disconnect" : "断开连接",
+    "Not supported!" : "不支持！",
+    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
+    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
+    "Error while loading browser sessions and device tokens" : "加载浏览器会话和设备令牌时出错",
     "Afrikaans (Namibia)" : "南非语（纳米比亚）",
     "Afrikaans (South Africa)" : "南非语（南非）",
     "Afrikaans" : "南非语",
@@ -544,285 +816,9 @@ OC.L10N.register(
     "Yoruba" : "约鲁巴语",
     "Zulu (South Africa)" : "祖鲁语（南非）",
     "Zulu" : "祖鲁语",
-    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定组启用。如果没有设置两步验证方式提供者，他们则不能登录到系统。",
-    "Enforce two-factor authentication" : "强制启用两步验证",
-    "Limit to groups" : "限制于组",
-    "Enforcement of two-factor authentication can be set for certain groups only." : "可以仅为某些组设置两步验证的强制执行。",
-    "Two-factor authentication is enforced for all\tmembers of the following groups." : "两步验证对以下分组的所有成员强制启用。",
-    "Enforced groups" : "强制群组",
-    "Two-factor authentication is not enforced for\tmembers of the following groups." : "两步验证不对以下分组的成员强制启用。",
-    "Excluded groups" : "排除群组",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
-    "Save changes" : "保存修改",
-    "Marked for remote wipe" : "标记为远程擦除",
-    "Device settings" : "设备设置",
-    "Allow filesystem access" : "允许访问文件系统",
-    "Rename" : "重命名",
-    "Revoke" : "撤销",
-    "Wipe device" : "擦除设备",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果擦除操作还未开始，撤销此令牌可能会妨碍对您设备的擦除操作",
-    "Internet Explorer" : "IE 浏览器",
-    "Edge" : "Edge 浏览器",
-    "Firefox" : "火狐浏览器",
-    "Google Chrome" : "谷歌浏览器",
-    "Safari" : "Safari 浏览器",
-    "Google Chrome for Android" : "安卓版谷歌浏览器",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloud iOS 应用",
-    "Nextcloud Android app" : "Nextcloud Android 应用",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
-    "Sync client - {os}" : "同步客户端 - {os}",
-    "This session" : "当前会话",
-    "Device" : "设备",
-    "Last activity" : "最后活跃",
-    "Devices & sessions" : "设备和活动链接",
-    "Web, desktop and mobile clients currently logged in to your account." : "您账号当前登录的 Web 页面，桌面和移动客户端。",
-    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
-    "Confirm wipe" : "确认擦除",
-    "Error while creating device token" : "创建设备令牌时出错",
-    "Error while updating device token scope" : "更新设备令牌范围时出错",
-    "Error while updating device token name" : "更新设备令牌名称时出错",
-    "Error while deleting the token" : "删除令牌时出错",
-    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
-    "App name" : "应用名",
-    "Create new app password" : "创建新应用密码",
-    "Use the credentials below to configure your app or device." : "使用下述凭据配置您的应用或设备。",
-    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
-    "Username" : "用户名",
-    "Password" : "密码",
-    "Done" : "完成",
-    "Show QR code for mobile apps" : "为移动应用展示QR二维码",
-    "Copied!" : "已复制！",
-    "Copy" : "复制",
-    "Could not copy app password. Please copy it manually." : "无法复制应用密码。请手动复制。",
-    "This app is supported via your current Nextcloud subscription." : "根据您的Nextcloud订阅，此应用受到支持。",
-    "Supported" : "受支持",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方应用由社区和内部开发。其可以提供核心功能并保证生产用途。",
-    "Official" : "官方",
-    "by" : "由",
-    "Update to {version}" : "更新至 {version}",
-    "Remove" : "移除",
-    "Disable" : "禁用",
-    "All" : "全部",
-    "Limit app usage to groups" : "限制可使用应用的分组",
-    "No results" : "没有结果",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
-    "View in store" : "在商店中查看",
-    "Visit website" : "访问网站",
-    "Report a bug" : "报告问题",
-    "User documentation" : "用户文档",
-    "Admin documentation" : "管理员文档",
-    "Developer documentation" : "开发者文档",
-    "Update to {update}" : "更新至 {update}",
-    "Results from other categories" : "来自其他类别的结果",
-    "No apps found for your version" : "未找到适合当前版本的应用",
-    "Disable all" : "禁用全部",
-    "Enable all" : "启用所有",
-    "Download and enable" : "下载并启用",
-    "Enable" : "启用",
-    "Enable untested app" : "启用未经测试的应用",
-    "The app will be downloaded from the app store" : "该应用将从应用商店下载",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的Nextcloud版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
-    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
-    "The backend does not support changing the display name" : "此后端不支持修改显示名称",
-    "New password" : "新密码",
-    "Add user in group" : "向群组中添加用户",
-    "Set user as admin for" : "设置用户为管理员",
-    "Select user quota" : "选择用户容量限额",
-    "No language set" : "没有设置语言",
-    "Never" : "从不",
-    "Delete user" : "删除用户",
-    "Wipe all devices" : "擦除所有设备",
-    "Disable user" : "禁用用户",
-    "Enable user" : "启用用户",
-    "Resend welcome email" : "重新发送欢迎邮件",
-    "{size} used" : "{size} 已使用",
-    "Welcome mail sent!" : "欢迎邮件已经发送！",
-    "Display name" : "显示名称",
-    "Email" : "电子邮件",
-    "Group admin for" : "分组管理员",
-    "Quota" : "配额",
-    "Language" : "语言",
-    "Storage location" : "存储位置",
-    "User backend" : "用户来源",
-    "Last login" : "最后登录",
-    "Will be autogenerated" : "将自动生成",
-    "Default language" : "默认语言",
-    "Add a new user" : "添加新用户",
-    "No users in here" : "这里没有用户",
-    "Default quota" : "默认配额",
-    "Password change is disabled because the master key is disabled" : "密码修改被禁用，因为主密码被禁用",
-    "Common languages" : "常用语言",
-    "All languages" : "所有语言",
-    "Your apps" : "您的应用",
-    "Active apps" : "已启用的应用",
-    "Disabled apps" : "已禁用的应用",
-    "Updates" : "更新",
-    "App bundles" : "应用软件包",
-    "{license}-licensed" : "{license}-许可协议",
-    "New user" : "新建用户",
-    "Default quota:" : "默认配额：",
-    "Select default quota" : "选择默认存储限额",
-    "Show Languages" : "显示语言",
-    "Show last login" : "显示最后登录",
-    "Show user backend" : "显示用户来源",
-    "Show storage path" : "显示存储路径",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "您正在删除 {group} 组。组中的用户将不会被删除。",
-    "Please confirm the group removal " : "请确认分组删除",
-    "Remove group" : "删除分组",
-    "Admins" : "管理员",
-    "Disabled users" : "已禁用的用户",
-    "Everyone" : "所有人",
-    "Add group" : "添加分组",
-    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
-    "App update" : "更新应用",
-    "Error: This app can not be enabled because it makes the server unstable" : "错误：无法启用应用因为它会导致服务器不稳定",
-    "SSL Root Certificates" : "SSL 根证书",
-    "Common Name" : "通用名称",
-    "Valid until" : "有效期至",
-    "Issued By" : "授权由",
-    "Valid until %s" : "有效期至 %s",
-    "Import root certificate" : "导入根证书",
-    "Administrator documentation" : "管理员文档",
-    "Documentation" : "文档",
-    "Forum" : "论坛",
-    "None" : "无",
-    "Login" : "登录",
-    "Plain" : "明文",
-    "NT LAN Manager" : "NT LAN 管理器",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Email server" : "电子邮件服务器",
-    "Open documentation" : "打开文档",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "设置此服务器以能够发送电子邮件（例如密码重置和通知）非常重要。",
-    "Send mode" : "发送模式",
-    "Encryption" : "加密",
-    "Sendmail mode" : "邮件发送模式",
-    "From address" : "来自地址",
-    "mail" : "邮件",
-    "Authentication method" : "认证方法",
-    "Authentication required" : "需要认证",
-    "Server address" : "服务器地址",
-    "Port" : "端口",
-    "Credentials" : "凭证",
-    "SMTP Username" : "SMTP 用户名",
-    "SMTP Password" : "SMTP 密码",
     "Store credentials" : "存储凭据",
-    "Test email settings" : "测试电子邮件设置",
-    "Send email" : "发送邮件",
-    "Security & setup warnings" : "安全及设置警告",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "您的每项配置对于实例的安全性和性能都至关重要。 为了帮助您，我们正在做一些自动检查。 有关详细信息，请参阅文档链接。",
-    "All checks passed." : "所有检查已通过。",
-    "There are some errors regarding your setup." : "关于您的设置有一些错误。",
-    "There are some warnings regarding your setup." : "关于您的设置有一些警告。",
-    "Checking for system and security issues." : "正在检查系统和安全问题。",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "请仔细检查<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安装指南↗</a>，并检查<a href=\"%2$s\">日志</a>中是否有错误或警告。",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "通过<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我们的安全检查 ↗</a>检查您 Nextcloud 的安全",
-    "Version" : "版本",
-    "Two-Factor Authentication" : "两步验证",
-    "Server-side encryption" : "服务器端加密",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "服务器端加密可以加密上传到此服务器的文件。这带来了诸如性能损失的限制，因此仅在需要时启用此功能。",
-    "Enable server-side encryption" : "启用服务器端加密",
-    "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有前提都满足时（例如：设定恢复密钥）才能解除加密。",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "单独的加密不能保证系统的安全性。请参考加密应用工作原理和支持的用例的文档获取更多信息。",
-    "Be aware that encryption always increases the file size." : "请注意，加密会增加文件大小。",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定期备份数据有助于保证数据完整，并且确保备份您的加密数据和加密密钥。",
-    "This is the final warning: Do you really want to enable encryption?" : "这是最后一次警告：您确定要启用加密？",
-    "Enable encryption" : "启用加密",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "没有加载加密模块，请在 APP 应用菜单中启用加密模块。",
-    "Select default encryption module:" : "选择默认的加密模块：",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您需要从旧版本（ownCloud<=8.0）迁移您的加密密钥。",
-    "Start migration" : "开始迁移",
-    "Background jobs" : "后台任务",
-    "Last job ran %s." : "上次定时任务执行于：%s。",
-    "Last job execution ran %s. Something seems wrong." : "上次定时任务执行于：%s。但存在一些问题。",
-    "Background job didn’t run yet!" : "后台任务当前没有运行！",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "为了优化性能，正确配置后台任务非常重要。对于较大的实例，推荐配置为 'Cron'。详情请参考相关文档。",
-    "Pick background job setting" : "选择后台任务设置",
-    "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php 注册到 webcron 服务上，通过 http 每 15 分钟执行 cron.php。",
     "Use system cron service to call the cron.php file every 15 minutes." : "使用系统定时任务服务每 15 分钟执行一次 cron.php 文件。",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "为了运行该功能，您需要 PHP posix 扩展。请参考 {linkstart}PHP 文档{linkend} 获取更多信息。",
-    "Sharing" : "共享",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "作为管理员，您可以调整共享行为。 有关详细信息，请参阅文档。",
-    "Allow apps to use the Share API" : "允许应用使用共享 API",
-    "Allow users to share via link" : "允许用户通过链接共享文件",
-    "Allow public uploads" : "允许公开上传",
-    "Always ask for a password" : "一直要求输入密码",
-    "Enforce password protection" : "强制密码保护",
-    "Set default expiration date" : "设置默认过期日期",
-    "Expire after " : "过期于",
-    "days" : "天",
-    "Enforce expiration date" : "强制过期日期",
-    "Allow resharing" : "允许二次共享",
-    "Allow sharing with groups" : "允许群组共享",
-    "Restrict users to only share with users in their groups" : "限制仅与组内用户共享",
-    "Exclude groups from sharing" : "在共享中排除组",
-    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "在共享对话框中允许用户名自动完成。 如果被禁用，则需要输入完整的用户名或电子邮件地址。",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "在公开链接上传页中显示免责声明。（仅当文件列表隐藏时显示。）",
-    "This text will be shown on the public link upload page when the file list is hidden." : "这些内容将在公开链接上传页中当文件列表隐藏时显示。",
-    "Default share permissions" : "默认共享权限",
-    "Personal" : "个人",
-    "Administration" : "管理",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud community{linkclose} 开发，{githubopen}源代码{linkclose} 基于 {licenseopen}AGPL{linkclose} 许可协议。",
-    "Like our Facebook page" : "点赞我们 facebook 页面！",
-    "Follow us on Twitter" : "在 Twitter 上关注我们！",
-    "Follow us on Mastodon" : "在Mastodon上关注我们",
-    "Check out our blog" : "浏览我们的博客！",
-    "Subscribe to our newsletter" : "订阅我们的最新消息！",
-    "Profile picture" : "个人头像",
-    "Upload new" : "上传",
-    "Select from Files" : "选择文件",
-    "Remove image" : "删除图片",
-    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
-    "Picture provided by original account" : "初始账号提供的图片",
-    "Cancel" : "取消",
-    "Choose as profile picture" : "选择个人头像",
-    "Details" : "详情",
-    "You are a member of the following groups:" : "您是以下群组的成员：",
-    "You are using <strong>%s</strong>" : "您正在使用<strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您正在使用 <strong>%1$s</strong> ，来自 <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "全名",
-    "No display name set" : "不显示名称设置",
-    "Your email address" : "您的电子邮件",
-    "No email address set" : "尚未设置 Email 地址",
-    "For password reset and notifications" : "用于密码重置和通知",
-    "Phone number" : "电话号码",
-    "Your phone number" : "您的电话号码",
-    "Address" : "地址",
-    "Your postal address" : "您的邮寄地址",
-    "Website" : "网站",
-    "It can take up to 24 hours before the account is displayed as verified." : "在帐户显示为验证之前最多可能需要24小时。",
-    "Link https://…" : "链接 https://…",
-    "Twitter" : "推特",
-    "Twitter handle @…" : "推特用户名@…",
-    "Help translate" : "帮助翻译",
-    "Locale" : "本地",
-    "Current password" : "当前密码",
-    "Change password" : "修改密码",
-    "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
-    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL 当前使用的过时的%s版本（%s）。请更新您的操作系统，否则像%s这样的特性将无法可靠地工作。",
-    "Disconnect" : "断开连接",
-    "iPhone iOS" : "iPhone iOS",
-    "iPad iOS" : "iPad iOS",
-    "iOS Client" : "iOS 客户端",
-    "Android Client" : "安卓客户端",
-    "Not supported!" : "不支持！",
-    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
-    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
-    "Error while loading browser sessions and device tokens" : "加载浏览器会话和设备令牌时出错",
-    "Default quota :" : "默认限额：",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "请仔细检查<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">安装指南↗</a>，并检查<a href=\"%s\">日志</a>中是否有错误或警告。",
-    "Follow us on Google+" : "在 Google+ 上关注我们",
-    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "您正在使用 <strong>%s</strong> ，来自 <strong>%s</strong> (<strong>%s %%</strong>)"
+    "Follow us on Google+" : "在 Google+ 上关注我们"
 },
 "nplurals=1; plural=0;");
