@@ -1,6 +1,33 @@
 OC.L10N.register(
     "settings",
     {
+    "Migration in progress. Please wait until the migration is finished" : "資料搬移中，請耐心等候直到資料搬移結束",
+    "Migration started …" : "開始遷移…",
+    "Saved" : "已儲存",
+    "Not saved" : "未儲存",
+    "Sending…" : "傳送中…",
+    "Email sent" : "Email 已寄出",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "發生錯誤，請您上傳 ASCII 編碼的 PEM 憑證",
+    "Valid until {date}" : "{date} 前有效",
+    "Delete" : "刪除",
+    "Local" : "本地",
+    "Private" : "私人的",
+    "Only visible to local users" : "僅本地用戶可見",
+    "Only visible to you" : "僅你可見",
+    "Contacts" : "聯絡人",
+    "Visible to local users and to trusted servers" : "僅本地用戶與信任的伺服器可見",
+    "Public" : "公開",
+    "Will be synced to a global and public address book" : "將會同步到全域公開的通訊錄",
+    "Verify" : "驗證",
+    "Verifying …" : "驗證中…",
+    "Unable to change password" : "無法修改密碼",
+    "Very weak password" : "密碼強度非常弱",
+    "Weak password" : "密碼強度弱",
+    "So-so password" : "密碼強度普通",
+    "Good password" : "密碼強度佳",
+    "Strong password" : "密碼強度極佳",
+    "Select a profile picture" : "選擇大頭貼照",
+    "Groups" : "群組",
     "{actor} removed you from group {group}" : "{actor} 將你從 {group} 群組中移除",
     "{actor} changed your password" : "{actor} 變更了您的密碼",
     "You changed your password" : "您已變更您的密碼",
@@ -15,9 +42,7 @@ OC.L10N.register(
     "Couldn't remove app." : "無法移除應用程式",
     "Couldn't update app." : "無法更新應用程式",
     "Wrong password" : "密碼錯誤",
-    "Saved" : "已儲存",
     "No user supplied" : "未提供使用者",
-    "Unable to change password" : "無法修改密碼",
     "Authentication error" : "認證錯誤",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "請提供一個admin管理者恢復密碼，否則將會失去所有使用者資料。",
     "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理者還原密碼",
@@ -56,33 +81,26 @@ OC.L10N.register(
     "Set your password" : "設定您的密碼",
     "Go to %s" : "前往 %s",
     "Install Client" : "安裝客戶端程式",
-    "Delete" : "刪除",
     "Unlimited" : "無限制",
-    "Verifying …" : "驗證中…",
-    "Verify" : "驗證",
-    "Migration in progress. Please wait until the migration is finished" : "資料搬移中，請耐心等候直到資料搬移結束",
-    "Migration started …" : "開始遷移…",
-    "Not saved" : "未儲存",
-    "Sending…" : "傳送中…",
-    "Email sent" : "Email 已寄出",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "發生錯誤，請您上傳 ASCII 編碼的 PEM 憑證",
-    "Valid until {date}" : "{date} 前有效",
-    "Local" : "本地",
-    "Private" : "私人的",
-    "Only visible to local users" : "僅本地用戶可見",
-    "Only visible to you" : "僅你可見",
-    "Contacts" : "聯絡人",
-    "Visible to local users and to trusted servers" : "僅本地用戶與信任的伺服器可見",
-    "Public" : "公開",
-    "Will be synced to a global and public address book" : "將會同步到全域公開的通訊錄",
-    "Very weak password" : "密碼強度非常弱",
-    "Weak password" : "密碼強度弱",
-    "So-so password" : "密碼強度普通",
-    "Good password" : "密碼強度佳",
-    "Strong password" : "密碼強度極佳",
-    "Select a profile picture" : "選擇大頭貼照",
-    "Groups" : "群組",
     "Limit to groups" : "限制給特定群組",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方應用程序是由社區內部和內部開發的。 它們提供核心功能，並可在正式成品使用。",
+    "Official" : "官方",
+    "Remove" : "移除",
+    "Disable" : "停用",
+    "All" : "所有",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最低的Nextcloud版本，未來將會產生問題。",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最高的Nextcloud版本，未來將會產生問題。",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "這個應用程式無法被安裝，因為欠缺下列相依套件：",
+    "View in store" : "在商店中檢視",
+    "Visit website" : "開啟網站",
+    "Report a bug" : "回報問題",
+    "User documentation" : "用戶說明文件",
+    "Admin documentation" : "管理者文件",
+    "Developer documentation" : "開發者說明文件",
+    "No apps found for your version" : "沒有找到適合您的版本的應用程式",
+    "Enable all" : "全部啟用",
+    "Enable" : "啟用",
+    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
     "Allow filesystem access" : "允許檔案系統的存取",
     "Revoke" : "撤銷",
     "Internet Explorer" : "Internet Explorer",
@@ -107,24 +125,6 @@ OC.L10N.register(
     "Done" : "完成",
     "Copied!" : "已複製",
     "Copy" : "複製",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方應用程序是由社區內部和內部開發的。 它們提供核心功能，並可在正式成品使用。",
-    "Official" : "官方",
-    "Remove" : "移除",
-    "Disable" : "停用",
-    "All" : "所有",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最低的Nextcloud版本，未來將會產生問題。",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未配置最高的Nextcloud版本，未來將會產生問題。",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "這個應用程式無法被安裝，因為欠缺下列相依套件：",
-    "View in store" : "在商店中檢視",
-    "Visit website" : "開啟網站",
-    "Report a bug" : "回報問題",
-    "User documentation" : "用戶說明文件",
-    "Admin documentation" : "管理者文件",
-    "Developer documentation" : "開發者說明文件",
-    "No apps found for your version" : "沒有找到適合您的版本的應用程式",
-    "Enable all" : "全部啟用",
-    "Enable" : "啟用",
-    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
     "New password" : "新密碼",
     "{size} used" : "{size} 已使用",
     "Email" : "信箱",
@@ -172,7 +172,6 @@ OC.L10N.register(
     "Credentials" : "帳密",
     "SMTP Username" : "SMTP 帳號",
     "SMTP Password" : "SMTP 密碼",
-    "Store credentials" : "儲存帳密",
     "Test email settings" : "測試郵件設定",
     "Send email" : "寄送郵件",
     "Security & setup warnings" : "安全及設定警告",
@@ -198,8 +197,6 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "背景工作從未執行！",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "為了獲得最佳的效能，設定背景工作非常重要，對於比較大的服務來說，建議使用 Cron 設定，請查閱說明文件以獲得更多資訊。",
     "Execute one task with each page loaded" : "每個頁面載入時執行",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php 已經在一個 webcron 服務中註冊，每 15 分鐘將會透過 HTTP 呼叫 cron.php",
-    "Use system cron service to call the cron.php file every 15 minutes." : "使用系統的 cron 服務來每隔 15 分鐘呼叫 cron.php",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統使用者 \"%s\" 來執行",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件，請查閱 {linkstart}PHP 說明文件{linkend} 以獲得更多細節。",
     "Sharing" : "分享",
@@ -252,6 +249,9 @@ OC.L10N.register(
     "Help translate" : "幫助翻譯",
     "Locale" : "所在地",
     "Current password" : "目前密碼",
-    "Change password" : "變更密碼"
+    "Change password" : "變更密碼",
+    "Store credentials" : "儲存帳密",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php 已經在一個 webcron 服務中註冊，每 15 分鐘將會透過 HTTP 呼叫 cron.php",
+    "Use system cron service to call the cron.php file every 15 minutes." : "使用系統的 cron 服務來每隔 15 分鐘呼叫 cron.php"
 },
 "nplurals=1; plural=0;");
